/*
 * Charset methods tests
 * Testing Charset methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

#include <locale.h>


/*
 * Name: g_convert
 * Params: const gchar *str, gssize len, const gchar *to_codeset, const gchar *from_codeset, gsize *bytes_read, gsize *bytes_written, GError **error
 * Returns: gchar*
 * Assertion: Converts a string from one character set to another.
 *            str : the string to convert
 *            len : the length of the string
 *            to_codeset : name of character set into which to convert str
 *            from_codeset : character set of str.
 *            bytes_read : location to store the number of bytes in the input string that were successfully converted, or NULL. Even if the conversion was successful, this may be less than len if there were partial characters at the end of the input. If the error G_CONVERT_ERROR_ILLEGAL_SEQUENCE occurs, the value stored will the byte offset after the last valid input sequence.
 *            bytes_written : the number of bytes stored in the output buffer (not including the terminating nul).
 *            error : location to store the error occuring, or NULL to ignore errors. Any of the errors in GConvertError may occur.
 *            Returns : If the conversion was successful, a newly allocated nul-terminated string, which must be freed with g_free(). Otherwise NULL and error will be set.
 * Params Values: to = "UTF-8", from = "GB2312"
 * Expected: 0xe4, 0xb8, 0xad, 0xe5, 0x9b, 0xbd  
 */
static void test_purpose_1()
{
    #define TOCODE    "UTF-8"
    #define FROMCODE  "GB2312"
    #define RETS      0xe4, 0xb8, 0xad, 0xe5, 0x9b, 0xbd
    #define RETS_BE   0xe4, 0xb8, 0xad, 0xe5, 0x9b, 0xbd
    #define FORMAT    "%c%c%c%c%c%c"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GString *gs, *rets;
    gchar *convert;
    GError *err = NULL;
    
    gs = g_string_sized_new(10);
    rets = g_string_sized_new(10);
    if (TOCODE == "UTF-16" && G_BYTE_ORDER == G_BIG_ENDIAN)
    	g_string_printf(rets, FORMAT, RETS_BE);
    else
    	g_string_printf(rets, FORMAT, RETS);
    g_string_printf(gs, "%c%c%c%c", 0xd6, 0xd0, 0xb9, 0xfa);
    convert = g_convert(gs->str, -1, TOCODE, FROMCODE, NULL, NULL, &err);
    if (NULL == convert || strcmp(convert, rets->str) != 0){
        TEST_FAIL("g_convert: failed", NULL);
    }
    g_string_free(gs, TRUE);
    g_string_free(rets, TRUE);
    g_free(convert);
    #undef TOCODE
    #undef FROMCODE
    #undef RETS
    #undef RETS_BE
    #undef FORMAT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_convert
 * Params: const gchar *str, gssize len, const gchar *to_codeset, const gchar *from_codeset, gsize *bytes_read, gsize *bytes_written, GError **error
 * Returns: gchar*
 * Assertion: Converts a string from one character set to another.
 *            str : the string to convert
 *            len : the length of the string
 *            to_codeset : name of character set into which to convert str
 *            from_codeset : character set of str.
 *            bytes_read : location to store the number of bytes in the input string that were successfully converted, or NULL. Even if the conversion was successful, this may be less than len if there were partial characters at the end of the input. If the error G_CONVERT_ERROR_ILLEGAL_SEQUENCE occurs, the value stored will the byte offset after the last valid input sequence.
 *            bytes_written : the number of bytes stored in the output buffer (not including the terminating nul).
 *            error : location to store the error occuring, or NULL to ignore errors. Any of the errors in GConvertError may occur.
 *            Returns : If the conversion was successful, a newly allocated nul-terminated string, which must be freed with g_free(). Otherwise NULL and error will be set.
 * Params Values: to = "UTF-16", from = "GB2312"
 * Expected: 0xff, 0xfe, 0x2d, 0x4e, 0xfd, 0x56  
 */
static void test_purpose_2()
{
    #define TOCODE    "UTF-16"
    #define FROMCODE  "GB2312"
    #define RETS      0xff, 0xfe, 0x2d, 0x4e, 0xfd, 0x56
    #define RETS_BE   0xfe, 0xff, 0x4e, 0x2d, 0x56, 0xfd
    #define FORMAT    "%c%c%c%c%c%c"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GString *gs, *rets;
    gchar *convert;
    GError *err = NULL;
    
    gs = g_string_sized_new(10);
    rets = g_string_sized_new(10);
    if (TOCODE == "UTF-16" && G_BYTE_ORDER == G_BIG_ENDIAN)
    	g_string_printf(rets, FORMAT, RETS_BE);
    else
    	g_string_printf(rets, FORMAT, RETS);
    g_string_printf(gs, "%c%c%c%c", 0xd6, 0xd0, 0xb9, 0xfa);
    convert = g_convert(gs->str, -1, TOCODE, FROMCODE, NULL, NULL, &err);
    if (NULL == convert || strcmp(convert, rets->str) != 0){
        TEST_FAIL("g_convert: failed", NULL);
    }
    g_string_free(gs, TRUE);
    g_string_free(rets, TRUE);
    g_free(convert);
    #undef TOCODE
    #undef FROMCODE
    #undef RETS
    #undef RETS_BE
    #undef FORMAT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_iconv_open
 * Params: const gchar *to_codeset, const gchar *from_codeset
 * Returns: GIConv
 * Assertion: Same as the standard UNIX routine iconv_open(), but may be implemented via libiconv on UNIX flavors that lack a native implementation.
 * GLib provides g_convert() and g_locale_to_utf8() which are likely more convenient than the raw iconv wrappers.
 *            to_codeset : destination codeset
 *            from_codeset : source codeset
 *            Returns : a "conversion descriptor", or (GIConv)-1 if opening the converter failed.
 * Params Values: TO "UTF-8", FROM "GB2312"
 * Expected: GIConv
 * 
 * Name: g_iconv_close
 * Params: GIConv converter
 * Returns: gint
 * Assertion: Same as the standard UNIX routine iconv_close(), but may be implemented via libiconv on UNIX flavors that lack a native implementation. Should be called to clean up the conversion descriptor from g_iconv_open() when you are done converting things.
 * GLib provides g_convert() and g_locale_to_utf8() which are likely more convenient than the raw iconv wrappers.
 *            converter : a conversion descriptor from g_iconv_open()
 *            Returns : -1 on error, 0 on success
 * Params Values: GIConv converter
 * Expected: 0  
 */
static void test_purpose_3()
{
    #define TO      "UTF-8"
    #define FROM    "GB2312"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GIConv converter = g_iconv_open(TO, FROM);
    if (converter == (GIConv)-1){
        TEST_FAIL("g_iconv_open: failed", NULL);
    }
    else{
        gint reti = g_iconv_close(converter);
        if (reti == -1){
            TEST_FAIL("g_iconv_close: failed", NULL);
        }
    }
    #undef TO
    #undef FROM
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for Charset ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {NULL,0}
};
