/*
 * DoubleQueues methods tests
 * Testing DoubleQueues methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: g_queue_new
 * Params: void
 * Returns: GQueue*
 * Assertion: Creates a new GQueue.
 *            Returns : a new GQueue.
 * Params Values: void
 * Expected: GQueue*  
 */
static void test_purpose_1()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GQueue *gq = g_queue_new();
    if (gq == NULL){
        TEST_FAIL("g_queue_new: new failed", NULL);
    }
    g_queue_free(gq);
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_queue_push_head
 * Params: GQueue *queue, gpointer data
 * Returns: void
 * Assertion: Adds a new element at the head of the queue.
 *            queue : a GQueue.
 *            data : the data for the new element. 
 * Params Values: 5
 * Expected: void  
 */
static void test_purpose_2()
{
    #define DATA 5
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GQueue *gq = g_queue_new();
    if (gq == NULL){
        TEST_FAIL("g_queue_push_head: new failed", NULL);
        return;
    }
    g_queue_push_head(gq, GINT_TO_POINTER(DATA));
    if ((gq->length != 1) || GPOINTER_TO_INT(gq->head->data) != DATA){
        TEST_FAIL("g_queue_push_head: push error", NULL);
    }
    g_queue_free(gq);
    
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_queue_push_tail
 * Params: GQueue *queue, gpointer data
 * Returns: void
 * Assertion: Adds a new element at the tail of the queue.
 *            queue : a GQueue.
 *            data : the data for the new element. 
 * Params Values: 5
 * Expected: void  
 */
static void test_purpose_3()
{
    #define DATA    5
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GQueue *gq = g_queue_new();
    if (gq == NULL){
         TEST_FAIL("g_queue_push_tail: new failed", NULL);
         return;
    }
    g_queue_push_head(gq, GINT_TO_POINTER(1));
    g_queue_push_tail(gq, GINT_TO_POINTER(DATA));
    if ((gq->length != 2) || GPOINTER_TO_INT(gq->tail->data) != DATA){
        TEST_FAIL("g_queue_push_tail: push error", NULL);
    }
    g_queue_free(gq);
    
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_queue_pop_head
 * Params: GQueue *queue
 * Returns: gpointer
 * Assertion: Removes the first element of the queue. 
 *            queue : a GQueue.
 *            Returns : the data of the first element in the queue, or NULL if the queue is empty.
 * Params Values: GQueue *
 * Expected: void  
 */
static void test_purpose_4()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GQueue *gq = g_queue_new();
    if (g_queue_is_empty(gq)){
        gpointer* pdata = g_queue_pop_head(gq);
        if (pdata != NULL){
            TEST_FAIL("g_queue_pop_head: gq = NULL, pdata should be NULL", NULL);
        }
    }
    g_queue_push_head(gq, GINT_TO_POINTER(1));
    g_queue_push_head(gq, GINT_TO_POINTER(2));
    {
        gpointer *pdata = g_queue_pop_head(gq);
        if (GPOINTER_TO_INT(pdata) != 2){
            TEST_FAIL("g_queue_pop_head: data error", NULL);
        }
    }
    g_queue_free(gq);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_queue_is_empty
 * Params: GQueue *queue
 * Returns: gboolean
 * Assertion: Returns TRUE if the queue is empty.
 *            queue : a GQueue.
 *            Returns : TRUE if the queue is empty. 
 * Params Values: GQueue *
 * Expected: gboolean  
 */
static void test_purpose_5()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GQueue *gq = g_queue_new();
    if (!g_queue_is_empty(gq)){
        TEST_FAIL("g_queue_is_empty: should be FALSE", NULL);
    }
    g_queue_push_head(gq, GINT_TO_POINTER(5));
    if (g_queue_is_empty(gq)){
        TEST_FAIL("g_queue_is_empty: should be TRUE", NULL);
    }
    g_queue_free(gq);
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for DoubleQueues ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {NULL,0}
};
