/*
 * GObject-Signals methods tests
 * Testing GObject-Signals methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
static gint flag = -1;

enum {TEST_SIG1, TEST_SIG2, TEST_SIG3, LAST_SIGNAL}; 
enum {TEST_SIG1_HANDLER, TEST_SIG2_HANDLER, TEST_SIG3_HANDLER};

static void test_sig1_handler(void)
{
    flag = TEST_SIG1_HANDLER;
}

static void test_sig2_handler(void)
{
    flag = TEST_SIG2_HANDLER;
}

static void test_sig3_handler(void)
{
    flag = TEST_SIG3_HANDLER;
}


#define TEST_TYPE   (test_get_type())
#define TEST(obj)   (G_TYPE_CHECK_INSTANCE_CAST((obj), TEST_TYPE, Test))

typedef struct _Test        Test;
typedef struct _TestClass   TestClass;

struct _Test {
    GObject parent;
};

struct _TestClass {
    GObjectClass parent_class;

    void (*test_sig1)(void);
    void (*test_sig2)(void);
    void (*test_sig3)(void);
};

static void test_init(Test* test)
{
}

static void test_class_init(TestClass* testclass)
{
    testclass->test_sig1 = test_sig1_handler;
    testclass->test_sig2 = test_sig2_handler;
    testclass->test_sig3 = test_sig3_handler;

}

GType test_get_type(void)
{
    static GType test_type = 0;
    if (!test_type){
        static const GTypeInfo test_info = {
            sizeof(TestClass),
            NULL, NULL,
            (GClassInitFunc)test_class_init,
            NULL, NULL,
            sizeof(Test),
            0,
            (GInstanceInitFunc)test_init
        };
        test_type = g_type_register_static(G_TYPE_OBJECT, "Test", &test_info, 0);
    }
    return test_type;
}

Test* test_new(void)
{
    Test* test = g_object_new(TEST_TYPE, NULL);
    
    return test;
}



/*
 * Name: g_signal_new
 * Params: const gchar *signal_name, GType itype, GSignalFlags signal_flags, guint class_offset,  GSignalAccumulator accumulator, gpointer accu_data, GSignalCMarshaller c_marshaller, GType return_type, guint n_params, ...
 * Returns: guint
 * Assertion: Creates a new signal. (This is usually done in the class initializer.)
 *            A signal name consists of segments consisting of ASCII letters and digits, separated by either the '-' or '_' character. The first character of a signal name must be a letter. Names which violate these rules lead to undefined behaviour of the GSignal system.
 *            When registering a signal and looking up a signal, either separator can be used, but they cannot be mixed.
 *            signal_name :    the name for the signal
 *            itype :  the type this signal pertains to. It will also pertain to types which are derived from this type.
 *            signal_flags :   a combination of GSignalFlags specifying detail of when the default handler is to be invoked. You should at least specify G_SIGNAL_RUN_FIRST or G_SIGNAL_RUN_LAST.
 *            class_offset :   The offset of the function pointer in the class structure for this type. Used to invoke a class method generically.
 *            accumulator :    the accumulator for this signal; may be NULL.
 *            accu_data :  user data for the accumulator.
 *            c_marshaller :   the function to translate arrays of parameter values to signal emissions into C language callback invocations.
 *            return_type :    the type of return value, or G_TYPE_NONE for a signal without a return value.
 * n_params :  the number of parameter types to follow.
 *            ... :    a list of types, one for each parameter.
 *            Returns :    the signal id
 * 
 * Name: g_signal_emit
 * Params: gpointer instance, guint signal_id, GQuark detail, ...
 * Returns: void
 * Assertion: Emits a signal.
 * Note that g_signal_emit() resets the return value to the default if no handlers are connected, in contrast to g_signal_emitv().
 *            instance :   the instance the signal is being emitted on.
 *            signal_id : the signal id
 *            detail :    the detail
 *            ... :   parameters to be passed to the signal, followed by a location for the return value. If the return type of the signal is G_TYPE_NONE, the return value location can be omitted.
 * 
 * Params Values: "Test_Sig1", G_SIGNAL_RUN_FIRST, NULL, NULL
 * Expected: TEST_SIG1_HANDLER              
 */
static void test_purpose_1()
{
    #define SIG_NAME    "Test_Sig1"
    #define SIG_FLAG    G_SIGNAL_RUN_FIRST
    #define SIG_ACC     NULL
    #define ACC_DATA    NULL
    #define EXP_RES     TEST_SIG1_HANDLER            
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint test_signals[LAST_SIGNAL] = { 0 };
    
    Test *test = NULL;
    g_type_init();
    
    test = test_new();
    test_signals[TEST_SIG1] = g_signal_new(SIG_NAME, TEST_TYPE, SIG_FLAG, G_STRUCT_OFFSET(TestClass, test_sig1),
                                           SIG_ACC, ACC_DATA, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0, NULL);             
    g_signal_emit(test, test_signals[TEST_SIG1], 0);
    if (flag != EXP_RES){
        TEST_FAIL("g_signal_new: failed", NULL);
    }
    flag = -1;
    
    #undef SIG_NAME
    #undef SIG_FLAG
    #undef SIG_ACC
    #undef ACC_DATA
    #undef EXP_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_signal_new
 * Params: const gchar *signal_name, GType itype, GSignalFlags signal_flags, guint class_offset,  GSignalAccumulator accumulator, gpointer accu_data, GSignalCMarshaller c_marshaller, GType return_type, guint n_params, ...
 * Returns: guint
 * Assertion: Creates a new signal. (This is usually done in the class initializer.)
 *            A signal name consists of segments consisting of ASCII letters and digits, separated by either the '-' or '_' character. The first character of a signal name must be a letter. Names which violate these rules lead to undefined behaviour of the GSignal system.
 *            When registering a signal and looking up a signal, either separator can be used, but they cannot be mixed.
 *            signal_name :    the name for the signal
 *            itype :  the type this signal pertains to. It will also pertain to types which are derived from this type.
 *            signal_flags :   a combination of GSignalFlags specifying detail of when the default handler is to be invoked. You should at least specify G_SIGNAL_RUN_FIRST or G_SIGNAL_RUN_LAST.
 *            class_offset :   The offset of the function pointer in the class structure for this type. Used to invoke a class method generically.
 *            accumulator :    the accumulator for this signal; may be NULL.
 *            accu_data :  user data for the accumulator.
 *            c_marshaller :   the function to translate arrays of parameter values to signal emissions into C language callback invocations.
 *            return_type :    the type of return value, or G_TYPE_NONE for a signal without a return value.
 * n_params :  the number of parameter types to follow.
 *            ... :    a list of types, one for each parameter.
 *            Returns :    the signal id
 * 
 * Name: g_signal_emit
 * Params: gpointer instance, guint signal_id, GQuark detail, ...
 * Returns: void
 * Assertion: Emits a signal.
 * Note that g_signal_emit() resets the return value to the default if no handlers are connected, in contrast to g_signal_emitv().
 *            instance :   the instance the signal is being emitted on.
 *            signal_id : the signal id
 *            detail :    the detail
 *            ... :   parameters to be passed to the signal, followed by a location for the return value. If the return type of the signal is G_TYPE_NONE, the return value location can be omitted.
 * 
 * Params Values: "Test_Sig2", G_SIGNAL_RUN_LAST, NULL, NULL
 * Expected: TEST_SIG1_HANDLER              
 */
static void test_purpose_2()
{
    #define SIG_NAME    "Test_Sig2"
    #define SIG_FLAG    G_SIGNAL_RUN_LAST
    #define SIG_ACC     NULL
    #define ACC_DATA    NULL
    #define EXP_RES     TEST_SIG1_HANDLER            
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint test_signals[LAST_SIGNAL] = { 0 };
    
    Test *test = NULL;
    g_type_init();
    
    test = test_new();
    test_signals[TEST_SIG1] = g_signal_new(SIG_NAME, TEST_TYPE, SIG_FLAG, G_STRUCT_OFFSET(TestClass, test_sig1),
                                           SIG_ACC, ACC_DATA, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0, NULL);             
    g_signal_emit(test, test_signals[TEST_SIG1], 0);
    if (flag != EXP_RES){
        TEST_FAIL("g_signal_new: failed", NULL);
    }
    flag = -1;
    
    #undef SIG_NAME
    #undef SIG_FLAG
    #undef SIG_ACC
    #undef ACC_DATA
    #undef EXP_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_signal_emit_by_name 
 * Params: gpointer instance, const gchar *detailed_signal, ...
 * Returns: void
 * Assertion: Emits a signal.
 * Note that g_signal_emit_by_name() resets the return value to the default if no handlers are connected, in contrast to g_signal_emitv().
 *            instance :   the instance the signal is being emitted on.
 *            detailed_signal :   a string of the form "signal-name::detail".
 *            ... :   parameters to be passed to the signal, followed by a location for the return value. If the return type of the signal is G_TYPE_NONE, the return value location can be omitted.
 * Params Values: "Test_Emit_Name"
 * Expected: TEST_SIG1_HANDLER              
 */
static void test_purpose_3()
{
    #define SIG_NAME    "Test_Emit_Name"
    #define EXP_RES     TEST_SIG1_HANDLER            
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint test_signals[LAST_SIGNAL] = { 0 };
    
    Test *test = NULL;
    g_type_init();
    
    test = test_new();
    test_signals[TEST_SIG1] = g_signal_new(SIG_NAME, TEST_TYPE, G_SIGNAL_RUN_FIRST, G_STRUCT_OFFSET(TestClass, test_sig1),
                                           NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0, NULL);              
    g_signal_emit_by_name(test, SIG_NAME);
    if (flag != EXP_RES){
        TEST_FAIL("g_signal_emit_by_name: failed", NULL);
    }
    flag = -1;
    
    #undef SIG_NAME
    #undef EXP_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_signal_connect_object 
 * Params: gpointer instance, const gchar *detailed_signal, GCallback c_handler, gpointer gobject, GConnectFlags connect_flags
 * Returns: gulong
 * Assertion:  This is similar to g_signal_connect_data(), but uses a closure which ensures that the gobject stays alive during the call to c_handler  by temporarily adding a reference count to gobject.
 *             It's possible to work around this problem in a way that will continue to work with future versions of GObject by checking that the signal handler is still connected before disconnected it.
 *             instance :  the instance to connect to.
 *             detailed_signal :   a string of the form "signal-name::detail".
 *             c_handler : the GCallback to connect.
 *             gobject :   the object to pass as data to c_handler.
 *             connect_flags : a combination of GConnnectFlags.
 *             Returns :   the handler id.
 * Params Values: G_CONNECT_AFTER
 * Expected: TEST_SIG2_HANDLER  
 */
static void test_purpose_4()
{
    #define CONN_FLAG   G_CONNECT_AFTER
    #define EXP_RES     TEST_SIG2_HANDLER
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint test_signals[LAST_SIGNAL] = { 0 };
    
    Test *test = NULL;
    g_type_init();
    
    test = test_new();
    test_signals[TEST_SIG2] = g_signal_new("Test_Sig2_Handler", TEST_TYPE, G_SIGNAL_RUN_FIRST, G_STRUCT_OFFSET(TestClass, test_sig1),
                                           NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0, NULL);              
    g_signal_connect_object(TEST(test), "Test_Sig2_Handler", G_CALLBACK(test_sig2_handler), NULL, CONN_FLAG);
    g_signal_emit(test, test_signals[TEST_SIG2], 0);
    if (flag != EXP_RES){
        TEST_FAIL("g_signal_connect_object: failed", NULL);
    }
    flag = -1;
    
    #undef CONN_FLAG
    #undef EXP_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_signal_lookup
 * Params: const gchar *name, GType itype
 * Returns: guint
 * Assertion: Given the name of the signal and the type of object it connects to, gets the signal's identifying integer. Emitting the signal by number is somewhat faster than using the name each time.
 *            Also tries the ancestors of the given type.
 *            name :   the signal's name.
 *            itype : the type that the signal operates on.
 *            Returns :   the signal's identifying number, or 0 if no signal was found.
 * Params Values: "Test_Sig2_Handler"
 * Expected: 1  
 */
static void test_purpose_5()
{
    #define SIG_NAME    "Test_Sig2_Handler"
    #define EXP_RET     1
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    guint ret;
    Test *test = NULL;
    g_type_init();
    
    test = test_new();
    
    ret = g_signal_lookup(SIG_NAME, TEST_TYPE);
    if (EXP_RET == 0){
        if (ret != 0){
            TEST_FAIL("g_signal_lookup: failed, should be 0", NULL);
        }
    }
    else{
        if (ret == 0){
            TEST_FAIL("g_signal_lookup: failed, should not be 0", NULL);
        }
    }
    
    #undef SIG_NAME
    #undef EXP_RET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_signal_lookup
 * Params: const gchar *name, GType itype
 * Returns: guint
 * Assertion: Given the name of the signal and the type of object it connects to, gets the signal's identifying integer. Emitting the signal by number is somewhat faster than using the name each time.
 *            Also tries the ancestors of the given type.
 *            name :   the signal's name.
 *            itype : the type that the signal operates on.
 *            Returns :   the signal's identifying number, or 0 if no signal was found.
 * Params Values: "No_Sig"
 * Expected: 0  
 */
static void test_purpose_6()
{
    #define SIG_NAME    "No_Sig"
    #define EXP_RET     0
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    guint ret;
    Test *test = NULL;
    g_type_init();
    
    test = test_new();
    
    ret = g_signal_lookup(SIG_NAME, TEST_TYPE);
    if (EXP_RET == 0){
        if (ret != 0){
            TEST_FAIL("g_signal_lookup: failed, should be 0", NULL);
        }
    }
    else{
        if (ret == 0){
            TEST_FAIL("g_signal_lookup: failed, should not be 0", NULL);
        }
    }
    
    #undef SIG_NAME
    #undef EXP_RET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_signal_handler_block
 * Params: gpointer instance, gulong handler_id
 * Returns: void
 * Assertion: Blocks a handler of an instance so it will not be called during any signal emissions unless it is unblocked again. Thus "blocking" a signal handler means to temporarily deactive it, a signal handler has to be unblocked exactly the same amount of times it has been blocked before to become active again.
 * The handler_id has to be a valid signal handler id, connected to a signal of instance.
 * Params Values: gpointer instance, gulong handler_id
 * Expected: void
 * 
 * Name: g_signal_handler_unblock
 * Params: gpointer instance, gulong handler_id
 * Returns: void
 * Assertion: Undoes the effect of a previous g_signal_handler_block() call. A blocked handler is skipped during signal emissions and will not be invoked, unblocking it (for exactly the amount of times it has been blocked before) reverts its "blocked" state, so the handler will be recognized by the signal system and is called upon future or currently ongoing signal emissions (since the order in which handlers are called during signal emissions is deterministic, whether the unblocked handler in question is called as part of a currently ongoing emission depends on how far that emission has proceeded yet).
 * The handler_id has to be a valid id of a signal handler that is connected to a signal of instance and is currently blocked.
 *            instance :   The instance to unblock the signal handler of.
 *            handler_id :    Handler id of the handler to be unblocked.
 * Params Values: gpointer instance, gulong handler_id
 * Expected: void  
 */
static void test_purpose_7()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gulong handler_id;
    gint test_signals[LAST_SIGNAL] = { 0 };
    if (flag != -1){
        flag = -1;
    }
    Test *test = NULL;
    g_type_init();
    
    test = test_new();
    test_signals[TEST_SIG3] = g_signal_new("Test_Sig3_Handler", TEST_TYPE, G_SIGNAL_RUN_FIRST, G_STRUCT_OFFSET(TestClass, test_sig1), NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0, NULL);
    handler_id = g_signal_connect_object(TEST(test), "Test_Sig3_Handler", G_CALLBACK(test_sig3_handler), NULL, G_CONNECT_AFTER);
    g_signal_handler_block(TEST(test), handler_id);
    g_signal_emit(test, test_signals[TEST_SIG3], 0);
    if (flag != TEST_SIG1_HANDLER){
        TEST_FAIL("g_signal_handler_block: failed flag = %d", flag);
    }
    g_signal_handler_unblock(TEST(test), handler_id);
    g_signal_emit(test, test_signals[TEST_SIG3], 0);
    if (flag != TEST_SIG3_HANDLER){
        TEST_FAIL("g_signal_handler_unblock: failed flag = %d", flag);
    }
    flag = -1;
    
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GObject-Signals ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {NULL,0}
};
