/*
 * GStrings methods tests
 * Testing GStrings methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: g_string_new 
 * Params: const gchar *init
 * Returns: GString*
 * Assertion: Creates a new GString, initialized with the given string.
 *            init : the initial text to copy into the string.
 *            Returns : the new GString.
 * Params Values: "Hello, LSB"
 * Expected: 10  
 */
static void test_purpose_1()
{
    #define INIT_STR    "Hello, LSB"
    #define STR_LEN     10
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GString *str = g_string_new(INIT_STR);
    if (strcmp(str->str, INIT_STR) != 0){
        TEST_FAIL("g_string_new: should be %s", INIT_STR);
    }
    else{
        if (str->len != STR_LEN){
            TEST_FAIL("g_string_new: should be %d", STR_LEN);
        }
    }
    g_string_free(str, TRUE);
    
    #undef INIT_STR
    #undef STR_LEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_string_free
 * Params: GString *string, gboolean free_segment
 * Returns: gchar*
 * Assertion: Frees the memory allocated for the GString. If free_segment is TRUE it also frees the character data.
 *            string : a GString.
 *            free_segment : if TRUE the actual character data is freed as well.
 *            Returns : the character data of string (i.e. NULL if free_segment is TRUE) 
 * Params Values: "Hello, LSB", TRUE
 * Expected: NULL  
 */
static void test_purpose_2()
{
    #define STRS       "Hello, LSB"
    #define SEGMENT    TRUE
    #define RETS       NULL
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GString *gs = g_string_new(STRS);
    if (SEGMENT){
        if(g_string_free(gs, SEGMENT) != NULL){
            TEST_FAIL("g_string_free: free failed", NULL);
        }
    }
    else if (strcmp(g_string_free(gs, SEGMENT), RETS) != 0){
        TEST_FAIL("g_string_free: free failed", NULL);
    }
    
    #undef STRS
    #undef SEGMENT
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_string_free
 * Params: GString *string, gboolean free_segment
 * Returns: gchar*
 * Assertion: Frees the memory allocated for the GString. If free_segment is TRUE it also frees the character data.
 *            string : a GString.
 *            free_segment : if TRUE the actual character data is freed as well.
 *            Returns : the character data of string (i.e. NULL if free_segment is TRUE) 
 * Params Values: "Hello, LSB", FALSE
 * Expected: "Hello, LSB"  
 */
static void test_purpose_3()
{
    #define STRS       "Hello, LSB"
    #define SEGMENT    FALSE
    #define RETS       "Hello, LSB"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GString *gs = g_string_new(STRS);
    if (SEGMENT){
        if(g_string_free(gs, SEGMENT) != NULL){
            TEST_FAIL("g_string_free: free failed", NULL);
        }
    }
    else if (strcmp(g_string_free(gs, SEGMENT), RETS) != 0){
        TEST_FAIL("g_string_free: free failed", NULL);
    }
    
    #undef STRS
    #undef SEGMENT
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_string_append
 * Params: GString *string, const gchar *val
 * Returns: GString*
 * Assertion: Adds a string onto the end of a GString, expanding it if necessary.
 *            string : a GString.
 *            val : the string to append onto the end of the GString.
 *            Returns : the GString. 
 * Params Values: " Glib Test"
 * Expected: "Hello, LSB Glib Test", 20  
 */
static void test_purpose_4()
{
    #define APP_VALS    " Glib Test"
    #define ACTUALS     "Hello, LSB Glib Test"
    #define ACTUAL_LEN  20
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GString *gs = g_string_new("Hello, LSB");
    gs = g_string_append(gs, APP_VALS);
    if ((strcmp(gs->str, ACTUALS) != 0) || (gs->len != ACTUAL_LEN)){
        TEST_FAIL("g_string_append: failed", NULL);
    }
    g_string_free(gs, TRUE);
    
    #undef APP_VALS
    #undef ACTUALS
    #undef ACTUAL_LEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_string_insert_c
 * Params: GString *string, gssize pos, gchar c
 * Returns: GString*
 * Assertion: Inserts a character into a GString, expanding it if necessary.
 *            string : a GString.
 *            pos : the position to insert the character.
 *            c : the character to insert.
 *            Returns : the GString. 
 * Params Values: 1, 'e'
 * Expected: "Hello, LSB"  
 */
static void test_purpose_5()
{
    #define POS    1
    #define CHAR   'e'
    #define RETS   "Hello, LSB"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GString *gs = g_string_new("Hllo, LSB");
    gsize len = gs->len;
    gs = g_string_insert_c(gs, POS, CHAR);
    if ((strcmp(gs->str, RETS) != 0) || (gs->len != (len + 1))){
        TEST_FAIL("g_string_insert_c: failed", NULL);
    }
    g_string_free(gs, TRUE);
    
    #undef POS
    #undef CHAR
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_string_append_printf
 * Params: GString *string, const gchar *format, ...
 * Returns: void
 * Assertion: Appends a formatted string onto the end of a GString. This function is is similar to g_string_printf() except that the text is appended to the GString.
 *            string : a GString.
 *            format : the string format. See the printf() documentation.
 *            ... : the parameters to insert into the format string. 
 * Params Values: "%s%d", "LSB", 4
 * Expected: "Hello, LSB4"  
 */
static void test_purpose_6()
{
    #define FORMAT    "%s%d"
    #define VAL1      "LSB"
    #define VAL2      4
    #define RETS      "Hello, LSB4"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GString *gs = g_string_new("Hello, ");
    g_string_append_printf(gs, FORMAT, VAL1, VAL2);
    if (strcmp(gs->str, RETS) != 0){
        TEST_FAIL("g_string_append_printf: failed", NULL);
    }
    g_string_free(gs, TRUE);
    
    #undef FORMAT
    #undef VAL1
    #undef VAL2
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_string_printf
 * Params: GString *string, const gchar *format, ...
 * Returns: void
 * Assertion: Writes a formatted string into a GString. This is similar to the standard sprintf() function, except that the GString buffer automatically expands to contain the results. The previous contents of the GString are destroyed. 
 *            string : a GString.
 *            format : the string format. See the printf() documentation.
 *            ... : the parameters to insert into the format string. 
 * Params Values: "%s%d", "Destroyed", 100
 * Expected: "Destroyed100"  
 */
static void test_purpose_7()
{
    #define FORMAT    "%s%d"
    #define VAL1      "Destroyed"
    #define VAL2      100
    #define RETS      "Destroyed100"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GString *gs = g_string_new("Hello, LSB");
    g_string_printf(gs, FORMAT, VAL1, VAL2);
    if (strcmp(gs->str, RETS) != 0){
        TEST_FAIL("g_string_printf: failed", NULL);
    }
    g_string_free(gs, TRUE);
    
    #undef FORMAT
    #undef VAL1
    #undef VAL2
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_string_hash
 * Params: GString *string
 * Returns: guint
 * Assertion: Creates a hash code for str; for use with GHashTable.
 *            str : a string to hash.
 *            Returns : hash code for str. 
 * Params Values: "Hello, LSB"
 * Expected: 397227061  
 */
static void test_purpose_8()
{
    #define STR    "Hello, LSB"
    #define HASH   397227061
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GString *gs = g_string_new(STR);
    if (g_string_hash(gs) != HASH){
        TEST_FAIL("g_string_hash: failed", NULL);
    }
    
    g_string_free(gs, TRUE);
    
    #undef STR
    #undef HASH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_string_append_c
 * Params: GString *string, gchar c
 * Returns: GString*
 * Assertion: Adds a character onto the end of a GString, expanding it if necessary.
 *            string : a GString.
 *            c : the character to append onto the end of the GString.
 *            Returns : the GString. 
 * Params Values: 'B'
 * Expected: "Hello, LSB"  
 */
static void test_purpose_9()
{
    #define CHAR    'B'
    #define RETS    "Hello, LSB"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GString *gs = g_string_new("Hello, LS");
    gs = g_string_append_c(gs, CHAR);
    if (strcmp(gs->str, RETS) != 0){
        TEST_FAIL("g_string_append_c: failed", NULL);
    }
    g_string_free(gs, TRUE);
    
    #undef CHAR
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_string_append_len
 * Params: GString *string, const gchar *val, gssize len
 * Returns: GString*
 * Assertion: Appends len bytes of val to string. Because len is provided, val may contain embedded nuls and need not be nul-terminated.
 *            string : a GString.
 *            val : bytes to append.
 *            len : number of bytes of val to use.
 *            Returns : the GString. 
 * Params Values: "LSB 4.0", 3
 * Expected: "Hello, LSB"  
 */
static void test_purpose_10()
{
    #define VAL    "LSB 4.0"
    #define LEN    3
    #define RETS   "Hello, LSB"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GString *gs = g_string_new("Hello, ");
    gs = g_string_append_len(gs, VAL, LEN);
    if (strcmp(gs->str, RETS) != 0){
        TEST_FAIL("g_string_append_len: failed", NULL);
    }
    g_string_free(gs, TRUE);
    
    #undef VAL
    #undef LEN
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_string_truncate
 * Params: GString *string, gsize len
 * Returns: GString*
 * Assertion: Cuts off the end of the GString, leaving the first len characters.
 *            string : a GString.
 *            len : the new size of the GString.
 *            Returns : the GString. 
 * Params Values: 5
 * Expected: "Hello"  
 */
static void test_purpose_11()
{
    #define LEN    5
    #define RETS   "Hello"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GString *gs = g_string_new("Hello, LSB");
    gs = g_string_truncate(gs, LEN);
    if (strcmp(gs->str, RETS) != 0){
        TEST_FAIL("g_string_truncate: failed", NULL);
    }
    g_string_free(gs, TRUE);
    
    #undef LEN
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_string_sized_new
 * Params: gsize dfl_size
 * Returns: GString*
 * Assertion: Creates a new GString, with enough space for dfl_size characters. This is useful if you are going to add a lot of text to the string and don't want it to be reallocated too often.
 *            dfl_size : the default size of the space allocated to hold the string.
 *            Returns : the new GString. 
 * Params Values: 10
 * Expected: 16  
 */
static void test_purpose_12()
{
    #define DFL        10
    #define ALLOC_LEN  16
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GString *gs = g_string_sized_new(DFL);
    if (gs->allocated_len != ALLOC_LEN){
        TEST_FAIL("g_string_sized_new: failed", NULL);
    }
    g_string_free(gs, TRUE);
    
    #undef DFL
    #undef ALLOC_LEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_string_sized_new
 * Params: gsize dfl_size
 * Returns: GString*
 * Assertion: Creates a new GString, with enough space for dfl_size characters. This is useful if you are going to add a lot of text to the string and don't want it to be reallocated too often.
 *            dfl_size : the default size of the space allocated to hold the string.
 *            Returns : the new GString. 
 * Params Values: 1024
 * Expected: 2048  
 */
static void test_purpose_13()
{
    #define DFL        1024
    #define ALLOC_LEN  2048
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GString *gs = g_string_sized_new(DFL);
    if (gs->allocated_len != ALLOC_LEN){
        TEST_FAIL("g_string_sized_new: failed", NULL);
    }
    g_string_free(gs, TRUE);
    
    #undef DFL
    #undef ALLOC_LEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_string_assign
 * Params: GString *string, const gchar *rval
 * Returns: GString*
 * Assertion: Copies the characters from a string into a GString, destroying any previous contents. It is rather like the standard strcpy() function, except that you do not have to worry about having enough space to copy the string.
 *            string : the destination GString. Its current contents are destroyed.
 *            rval :
 *            Returns : the destination GString. 
 * Params Values: "Destroyed"
 * Expected: "Destroyed"  
 */
static void test_purpose_14()
{
    #define STRS    "Destroyed"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GString *gs = g_string_new("Hello, LSB");
    gs = g_string_assign(gs, STRS);
    if (strcmp(gs->str, STRS) != 0){
        TEST_FAIL("g_string_assign: failed", NULL);
    }
    g_string_free(gs, TRUE);
    
    #undef STRS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_string_prepend
 * Params: GString *string, const gchar *rval
 * Returns: GString*
 * Assertion: Adds a string on to the start of a GString, expanding it if necessary.
 *            string : a GString.
 *            val : the string to prepend on the start of the GString.
 *            Returns : the GString. 
 * Params Values: "Hello, "
 * Expected: "Hello, LSB"  
 */
static void test_purpose_15()
{
    #define RVAL    "Hello, "
    #define STRS    "Hello, LSB"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GString *gs = g_string_new("LSB");
    gs = g_string_prepend(gs, RVAL);
    if (strcmp(gs->str, STRS) != 0){
        TEST_FAIL("g_string_prepend: failed", NULL);
    }
    g_string_free(gs, TRUE);
    
    #undef RVAL
    #undef STRS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_string_erase
 * Params: GString *string, gssize pos, gssize len
 * Returns: GString*
 * Assertion: Removes len characters from a GString, starting at position pos. The rest of the GString is shifted down to fill the gap.
 *            string : a GString.
 *            pos : the position of the characters to remove.
 *            len : the number of characters to remove, or -1 to remove all following characters.
 *            Returns : the GString. 
 * Params Values: 1, 5
 * Expected: "H LSB"  
 */
static void test_purpose_16()
{
    #define POS    1
    #define LEN    5
    #define RETS   "H LSB"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GString *gs = g_string_new("Hello, LSB");
    gs = g_string_erase(gs, POS, LEN);
    if (strcmp(gs->str, RETS) != 0){
        TEST_FAIL("g_string_erase: failed", NULL);
    }
    g_string_free(gs, TRUE);
    
    #undef POS
    #undef LEN
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_string_new_len
 * Params: const gchar *init, gssize len
 * Returns: GString*
 * Assertion: Creates a new GString with len bytes of the init buffer. Because a length is provided, init need not be nul-terminated, and can contain embedded nul bytes.
 *            init : initial contents of string.
 *            len : length of init to use.
 *            Returns : a new GString. 
 * Params Values: "Hello, LSB", 5
 * Expected: "Hello"  
 */
static void test_purpose_17()
{
    #define INIT    "Hello, LSB"
    #define LEN     5
    #define RETS    "Hello"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GString *gs = g_string_new_len(INIT, LEN);
    if (strcmp(gs->str, RETS) != 0){
        TEST_FAIL("g_string_new_len: failed", NULL);
    }
    g_string_free(gs, TRUE);
    
    #undef INIT
    #undef LEN
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_string_insert
 * Params: GString *string, gssize pos, const gchar *val
 * Returns: GString*
 * Assertion: Inserts a copy of a string into a GString, expanding it if necessary.
 *            string : a GString.
 *            pos : the position to insert the copy of the string.
 *            val : the string to insert.
 *            Returns : the GString. 
 * Params Values: 5, ", "
 * Expected: "Hello, LSB"  
 */
static void test_purpose_18()
{
    #define POS    5
    #define VAL    ", "
    #define RETS   "Hello, LSB"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GString *gs = g_string_new("HelloLSB");
    gs = g_string_insert(gs, POS, VAL);
    if (strcmp(gs->str, RETS) != 0){
        TEST_FAIL("g_string_insert: failed", NULL);
    }
    g_string_free(gs, TRUE);
    #undef POS
    #undef VAL
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_string_set_size
 * Params: GString *string, gsize len
 * Returns: GString*
 * Assertion: Sets the length of a GString. If the length is less than the current length, the string will be truncated. If the length is greater than the current length, the contents of the newly added area are undefined. (However, as always, string->str[string->len] will be a nul byte.)
 *            string : a GString
 *            len : the new length
 *            Returns : string 
 * Params Values: 5
 * Expected: "Hello"  
 */
static void test_purpose_19()
{
    #define LEN    5
    #define RETS   "Hello"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GString *gs = g_string_new("Hello, LSB");
    gsize len = gs->len;
    gs = g_string_set_size(gs, LEN);
    if (gs->len != LEN){
        TEST_FAIL("g_string_set_size: length failed", NULL);
    }
    else{
        if (LEN > len){
            if (gs->str[gs->len] != NULL){
                TEST_FAIL("g_string_set_size: the last byte should be NULL", NULL);
            }
        }
        else{
            if (strcmp(gs->str, RETS) != 0){
                TEST_FAIL("g_string_set_size: failed", NULL);
            }
        }
    }
    g_string_free(gs, TRUE);
    #undef LEN
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_string_set_size
 * Params: GString *string, gsize len
 * Returns: GString*
 * Assertion: Sets the length of a GString. If the length is less than the current length, the string will be truncated. If the length is greater than the current length, the contents of the newly added area are undefined. (However, as always, string->str[string->len] will be a nul byte.)
 *            string : a GString
 *            len : the new length
 *            Returns : string 
 * Params Values: 15
 * Expected: "Hello, LSB"  
 */
static void test_purpose_20()
{
    #define LEN    15
    #define RETS   "Hello, LSB"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GString *gs = g_string_new("Hello, LSB");
    gsize len = gs->len;
    gs = g_string_set_size(gs, LEN);
    if (gs->len != LEN){
        TEST_FAIL("g_string_set_size: length failed", NULL);
    }
    else{
        if (LEN > len){
            if (gs->str[gs->len] != NULL){
                TEST_FAIL("g_string_set_size: the last byte should be NULL", NULL);
            }
        }
        else{
            if (strcmp(gs->str, RETS) != 0){
                TEST_FAIL("g_string_set_size: failed", NULL);
            }
        }
    }
    g_string_free(gs, TRUE);
    #undef LEN
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_string_equal
 * Params: const GString *v, const GString *v2
 * Returns: gboolean
 * Assertion: Compares two strings for equality, returning TRUE if they are equal. For use with GHashTable.
 *            v : a GString.
 *            v2 :	another GString.
 *            Returns : TRUE if they strings are the same length and contain the same bytes. 
 * Params Values: "Hello, LSB", "Hello, LSB"
 * Expected: TRUE  
 */
static void test_purpose_21()
{
    #define STR1    "Hello, LSB"
    #define STR2    "Hello, LSB"
    #define RETB    TRUE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GString *gs1 = g_string_new(STR1);
    GString *gs2 = g_string_new(STR2);
    if (g_string_equal(gs1, gs2) != RETB){
        TEST_FAIL("g_string_equal: failed", NULL);
    }
    g_string_free(gs1, TRUE);
    g_string_free(gs2, TRUE);
    
    #undef STR1
    #undef STR2
    #undef RETB
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_string_equal
 * Params: const GString *v, const GString *v2
 * Returns: gboolean
 * Assertion: Compares two strings for equality, returning TRUE if they are equal. For use with GHashTable.
 *            v : a GString.
 *            v2 :	another GString.
 *            Returns : TRUE if they strings are the same length and contain the same bytes. 
 * Params Values: "Hello, LSB", "Hello, lsb"
 * Expected: FALSE  
 */
static void test_purpose_22()
{
    #define STR1    "Hello, LSB"
    #define STR2    "Hello, lsb"
    #define RETB    FALSE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GString *gs1 = g_string_new(STR1);
    GString *gs2 = g_string_new(STR2);
    if (g_string_equal(gs1, gs2) != RETB){
        TEST_FAIL("g_string_equal: failed", NULL);
    }
    g_string_free(gs1, TRUE);
    g_string_free(gs2, TRUE);
    
    #undef STR1
    #undef STR2
    #undef RETB
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_string_append_unichar
 * Params: GString *string, gunichar wc
 * Returns: GString*
 * Assertion: Converts a Unicode character into UTF-8, and appends it to the string.
 *            string : a GString
 *            wc :	a Unicode character
 *            Returns : string 
 * Params Values: GString *string, gunichar wc
 * Expected: GString*  
 */
static void test_purpose_23()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    FILE *fp = fopen("unichar.txt", "w");
    if (fp == NULL){
        TEST_FAIL("g_string_append_unichar: create files error", NULL);
        return;
    }
    fprintf(fp, "%c%c%c", 0xe4, 0xb8, 0xad);
    fclose(fp);
    gchar *buf;
    if (!g_file_get_contents("unichar.txt", &buf, NULL, NULL)){
        TEST_FAIL("g_string_append_unichar: file error", NULL);
    }
    else{
        if (!g_utf8_validate(buf, -1, NULL)){
            TEST_FAIL("g_string_append_unichar: not utf8", NULL);
        }
        else{
            GString *gs = g_string_new("Hello");
            gunichar wc = g_utf8_get_char(buf);
            gs = g_string_append_unichar(gs, wc);
            if (((guchar)(gs->str[gs->len - 1]) != 0xad) || ((guchar)(gs->str[gs->len - 2]) != 0xb8) || ((guchar)(gs->str[gs->len - 3]) != 0xe4)){
                TEST_FAIL("g_string_append_unichar: append failed", NULL);
            }
            g_string_free(gs, TRUE);
        }
        g_free(buf);
        g_unlink("unichar.txt");
    }
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_string_insert_unichar
 * Params: GString *string, gssize pos, gunichar wc
 * Returns: GString*
 * Assertion: Converts a Unicode character into UTF-8, and insert it into the string at the given position. 
 *            string : a GString
 *            pos : the position at which to insert character, or -1 to append at the end of the string.
 *            wc :	a Unicode character
 *            Returns : string 
 * Params Values: position = 2
 * Expected: GString*  
 */
static void test_purpose_24()
{
    #define POS    2
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    FILE *fp = fopen("unichar.txt", "w");
    if (fp == NULL){
        TEST_FAIL("g_string_insert_unichar: create files error", NULL);
        return;
    }
    fprintf(fp, "%c%c%c", 0xe4, 0xb8, 0xad);
    fclose(fp);
    gchar *buf;
    if (!g_file_get_contents("unichar.txt", &buf, NULL, NULL)){
        TEST_FAIL("g_string_insert_unichar: file error", NULL);
    }
    else{
        if (!g_utf8_validate(buf, -1, NULL)){
            TEST_FAIL("g_string_insert_unichar: not utf8", NULL);
        }
        else{
            GString *gs = g_string_new("Hello");
            gunichar wc = g_utf8_get_char(buf);
            gs = g_string_insert_unichar(gs, POS, wc);
            if (POS == -1){
                if (((guchar)(gs->str[gs->len - 1]) != 0xad) || ((guchar)(gs->str[gs->len - 2]) != 0xb8) || ((guchar)(gs->str[gs->len - 3]) != 0xe4)){
                    TEST_FAIL("g_string_insert_unichar: insert failed", NULL);
                }
            }
            else{
                if (((guchar)(gs->str[POS + 2]) != 0xad) || ((guchar)(gs->str[POS + 1]) != 0xb8) || ((guchar)(gs->str[POS]) != 0xe4)){
                    TEST_FAIL("g_string_insert_unichar: insert failed", NULL);
                }
            }
            g_string_free(gs, TRUE);
        }
        g_free(buf);
        g_unlink("unichar.txt");
    }
    
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_string_insert_unichar
 * Params: GString *string, gssize pos, gunichar wc
 * Returns: GString*
 * Assertion: Converts a Unicode character into UTF-8, and insert it into the string at the given position. 
 *            string : a GString
 *            pos : the position at which to insert character, or -1 to append at the end of the string.
 *            wc :	a Unicode character
 *            Returns : string 
 * Params Values: position = -1
 * Expected: GString*  
 */
static void test_purpose_25()
{
    #define POS    -1
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    FILE *fp = fopen("unichar.txt", "w");
    if (fp == NULL){
        TEST_FAIL("g_string_insert_unichar: create files error", NULL);
        return;
    }
    fprintf(fp, "%c%c%c", 0xe4, 0xb8, 0xad);
    fclose(fp);
    gchar *buf;
    if (!g_file_get_contents("unichar.txt", &buf, NULL, NULL)){
        TEST_FAIL("g_string_insert_unichar: file error", NULL);
    }
    else{
        if (!g_utf8_validate(buf, -1, NULL)){
            TEST_FAIL("g_string_insert_unichar: not utf8", NULL);
        }
        else{
            GString *gs = g_string_new("Hello");
            gunichar wc = g_utf8_get_char(buf);
            gs = g_string_insert_unichar(gs, POS, wc);
            if (POS == -1){
                if (((guchar)(gs->str[gs->len - 1]) != 0xad) || ((guchar)(gs->str[gs->len - 2]) != 0xb8) || ((guchar)(gs->str[gs->len - 3]) != 0xe4)){
                    TEST_FAIL("g_string_insert_unichar: insert failed", NULL);
                }
            }
            else{
                if (((guchar)(gs->str[POS + 2]) != 0xad) || ((guchar)(gs->str[POS + 1]) != 0xb8) || ((guchar)(gs->str[POS]) != 0xe4)){
                    TEST_FAIL("g_string_insert_unichar: insert failed", NULL);
                }
            }
            g_string_free(gs, TRUE);
        }
        g_free(buf);
        g_unlink("unichar.txt");
    }
    
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GStrings ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {NULL,0}
};
