/*
 * GdkDisplay methods tests
 * Testing GdkDisplay methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gdk_display_get_default
 * Params: void
 * Returns: GdkDisplay*
 * Assertion: Gets the default GdkDisplay. This is a convenience function for:
 *                 gdk_display_manager_get_default_display (gdk_display_manager_get())
 *            Returns :     a GdkDisplay, or NULL if there is no default display.
 * Params Values: void
 * Expected: GdkDisplay*  
 */
static void test_purpose_1()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GdkDisplay* gdk_display = gdk_display_get_default();
    if (gdk_display == NULL)
        TEST_FAIL("gdk_display_get_default: failed", NULL);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_display_get_screen
 * Params: GdkDisplay *display, gint screen_num
 * Returns: GdkScreen*
 * Assertion: Returns a screen object for one of the screens of the display.
 *            display :     a GdkDisplay
 *            screen_num :    the screen number
 *            Returns :   the GdkScreen object
 * Params Values: 0
 * Expected: GdkScreen*  
 */
static void test_purpose_2()
{
    #define SCR_NUM     0
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GdkDisplay* gdk_display = gdk_display_get_default();
    if (gdk_display == NULL){
        TEST_FAIL("gdk_display_get_screen: failed", NULL);
        return;
    }
    GdkScreen *gdk_scr = gdk_display_get_screen(gdk_display, SCR_NUM);
    if (SCR_NUM > 0){
        if (gdk_scr != NULL)
            TEST_FAIL("gdk_display_get_screen: should be NULL", NULL);
    }
    else{
        if (gdk_scr == NULL)
            TEST_FAIL("gdk_display_get_screen: should not be NULL", NULL);
    }
    #undef SCR_NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_display_get_screen
 * Params: GdkDisplay *display, gint screen_num
 * Returns: GdkScreen*
 * Assertion: Returns a screen object for one of the screens of the display.
 *            display :     a GdkDisplay
 *            screen_num :    the screen number
 *            Returns :   the GdkScreen object
 * Params Values: 0x0f
 * Expected: GdkScreen*  
 */
static void test_purpose_3()
{
    #define SCR_NUM     0x0f
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GdkDisplay* gdk_display = gdk_display_get_default();
    if (gdk_display == NULL){
        TEST_FAIL("gdk_display_get_screen: failed", NULL);
        return;
    }
    GdkScreen *gdk_scr = gdk_display_get_screen(gdk_display, SCR_NUM);
    if (SCR_NUM > 0){
        if (gdk_scr != NULL)
            TEST_FAIL("gdk_display_get_screen: should be NULL", NULL);
    }
    else{
        if (gdk_scr == NULL)
            TEST_FAIL("gdk_display_get_screen: should not be NULL", NULL);
    }
    #undef SCR_NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_display_get_n_screens
 * Params: GdkDisplay *display
 * Returns: gint
 * Assertion: Gets the number of screen managed by the display.
 *            display :     a GdkDisplay
 *            Returns :   number of screens.
 * Params Values: GdkDisplay *display
 * Expected: gint  
 */
static void test_purpose_4()
{
    gint screens;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GdkDisplay* gdk_display = gdk_display_get_default();
    if (gdk_display == NULL){
        TEST_FAIL("gdk_display_get_n_screens: failed", NULL);
        return;
    }
    screens = gdk_display_get_n_screens(gdk_display);
    if (screens != 1)
        TEST_FAIL("gdk_display_get_n_screens: should be 1", NULL);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_display_beep
 * Params: GdkDisplay *display
 * Returns: void
 * Assertion: Emits a short beep on display
 *            display :     a GdkDisplay
 * Params Values: GdkDisplay *display
 * Expected: void  
 */
static void test_purpose_5()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GdkDisplay* gdk_display = gdk_display_get_default();
    if (gdk_display == NULL){
        TEST_FAIL("gdk_display_beep: failed", NULL);
        return;
    }
    gdk_display_beep(gdk_display);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_display_open
 * Params: const gchar *display_name
 * Returns: GdkDisplay*
 * Assertion: Opens a display.
 *            display_name :    the name of the display to open
 *            Returns :   a GdkDisplay, or NULL if the display could not be opened.
 * Params Values: const gchar *display_name
 * Expected: GdkDisplay*  
 */
static void test_purpose_6()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GdkDisplay *gdk_display = gdk_display_open("LSB_TEST");
    if (gdk_display != NULL)
        TEST_FAIL("gdk_display_open: should be NULL", NULL);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_display_open
 * Params: GdkDisplay *display
 * Returns: GList*
 * Assertion: Returns the list of available input devices attached to display. The list is statically allocated and should not be freed.
 *            display :   a GdkDisplay
 *            Returns :   a list of GdkDevice
 * Params Values: GdkDisplay *display
 * Expected: GList*  
 */
static void test_purpose_7()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GdkDisplay* gdk_display = gdk_display_get_default();
    GList *dev_list = gdk_display_list_devices(gdk_display);
    if (dev_list == NULL)
        TEST_FAIL("gdk_display_list_devices: should have one device at least", NULL);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_display_get_pointer
 * Params: GdkDisplay *display, GdkScreen **screen, gint *x, gint *y, GdkModifierType *mask
 * Returns: void
 * Assertion: Gets the current location of the pointer and the current modifier mask for a given display.
 *            display :     a GdkDisplay
 *            screen :    location to store the screen that the cursor is on, or NULL.
 *            x : location to store root window X coordinate of pointer, or NULL.
 *            y : location to store root window Y coordinate of pointer, or NULL.
 *            mask :  location to store current modifier mask, or NULL
 * Params Values: GdkDisplay *display, GdkScreen **screen, gint *x, gint *y, GdkModifierType *mask
 * Expected: void  
 */
static void test_purpose_8()
{
    gint x;
    gint y;
    GdkModifierType mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GdkDisplay* gdk_display = gdk_display_get_default();
    gdk_display_get_pointer(gdk_display, NULL, &x, &y, &mask);
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GdkDisplay ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {NULL,0}
};
