/*
 * GtkAdjustment methods tests
 * Testing GtkAdjustment methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
#include <float.h>
gint global_counter;

void global_changed_signal (GtkAdjustment *adjustment,gpointer user_data)
{
    global_counter++;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: G_MINDOUBLE, 0.0, 0.0, 0.0, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_1()
{
    #define VALUE G_MINDOUBLE
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, G_MINDOUBLE, 0.0, 0.0, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_2()
{
    #define VALUE 0.0
    #define LOWER G_MINDOUBLE
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, G_MINDOUBLE, 0.0, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_3()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER G_MINDOUBLE
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, 0.0, G_MINDOUBLE, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_4()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT G_MINDOUBLE
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, 0.0, 0.0, G_MINDOUBLE, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_5()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT G_MINDOUBLE
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, 0.0, 0.0, 0.0, G_MINDOUBLE
 * Expected:GtkAdjustment*   
 */
static void test_purpose_6()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE G_MINDOUBLE
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: G_MAXDOUBLE, 0.0, 0.0, 0.0, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_7()
{
    #define VALUE G_MAXDOUBLE
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, G_MAXDOUBLE, 0.0, 0.0, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_8()
{
    #define VALUE 0.0
    #define LOWER G_MAXDOUBLE
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, G_MAXDOUBLE, 0.0, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_9()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER G_MAXDOUBLE
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, 0.0, G_MAXDOUBLE, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_10()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT G_MAXDOUBLE
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, 0.0, 0.0, G_MAXDOUBLE, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_11()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT G_MAXDOUBLE
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, 0.0, 0.0, 0.0, G_MAXDOUBLE
 * Expected:GtkAdjustment*   
 */
static void test_purpose_12()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE G_MAXDOUBLE
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 100000.0, 0.0, 0.0, 0.0, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_13()
{
    #define VALUE 100000.0
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 100000.0, 0.0, 0.0, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_14()
{
    #define VALUE 0.0
    #define LOWER 100000.0
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, 100000.0, 0.0, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_15()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER 100000.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, 0.0, 100000.0, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_16()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT 100000.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, 0.0, 0.0, 100000.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_17()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 100000.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, 0.0, 0.0, 0.0, 100000.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_18()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 100000.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: -100000.0, 0.0, 0.0, 0.0, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_19()
{
    #define VALUE -100000.0
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, -100000.0, 0.0, 0.0, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_20()
{
    #define VALUE 0.0
    #define LOWER -100000.0
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, -100000.0, 0.0, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_21()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER -100000.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, 0.0, -100000.0, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_22()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT -100000.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, 0.0, 0.0, -100000.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_23()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT -100000.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, 0.0, 0.0, 0.0, -100000.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_24()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE -100000.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 1.0, 0.0, 0.0, 0.0, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_25()
{
    #define VALUE 1.0
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 1.0, 0.0, 0.0, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_26()
{
    #define VALUE 0.0
    #define LOWER 1.0
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, 1.0, 0.0, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_27()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER 1.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, 0.0, 1.0, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_28()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT 1.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, 0.0, 0.0, 1.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_29()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 1.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, 0.0, 0.0, 0.0, 1.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_30()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 1.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: -1.0, 0.0, 0.0, 0.0, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_31()
{
    #define VALUE -1.0
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, -1.0, 0.0, 0.0, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_32()
{
    #define VALUE 0.0
    #define LOWER -1.0
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, -1.0, 0.0, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_33()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER -1.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, 0.0, -1.0, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_34()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT -1.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, 0.0, 0.0, -1.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_35()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT -1.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, 0.0, 0.0, 0.0, -1.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_36()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE -1.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: -0.5, 0.0, 0.0, 0.0, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_37()
{
    #define VALUE -0.5
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, -0.5, 0.0, 0.0, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_38()
{
    #define VALUE 0.0
    #define LOWER -0.5
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, -0.5, 0.0, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_39()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER -0.5
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, 0.0, -0.5, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_40()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT -0.5
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, 0.0, 0.0, -0.5, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_41()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT -0.5
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, 0.0, 0.0, 0.0, -0.5
 * Expected:GtkAdjustment*   
 */
static void test_purpose_42()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE -0.5
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.5, 0.0, 0.0, 0.0, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_43()
{
    #define VALUE 0.5
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.5, 0.0, 0.0, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_44()
{
    #define VALUE 0.0
    #define LOWER 0.5
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, 0.5, 0.0, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_45()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER 0.5
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, 0.0, 0.5, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_46()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT 0.5
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, 0.0, 0.0, 0.5, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_47()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.5
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, 0.0, 0.0, 0.0, 0.5
 * Expected:GtkAdjustment*   
 */
static void test_purpose_48()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.5
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_new 
 * Params: gdouble value, gdouble lower, gdouble upper, gdouble step_increment,
 *         gdouble page_increment, gdouble page_size
 * Returns: GtkObject*
 * Assertion: Creates a new GtkAdjustment.
 * Params Values: 0.0, 0.0, 0.0, 0.0, 0.0, 0.0
 * Expected:GtkAdjustment*   
 */
static void test_purpose_49()
{
    #define VALUE 0.0
    #define LOWER 0.0
    #define UPPER 0.0
    #define STEP_INCREMENT 0.0
    #define PAGE_INCREMENT 0.0
    #define PAGE_SIZE 0.0
    
    GtkObject *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_adjustment_new (VALUE,
                                 LOWER,
                                 UPPER,
                                 STEP_INCREMENT,
                                 PAGE_INCREMENT,
                                 PAGE_SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy(widget);
    
    #undef VALUE
    #undef LOWER 
    #undef UPPER 
    #undef STEP_INCREMENT 
    #undef PAGE_INCREMENT 
    #undef PAGE_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_set_value
 * Params: GtkAdjustment *adjustment, gdouble value
 * Returns: void
 * Assertion: Sets the GtkAdjustment value
 * Params Values:  GtkAdjustment *adjustment, 1.0
 * Expected: void
 * 
 * Name: gtk_adjustment_get_value
 * Params: GtkAdjustment *adjustment
 * Returns: gdouble value
 * Assertion: Gets the current value of the adjustment.
 * Params Values:  GtkAdjustment *adjustment
 * Expected: 1.0  
 */
static void test_purpose_50()
{
    #define ADJ gtk_adjustment_new (1.0, 1.0, 5.0, 5.0, 20.0, 50.0)
    #define VALUE 1.0
    
    GtkObject *widget;
    gdouble value;
    gdouble real_value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = ADJ;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_adjustment_set_value (GTK_ADJUSTMENT (widget), VALUE);
    real_value = gtk_adjustment_get_value (GTK_ADJUSTMENT (widget));
    if (real_value != VALUE)
    {
        if ((GTK_ADJUSTMENT (widget)->upper < VALUE) && (real_value != GTK_ADJUSTMENT (widget)->upper))
        {
            TEST_FAIL ("value > upper", NULL);
        }
        if ((VALUE < GTK_ADJUSTMENT (widget)->lower) && (real_value != GTK_ADJUSTMENT (widget)->lower))
        {
            TEST_FAIL ("lower < value", NULL);
        }
    }
    
    gtk_object_destroy(widget);
    
    #undef ADJ
    #undef VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_set_value
 * Params: GtkAdjustment *adjustment, gdouble value
 * Returns: void
 * Assertion: Sets the GtkAdjustment value
 * Params Values:  GtkAdjustment *adjustment, 5.0
 * Expected: void
 * 
 * Name: gtk_adjustment_get_value
 * Params: GtkAdjustment *adjustment
 * Returns: gdouble value
 * Assertion: Gets the current value of the adjustment.
 * Params Values:  GtkAdjustment *adjustment
 * Expected: 5.0  
 */
static void test_purpose_51()
{
    #define ADJ gtk_adjustment_new (1.0, 1.0, 5.0, 5.0, 20.0, 50.0)
    #define VALUE 5.0
    
    GtkObject *widget;
    gdouble value;
    gdouble real_value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = ADJ;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_adjustment_set_value (GTK_ADJUSTMENT (widget), VALUE);
    real_value = gtk_adjustment_get_value (GTK_ADJUSTMENT (widget));
    if (real_value != VALUE)
    {
        if ((GTK_ADJUSTMENT (widget)->upper < VALUE) && (real_value != GTK_ADJUSTMENT (widget)->upper))
        {
            TEST_FAIL ("value > upper", NULL);
        }
        if ((VALUE < GTK_ADJUSTMENT (widget)->lower) && (real_value != GTK_ADJUSTMENT (widget)->lower))
        {
            TEST_FAIL ("lower < value", NULL);
        }
    }
    
    gtk_object_destroy(widget);
    
    #undef ADJ
    #undef VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_set_value
 * Params: GtkAdjustment *adjustment, gdouble value
 * Returns: void
 * Assertion: Sets the GtkAdjustment value
 * Params Values:  GtkAdjustment *adjustment, 0.0
 * Expected: void
 * 
 * Name: gtk_adjustment_get_value
 * Params: GtkAdjustment *adjustment
 * Returns: gdouble value
 * Assertion: Gets the current value of the adjustment.
 * Params Values:  GtkAdjustment *adjustment
 * Expected: 0.0  
 */
static void test_purpose_52()
{
    #define ADJ gtk_adjustment_new (1.0, 1.0, 5.0, 5.0, 20.0, 50.0)
    #define VALUE 0.0
    
    GtkObject *widget;
    gdouble value;
    gdouble real_value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = ADJ;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_adjustment_set_value (GTK_ADJUSTMENT (widget), VALUE);
    real_value = gtk_adjustment_get_value (GTK_ADJUSTMENT (widget));
    if (real_value != VALUE)
    {
        if ((GTK_ADJUSTMENT (widget)->upper < VALUE) && (real_value != GTK_ADJUSTMENT (widget)->upper))
        {
            TEST_FAIL ("value > upper", NULL);
        }
        if ((VALUE < GTK_ADJUSTMENT (widget)->lower) && (real_value != GTK_ADJUSTMENT (widget)->lower))
        {
            TEST_FAIL ("lower < value", NULL);
        }
    }
    
    gtk_object_destroy(widget);
    
    #undef ADJ
    #undef VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_set_value
 * Params: GtkAdjustment *adjustment, gdouble value
 * Returns: void
 * Assertion: Sets the GtkAdjustment value
 * Params Values:  GtkAdjustment *adjustment, G_MAXDOUBLE
 * Expected: void
 * 
 * Name: gtk_adjustment_get_value
 * Params: GtkAdjustment *adjustment
 * Returns: gdouble value
 * Assertion: Gets the current value of the adjustment.
 * Params Values:  GtkAdjustment *adjustment
 * Expected: G_MAXDOUBLE  
 */
static void test_purpose_53()
{
    #define ADJ gtk_adjustment_new (1.0, G_MINDOUBLE, G_MAXDOUBLE, 5.0, 20.0, 50.0)
    #define VALUE G_MAXDOUBLE
    
    GtkObject *widget;
    gdouble value;
    gdouble real_value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = ADJ;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_adjustment_set_value (GTK_ADJUSTMENT (widget), VALUE);
    real_value = gtk_adjustment_get_value (GTK_ADJUSTMENT (widget));
    if (real_value != VALUE)
    {
        if ((GTK_ADJUSTMENT (widget)->upper < VALUE) && (real_value != GTK_ADJUSTMENT (widget)->upper))
        {
            TEST_FAIL ("value > upper", NULL);
        }
        if ((VALUE < GTK_ADJUSTMENT (widget)->lower) && (real_value != GTK_ADJUSTMENT (widget)->lower))
        {
            TEST_FAIL ("lower < value", NULL);
        }
    }
    
    gtk_object_destroy(widget);
    
    #undef ADJ
    #undef VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_set_value
 * Params: GtkAdjustment *adjustment, gdouble value
 * Returns: void
 * Assertion: Sets the GtkAdjustment value
 * Params Values:  GtkAdjustment *adjustment, G_MINDOUBLE
 * Expected: void
 * 
 * Name: gtk_adjustment_get_value
 * Params: GtkAdjustment *adjustment
 * Returns: gdouble value
 * Assertion: Gets the current value of the adjustment.
 * Params Values:  GtkAdjustment *adjustment
 * Expected: G_MINDOUBLE  
 */
static void test_purpose_54()
{
    #define ADJ gtk_adjustment_new (1.0, G_MINDOUBLE, G_MAXDOUBLE, 5.0, 20.0, 50.0)
    #define VALUE G_MINDOUBLE
    
    GtkObject *widget;
    gdouble value;
    gdouble real_value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = ADJ;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ADJUSTMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_adjustment_set_value (GTK_ADJUSTMENT (widget), VALUE);
    real_value = gtk_adjustment_get_value (GTK_ADJUSTMENT (widget));
    if (real_value != VALUE)
    {
        if ((GTK_ADJUSTMENT (widget)->upper < VALUE) && (real_value != GTK_ADJUSTMENT (widget)->upper))
        {
            TEST_FAIL ("value > upper", NULL);
        }
        if ((VALUE < GTK_ADJUSTMENT (widget)->lower) && (real_value != GTK_ADJUSTMENT (widget)->lower))
        {
            TEST_FAIL ("lower < value", NULL);
        }
    }
    
    gtk_object_destroy(widget);
    
    #undef ADJ
    #undef VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_changed
 * Params: GtkAdjustment *adjustment
 * Returns: void
 * Assertion: Emits a "changed" signal from the GtkAdjustment.
 * Params Values:  GtkAdjustment *adjustment
 * Expected: void  
 */
static void test_purpose_55()
{
    GtkObject *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    widget = gtk_adjustment_new (1.0, 1.0, 5.0, 5.0, 20.0, 50.0);
    
    g_signal_connect (G_OBJECT (widget), "changed", 
                        GTK_SIGNAL_FUNC (global_changed_signal), NULL);
    
    gtk_adjustment_changed (GTK_ADJUSTMENT (widget));
    if (global_counter == 0)
    {
        TEST_FAIL ("GtkAdjustment widget should emit 'changed' signal", NULL);
    }
    
    gtk_object_destroy(widget);
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_value_changed
 * Params: GtkAdjustment *adjustment
 * Returns: void
 * Assertion: Emits a "value_changed" signal from the GtkAdjustment.
 * Params Values:  GtkAdjustment *adjustment
 * Expected: void  
 */
static void test_purpose_56()
{
    GtkObject *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    widget = gtk_adjustment_new (1.0, 1.0, 5.0, 5.0, 20.0, 50.0);
    
    g_signal_connect (G_OBJECT (widget), "value_changed", 
                        GTK_SIGNAL_FUNC (global_changed_signal), NULL);
    
    gtk_adjustment_value_changed (GTK_ADJUSTMENT (widget));
    if (global_counter == 0)
    {
        TEST_FAIL ("GtkAdjustment widget should emit 'value_changed' signal", NULL);
    }
    
    gtk_object_destroy(widget);
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_clamp_page 
 * Params: GtkAdjustment *adjustment, gdouble lower, gdouble upper
 * Returns: void
 * Assertion: Updates the GtkAdjustment value to ensure that the range between lower and upper is in the current page (i.e. between value and value + page_size).
 * Params Values:  GtkAdjustment *adjustment, 5.0, 17.0
 * Expected: void  
 */
static void test_purpose_57()
{
    #define VALUE 1.0
    #define LOWER 5.0
    #define UPPER 17.0
    
    GtkObject *widget;
    gdouble lower;
    gdouble upper;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    lower = LOWER;
    upper = UPPER;
    value = VALUE;
    
    widget = gtk_adjustment_new (VALUE, 1.0, 5.0, 5.0, 20.0, 0.0);
    
    if(lower > GTK_ADJUSTMENT (widget)->upper) 
      lower = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(lower < GTK_ADJUSTMENT (widget)->lower)  
      lower = GTK_ADJUSTMENT (widget)->lower; 
     else lower = lower;
    
    if(upper > GTK_ADJUSTMENT (widget)->upper) 
      upper = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(upper < GTK_ADJUSTMENT (widget)->lower)  
      upper = GTK_ADJUSTMENT (widget)->lower; 
     else upper = upper;
    
    if (value + GTK_ADJUSTMENT (widget)->page_size < upper)
      value = upper - GTK_ADJUSTMENT (widget)->page_size;
    if (value > lower)
      value = lower;
    
    gtk_adjustment_clamp_page (GTK_ADJUSTMENT (widget),LOWER,UPPER);
    
    if (GTK_ADJUSTMENT (widget)->value != value)
    {
        TEST_FAIL ("Value is not updated",NULL)
    }
    
    
    gtk_object_destroy(widget);
    #undef VALUE
    #undef LOWER
    #undef UPPER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_clamp_page 
 * Params: GtkAdjustment *adjustment, gdouble lower, gdouble upper
 * Returns: void
 * Assertion: Updates the GtkAdjustment value to ensure that the range between lower and upper is in the current page (i.e. between value and value + page_size).
 * Params Values:  GtkAdjustment *adjustment, 25.0, 37.0
 * Expected: void  
 */
static void test_purpose_58()
{
    #define VALUE 1.0
    #define LOWER 25.0
    #define UPPER 37.0
    
    GtkObject *widget;
    gdouble lower;
    gdouble upper;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    lower = LOWER;
    upper = UPPER;
    value = VALUE;
    
    widget = gtk_adjustment_new (VALUE, 1.0, 5.0, 5.0, 20.0, 0.0);
    
    if(lower > GTK_ADJUSTMENT (widget)->upper) 
      lower = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(lower < GTK_ADJUSTMENT (widget)->lower)  
      lower = GTK_ADJUSTMENT (widget)->lower; 
     else lower = lower;
    
    if(upper > GTK_ADJUSTMENT (widget)->upper) 
      upper = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(upper < GTK_ADJUSTMENT (widget)->lower)  
      upper = GTK_ADJUSTMENT (widget)->lower; 
     else upper = upper;
    
    if (value + GTK_ADJUSTMENT (widget)->page_size < upper)
      value = upper - GTK_ADJUSTMENT (widget)->page_size;
    if (value > lower)
      value = lower;
    
    gtk_adjustment_clamp_page (GTK_ADJUSTMENT (widget),LOWER,UPPER);
    
    if (GTK_ADJUSTMENT (widget)->value != value)
    {
        TEST_FAIL ("Value is not updated",NULL)
    }
    
    
    gtk_object_destroy(widget);
    #undef VALUE
    #undef LOWER
    #undef UPPER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_clamp_page 
 * Params: GtkAdjustment *adjustment, gdouble lower, gdouble upper
 * Returns: void
 * Assertion: Updates the GtkAdjustment value to ensure that the range between lower and upper is in the current page (i.e. between value and value + page_size).
 * Params Values:  GtkAdjustment *adjustment, 10.0, 1000.0
 * Expected: void  
 */
static void test_purpose_59()
{
    #define VALUE 1.0
    #define LOWER 10.0
    #define UPPER 1000.0
    
    GtkObject *widget;
    gdouble lower;
    gdouble upper;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    lower = LOWER;
    upper = UPPER;
    value = VALUE;
    
    widget = gtk_adjustment_new (VALUE, 1.0, 5.0, 5.0, 20.0, 0.0);
    
    if(lower > GTK_ADJUSTMENT (widget)->upper) 
      lower = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(lower < GTK_ADJUSTMENT (widget)->lower)  
      lower = GTK_ADJUSTMENT (widget)->lower; 
     else lower = lower;
    
    if(upper > GTK_ADJUSTMENT (widget)->upper) 
      upper = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(upper < GTK_ADJUSTMENT (widget)->lower)  
      upper = GTK_ADJUSTMENT (widget)->lower; 
     else upper = upper;
    
    if (value + GTK_ADJUSTMENT (widget)->page_size < upper)
      value = upper - GTK_ADJUSTMENT (widget)->page_size;
    if (value > lower)
      value = lower;
    
    gtk_adjustment_clamp_page (GTK_ADJUSTMENT (widget),LOWER,UPPER);
    
    if (GTK_ADJUSTMENT (widget)->value != value)
    {
        TEST_FAIL ("Value is not updated",NULL)
    }
    
    
    gtk_object_destroy(widget);
    #undef VALUE
    #undef LOWER
    #undef UPPER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_clamp_page 
 * Params: GtkAdjustment *adjustment, gdouble lower, gdouble upper
 * Returns: void
 * Assertion: Updates the GtkAdjustment value to ensure that the range between lower and upper is in the current page (i.e. between value and value + page_size).
 * Params Values:  GtkAdjustment *adjustment, -10.0, 10.0
 * Expected: void  
 */
static void test_purpose_60()
{
    #define VALUE 1.0
    #define LOWER -10.0
    #define UPPER 10.0
    
    GtkObject *widget;
    gdouble lower;
    gdouble upper;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    lower = LOWER;
    upper = UPPER;
    value = VALUE;
    
    widget = gtk_adjustment_new (VALUE, 1.0, 5.0, 5.0, 20.0, 0.0);
    
    if(lower > GTK_ADJUSTMENT (widget)->upper) 
      lower = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(lower < GTK_ADJUSTMENT (widget)->lower)  
      lower = GTK_ADJUSTMENT (widget)->lower; 
     else lower = lower;
    
    if(upper > GTK_ADJUSTMENT (widget)->upper) 
      upper = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(upper < GTK_ADJUSTMENT (widget)->lower)  
      upper = GTK_ADJUSTMENT (widget)->lower; 
     else upper = upper;
    
    if (value + GTK_ADJUSTMENT (widget)->page_size < upper)
      value = upper - GTK_ADJUSTMENT (widget)->page_size;
    if (value > lower)
      value = lower;
    
    gtk_adjustment_clamp_page (GTK_ADJUSTMENT (widget),LOWER,UPPER);
    
    if (GTK_ADJUSTMENT (widget)->value != value)
    {
        TEST_FAIL ("Value is not updated",NULL)
    }
    
    
    gtk_object_destroy(widget);
    #undef VALUE
    #undef LOWER
    #undef UPPER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_clamp_page 
 * Params: GtkAdjustment *adjustment, gdouble lower, gdouble upper
 * Returns: void
 * Assertion: Updates the GtkAdjustment value to ensure that the range between lower and upper is in the current page (i.e. between value and value + page_size).
 * Params Values:  GtkAdjustment *adjustment, 5.0, 17.0
 * Expected: void  
 */
static void test_purpose_61()
{
    #define VALUE 100.0
    #define LOWER 5.0
    #define UPPER 17.0
    
    GtkObject *widget;
    gdouble lower;
    gdouble upper;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    lower = LOWER;
    upper = UPPER;
    value = VALUE;
    
    widget = gtk_adjustment_new (VALUE, 1.0, 5.0, 5.0, 20.0, 0.0);
    
    if(lower > GTK_ADJUSTMENT (widget)->upper) 
      lower = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(lower < GTK_ADJUSTMENT (widget)->lower)  
      lower = GTK_ADJUSTMENT (widget)->lower; 
     else lower = lower;
    
    if(upper > GTK_ADJUSTMENT (widget)->upper) 
      upper = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(upper < GTK_ADJUSTMENT (widget)->lower)  
      upper = GTK_ADJUSTMENT (widget)->lower; 
     else upper = upper;
    
    if (value + GTK_ADJUSTMENT (widget)->page_size < upper)
      value = upper - GTK_ADJUSTMENT (widget)->page_size;
    if (value > lower)
      value = lower;
    
    gtk_adjustment_clamp_page (GTK_ADJUSTMENT (widget),LOWER,UPPER);
    
    if (GTK_ADJUSTMENT (widget)->value != value)
    {
        TEST_FAIL ("Value is not updated",NULL)
    }
    
    
    gtk_object_destroy(widget);
    #undef VALUE
    #undef LOWER
    #undef UPPER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_clamp_page 
 * Params: GtkAdjustment *adjustment, gdouble lower, gdouble upper
 * Returns: void
 * Assertion: Updates the GtkAdjustment value to ensure that the range between lower and upper is in the current page (i.e. between value and value + page_size).
 * Params Values:  GtkAdjustment *adjustment, 25.0, 37.0
 * Expected: void  
 */
static void test_purpose_62()
{
    #define VALUE 100.0
    #define LOWER 25.0
    #define UPPER 37.0
    
    GtkObject *widget;
    gdouble lower;
    gdouble upper;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    lower = LOWER;
    upper = UPPER;
    value = VALUE;
    
    widget = gtk_adjustment_new (VALUE, 1.0, 5.0, 5.0, 20.0, 0.0);
    
    if(lower > GTK_ADJUSTMENT (widget)->upper) 
      lower = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(lower < GTK_ADJUSTMENT (widget)->lower)  
      lower = GTK_ADJUSTMENT (widget)->lower; 
     else lower = lower;
    
    if(upper > GTK_ADJUSTMENT (widget)->upper) 
      upper = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(upper < GTK_ADJUSTMENT (widget)->lower)  
      upper = GTK_ADJUSTMENT (widget)->lower; 
     else upper = upper;
    
    if (value + GTK_ADJUSTMENT (widget)->page_size < upper)
      value = upper - GTK_ADJUSTMENT (widget)->page_size;
    if (value > lower)
      value = lower;
    
    gtk_adjustment_clamp_page (GTK_ADJUSTMENT (widget),LOWER,UPPER);
    
    if (GTK_ADJUSTMENT (widget)->value != value)
    {
        TEST_FAIL ("Value is not updated",NULL)
    }
    
    
    gtk_object_destroy(widget);
    #undef VALUE
    #undef LOWER
    #undef UPPER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_clamp_page 
 * Params: GtkAdjustment *adjustment, gdouble lower, gdouble upper
 * Returns: void
 * Assertion: Updates the GtkAdjustment value to ensure that the range between lower and upper is in the current page (i.e. between value and value + page_size).
 * Params Values:  GtkAdjustment *adjustment, 10.0, 1000.0
 * Expected: void  
 */
static void test_purpose_63()
{
    #define VALUE 100.0
    #define LOWER 10.0
    #define UPPER 1000.0
    
    GtkObject *widget;
    gdouble lower;
    gdouble upper;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    lower = LOWER;
    upper = UPPER;
    value = VALUE;
    
    widget = gtk_adjustment_new (VALUE, 1.0, 5.0, 5.0, 20.0, 0.0);
    
    if(lower > GTK_ADJUSTMENT (widget)->upper) 
      lower = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(lower < GTK_ADJUSTMENT (widget)->lower)  
      lower = GTK_ADJUSTMENT (widget)->lower; 
     else lower = lower;
    
    if(upper > GTK_ADJUSTMENT (widget)->upper) 
      upper = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(upper < GTK_ADJUSTMENT (widget)->lower)  
      upper = GTK_ADJUSTMENT (widget)->lower; 
     else upper = upper;
    
    if (value + GTK_ADJUSTMENT (widget)->page_size < upper)
      value = upper - GTK_ADJUSTMENT (widget)->page_size;
    if (value > lower)
      value = lower;
    
    gtk_adjustment_clamp_page (GTK_ADJUSTMENT (widget),LOWER,UPPER);
    
    if (GTK_ADJUSTMENT (widget)->value != value)
    {
        TEST_FAIL ("Value is not updated",NULL)
    }
    
    
    gtk_object_destroy(widget);
    #undef VALUE
    #undef LOWER
    #undef UPPER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_clamp_page 
 * Params: GtkAdjustment *adjustment, gdouble lower, gdouble upper
 * Returns: void
 * Assertion: Updates the GtkAdjustment value to ensure that the range between lower and upper is in the current page (i.e. between value and value + page_size).
 * Params Values:  GtkAdjustment *adjustment, 5.0, 17.0
 * Expected: void  
 */
static void test_purpose_64()
{
    #define VALUE 1.0
    #define LOWER 5.0
    #define UPPER 17.0
    
    GtkObject *widget;
    gdouble lower;
    gdouble upper;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    lower = LOWER;
    upper = UPPER;
    value = VALUE;
    
    widget = gtk_adjustment_new (VALUE, 1.0, 5.0, 5.0, 20.0, 0.0);
    
    if(lower > GTK_ADJUSTMENT (widget)->upper) 
      lower = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(lower < GTK_ADJUSTMENT (widget)->lower)  
      lower = GTK_ADJUSTMENT (widget)->lower; 
     else lower = lower;
    
    if(upper > GTK_ADJUSTMENT (widget)->upper) 
      upper = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(upper < GTK_ADJUSTMENT (widget)->lower)  
      upper = GTK_ADJUSTMENT (widget)->lower; 
     else upper = upper;
    
    if (value + GTK_ADJUSTMENT (widget)->page_size < upper)
      value = upper - GTK_ADJUSTMENT (widget)->page_size;
    if (value > lower)
      value = lower;
    
    gtk_adjustment_clamp_page (GTK_ADJUSTMENT (widget),LOWER,UPPER);
    
    if (GTK_ADJUSTMENT (widget)->value != value)
    {
        TEST_FAIL ("Value is not updated",NULL)
    }
    
    
    gtk_object_destroy(widget);
    #undef VALUE
    #undef LOWER
    #undef UPPER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_clamp_page 
 * Params: GtkAdjustment *adjustment, gdouble lower, gdouble upper
 * Returns: void
 * Assertion: Updates the GtkAdjustment value to ensure that the range between lower and upper is in the current page (i.e. between value and value + page_size).
 * Params Values:  GtkAdjustment *adjustment, 25.0, 37.0
 * Expected: void  
 */
static void test_purpose_65()
{
    #define VALUE 1.0
    #define LOWER 25.0
    #define UPPER 37.0
    
    GtkObject *widget;
    gdouble lower;
    gdouble upper;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    lower = LOWER;
    upper = UPPER;
    value = VALUE;
    
    widget = gtk_adjustment_new (VALUE, 1.0, 5.0, 5.0, 20.0, 0.0);
    
    if(lower > GTK_ADJUSTMENT (widget)->upper) 
      lower = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(lower < GTK_ADJUSTMENT (widget)->lower)  
      lower = GTK_ADJUSTMENT (widget)->lower; 
     else lower = lower;
    
    if(upper > GTK_ADJUSTMENT (widget)->upper) 
      upper = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(upper < GTK_ADJUSTMENT (widget)->lower)  
      upper = GTK_ADJUSTMENT (widget)->lower; 
     else upper = upper;
    
    if (value + GTK_ADJUSTMENT (widget)->page_size < upper)
      value = upper - GTK_ADJUSTMENT (widget)->page_size;
    if (value > lower)
      value = lower;
    
    gtk_adjustment_clamp_page (GTK_ADJUSTMENT (widget),LOWER,UPPER);
    
    if (GTK_ADJUSTMENT (widget)->value != value)
    {
        TEST_FAIL ("Value is not updated",NULL)
    }
    
    
    gtk_object_destroy(widget);
    #undef VALUE
    #undef LOWER
    #undef UPPER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_clamp_page 
 * Params: GtkAdjustment *adjustment, gdouble lower, gdouble upper
 * Returns: void
 * Assertion: Updates the GtkAdjustment value to ensure that the range between lower and upper is in the current page (i.e. between value and value + page_size).
 * Params Values:  GtkAdjustment *adjustment, 10.0, 1000.0
 * Expected: void  
 */
static void test_purpose_66()
{
    #define VALUE 1.0
    #define LOWER 10.0
    #define UPPER 1000.0
    
    GtkObject *widget;
    gdouble lower;
    gdouble upper;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    lower = LOWER;
    upper = UPPER;
    value = VALUE;
    
    widget = gtk_adjustment_new (VALUE, 1.0, 5.0, 5.0, 20.0, 0.0);
    
    if(lower > GTK_ADJUSTMENT (widget)->upper) 
      lower = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(lower < GTK_ADJUSTMENT (widget)->lower)  
      lower = GTK_ADJUSTMENT (widget)->lower; 
     else lower = lower;
    
    if(upper > GTK_ADJUSTMENT (widget)->upper) 
      upper = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(upper < GTK_ADJUSTMENT (widget)->lower)  
      upper = GTK_ADJUSTMENT (widget)->lower; 
     else upper = upper;
    
    if (value + GTK_ADJUSTMENT (widget)->page_size < upper)
      value = upper - GTK_ADJUSTMENT (widget)->page_size;
    if (value > lower)
      value = lower;
    
    gtk_adjustment_clamp_page (GTK_ADJUSTMENT (widget),LOWER,UPPER);
    
    if (GTK_ADJUSTMENT (widget)->value != value)
    {
        TEST_FAIL ("Value is not updated",NULL)
    }
    
    
    gtk_object_destroy(widget);
    #undef VALUE
    #undef LOWER
    #undef UPPER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_clamp_page 
 * Params: GtkAdjustment *adjustment, gdouble lower, gdouble upper
 * Returns: void
 * Assertion: If the range is larger than the page size, then only the start of it will be in the current page.
 * Params Values:  GtkAdjustment *adjustment, 10.0, 30.0
 * Expected: void  
 */
static void test_purpose_67()
{
    #define VALUE 1.0
    #define LOWER 10.0
    #define UPPER 30.0
    
    GtkObject *widget;
    gdouble lower;
    gdouble upper;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    lower = LOWER;
    upper = UPPER;
    value = VALUE;
    
    widget = gtk_adjustment_new (VALUE, 1.0, 5.0, 5.0, 20.0, 0.0);
    
    if(lower > GTK_ADJUSTMENT (widget)->upper) 
      lower = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(lower < GTK_ADJUSTMENT (widget)->lower)  
      lower = GTK_ADJUSTMENT (widget)->lower; 
     else lower = lower;
    
    if(upper > GTK_ADJUSTMENT (widget)->upper) 
      upper = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(upper < GTK_ADJUSTMENT (widget)->lower)  
      upper = GTK_ADJUSTMENT (widget)->lower; 
     else upper = upper;
    
    if (value + GTK_ADJUSTMENT (widget)->page_size < upper)
      value = upper - GTK_ADJUSTMENT (widget)->page_size;
    if (value > lower)
      value = lower;
    
    gtk_adjustment_clamp_page (GTK_ADJUSTMENT (widget),LOWER,UPPER);
    
    if (GTK_ADJUSTMENT (widget)->value != value)
    {
        TEST_FAIL ("Value is not updated",NULL)
    }
    
    
    gtk_object_destroy(widget);
    #undef VALUE
    #undef LOWER
    #undef UPPER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_clamp_page 
 * Params: GtkAdjustment *adjustment, gdouble lower, gdouble upper
 * Returns: void
 * Assertion: If the range is larger than the page size, then only the start of it will be in the current page.
 * Params Values:  GtkAdjustment *adjustment, 10.0, 30.0
 * Expected: void  
 */
static void test_purpose_68()
{
    #define VALUE 1.0
    #define LOWER 10.0
    #define UPPER 30.0
    
    GtkObject *widget;
    gdouble lower;
    gdouble upper;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    lower = LOWER;
    upper = UPPER;
    value = VALUE;
    
    widget = gtk_adjustment_new (VALUE, 1.0, 5.0, 5.0, 20.0, 0.0);
    
    if(lower > GTK_ADJUSTMENT (widget)->upper) 
      lower = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(lower < GTK_ADJUSTMENT (widget)->lower)  
      lower = GTK_ADJUSTMENT (widget)->lower; 
     else lower = lower;
    
    if(upper > GTK_ADJUSTMENT (widget)->upper) 
      upper = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(upper < GTK_ADJUSTMENT (widget)->lower)  
      upper = GTK_ADJUSTMENT (widget)->lower; 
     else upper = upper;
    
    if (value + GTK_ADJUSTMENT (widget)->page_size < upper)
      value = upper - GTK_ADJUSTMENT (widget)->page_size;
    if (value > lower)
      value = lower;
    
    gtk_adjustment_clamp_page (GTK_ADJUSTMENT (widget),LOWER,UPPER);
    
    if (GTK_ADJUSTMENT (widget)->value != value)
    {
        TEST_FAIL ("Value is not updated",NULL)
    }
    
    
    gtk_object_destroy(widget);
    #undef VALUE
    #undef LOWER
    #undef UPPER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_clamp_page 
 * Params: GtkAdjustment *adjustment, gdouble lower, gdouble upper
 * Returns: void
 * Assertion: If the range is larger than the page size, then only the start of it will be in the current page.
 * Params Values:  GtkAdjustment *adjustment, 10.0, 30.0
 * Expected: void  
 */
static void test_purpose_69()
{
    #define VALUE 100.0
    #define LOWER 10.0
    #define UPPER 30.0
    
    GtkObject *widget;
    gdouble lower;
    gdouble upper;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    lower = LOWER;
    upper = UPPER;
    value = VALUE;
    
    widget = gtk_adjustment_new (VALUE, 1.0, 5.0, 5.0, 20.0, 0.0);
    
    if(lower > GTK_ADJUSTMENT (widget)->upper) 
      lower = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(lower < GTK_ADJUSTMENT (widget)->lower)  
      lower = GTK_ADJUSTMENT (widget)->lower; 
     else lower = lower;
    
    if(upper > GTK_ADJUSTMENT (widget)->upper) 
      upper = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(upper < GTK_ADJUSTMENT (widget)->lower)  
      upper = GTK_ADJUSTMENT (widget)->lower; 
     else upper = upper;
    
    if (value + GTK_ADJUSTMENT (widget)->page_size < upper)
      value = upper - GTK_ADJUSTMENT (widget)->page_size;
    if (value > lower)
      value = lower;
    
    gtk_adjustment_clamp_page (GTK_ADJUSTMENT (widget),LOWER,UPPER);
    
    if (GTK_ADJUSTMENT (widget)->value != value)
    {
        TEST_FAIL ("Value is not updated",NULL)
    }
    
    
    gtk_object_destroy(widget);
    #undef VALUE
    #undef LOWER
    #undef UPPER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_clamp_page 
 * Params: GtkAdjustment *adjustment, gdouble lower, gdouble upper
 * Returns: void
 * Assertion: If the range is larger than the page size, then only the start of it will be in the current page.
 * Params Values:  GtkAdjustment *adjustment, 10.0, 1000.0
 * Expected: void  
 */
static void test_purpose_70()
{
    #define VALUE 1.0
    #define LOWER 10.0
    #define UPPER 1000.0
    
    GtkObject *widget;
    gdouble lower;
    gdouble upper;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    lower = LOWER;
    upper = UPPER;
    value = VALUE;
    
    widget = gtk_adjustment_new (VALUE, 1.0, 5.0, 5.0, 20.0, 0.0);
    
    if(lower > GTK_ADJUSTMENT (widget)->upper) 
      lower = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(lower < GTK_ADJUSTMENT (widget)->lower)  
      lower = GTK_ADJUSTMENT (widget)->lower; 
     else lower = lower;
    
    if(upper > GTK_ADJUSTMENT (widget)->upper) 
      upper = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(upper < GTK_ADJUSTMENT (widget)->lower)  
      upper = GTK_ADJUSTMENT (widget)->lower; 
     else upper = upper;
    
    if (value + GTK_ADJUSTMENT (widget)->page_size < upper)
      value = upper - GTK_ADJUSTMENT (widget)->page_size;
    if (value > lower)
      value = lower;
    
    gtk_adjustment_clamp_page (GTK_ADJUSTMENT (widget),LOWER,UPPER);
    
    if (GTK_ADJUSTMENT (widget)->value != value)
    {
        TEST_FAIL ("Value is not updated",NULL)
    }
    
    
    gtk_object_destroy(widget);
    #undef VALUE
    #undef LOWER
    #undef UPPER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_clamp_page 
 * Params: GtkAdjustment *adjustment, gdouble lower, gdouble upper
 * Returns: void
 * Assertion: If the range is larger than the page size, then only the start of it will be in the current page.
 * Params Values:  GtkAdjustment *adjustment, 10.0, 1000.0
 * Expected: void  
 */
static void test_purpose_71()
{
    #define VALUE 1.0
    #define LOWER 10.0
    #define UPPER 1000.0
    
    GtkObject *widget;
    gdouble lower;
    gdouble upper;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    lower = LOWER;
    upper = UPPER;
    value = VALUE;
    
    widget = gtk_adjustment_new (VALUE, 1.0, 5.0, 5.0, 20.0, 0.0);
    
    if(lower > GTK_ADJUSTMENT (widget)->upper) 
      lower = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(lower < GTK_ADJUSTMENT (widget)->lower)  
      lower = GTK_ADJUSTMENT (widget)->lower; 
     else lower = lower;
    
    if(upper > GTK_ADJUSTMENT (widget)->upper) 
      upper = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(upper < GTK_ADJUSTMENT (widget)->lower)  
      upper = GTK_ADJUSTMENT (widget)->lower; 
     else upper = upper;
    
    if (value + GTK_ADJUSTMENT (widget)->page_size < upper)
      value = upper - GTK_ADJUSTMENT (widget)->page_size;
    if (value > lower)
      value = lower;
    
    gtk_adjustment_clamp_page (GTK_ADJUSTMENT (widget),LOWER,UPPER);
    
    if (GTK_ADJUSTMENT (widget)->value != value)
    {
        TEST_FAIL ("Value is not updated",NULL)
    }
    
    
    gtk_object_destroy(widget);
    #undef VALUE
    #undef LOWER
    #undef UPPER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_clamp_page 
 * Params: GtkAdjustment *adjustment, gdouble lower, gdouble upper
 * Returns: void
 * Assertion: If the range is larger than the page size, then only the start of it will be in the current page.
 * Params Values:  GtkAdjustment *adjustment, 10.0, 1000.0
 * Expected: void  
 */
static void test_purpose_72()
{
    #define VALUE 100.0
    #define LOWER 10.0
    #define UPPER 1000.0
    
    GtkObject *widget;
    gdouble lower;
    gdouble upper;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    lower = LOWER;
    upper = UPPER;
    value = VALUE;
    
    widget = gtk_adjustment_new (VALUE, 1.0, 5.0, 5.0, 20.0, 0.0);
    
    if(lower > GTK_ADJUSTMENT (widget)->upper) 
      lower = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(lower < GTK_ADJUSTMENT (widget)->lower)  
      lower = GTK_ADJUSTMENT (widget)->lower; 
     else lower = lower;
    
    if(upper > GTK_ADJUSTMENT (widget)->upper) 
      upper = GTK_ADJUSTMENT (widget)->upper;
    else 
     if(upper < GTK_ADJUSTMENT (widget)->lower)  
      upper = GTK_ADJUSTMENT (widget)->lower; 
     else upper = upper;
    
    if (value + GTK_ADJUSTMENT (widget)->page_size < upper)
      value = upper - GTK_ADJUSTMENT (widget)->page_size;
    if (value > lower)
      value = lower;
    
    gtk_adjustment_clamp_page (GTK_ADJUSTMENT (widget),LOWER,UPPER);
    
    if (GTK_ADJUSTMENT (widget)->value != value)
    {
        TEST_FAIL ("Value is not updated",NULL)
    }
    
    
    gtk_object_destroy(widget);
    #undef VALUE
    #undef LOWER
    #undef UPPER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_clamp_page 
 * Params: GtkAdjustment *adjustment, gdouble lower, gdouble upper
 * Returns: void
 * Assertion: A "changed" signal will be emitted if the value is changed.
 * Params Values:  GtkAdjustment *adjustment, 4.0, 17.0
 * Expected: void  
 */
static void test_purpose_73()
{
    #define VALUE 5.0
    #define LOWER 4.0
    #define UPPER 17.0
    
    GtkObject *widget;
    gdouble lower;
    gdouble upper;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    widget = gtk_adjustment_new (VALUE, 1.0, 5.0, 5.0, 20.0, 0.0);
    
    g_signal_connect (G_OBJECT (widget), "value_changed", 
                        GTK_SIGNAL_FUNC (global_changed_signal), NULL);
    
    gtk_adjustment_clamp_page (GTK_ADJUSTMENT (widget),LOWER,UPPER);
    
    
    if (global_counter == 0)
    {
        TEST_FAIL ("GtkAdjustment widget should emit 'changed' signal", NULL);
    }
    
    gtk_object_destroy(widget);
    #undef VALUE
    #undef LOWER
    #undef UPPER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_clamp_page 
 * Params: GtkAdjustment *adjustment, gdouble lower, gdouble upper
 * Returns: void
 * Assertion: A "changed" signal will be emitted if the value is changed.
 * Params Values:  GtkAdjustment *adjustment, 1.0, 37.0
 * Expected: void  
 */
static void test_purpose_74()
{
    #define VALUE 20.0
    #define LOWER 1.0
    #define UPPER 37.0
    
    GtkObject *widget;
    gdouble lower;
    gdouble upper;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    widget = gtk_adjustment_new (VALUE, 1.0, 5.0, 5.0, 20.0, 0.0);
    
    g_signal_connect (G_OBJECT (widget), "value_changed", 
                        GTK_SIGNAL_FUNC (global_changed_signal), NULL);
    
    gtk_adjustment_clamp_page (GTK_ADJUSTMENT (widget),LOWER,UPPER);
    
    
    if (global_counter == 0)
    {
        TEST_FAIL ("GtkAdjustment widget should emit 'changed' signal", NULL);
    }
    
    gtk_object_destroy(widget);
    #undef VALUE
    #undef LOWER
    #undef UPPER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_adjustment_clamp_page 
 * Params: GtkAdjustment *adjustment, gdouble lower, gdouble upper
 * Returns: void
 * Assertion: A "changed" signal will be emitted if the value is changed.
 * Params Values:  GtkAdjustment *adjustment, 1.0, 1000.0
 * Expected: void  
 */
static void test_purpose_75()
{
    #define VALUE 2.0
    #define LOWER 1.0
    #define UPPER 1000.0
    
    GtkObject *widget;
    gdouble lower;
    gdouble upper;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    widget = gtk_adjustment_new (VALUE, 1.0, 5.0, 5.0, 20.0, 0.0);
    
    g_signal_connect (G_OBJECT (widget), "value_changed", 
                        GTK_SIGNAL_FUNC (global_changed_signal), NULL);
    
    gtk_adjustment_clamp_page (GTK_ADJUSTMENT (widget),LOWER,UPPER);
    
    
    if (global_counter == 0)
    {
        TEST_FAIL ("GtkAdjustment widget should emit 'changed' signal", NULL);
    }
    
    gtk_object_destroy(widget);
    #undef VALUE
    #undef LOWER
    #undef UPPER
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkAdjustment ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {test_purpose_52, 1},
    {test_purpose_53, 1},
    {test_purpose_54, 1},
    {test_purpose_55, 1},
    {test_purpose_56, 1},
    {test_purpose_57, 1},
    {test_purpose_58, 1},
    {test_purpose_59, 1},
    {test_purpose_60, 1},
    {test_purpose_61, 1},
    {test_purpose_62, 1},
    {test_purpose_63, 1},
    {test_purpose_64, 1},
    {test_purpose_65, 1},
    {test_purpose_66, 1},
    {test_purpose_67, 1},
    {test_purpose_68, 1},
    {test_purpose_69, 1},
    {test_purpose_70, 1},
    {test_purpose_71, 1},
    {test_purpose_72, 1},
    {test_purpose_73, 1},
    {test_purpose_74, 1},
    {test_purpose_75, 1},
    {NULL,0}
};
