/*
 * GtkCellRendererToggle methods tests
 * Testing GtkCellRendererToggle methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name:   gtk_cell_renderer_toggle_new
 * Params: void
 * Returns: GtkCellRenderer* 
 * Assertion: Creates a new GtkCellRendererToggle.
 * Params Values: void
 * Expected: GtkCellRendererToggle*  
 */
static void test_purpose_1()
{
    GtkCellRenderer* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_cell_renderer_toggle_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER_TOGGLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    gtk_object_destroy (GTK_OBJECT (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_cell_renderer_toggle_get_active
 * Params: GtkCellRendererToggle *toggle
 * Returns: gboolean
 * Assertion: Returns whether the cell renderer is active.
 * Params Values: a newly created GtkCellRendererToggle
 * Expected: void
 * 
 * Name:  gtk_cell_renderer_toggle_set_active
 * Params: GtkCellRendererToggle *toggle, gboolean setting
 * Returns: void
 * Assertion: Activates or deactivates a cell renderer.
 * Params Values: a newly created GtkCellRendererToggle*, TRUE
 * Expected: void  
 */
static void test_purpose_2()
{
    #define SETTING  TRUE
    
    GtkCellRenderer* widget;
    gboolean setting;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_cell_renderer_toggle_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER_TOGGLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_cell_renderer_toggle_set_active(GTK_CELL_RENDERER_TOGGLE (widget), SETTING);
    
    setting = gtk_cell_renderer_toggle_get_active(GTK_CELL_RENDERER_TOGGLE (widget));
    if (setting != SETTING)
    {
        TEST_FAIL ("setting = %d, should be %d", setting, SETTING);
    }
    
    gtk_object_destroy (GTK_OBJECT (widget));
    
    #undef SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_cell_renderer_toggle_get_active
 * Params: GtkCellRendererToggle *toggle
 * Returns: gboolean
 * Assertion: Returns whether the cell renderer is active.
 * Params Values: a newly created GtkCellRendererToggle
 * Expected: void
 * 
 * Name:  gtk_cell_renderer_toggle_set_active
 * Params: GtkCellRendererToggle *toggle, gboolean setting
 * Returns: void
 * Assertion: Activates or deactivates a cell renderer.
 * Params Values: a newly created GtkCellRendererToggle*, FALSE
 * Expected: void  
 */
static void test_purpose_3()
{
    #define SETTING  FALSE
    
    GtkCellRenderer* widget;
    gboolean setting;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_cell_renderer_toggle_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER_TOGGLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_cell_renderer_toggle_set_active(GTK_CELL_RENDERER_TOGGLE (widget), SETTING);
    
    setting = gtk_cell_renderer_toggle_get_active(GTK_CELL_RENDERER_TOGGLE (widget));
    if (setting != SETTING)
    {
        TEST_FAIL ("setting = %d, should be %d", setting, SETTING);
    }
    
    gtk_object_destroy (GTK_OBJECT (widget));
    
    #undef SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_cell_renderer_toggle_get_radio
 * Params: GtkCellRendererToggle *toggle
 * Returns: gboolean
 * Assertion: Returns wether we're rendering radio toggles rather than checkboxes.
 * Params Values: a newly created GtkCellRendererToggle
 * Expected: gboolean
 * 
 * Name:  gtk_cell_renderer_toggle_set_radio
 * Params: GtkCellRendererToggle *toggle, gboolean radio
 * Returns: void
 * Assertion: If radio is TRUE, the cell renderer renders a radio toggle (i.e. a toggle in a group of mutually-exclusive toggles).
 * Params Values: a newly created GtkCellRendererToggle*, TRUE
 * Expected: void
 * 
 * Name:  gtk_cell_renderer_toggle_set_radio
 * Params: GtkCellRendererToggle *toggle, gboolean radio
 * Returns: void
 * Assertion: If FALSE, it renders a check toggle (a standalone boolean option).
 * Params Values: a newly created GtkCellRendererToggle*, TRUE
 * Expected: void  
 */
static void test_purpose_4()
{
    #define RADIO  TRUE
    
    GtkCellRenderer* widget;
    gboolean radio;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_cell_renderer_toggle_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER_TOGGLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_cell_renderer_toggle_set_radio(GTK_CELL_RENDERER_TOGGLE (widget), RADIO);
    
    radio = gtk_cell_renderer_toggle_get_radio(GTK_CELL_RENDERER_TOGGLE (widget));
    if (radio != RADIO)
    {
        TEST_FAIL ("radio = %d, should be %d", radio, RADIO);
    }
    
    gtk_object_destroy (GTK_OBJECT (widget));
    
    #undef RADIO
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_cell_renderer_toggle_get_radio
 * Params: GtkCellRendererToggle *toggle
 * Returns: gboolean
 * Assertion: Returns wether we're rendering radio toggles rather than checkboxes.
 * Params Values: a newly created GtkCellRendererToggle
 * Expected: gboolean
 * 
 * Name:  gtk_cell_renderer_toggle_set_radio
 * Params: GtkCellRendererToggle *toggle, gboolean radio
 * Returns: void
 * Assertion: If radio is TRUE, the cell renderer renders a radio toggle (i.e. a toggle in a group of mutually-exclusive toggles).
 * Params Values: a newly created GtkCellRendererToggle*, FALSE
 * Expected: void
 * 
 * Name:  gtk_cell_renderer_toggle_set_radio
 * Params: GtkCellRendererToggle *toggle, gboolean radio
 * Returns: void
 * Assertion: If FALSE, it renders a check toggle (a standalone boolean option).
 * Params Values: a newly created GtkCellRendererToggle*, FALSE
 * Expected: void  
 */
static void test_purpose_5()
{
    #define RADIO  FALSE
    
    GtkCellRenderer* widget;
    gboolean radio;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_cell_renderer_toggle_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER_TOGGLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_cell_renderer_toggle_set_radio(GTK_CELL_RENDERER_TOGGLE (widget), RADIO);
    
    radio = gtk_cell_renderer_toggle_get_radio(GTK_CELL_RENDERER_TOGGLE (widget));
    if (radio != RADIO)
    {
        TEST_FAIL ("radio = %d, should be %d", radio, RADIO);
    }
    
    gtk_object_destroy (GTK_OBJECT (widget));
    
    #undef RADIO
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkCellRendererToggle ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {NULL,0}
};
