/*
 * GtkCheckButton methods tests
 * Testing GtkCheckButton methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_check_button_new
 * Params: void
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckButton.
 * Params Values: void
 * Expected: GtkCheckButton*  
 */
static void test_purpose_1()
{
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_button_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_CHECK_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_button_new_with_label
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckButton with a GtkLabel to the right of it.
 * Params Values: NULL
 * Expected: GtkCheckButton*  
 */
static void test_purpose_2()
{
    #define LABEL NULL
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_button_new_with_label (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_CHECK_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_button_new_with_label
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckButton with a GtkLabel to the right of it.
 * Params Values: ""
 * Expected: GtkCheckButton*  
 */
static void test_purpose_3()
{
    #define LABEL ""
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_button_new_with_label (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_CHECK_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_button_new_with_label
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckButton with a GtkLabel to the right of it.
 * Params Values: " "
 * Expected: GtkCheckButton*  
 */
static void test_purpose_4()
{
    #define LABEL " "
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_button_new_with_label (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_CHECK_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_button_new_with_label
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckButton with a GtkLabel to the right of it.
 * Params Values: "   "
 * Expected: GtkCheckButton*  
 */
static void test_purpose_5()
{
    #define LABEL "   "
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_button_new_with_label (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_CHECK_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_button_new_with_label
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckButton with a GtkLabel to the right of it.
 * Params Values: "Label String"
 * Expected: GtkCheckButton*  
 */
static void test_purpose_6()
{
    #define LABEL "Label String"
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_button_new_with_label (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_CHECK_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_button_new_with_label
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckButton with a GtkLabel to the right of it.
 * Params Values: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: GtkCheckButton*  
 */
static void test_purpose_7()
{
    #define LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_button_new_with_label (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_CHECK_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_button_new_with_label
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckButton with a GtkLabel to the right of it.
 * Params Values: "!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: GtkCheckButton*  
 */
static void test_purpose_8()
{
    #define LABEL "!@#$%^&*()_+|~=\";:'?<>`/"
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_button_new_with_label (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_CHECK_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_button_new_with_label
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckButton with a GtkLabel to the right of it.
 * Params Values: "_a_b"
 * Expected: GtkCheckButton*  
 */
static void test_purpose_9()
{
    #define LABEL "_a_b"
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_button_new_with_label (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_CHECK_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_button_new_with_label
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckButton with a GtkLabel to the right of it.
 * Params Values: "\n\t\""
 * Expected: GtkCheckButton*  
 */
static void test_purpose_10()
{
    #define LABEL "\n\t\""
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_button_new_with_label (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_CHECK_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_button_new_with_label
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckButton with a GtkLabel to the right of it.
 * Params Values: "_\n\t\""
 * Expected: GtkCheckButton*  
 */
static void test_purpose_11()
{
    #define LABEL "_\n\t\""
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_button_new_with_label (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_CHECK_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_button_new_with_label
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckButton with a GtkLabel to the right of it.
 * Params Values: "\b"
 * Expected: GtkCheckButton*  
 */
static void test_purpose_12()
{
    #define LABEL "\b"
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_button_new_with_label (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_CHECK_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_button_new_with_label
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckButton with a GtkLabel to the right of it.
 * Params Values: "_\b"
 * Expected: GtkCheckButton*  
 */
static void test_purpose_13()
{
    #define LABEL "_\b"
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_button_new_with_label (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_CHECK_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckButton containing a label.
 * Params Values: NULL
 * Expected: GtkCheckButton*  
 */
static void test_purpose_14()
{
    #define LABEL NULL
    #define CORRECT_LABEL NULL
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_CHECK_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckButton containing a label.
 * Params Values: ""
 * Expected: GtkCheckButton*  
 */
static void test_purpose_15()
{
    #define LABEL ""
    #define CORRECT_LABEL ""
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_CHECK_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckButton containing a label.
 * Params Values: " "
 * Expected: GtkCheckButton*  
 */
static void test_purpose_16()
{
    #define LABEL " "
    #define CORRECT_LABEL " "
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_CHECK_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckButton containing a label.
 * Params Values: "_ "
 * Expected: GtkCheckButton*  
 */
static void test_purpose_17()
{
    #define LABEL "_ "
    #define CORRECT_LABEL " "
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_CHECK_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckButton containing a label.
 * Params Values: "Label String"
 * Expected: GtkCheckButton*  
 */
static void test_purpose_18()
{
    #define LABEL "Label String"
    #define CORRECT_LABEL "Label String"
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_CHECK_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckButton containing a label.
 * Params Values: "Label S_tring"
 * Expected: GtkCheckButton*  
 */
static void test_purpose_19()
{
    #define LABEL "Label S_tring"
    #define CORRECT_LABEL "Label String"
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_CHECK_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckButton containing a label.
 * Params Values: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: GtkCheckButton*  
 */
static void test_purpose_20()
{
    #define LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define CORRECT_LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_CHECK_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckButton containing a label.
 * Params Values: "abcdefghi_jklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: GtkCheckButton*  
 */
static void test_purpose_21()
{
    #define LABEL "abcdefghi_jklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define CORRECT_LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_CHECK_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckButton containing a label.
 * Params Values: "!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: GtkCheckButton*  
 */
static void test_purpose_22()
{
    #define LABEL "!@#$%^&*()_+|~=\";:'?<>`/"
    #define CORRECT_LABEL "!@#$%^&*()+|~=\";:'?<>`/"
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_CHECK_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckButton containing a label.
 * Params Values: "_a_b"
 * Expected: GtkCheckButton*  
 */
static void test_purpose_23()
{
    #define LABEL "_a_b"
    #define CORRECT_LABEL "ab"
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_CHECK_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckButton containing a label.
 * Params Values: "\n\t\""
 * Expected: GtkCheckButton*  
 */
static void test_purpose_24()
{
    #define LABEL "\n\t\""
    #define CORRECT_LABEL "\n\t\""
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_CHECK_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckButton containing a label.
 * Params Values: "_\n\t\""
 * Expected: GtkCheckButton*  
 */
static void test_purpose_25()
{
    #define LABEL "_\n\t\""
    #define CORRECT_LABEL "\n\t\""
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_CHECK_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckButton containing a label.
 * Params Values: "\b"
 * Expected: GtkCheckButton*  
 */
static void test_purpose_26()
{
    #define LABEL "\b"
    #define CORRECT_LABEL "\b"
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_CHECK_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckButton containing a label.
 * Params Values: "_\b"
 * Expected: GtkCheckButton*  
 */
static void test_purpose_27()
{
    #define LABEL "_\b"
    #define CORRECT_LABEL "\b"
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_CHECK_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkCheckButton ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {NULL,0}
};
