/*
 * GtkMenu methods tests
 * Testing GtkMenu methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

gint global_counter;

void global_attach_func (GtkWidget *attach_widget, GtkMenu *menu)
{
    global_counter++;
}

void global_pos_func (GtkMenu *menu,gint *x,gint *y,gboolean *push_in,gpointer user_data)
{
    global_counter++;
}

/*
 * Name: gtk_menu_new
 * Params: void
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkMenu.
 * Params Values: void
 * Expected: GtkMenu*  
 */
static void test_purpose_1()
{
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_widget_show (widget);
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_set_accel_group
 * Params: GtkMenu *menu, GtkAccelGroup *accel_group
 * Returns: void
 * Assertion: Set the GtkAccelGroup which holds global accelerators for the menu.
 * Params Values: GtkMenu *menu, gtk_accel_group_new ()
 * Expected: void
 * 
 * Name: gtk_menu_get_accel_group
 * Params: GtkMenu *menu
 * Returns: GtkAccelGroup *accel_group
 * Assertion: Gets the GtkAccelGroup which holds global accelerators for the menu.
 * Params Values: GtkMenu *menu
 * Expected: gtk_accel_group_new ()  
 */
static void test_purpose_2()
{
    #define  ACCEL_GROUP gtk_accel_group_new ()
    
    GtkWidget *widget;
    GtkAccelGroup *accel_group;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    gtk_widget_show (widget);
    
    accel_group = ACCEL_GROUP;
    gtk_menu_set_accel_group (GTK_MENU (widget), accel_group);
    if (accel_group != gtk_menu_get_accel_group (GTK_MENU (widget)))
    {
        TEST_FAIL ("Accel group fails", NULL);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef ACCEL_GROUP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_set_active
 * Params: GtkMenu *menu, guint index
 * Returns: void
 * Assertion: Selects the specified menu item within the menu.
 * Params Values: GtkMenu *menu, 10
 * Expected: void
 * 
 * Name: gtk_menu_get_active
 * Params: GtkMenu *menu
 * Returns: GtkWidget*
 * Assertion: Returns the selected menu item from the menu.
 * Params Values: GtkMenu *menu
 * Expected: GtkWidget*  
 */
static void test_purpose_3()
{
    #define  COUNT 10
    #define  INDEX 1
    
    GtkWidget *widget;
    GtkWidget* items[COUNT];
    gint i;
    gchar buff[100];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    gtk_widget_show (widget);
    
    for (i = 0; i < COUNT; i++) 
    {
        sprintf(buff, "Item %i", i);
        items[i] = gtk_menu_item_new_with_label(buff);
        gtk_menu_shell_append ((GtkMenuShell *)GTK_MENU_SHELL (widget), items[i]);
        gtk_widget_show (items[i]);
    }
    
    gtk_menu_set_active(GTK_MENU (widget), INDEX);
    if (items[INDEX] != gtk_menu_get_active(GTK_MENU (widget)))
    {
        TEST_FAIL("Active item fails", NULL);
    }
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef COUNT
    #undef INDEX
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_set_active
 * Params: GtkMenu *menu, guint index
 * Returns: void
 * Assertion: Selects the specified menu item within the menu.
 * Params Values: GtkMenu *menu, 10
 * Expected: void
 * 
 * Name: gtk_menu_get_active
 * Params: GtkMenu *menu
 * Returns: GtkWidget*
 * Assertion: Returns the selected menu item from the menu.
 * Params Values: GtkMenu *menu
 * Expected: GtkWidget*  
 */
static void test_purpose_4()
{
    #define  COUNT 10
    #define  INDEX 5
    
    GtkWidget *widget;
    GtkWidget* items[COUNT];
    gint i;
    gchar buff[100];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    gtk_widget_show (widget);
    
    for (i = 0; i < COUNT; i++) 
    {
        sprintf(buff, "Item %i", i);
        items[i] = gtk_menu_item_new_with_label(buff);
        gtk_menu_shell_append ((GtkMenuShell *)GTK_MENU_SHELL (widget), items[i]);
        gtk_widget_show (items[i]);
    }
    
    gtk_menu_set_active(GTK_MENU (widget), INDEX);
    if (items[INDEX] != gtk_menu_get_active(GTK_MENU (widget)))
    {
        TEST_FAIL("Active item fails", NULL);
    }
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef COUNT
    #undef INDEX
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_set_active
 * Params: GtkMenu *menu, guint index
 * Returns: void
 * Assertion: Selects the specified menu item within the menu.
 * Params Values: GtkMenu *menu, 10
 * Expected: void
 * 
 * Name: gtk_menu_get_active
 * Params: GtkMenu *menu
 * Returns: GtkWidget*
 * Assertion: Returns the selected menu item from the menu.
 * Params Values: GtkMenu *menu
 * Expected: GtkWidget*  
 */
static void test_purpose_5()
{
    #define  COUNT 10
    #define  INDEX 5
    
    GtkWidget *widget;
    GtkWidget* items[COUNT];
    gint i;
    gchar buff[100];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    gtk_widget_show (widget);
    
    for (i = 0; i < COUNT; i++) 
    {
        sprintf(buff, "Item %i", i);
        items[i] = gtk_menu_item_new_with_label(buff);
        gtk_menu_shell_append ((GtkMenuShell *)GTK_MENU_SHELL (widget), items[i]);
        gtk_widget_show (items[i]);
    }
    
    gtk_menu_set_active(GTK_MENU (widget), INDEX);
    if (items[INDEX] != gtk_menu_get_active(GTK_MENU (widget)))
    {
        TEST_FAIL("Active item fails", NULL);
    }
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef COUNT
    #undef INDEX
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_set_active
 * Params: GtkMenu *menu, guint index
 * Returns: void
 * Assertion: Selects the specified menu item within the menu.
 * Params Values: GtkMenu *menu, 1000
 * Expected: void
 * 
 * Name: gtk_menu_get_active
 * Params: GtkMenu *menu
 * Returns: GtkWidget*
 * Assertion: Returns the selected menu item from the menu.
 * Params Values: GtkMenu *menu
 * Expected: GtkWidget*  
 */
static void test_purpose_6()
{
    #define  COUNT 1000
    #define  INDEX 999
    
    GtkWidget *widget;
    GtkWidget* items[COUNT];
    gint i;
    gchar buff[100];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    gtk_widget_show (widget);
    
    for (i = 0; i < COUNT; i++) 
    {
        sprintf(buff, "Item %i", i);
        items[i] = gtk_menu_item_new_with_label(buff);
        gtk_menu_shell_append ((GtkMenuShell *)GTK_MENU_SHELL (widget), items[i]);
        gtk_widget_show (items[i]);
    }
    
    gtk_menu_set_active(GTK_MENU (widget), INDEX);
    if (items[INDEX] != gtk_menu_get_active(GTK_MENU (widget)))
    {
        TEST_FAIL("Active item fails", NULL);
    }
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef COUNT
    #undef INDEX
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_set_title
 * Params: GtkMenu *menu, const gchar *title
 * Returns: void
 * Assertion: Sets the title string for the menu.
 * Params Values: GtkMenu *menu, "Text"
 * Expected: void  
 */
static void test_purpose_7()
{
    #define  TITLE "Text"
    
    GtkWidget *widget;
    gchar* real_title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_menu_set_title (GTK_MENU (widget), TITLE);
    g_object_get (GTK_OBJECT (widget), "tearoff-title", &real_title, NULL);
    
    gtk_widget_show (widget);
    
    if (!TITLE)
    {
        if (real_title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    
    } else if (strcmp (real_title, (gchar*) TITLE)) {
    
        TEST_FAIL ("real_title is '%s', should be '%s'", 
                   real_title, (gchar*) TITLE);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_set_title
 * Params: GtkMenu *menu, const gchar *title
 * Returns: void
 * Assertion: Sets the title string for the menu.
 * Params Values: GtkMenu *menu, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890" 
 * Expected: void  
 */
static void test_purpose_8()
{
    #define  TITLE "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890" 
    
    GtkWidget *widget;
    gchar* real_title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_menu_set_title (GTK_MENU (widget), TITLE);
    g_object_get (GTK_OBJECT (widget), "tearoff-title", &real_title, NULL);
    
    gtk_widget_show (widget);
    
    if (!TITLE)
    {
        if (real_title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    
    } else if (strcmp (real_title, (gchar*) TITLE)) {
    
        TEST_FAIL ("real_title is '%s', should be '%s'", 
                   real_title, (gchar*) TITLE);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_set_title
 * Params: GtkMenu *menu, const gchar *title
 * Returns: void
 * Assertion: Sets the title string for the menu.
 * Params Values: GtkMenu *menu, "!@#$%^&*()_+|~=\";:'?<>`/" 
 * Expected: void  
 */
static void test_purpose_9()
{
    #define  TITLE "!@#$%^&*()_+|~=\";:'?<>`/" 
    
    GtkWidget *widget;
    gchar* real_title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_menu_set_title (GTK_MENU (widget), TITLE);
    g_object_get (GTK_OBJECT (widget), "tearoff-title", &real_title, NULL);
    
    gtk_widget_show (widget);
    
    if (!TITLE)
    {
        if (real_title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    
    } else if (strcmp (real_title, (gchar*) TITLE)) {
    
        TEST_FAIL ("real_title is '%s', should be '%s'", 
                   real_title, (gchar*) TITLE);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_set_title
 * Params: GtkMenu *menu, const gchar *title
 * Returns: void
 * Assertion: Sets the title string for the menu.
 * Params Values: GtkMenu *menu, "" 
 * Expected: void  
 */
static void test_purpose_10()
{
    #define  TITLE "" 
    
    GtkWidget *widget;
    gchar* real_title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_menu_set_title (GTK_MENU (widget), TITLE);
    g_object_get (GTK_OBJECT (widget), "tearoff-title", &real_title, NULL);
    
    gtk_widget_show (widget);
    
    if (!TITLE)
    {
        if (real_title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    
    } else if (strcmp (real_title, (gchar*) TITLE)) {
    
        TEST_FAIL ("real_title is '%s', should be '%s'", 
                   real_title, (gchar*) TITLE);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_set_title
 * Params: GtkMenu *menu, const gchar *title
 * Returns: void
 * Assertion: Sets the title string for the menu.
 * Params Values: GtkMenu *menu, " " 
 * Expected: void  
 */
static void test_purpose_11()
{
    #define  TITLE " " 
    
    GtkWidget *widget;
    gchar* real_title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_menu_set_title (GTK_MENU (widget), TITLE);
    g_object_get (GTK_OBJECT (widget), "tearoff-title", &real_title, NULL);
    
    gtk_widget_show (widget);
    
    if (!TITLE)
    {
        if (real_title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    
    } else if (strcmp (real_title, (gchar*) TITLE)) {
    
        TEST_FAIL ("real_title is '%s', should be '%s'", 
                   real_title, (gchar*) TITLE);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_set_title
 * Params: GtkMenu *menu, const gchar *title
 * Returns: void
 * Assertion: Sets the title string for the menu.
 * Params Values: GtkMenu *menu, "   " 
 * Expected: void  
 */
static void test_purpose_12()
{
    #define  TITLE "   " 
    
    GtkWidget *widget;
    gchar* real_title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_menu_set_title (GTK_MENU (widget), TITLE);
    g_object_get (GTK_OBJECT (widget), "tearoff-title", &real_title, NULL);
    
    gtk_widget_show (widget);
    
    if (!TITLE)
    {
        if (real_title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    
    } else if (strcmp (real_title, (gchar*) TITLE)) {
    
        TEST_FAIL ("real_title is '%s', should be '%s'", 
                   real_title, (gchar*) TITLE);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_set_title
 * Params: GtkMenu *menu, const gchar *title
 * Returns: void
 * Assertion: Sets the title string for the menu.
 * Params Values: GtkMenu *menu, "Text"
 * Expected: void  
 */
static void test_purpose_13()
{
    #define  TITLE "Text"
    
    GtkWidget *widget;
    gchar* real_title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_menu_set_title (GTK_MENU (widget), TITLE);
    g_object_get (GTK_OBJECT (widget), "tearoff-title", &real_title, NULL);
    
    gtk_widget_show (widget);
    
    if (!TITLE)
    {
        if (real_title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    
    } else if (strcmp (real_title, (gchar*) TITLE)) {
    
        TEST_FAIL ("real_title is '%s', should be '%s'", 
                   real_title, (gchar*) TITLE);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_set_title
 * Params: GtkMenu *menu, const gchar *title
 * Returns: void
 * Assertion: Sets the title string for the menu.
 * Params Values: GtkMenu *menu, "\b\n\t" 
 * Expected: void  
 */
static void test_purpose_14()
{
    #define  TITLE "\b\n\t" 
    
    GtkWidget *widget;
    gchar* real_title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_menu_set_title (GTK_MENU (widget), TITLE);
    g_object_get (GTK_OBJECT (widget), "tearoff-title", &real_title, NULL);
    
    gtk_widget_show (widget);
    
    if (!TITLE)
    {
        if (real_title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    
    } else if (strcmp (real_title, (gchar*) TITLE)) {
    
        TEST_FAIL ("real_title is '%s', should be '%s'", 
                   real_title, (gchar*) TITLE);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_set_title
 * Params: GtkMenu *menu, const gchar *title
 * Returns: void
 * Assertion: Sets the title string for the menu.
 * Params Values: GtkMenu *menu, NULL
 * Expected: void  
 */
static void test_purpose_15()
{
    #define  TITLE NULL
    
    GtkWidget *widget;
    gchar* real_title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_menu_set_title (GTK_MENU (widget), TITLE);
    g_object_get (GTK_OBJECT (widget), "tearoff-title", &real_title, NULL);
    
    gtk_widget_show (widget);
    
    if (!TITLE)
    {
        if (real_title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    
    } else if (strcmp (real_title, (gchar*) TITLE)) {
    
        TEST_FAIL ("real_title is '%s', should be '%s'", 
                   real_title, (gchar*) TITLE);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_get_title
 * Params: GtkMenu *menu
 * Returns: G_CONST_RETURN gchar *title
 * Assertion: Returns the title of the menu.
 * Params Values: GtkMenu *menu
 * Expected: "Text"  
 */
static void test_purpose_16()
{
    #define  TITLE "Text"
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    g_object_set (GTK_OBJECT (widget), "tearoff-title", TITLE , NULL);
    real_title = gtk_menu_get_title (GTK_MENU (widget));
    
    gtk_widget_show (widget);
    
    if (!TITLE)
    {
        if (real_title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    
    } else if (strcmp (real_title, (gchar*) TITLE)) {
    
        TEST_FAIL ("real_title is '%s', should be '%s'", 
                   real_title, (gchar*) TITLE);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_get_title
 * Params: GtkMenu *menu
 * Returns: G_CONST_RETURN gchar *title
 * Assertion: Returns the title of the menu.
 * Params Values: GtkMenu *menu
 * Expected: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"   
 */
static void test_purpose_17()
{
    #define  TITLE "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890" 
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    g_object_set (GTK_OBJECT (widget), "tearoff-title", TITLE , NULL);
    real_title = gtk_menu_get_title (GTK_MENU (widget));
    
    gtk_widget_show (widget);
    
    if (!TITLE)
    {
        if (real_title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    
    } else if (strcmp (real_title, (gchar*) TITLE)) {
    
        TEST_FAIL ("real_title is '%s', should be '%s'", 
                   real_title, (gchar*) TITLE);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_get_title
 * Params: GtkMenu *menu
 * Returns: G_CONST_RETURN gchar *title
 * Assertion: Returns the title of the menu.
 * Params Values: GtkMenu *menu
 * Expected: "!@#$%^&*()_+|~=\";:'?<>`/"   
 */
static void test_purpose_18()
{
    #define  TITLE "!@#$%^&*()_+|~=\";:'?<>`/" 
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    g_object_set (GTK_OBJECT (widget), "tearoff-title", TITLE , NULL);
    real_title = gtk_menu_get_title (GTK_MENU (widget));
    
    gtk_widget_show (widget);
    
    if (!TITLE)
    {
        if (real_title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    
    } else if (strcmp (real_title, (gchar*) TITLE)) {
    
        TEST_FAIL ("real_title is '%s', should be '%s'", 
                   real_title, (gchar*) TITLE);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_get_title
 * Params: GtkMenu *menu
 * Returns: G_CONST_RETURN gchar *title
 * Assertion: Returns the title of the menu.
 * Params Values: GtkMenu *menu
 * Expected: ""   
 */
static void test_purpose_19()
{
    #define  TITLE "" 
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    g_object_set (GTK_OBJECT (widget), "tearoff-title", TITLE , NULL);
    real_title = gtk_menu_get_title (GTK_MENU (widget));
    
    gtk_widget_show (widget);
    
    if (!TITLE)
    {
        if (real_title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    
    } else if (strcmp (real_title, (gchar*) TITLE)) {
    
        TEST_FAIL ("real_title is '%s', should be '%s'", 
                   real_title, (gchar*) TITLE);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_get_title
 * Params: GtkMenu *menu
 * Returns: G_CONST_RETURN gchar *title
 * Assertion: Returns the title of the menu.
 * Params Values: GtkMenu *menu
 * Expected: " "   
 */
static void test_purpose_20()
{
    #define  TITLE " " 
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    g_object_set (GTK_OBJECT (widget), "tearoff-title", TITLE , NULL);
    real_title = gtk_menu_get_title (GTK_MENU (widget));
    
    gtk_widget_show (widget);
    
    if (!TITLE)
    {
        if (real_title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    
    } else if (strcmp (real_title, (gchar*) TITLE)) {
    
        TEST_FAIL ("real_title is '%s', should be '%s'", 
                   real_title, (gchar*) TITLE);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_get_title
 * Params: GtkMenu *menu
 * Returns: G_CONST_RETURN gchar *title
 * Assertion: Returns the title of the menu.
 * Params Values: GtkMenu *menu
 * Expected: "   "   
 */
static void test_purpose_21()
{
    #define  TITLE "   " 
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    g_object_set (GTK_OBJECT (widget), "tearoff-title", TITLE , NULL);
    real_title = gtk_menu_get_title (GTK_MENU (widget));
    
    gtk_widget_show (widget);
    
    if (!TITLE)
    {
        if (real_title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    
    } else if (strcmp (real_title, (gchar*) TITLE)) {
    
        TEST_FAIL ("real_title is '%s', should be '%s'", 
                   real_title, (gchar*) TITLE);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_get_title
 * Params: GtkMenu *menu
 * Returns: G_CONST_RETURN gchar *title
 * Assertion: Returns the title of the menu.
 * Params Values: GtkMenu *menu
 * Expected: "Text"  
 */
static void test_purpose_22()
{
    #define  TITLE "Text"
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    g_object_set (GTK_OBJECT (widget), "tearoff-title", TITLE , NULL);
    real_title = gtk_menu_get_title (GTK_MENU (widget));
    
    gtk_widget_show (widget);
    
    if (!TITLE)
    {
        if (real_title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    
    } else if (strcmp (real_title, (gchar*) TITLE)) {
    
        TEST_FAIL ("real_title is '%s', should be '%s'", 
                   real_title, (gchar*) TITLE);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_get_title
 * Params: GtkMenu *menu
 * Returns: G_CONST_RETURN gchar *title
 * Assertion: Returns the title of the menu.
 * Params Values: GtkMenu *menu
 * Expected: "\b\n\t"   
 */
static void test_purpose_23()
{
    #define  TITLE "\b\n\t" 
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    g_object_set (GTK_OBJECT (widget), "tearoff-title", TITLE , NULL);
    real_title = gtk_menu_get_title (GTK_MENU (widget));
    
    gtk_widget_show (widget);
    
    if (!TITLE)
    {
        if (real_title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    
    } else if (strcmp (real_title, (gchar*) TITLE)) {
    
        TEST_FAIL ("real_title is '%s', should be '%s'", 
                   real_title, (gchar*) TITLE);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_get_title
 * Params: GtkMenu *menu
 * Returns: G_CONST_RETURN gchar *title
 * Assertion: Returns the title of the menu.
 * Params Values: GtkMenu *menu
 * Expected: NULL  
 */
static void test_purpose_24()
{
    #define  TITLE NULL
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    g_object_set (GTK_OBJECT (widget), "tearoff-title", TITLE , NULL);
    real_title = gtk_menu_get_title (GTK_MENU (widget));
    
    gtk_widget_show (widget);
    
    if (!TITLE)
    {
        if (real_title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    
    } else if (strcmp (real_title, (gchar*) TITLE)) {
    
        TEST_FAIL ("real_title is '%s', should be '%s'", 
                   real_title, (gchar*) TITLE);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TITLE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_attach_to_widget
 * Params: GtkMenu *menu, GtkWidget *attach_widget, GtkMenuDetachFunc detacher
 * Returns: void
 * Assertion: Attaches the menu to the widget and provides a callback function that will be invoked when the menu calls gtk_menu_detach() during its destruction.
 * Params Values: GtkMenu *menu, gtk_window_new (GTK_WINDOW_TOPLEVEL)
 * Expected: void
 * 
 * Name: gtk_menu_get_attach_widget
 * Params: GtkMenu *menu
 * Returns: GtkWidget*
 * Assertion: Returns the GtkWidget that the menu is attached to.
 * Params Values: GtkMenu *menu
 * Expected: GtkWidget* set by gtk_menu_attach_to_widget()  
 */
static void test_purpose_25()
{
    #define  WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    
    GtkWidget *widget;
    GtkWidget *attach_widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    
    widget = gtk_menu_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    attach_widget = WIDGET;
    gtk_menu_attach_to_widget (GTK_MENU (widget), attach_widget, global_attach_func);
    
    gtk_widget_show (widget);
    
    if (attach_widget != gtk_menu_get_attach_widget (GTK_MENU (widget)))
    {
        TEST_FAIL("attach_widget differs from the one was set", NULL);
    }
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    if (global_counter != 1)
    {
        TEST_FAIL 
            ("global_attach_func() was not called during attach_widget destrustion", 
             NULL);
    }
    #undef WIDGET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_attach_to_widget
 * Params: GtkMenu *menu, GtkWidget *attach_widget, GtkMenuDetachFunc detacher
 * Returns: void
 * Assertion: Attaches the menu to the widget and provides a callback function that will be invoked when the menu calls gtk_menu_detach() during its destruction.
 * Params Values: GtkMenu *menu, gtk_label_new (NULL)
 * Expected: void
 * 
 * Name: gtk_menu_get_attach_widget
 * Params: GtkMenu *menu
 * Returns: GtkWidget*
 * Assertion: Returns the GtkWidget that the menu is attached to.
 * Params Values: GtkMenu *menu
 * Expected: GtkWidget* set by gtk_menu_attach_to_widget()  
 */
static void test_purpose_26()
{
    #define  WIDGET gtk_label_new (NULL)
    
    GtkWidget *widget;
    GtkWidget *attach_widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    
    widget = gtk_menu_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    attach_widget = WIDGET;
    gtk_menu_attach_to_widget (GTK_MENU (widget), attach_widget, global_attach_func);
    
    gtk_widget_show (widget);
    
    if (attach_widget != gtk_menu_get_attach_widget (GTK_MENU (widget)))
    {
        TEST_FAIL("attach_widget differs from the one was set", NULL);
    }
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    if (global_counter != 1)
    {
        TEST_FAIL 
            ("global_attach_func() was not called during attach_widget destrustion", 
             NULL);
    }
    #undef WIDGET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_attach_to_widget
 * Params: GtkMenu *menu, GtkWidget *attach_widget, GtkMenuDetachFunc detacher
 * Returns: void
 * Assertion: Attaches the menu to the widget and provides a callback function that will be invoked when the menu calls gtk_menu_detach() during its destruction.
 * Params Values: GtkMenu *menu, gtk_hbox_new (TRUE, 3);
 * Expected: void
 * 
 * Name: gtk_menu_get_attach_widget
 * Params: GtkMenu *menu
 * Returns: GtkWidget*
 * Assertion: Returns the GtkWidget that the menu is attached to.
 * Params Values: GtkMenu *menu
 * Expected: GtkWidget* set by gtk_menu_attach_to_widget()  
 */
static void test_purpose_27()
{
    #define  WIDGET gtk_hbox_new (TRUE, 3);
    
    GtkWidget *widget;
    GtkWidget *attach_widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    
    widget = gtk_menu_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    attach_widget = WIDGET;
    gtk_menu_attach_to_widget (GTK_MENU (widget), attach_widget, global_attach_func);
    
    gtk_widget_show (widget);
    
    if (attach_widget != gtk_menu_get_attach_widget (GTK_MENU (widget)))
    {
        TEST_FAIL("attach_widget differs from the one was set", NULL);
    }
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    if (global_counter != 1)
    {
        TEST_FAIL 
            ("global_attach_func() was not called during attach_widget destrustion", 
             NULL);
    }
    #undef WIDGET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_reorder_child 
 * Params: GtkMenu *menu, GtkWidget *child, gint position
 * Returns: void
 * Assertion: Moves a GtkMenuItem to a new position within the GtkMenu.
 * Params Values: GtkMenu *menu, GtkMenuItem*,0
 * Expected: void  
 */
static void test_purpose_28()
{
    #define  POSITION 0
    
    GtkWidget *widget;
    GtkWidget *child;
    GList*children;
    gint pos;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    gtk_widget_show (widget);
    child = gtk_menu_item_new_with_label ("Child");
    gtk_widget_show (child);
    
    gtk_menu_shell_append (GTK_MENU_SHELL (widget), child);
    
    for (i = 0; i < 5; i++)
    {
        GtkWidget* item = gtk_menu_item_new_with_label ("Item");
        gtk_widget_show (item);
        gtk_menu_shell_append (GTK_MENU_SHELL (widget), item);
    }
    
    gtk_menu_reorder_child (GTK_MENU (widget), child, POSITION);
    
    children = GTK_MENU_SHELL (widget)->children;
    
    pos = g_list_index (children, child);
    if (pos != POSITION)
    {
        TEST_FAIL ("position is '%d',should be '%d'",pos,POSITION);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef POSITION
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_reorder_child 
 * Params: GtkMenu *menu, GtkWidget *child, gint position
 * Returns: void
 * Assertion: Moves a GtkMenuItem to a new position within the GtkMenu.
 * Params Values: GtkMenu *menu, GtkMenuItem*,1
 * Expected: void  
 */
static void test_purpose_29()
{
    #define  POSITION 1
    
    GtkWidget *widget;
    GtkWidget *child;
    GList*children;
    gint pos;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    gtk_widget_show (widget);
    child = gtk_menu_item_new_with_label ("Child");
    gtk_widget_show (child);
    
    gtk_menu_shell_append (GTK_MENU_SHELL (widget), child);
    
    for (i = 0; i < 5; i++)
    {
        GtkWidget* item = gtk_menu_item_new_with_label ("Item");
        gtk_widget_show (item);
        gtk_menu_shell_append (GTK_MENU_SHELL (widget), item);
    }
    
    gtk_menu_reorder_child (GTK_MENU (widget), child, POSITION);
    
    children = GTK_MENU_SHELL (widget)->children;
    
    pos = g_list_index (children, child);
    if (pos != POSITION)
    {
        TEST_FAIL ("position is '%d',should be '%d'",pos,POSITION);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef POSITION
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_reorder_child 
 * Params: GtkMenu *menu, GtkWidget *child, gint position
 * Returns: void
 * Assertion: Moves a GtkMenuItem to a new position within the GtkMenu.
 * Params Values: GtkMenu *menu, GtkMenuItem*,4
 * Expected: void  
 */
static void test_purpose_30()
{
    #define  POSITION 4
    
    GtkWidget *widget;
    GtkWidget *child;
    GList*children;
    gint pos;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    gtk_widget_show (widget);
    child = gtk_menu_item_new_with_label ("Child");
    gtk_widget_show (child);
    
    gtk_menu_shell_append (GTK_MENU_SHELL (widget), child);
    
    for (i = 0; i < 5; i++)
    {
        GtkWidget* item = gtk_menu_item_new_with_label ("Item");
        gtk_widget_show (item);
        gtk_menu_shell_append (GTK_MENU_SHELL (widget), item);
    }
    
    gtk_menu_reorder_child (GTK_MENU (widget), child, POSITION);
    
    children = GTK_MENU_SHELL (widget)->children;
    
    pos = g_list_index (children, child);
    if (pos != POSITION)
    {
        TEST_FAIL ("position is '%d',should be '%d'",pos,POSITION);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef POSITION
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_reorder_child 
 * Params: GtkMenu *menu, GtkWidget *child, gint position
 * Returns: void
 * Assertion: Moves a GtkMenuItem to a new position within the GtkMenu.
 * Params Values: GtkMenu *menu, GtkMenuItem*,5
 * Expected: void  
 */
static void test_purpose_31()
{
    #define  POSITION 5
    
    GtkWidget *widget;
    GtkWidget *child;
    GList*children;
    gint pos;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    gtk_widget_show (widget);
    child = gtk_menu_item_new_with_label ("Child");
    gtk_widget_show (child);
    
    gtk_menu_shell_append (GTK_MENU_SHELL (widget), child);
    
    for (i = 0; i < 5; i++)
    {
        GtkWidget* item = gtk_menu_item_new_with_label ("Item");
        gtk_widget_show (item);
        gtk_menu_shell_append (GTK_MENU_SHELL (widget), item);
    }
    
    gtk_menu_reorder_child (GTK_MENU (widget), child, POSITION);
    
    children = GTK_MENU_SHELL (widget)->children;
    
    pos = g_list_index (children, child);
    if (pos != POSITION)
    {
        TEST_FAIL ("position is '%d',should be '%d'",pos,POSITION);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef POSITION
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_detach 
 * Params: GtkMenu *menu
 * Returns: void
 * Assertion: Detaches the menu from the widget to which it had been attached.
 * Params Values: GtkMenu *menu
 * Expected: void  
 */
static void test_purpose_32()
{
    #define  WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    
    GtkWidget *widget;
    GtkWidget *attach_widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    widget = gtk_menu_new ();
    gtk_widget_show (widget);
    
    attach_widget = WIDGET;
    gtk_menu_attach_to_widget (GTK_MENU (widget), attach_widget, global_attach_func);
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_menu_detach (GTK_MENU (widget));
    if (global_counter != 1)
    {
        TEST_FAIL 
            ("global_attach_func() was not called during attach_widget destrustion", 
             NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    gtk_widget_destroy (attach_widget);
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_popdown 
 * Params: GtkMenu *menu
 * Returns: void
 * Assertion: Removes the menu from the screen.
 * Params Values: GtkMenu *menu
 * Expected: void  
 */
static void test_purpose_33()
{
    
    GtkWidget *menu;
    GtkWidget *item;
    gboolean visible;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    menu = gtk_menu_new ();
    gtk_widget_show (menu);
    item = gtk_menu_item_new_with_label ("String");
    gtk_widget_show (item);
    
    for (i = 0; i < 5; i++)
    {
        GtkWidget* item = gtk_menu_item_new_with_label ("Label");
        gtk_widget_show (item);
        gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
    }
    
    gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (menu);
    /******* -------------  *******/  
    
    gtk_menu_popdown (GTK_MENU (menu));
    
    if (GTK_WIDGET_VISIBLE (menu))
    {
        TEST_FAIL ("Menu is not removed",NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (menu));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_popup 
 * Params: GtkMenu *menu, GtkWidget *parent_menu_shell, GtkWidget *parent_menu_item, GtkMenuPositionFunc func, gpointer data, guint button, guint32 activate_time
 * Returns: void
 * Assertion: Displays a menu and makes it available for selection.
 * Params Values: GtkMenu*, NULL,NULL,<%5%>,0,GDK_CURRENT_TIME,NULL
 * Expected: void  
 */
static void test_purpose_34()
{
    #define PARENT_ITEM NULL
    #define DATA  NULL
    #define BUTTON  0
    #define TIME  GDK_CURRENT_TIME
    #define FUNC  NULL
    
    GtkWidget *menu;
    GtkWidget *item;
    GtkWidget *parent_menu_shell;
    GtkWidget *parent_menu_item;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    menu = gtk_menu_new ();
    gtk_widget_show (menu);
    item = gtk_menu_item_new_with_label ("Item");
    gtk_widget_show (item);
    gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
    
    parent_menu_item = PARENT_ITEM;
    if (parent_menu_item)
    {
        gtk_widget_show (parent_menu_item);
        gtk_menu_item_set_submenu (GTK_MENU_ITEM (parent_menu_item), menu);
    
        gtk_menu_popup (
                    GTK_MENU (GTK_MENU_ITEM (parent_menu_item)->submenu),
                    parent_menu_item->parent,
                    parent_menu_item,
                    FUNC,
                    DATA,
                    BUTTON,
                    TIME
                    );
    } else {
    
        gtk_menu_popup (
                    GTK_MENU (menu),
                    NULL,
                    NULL,
                    FUNC,
                    DATA,
                    BUTTON,
                    TIME
                    );
    }
    
    if (!GTK_WIDGET_VISIBLE (menu))
    {
        TEST_FAIL ("Menu is not displaied",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (menu);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (menu));
    
    #undef PARENT_ITEM 
    #undef TIME
    #undef DATA
    #undef BUTTON
    #undef FUNC
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_popup 
 * Params: GtkMenu *menu, GtkWidget *parent_menu_shell, GtkWidget *parent_menu_item, GtkMenuPositionFunc func, gpointer data, guint button, guint32 activate_time
 * Returns: void
 * Assertion: Displays a menu and makes it available for selection.
 * Params Values: GtkMenu*, gtk_menu_item_new_with_label ("Parent"),NULL,<%5%>,0,GDK_CURRENT_TIME,global_pos_func
 * Expected: void  
 */
static void test_purpose_35()
{
    #define PARENT_ITEM gtk_menu_item_new_with_label ("Parent")
    #define DATA  NULL
    #define BUTTON  0
    #define TIME  GDK_CURRENT_TIME
    #define FUNC  global_pos_func
    
    GtkWidget *menu;
    GtkWidget *item;
    GtkWidget *parent_menu_shell;
    GtkWidget *parent_menu_item;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    menu = gtk_menu_new ();
    gtk_widget_show (menu);
    item = gtk_menu_item_new_with_label ("Item");
    gtk_widget_show (item);
    gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
    
    parent_menu_item = PARENT_ITEM;
    if (parent_menu_item)
    {
        gtk_widget_show (parent_menu_item);
        gtk_menu_item_set_submenu (GTK_MENU_ITEM (parent_menu_item), menu);
    
        gtk_menu_popup (
                    GTK_MENU (GTK_MENU_ITEM (parent_menu_item)->submenu),
                    parent_menu_item->parent,
                    parent_menu_item,
                    FUNC,
                    DATA,
                    BUTTON,
                    TIME
                    );
    } else {
    
        gtk_menu_popup (
                    GTK_MENU (menu),
                    NULL,
                    NULL,
                    FUNC,
                    DATA,
                    BUTTON,
                    TIME
                    );
    }
    
    if (!GTK_WIDGET_VISIBLE (menu))
    {
        TEST_FAIL ("Menu is not displaied",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (menu);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (menu));
    
    #undef PARENT_ITEM 
    #undef TIME
    #undef DATA
    #undef BUTTON
    #undef FUNC
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_popup 
 * Params: GtkMenu *menu, GtkWidget *parent_menu_shell, GtkWidget *parent_menu_item, GtkMenuPositionFunc func, gpointer data, guint button, guint32 activate_time
 * Returns: void
 * Assertion: Displays a menu and makes it available for selection.
 * Params Values: GtkMenu*, gtk_menu_item_new_with_label ("Parent"),NULL,<%5%>,1,GDK_CURRENT_TIME,global_pos_func
 * Expected: void  
 */
static void test_purpose_36()
{
    #define PARENT_ITEM gtk_menu_item_new_with_label ("Parent")
    #define DATA  NULL
    #define BUTTON  1
    #define TIME  GDK_CURRENT_TIME
    #define FUNC  global_pos_func
    
    GtkWidget *menu;
    GtkWidget *item;
    GtkWidget *parent_menu_shell;
    GtkWidget *parent_menu_item;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    menu = gtk_menu_new ();
    gtk_widget_show (menu);
    item = gtk_menu_item_new_with_label ("Item");
    gtk_widget_show (item);
    gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
    
    parent_menu_item = PARENT_ITEM;
    if (parent_menu_item)
    {
        gtk_widget_show (parent_menu_item);
        gtk_menu_item_set_submenu (GTK_MENU_ITEM (parent_menu_item), menu);
    
        gtk_menu_popup (
                    GTK_MENU (GTK_MENU_ITEM (parent_menu_item)->submenu),
                    parent_menu_item->parent,
                    parent_menu_item,
                    FUNC,
                    DATA,
                    BUTTON,
                    TIME
                    );
    } else {
    
        gtk_menu_popup (
                    GTK_MENU (menu),
                    NULL,
                    NULL,
                    FUNC,
                    DATA,
                    BUTTON,
                    TIME
                    );
    }
    
    if (!GTK_WIDGET_VISIBLE (menu))
    {
        TEST_FAIL ("Menu is not displaied",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (menu);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (menu));
    
    #undef PARENT_ITEM 
    #undef TIME
    #undef DATA
    #undef BUTTON
    #undef FUNC
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_popup 
 * Params: GtkMenu *menu, GtkWidget *parent_menu_shell, GtkWidget *parent_menu_item, GtkMenuPositionFunc func, gpointer data, guint button, guint32 activate_time
 * Returns: void
 * Assertion: Displays a menu and makes it available for selection.
 * Params Values: GtkMenu*, gtk_menu_item_new_with_label ("Parent"),NULL,<%5%>,2,GDK_CURRENT_TIME,global_pos_func
 * Expected: void  
 */
static void test_purpose_37()
{
    #define PARENT_ITEM gtk_menu_item_new_with_label ("Parent")
    #define DATA  NULL
    #define BUTTON  2
    #define TIME  GDK_CURRENT_TIME
    #define FUNC  global_pos_func
    
    GtkWidget *menu;
    GtkWidget *item;
    GtkWidget *parent_menu_shell;
    GtkWidget *parent_menu_item;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    menu = gtk_menu_new ();
    gtk_widget_show (menu);
    item = gtk_menu_item_new_with_label ("Item");
    gtk_widget_show (item);
    gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
    
    parent_menu_item = PARENT_ITEM;
    if (parent_menu_item)
    {
        gtk_widget_show (parent_menu_item);
        gtk_menu_item_set_submenu (GTK_MENU_ITEM (parent_menu_item), menu);
    
        gtk_menu_popup (
                    GTK_MENU (GTK_MENU_ITEM (parent_menu_item)->submenu),
                    parent_menu_item->parent,
                    parent_menu_item,
                    FUNC,
                    DATA,
                    BUTTON,
                    TIME
                    );
    } else {
    
        gtk_menu_popup (
                    GTK_MENU (menu),
                    NULL,
                    NULL,
                    FUNC,
                    DATA,
                    BUTTON,
                    TIME
                    );
    }
    
    if (!GTK_WIDGET_VISIBLE (menu))
    {
        TEST_FAIL ("Menu is not displaied",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (menu);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (menu));
    
    #undef PARENT_ITEM 
    #undef TIME
    #undef DATA
    #undef BUTTON
    #undef FUNC
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_reposition 
 * Params: GtkMenu *menu
 * Returns: void
 * Assertion: Repositions the menu according to its position function.
 * Params Values: GtkMenu *menu
 * Expected: void  
 */
static void test_purpose_38()
{
    
    GtkWidget *widget;
    GtkWidget *child;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    gtk_menu_reposition (GTK_MENU (widget));
    
    gtk_widget_show (widget);
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_set_tearoff_state
 * Params: GtkMenu *menu, gboolean torn_off
 * Returns: void
 * Assertion: Changes the tearoff state of the menu.
 * Params Values: GtkMenu *menu, TRUE
 * Expected: void
 * 
 * Name: gtk_menu_get_tearoff_state
 * Params: GtkMenu *menu
 * Returns: gboolean
 * Assertion: Returns whether the menu is torn off.
 * Params Values: GtkMenu *menu
 * Expected: GtkWidget*  
 */
static void test_purpose_39()
{
    #define  STATE TRUE
    
    GtkWidget *widget = NULL;
    gboolean real_state;
    GtkWidget *owner = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    if (STATE)
    {
        owner = gtk_window_new (GTK_WINDOW_TOPLEVEL);
        gtk_widget_realize (owner);
        gtk_menu_attach_to_widget (GTK_MENU (widget), owner, (GtkMenuDetachFunc)global_attach_func);
    } 
    
    gtk_widget_realize (widget);
    gtk_menu_set_tearoff_state (GTK_MENU (widget), STATE);
    
    real_state = gtk_menu_get_tearoff_state (GTK_MENU (widget));
    if (real_state != STATE)
    {
        TEST_FAIL("real_state = %d, should be %d", real_state, STATE);
    }
    
    gtk_widget_show (widget);
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (STATE)
    {
        gtk_menu_detach (GTK_MENU (widget));
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    if (owner)
      gtk_widget_destroy (owner);
    
    #undef STATE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_set_tearoff_state
 * Params: GtkMenu *menu, gboolean torn_off
 * Returns: void
 * Assertion: Changes the tearoff state of the menu.
 * Params Values: GtkMenu *menu, FALSE
 * Expected: void
 * 
 * Name: gtk_menu_get_tearoff_state
 * Params: GtkMenu *menu
 * Returns: gboolean
 * Assertion: Returns whether the menu is torn off.
 * Params Values: GtkMenu *menu
 * Expected: GtkWidget*  
 */
static void test_purpose_40()
{
    #define  STATE FALSE
    
    GtkWidget *widget = NULL;
    gboolean real_state;
    GtkWidget *owner = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    if (STATE)
    {
        owner = gtk_window_new (GTK_WINDOW_TOPLEVEL);
        gtk_widget_realize (owner);
        gtk_menu_attach_to_widget (GTK_MENU (widget), owner, (GtkMenuDetachFunc)global_attach_func);
    } 
    
    gtk_widget_realize (widget);
    gtk_menu_set_tearoff_state (GTK_MENU (widget), STATE);
    
    real_state = gtk_menu_get_tearoff_state (GTK_MENU (widget));
    if (real_state != STATE)
    {
        TEST_FAIL("real_state = %d, should be %d", real_state, STATE);
    }
    
    gtk_widget_show (widget);
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (STATE)
    {
        gtk_menu_detach (GTK_MENU (widget));
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    if (owner)
      gtk_widget_destroy (owner);
    
    #undef STATE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_set_accel_path
 * Params: GtkMenu *menu,const gchar *accel_path
 * Returns: void
 * Assertion: Sets an accelerator path for this menu from which accelerator paths for its immediate children, its menu items, can be constructed.
 * Params Values: GtkMenu *menu, "<test>/action_A"
 * Expected: void  
 */
static void test_purpose_41()
{
    #define PATH "<test>/action_A"
    #define KEY GDK_A
    #define MODS GDK_SHIFT_MASK
    
    GtkWidget *menu;
    GtkWidget *widget;
    GtkAccelKey key;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    menu = gtk_menu_new ();
    if (!menu)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    widget = gtk_menu_item_new_with_label ("Item");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    gtk_widget_show (menu);
    
    gtk_accel_map_add_entry (PATH, KEY, MODS);
    gtk_menu_set_accel_path (GTK_MENU (menu), PATH);
    
    if (!gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns NULL", NULL);
        return;
    }
    if (key.accel_key != KEY)
    {
        TEST_FAIL ("accel keys not equal", NULL);
        return;
    }
    
    gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (menu);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (menu));
    
    #undef PATH
    #undef KEY
    #undef MODS
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_set_accel_path
 * Params: GtkMenu *menu,const gchar *accel_path
 * Returns: void
 * Assertion: Sets an accelerator path for this menu from which accelerator paths for its immediate children, its menu items, can be constructed.
 * Params Values: GtkMenu *menu, "<test>/action_B"
 * Expected: void  
 */
static void test_purpose_42()
{
    #define PATH "<test>/action_B"
    #define KEY GDK_B
    #define MODS GDK_SHIFT_MASK
    
    GtkWidget *menu;
    GtkWidget *widget;
    GtkAccelKey key;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    menu = gtk_menu_new ();
    if (!menu)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    widget = gtk_menu_item_new_with_label ("Item");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    gtk_widget_show (menu);
    
    gtk_accel_map_add_entry (PATH, KEY, MODS);
    gtk_menu_set_accel_path (GTK_MENU (menu), PATH);
    
    if (!gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns NULL", NULL);
        return;
    }
    if (key.accel_key != KEY)
    {
        TEST_FAIL ("accel keys not equal", NULL);
        return;
    }
    
    gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (menu);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (menu));
    
    #undef PATH
    #undef KEY
    #undef MODS
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_set_accel_path
 * Params: GtkMenu *menu,const gchar *accel_path
 * Returns: void
 * Assertion: Sets an accelerator path for this menu from which accelerator paths for its immediate children, its menu items, can be constructed.
 * Params Values: GtkMenu *menu, "<test>/action_1"
 * Expected: void  
 */
static void test_purpose_43()
{
    #define PATH "<test>/action_1"
    #define KEY GDK_1
    #define MODS 0
    
    GtkWidget *menu;
    GtkWidget *widget;
    GtkAccelKey key;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    menu = gtk_menu_new ();
    if (!menu)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    widget = gtk_menu_item_new_with_label ("Item");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    gtk_widget_show (menu);
    
    gtk_accel_map_add_entry (PATH, KEY, MODS);
    gtk_menu_set_accel_path (GTK_MENU (menu), PATH);
    
    if (!gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns NULL", NULL);
        return;
    }
    if (key.accel_key != KEY)
    {
        TEST_FAIL ("accel keys not equal", NULL);
        return;
    }
    
    gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (menu);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (menu));
    
    #undef PATH
    #undef KEY
    #undef MODS
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_set_accel_path
 * Params: GtkMenu *menu,const gchar *accel_path
 * Returns: void
 * Assertion: For example, a menu containing menu items "New" and "Exit", will, after gtk_menu_set_accel_path (menu, "<Gnumeric-Sheet>/File"); has been called, assign its items the accel paths: "<Gnumeric-Sheet>/File/New" and "<Gnumeric-Sheet>/File/Exit"
 * Params Values: GtkMenu *menu, <%0%>
 * Expected: void  
 */
static void test_purpose_44()
{
    
    GtkWidget *menu;
    GtkWidget *widget;
    GtkAccelKey key;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    menu = gtk_menu_new ();
    gtk_widget_show (menu);
    
    widget = gtk_menu_item_new_with_label ("New");
    gtk_menu_shell_append (GTK_MENU_SHELL (menu), widget);
    gtk_widget_show (widget);
    
    widget = gtk_menu_item_new_with_label ("Exit");
    gtk_menu_shell_append (GTK_MENU_SHELL (menu), widget);
    gtk_widget_show (widget);
    
    gtk_accel_map_add_entry ("<Gnumeric-Sheet>/File", GDK_A, GDK_SHIFT_MASK);
    gtk_accel_map_add_entry ("<Gnumeric-Sheet>/File/New", GDK_B, GDK_SHIFT_MASK);
    gtk_accel_map_add_entry ("<Gnumeric-Sheet>/File/Exit", GDK_C, GDK_SHIFT_MASK);
    
    gtk_menu_set_accel_path (GTK_MENU (menu), "<Gnumeric-Sheet>/File");
    
    if (!gtk_accel_map_lookup_entry ("<Gnumeric-Sheet>/File/New", &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns NULL", NULL);
        return;
    };
    
    if (!gtk_accel_map_lookup_entry ("<Gnumeric-Sheet>/File/Exit", &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns NULL", NULL);
        return;
    };
    
    gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (menu);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (menu));
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_menu_set_screen
 * Params: GtkMenu *menu, GdkScreen *screen
 * Returns: void
 * Assertion: Sets the GtkScreen on which the GtkMenu will be displayed.
 * Params Values: GtkMenu*, gdk_screen_get_default ()
 * Expected: void  
 */
static void test_purpose_45()
{
    #define SCREEN gdk_screen_get_default ()
    
    GtkWidget* widget;
    GdkScreen* screen;
    GdkScreen* real_screen;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    screen = SCREEN;
    
    gtk_widget_show (widget);
    gtk_menu_set_screen (GTK_MENU (widget), screen);
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget); 
    /******* -------------  *******/  
    
    real_screen = gtk_widget_get_screen (widget);
    if (screen != NULL)
    {
        if (real_screen != screen)
        {
            TEST_FAIL ("real_screen is not the one the widget was created for", 
                       NULL);
        }
    } else {
        GdkScreen* toplevel_screen;
    
        toplevel_screen = gtk_widget_get_screen (gtk_widget_get_toplevel (widget));
        if (real_screen != toplevel_screen)
        {
            TEST_FAIL ("real_screen is not the one the widget's toplevel was created for", NULL);
        }
    }
        
    
    gtk_widget_destroy (widget);
    
    #undef SCREEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_menu_set_screen
 * Params: GtkMenu *menu, GdkScreen *screen
 * Returns: void
 * Assertion: Sets the GtkScreen on which the GtkMenu will be displayed.
 * Params Values: GtkMenu*, gtk_widget_get_screen (gtk_button_new ())
 * Expected: void  
 */
static void test_purpose_46()
{
    #define SCREEN gtk_widget_get_screen (gtk_button_new ())
    
    GtkWidget* widget;
    GdkScreen* screen;
    GdkScreen* real_screen;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    screen = SCREEN;
    
    gtk_widget_show (widget);
    gtk_menu_set_screen (GTK_MENU (widget), screen);
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget); 
    /******* -------------  *******/  
    
    real_screen = gtk_widget_get_screen (widget);
    if (screen != NULL)
    {
        if (real_screen != screen)
        {
            TEST_FAIL ("real_screen is not the one the widget was created for", 
                       NULL);
        }
    } else {
        GdkScreen* toplevel_screen;
    
        toplevel_screen = gtk_widget_get_screen (gtk_widget_get_toplevel (widget));
        if (real_screen != toplevel_screen)
        {
            TEST_FAIL ("real_screen is not the one the widget's toplevel was created for", NULL);
        }
    }
        
    
    gtk_widget_destroy (widget);
    
    #undef SCREEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_menu_set_screen
 * Params: GtkMenu *menu, GdkScreen *screen
 * Returns: void
 * Assertion: Sets the GtkScreen on which the GtkMenu will be displayed.
 * Params Values: GtkMenu*, gtk_widget_get_screen (gtk_button_new_with_label ("button"))
 * Expected: void  
 */
static void test_purpose_47()
{
    #define SCREEN gtk_widget_get_screen (gtk_button_new_with_label ("button"))
    
    GtkWidget* widget;
    GdkScreen* screen;
    GdkScreen* real_screen;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    screen = SCREEN;
    
    gtk_widget_show (widget);
    gtk_menu_set_screen (GTK_MENU (widget), screen);
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget); 
    /******* -------------  *******/  
    
    real_screen = gtk_widget_get_screen (widget);
    if (screen != NULL)
    {
        if (real_screen != screen)
        {
            TEST_FAIL ("real_screen is not the one the widget was created for", 
                       NULL);
        }
    } else {
        GdkScreen* toplevel_screen;
    
        toplevel_screen = gtk_widget_get_screen (gtk_widget_get_toplevel (widget));
        if (real_screen != toplevel_screen)
        {
            TEST_FAIL ("real_screen is not the one the widget's toplevel was created for", NULL);
        }
    }
        
    
    gtk_widget_destroy (widget);
    
    #undef SCREEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_menu_set_screen
 * Params: GtkMenu *menu, GdkScreen *screen
 * Returns: void
 * Assertion: Sets the GtkScreen on which the GtkMenu will be displayed.
 * Params Values: GtkMenu*, gtk_widget_get_screen (gtk_window_new (GTK_WINDOW_TOPLEVEL))
 * Expected: void  
 */
static void test_purpose_48()
{
    #define SCREEN gtk_widget_get_screen (gtk_window_new (GTK_WINDOW_TOPLEVEL))
    
    GtkWidget* widget;
    GdkScreen* screen;
    GdkScreen* real_screen;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    screen = SCREEN;
    
    gtk_widget_show (widget);
    gtk_menu_set_screen (GTK_MENU (widget), screen);
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget); 
    /******* -------------  *******/  
    
    real_screen = gtk_widget_get_screen (widget);
    if (screen != NULL)
    {
        if (real_screen != screen)
        {
            TEST_FAIL ("real_screen is not the one the widget was created for", 
                       NULL);
        }
    } else {
        GdkScreen* toplevel_screen;
    
        toplevel_screen = gtk_widget_get_screen (gtk_widget_get_toplevel (widget));
        if (real_screen != toplevel_screen)
        {
            TEST_FAIL ("real_screen is not the one the widget's toplevel was created for", NULL);
        }
    }
        
    
    gtk_widget_destroy (widget);
    
    #undef SCREEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_menu_set_screen
 * Params: GtkMenu *menu, GdkScreen *screen
 * Returns: void
 * Assertion: Sets the GtkScreen on which the GtkMenu will be displayed.
 * Params Values: GtkMenu*, gtk_widget_get_screen (gtk_calendar_new ())
 * Expected: void  
 */
static void test_purpose_49()
{
    #define SCREEN gtk_widget_get_screen (gtk_calendar_new ())
    
    GtkWidget* widget;
    GdkScreen* screen;
    GdkScreen* real_screen;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    screen = SCREEN;
    
    gtk_widget_show (widget);
    gtk_menu_set_screen (GTK_MENU (widget), screen);
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget); 
    /******* -------------  *******/  
    
    real_screen = gtk_widget_get_screen (widget);
    if (screen != NULL)
    {
        if (real_screen != screen)
        {
            TEST_FAIL ("real_screen is not the one the widget was created for", 
                       NULL);
        }
    } else {
        GdkScreen* toplevel_screen;
    
        toplevel_screen = gtk_widget_get_screen (gtk_widget_get_toplevel (widget));
        if (real_screen != toplevel_screen)
        {
            TEST_FAIL ("real_screen is not the one the widget's toplevel was created for", NULL);
        }
    }
        
    
    gtk_widget_destroy (widget);
    
    #undef SCREEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_menu_set_screen
 * Params: GtkMenu *menu, GdkScreen *screen
 * Returns: void
 * Assertion: Sets the GtkScreen on which the GtkMenu will be displayed.
 * Params Values: GtkMenu*, gtk_widget_get_screen (gtk_text_view_new ())
 * Expected: void  
 */
static void test_purpose_50()
{
    #define SCREEN gtk_widget_get_screen (gtk_text_view_new ())
    
    GtkWidget* widget;
    GdkScreen* screen;
    GdkScreen* real_screen;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    screen = SCREEN;
    
    gtk_widget_show (widget);
    gtk_menu_set_screen (GTK_MENU (widget), screen);
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget); 
    /******* -------------  *******/  
    
    real_screen = gtk_widget_get_screen (widget);
    if (screen != NULL)
    {
        if (real_screen != screen)
        {
            TEST_FAIL ("real_screen is not the one the widget was created for", 
                       NULL);
        }
    } else {
        GdkScreen* toplevel_screen;
    
        toplevel_screen = gtk_widget_get_screen (gtk_widget_get_toplevel (widget));
        if (real_screen != toplevel_screen)
        {
            TEST_FAIL ("real_screen is not the one the widget's toplevel was created for", NULL);
        }
    }
        
    
    gtk_widget_destroy (widget);
    
    #undef SCREEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_menu_set_screen
 * Params: GtkMenu *menu, GdkScreen *screen
 * Returns: void
 * Assertion: Sets the GtkScreen on which the GtkMenu will be displayed.
 * Params Values: GtkMenu*, NULL
 * Expected: void  
 */
static void test_purpose_51()
{
    #define SCREEN NULL
    
    GtkWidget* widget;
    GdkScreen* screen;
    GdkScreen* real_screen;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    screen = SCREEN;
    
    gtk_widget_show (widget);
    gtk_menu_set_screen (GTK_MENU (widget), screen);
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget); 
    /******* -------------  *******/  
    
    real_screen = gtk_widget_get_screen (widget);
    if (screen != NULL)
    {
        if (real_screen != screen)
        {
            TEST_FAIL ("real_screen is not the one the widget was created for", 
                       NULL);
        }
    } else {
        GdkScreen* toplevel_screen;
    
        toplevel_screen = gtk_widget_get_screen (gtk_widget_get_toplevel (widget));
        if (real_screen != toplevel_screen)
        {
            TEST_FAIL ("real_screen is not the one the widget's toplevel was created for", NULL);
        }
    }
        
    
    gtk_widget_destroy (widget);
    
    #undef SCREEN
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkMenu ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {NULL,0}
};
