/*
 * GtkMenuItem methods tests
 * Testing GtkMenuItem methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
gint global_counter_activate;
gint global_counter_deselect;
gint global_counter_select;
gint global_counter_toggle_size_request;
gint global_counter_toggle_size_allocate;

void global_activate_signal_handler   (GtkMenuItem *item, gpointer user_data)
{
    global_counter_activate++;
}

void global_deselect_signal_handler   (GtkMenuItem *item, gpointer user_data)
{
    global_counter_deselect++;
}

void global_select_signal_handler   (GtkMenuItem *item, gpointer user_data)
{
    global_counter_select++;
}

void global_toggle_size_request_signal_handler   (GtkMenuItem *item, gpointer user_data)
{
    global_counter_toggle_size_request++;
}

void global_toggle_size_allocate_signal_handler   (GtkMenuItem *item, gpointer user_data)
{
    global_counter_toggle_size_allocate++;
}

/*
 * Name: gtk_menu_item_new
 * Params: void
 * Returns: GtkMenuItem*
 * Assertion: Creates a new GtkMenuItem.
 * Params Values: void
 * Expected: GtkMenuItem*  
 */
static void test_purpose_1()
{
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_item_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_item_new_with_label
 * Params: const gchar *label
 * Returns: GtkMenuItem*
 * Assertion: Creates a new GtkMenuItem whose child is a GtkLabel.
 * Params Values: "Text"
 * Expected: GtkMenuItem*  
 */
static void test_purpose_2()
{
    #define LABEL "Text"
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_item_new_with_label (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    child = g_list_nth_data (children, 0);
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
    } 
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_item_new_with_label
 * Params: const gchar *label
 * Returns: GtkMenuItem*
 * Assertion: Creates a new GtkMenuItem whose child is a GtkLabel.
 * Params Values: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: GtkMenuItem*  
 */
static void test_purpose_3()
{
    #define LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_item_new_with_label (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    child = g_list_nth_data (children, 0);
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
    } 
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_item_new_with_label
 * Params: const gchar *label
 * Returns: GtkMenuItem*
 * Assertion: Creates a new GtkMenuItem whose child is a GtkLabel.
 * Params Values: "!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: GtkMenuItem*  
 */
static void test_purpose_4()
{
    #define LABEL "!@#$%^&*()_+|~=\";:'?<>`/"
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_item_new_with_label (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    child = g_list_nth_data (children, 0);
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
    } 
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_item_new_with_label
 * Params: const gchar *label
 * Returns: GtkMenuItem*
 * Assertion: Creates a new GtkMenuItem whose child is a GtkLabel.
 * Params Values: "\n\t"
 * Expected: GtkMenuItem*  
 */
static void test_purpose_5()
{
    #define LABEL "\n\t"
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_item_new_with_label (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    child = g_list_nth_data (children, 0);
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
    } 
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_item_new_with_label
 * Params: const gchar *label
 * Returns: GtkMenuItem*
 * Assertion: Creates a new GtkMenuItem whose child is a GtkLabel.
 * Params Values: ""
 * Expected: GtkMenuItem*  
 */
static void test_purpose_6()
{
    #define LABEL ""
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_item_new_with_label (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    child = g_list_nth_data (children, 0);
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
    } 
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_item_new_with_label
 * Params: const gchar *label
 * Returns: GtkMenuItem*
 * Assertion: Creates a new GtkMenuItem whose child is a GtkLabel.
 * Params Values: " "
 * Expected: GtkMenuItem*  
 */
static void test_purpose_7()
{
    #define LABEL " "
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_item_new_with_label (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    child = g_list_nth_data (children, 0);
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
    } 
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkMenuItem*
 * Assertion: Creates a new GtkMenuItem containing a label.
 * Params Values: "_Text"
 * Expected: GtkMenuItem*  
 */
static void test_purpose_8()
{
    #define LABEL "_Text"
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_item_new_with_mnemonic (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    child = g_list_nth_data (children, 0);
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
    } 
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkMenuItem*
 * Assertion: Creates a new GtkMenuItem containing a label.
 * Params Values: "abc_de_fghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: GtkMenuItem*  
 */
static void test_purpose_9()
{
    #define LABEL "abc_de_fghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_item_new_with_mnemonic (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    child = g_list_nth_data (children, 0);
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
    } 
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkMenuItem*
 * Assertion: Creates a new GtkMenuItem containing a label.
 * Params Values: "!@#$%^_&*()_+|~=\";:'_?<>`/"
 * Expected: GtkMenuItem*  
 */
static void test_purpose_10()
{
    #define LABEL "!@#$%^_&*()_+|~=\";:'_?<>`/"
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_item_new_with_mnemonic (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    child = g_list_nth_data (children, 0);
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
    } 
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkMenuItem*
 * Assertion: Creates a new GtkMenuItem containing a label.
 * Params Values: "\n_\t"
 * Expected: GtkMenuItem*  
 */
static void test_purpose_11()
{
    #define LABEL "\n_\t"
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_item_new_with_mnemonic (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    child = g_list_nth_data (children, 0);
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
    } 
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkMenuItem*
 * Assertion: Creates a new GtkMenuItem containing a label.
 * Params Values: ""
 * Expected: GtkMenuItem*  
 */
static void test_purpose_12()
{
    #define LABEL ""
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_item_new_with_mnemonic (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    child = g_list_nth_data (children, 0);
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
    } 
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkMenuItem*
 * Assertion: Creates a new GtkMenuItem containing a label.
 * Params Values: "_ "
 * Expected: GtkMenuItem*  
 */
static void test_purpose_13()
{
    #define LABEL "_ "
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_item_new_with_mnemonic (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    child = g_list_nth_data (children, 0);
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
    } 
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkMenuItem*
 * Assertion: The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the menu item.
 * Params Values: "Te_xt"
 * Expected: GtkMenuItem*  
 */
static void test_purpose_14()
{
    #define LABEL "Te_xt"
    #define KEY GDK_x
    
    GtkWidget* widget;
    GList* children;
    gpointer child;
    guint keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_item_new_with_mnemonic (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    child = g_list_nth_data (children, 0);
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
        return;
    } 
    
    keyval = gtk_label_get_mnemonic_keyval (GTK_LABEL (child));
    if (keyval != KEY)
    {
        TEST_FAIL ("keyval = %i, should be %i", keyval, KEY);
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef KEY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkMenuItem*
 * Assertion: The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the menu item.
 * Params Values: "_Text"
 * Expected: GtkMenuItem*  
 */
static void test_purpose_15()
{
    #define LABEL "_Text"
    #define KEY GDK_t
    
    GtkWidget* widget;
    GList* children;
    gpointer child;
    guint keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_item_new_with_mnemonic (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    child = g_list_nth_data (children, 0);
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
        return;
    } 
    
    keyval = gtk_label_get_mnemonic_keyval (GTK_LABEL (child));
    if (keyval != KEY)
    {
        TEST_FAIL ("keyval = %i, should be %i", keyval, KEY);
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef KEY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkMenuItem*
 * Assertion: The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the menu item.
 * Params Values: "T_ext"
 * Expected: GtkMenuItem*  
 */
static void test_purpose_16()
{
    #define LABEL "T_ext"
    #define KEY GDK_e
    
    GtkWidget* widget;
    GList* children;
    gpointer child;
    guint keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_item_new_with_mnemonic (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    child = g_list_nth_data (children, 0);
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
        return;
    } 
    
    keyval = gtk_label_get_mnemonic_keyval (GTK_LABEL (child));
    if (keyval != KEY)
    {
        TEST_FAIL ("keyval = %i, should be %i", keyval, KEY);
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef KEY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_item_set_right_justified
 * Params: GtkMenuItem *menu_item, gboolean right_justified
 * Returns: void
 * Assertion: Sets whether the menu item appears justified at the right side of a menu bar.
 * Params Values: a newly created GtkMenuItem*, TRUE
 * Expected: void
 * 
 * Name: gtk_menu_item_get_right_justified
 * Params: GtkMenuItem *menu_item
 * Returns: gboolean
 * Assertion: Gets whether the menu item appears justified at the right side of the menu bar.
 * Params Values: a newly created GtkMenuItem*
 * Expected: TRUE  
 */
static void test_purpose_17()
{
    #define RIGHT_JUSTIFIED TRUE
    
    GtkWidget *widget;
    gboolean right_justified;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_item_new_with_label ("Item");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_menu_item_set_right_justified (GTK_MENU_ITEM (widget), RIGHT_JUSTIFIED);
    
    right_justified = gtk_menu_item_get_right_justified (GTK_MENU_ITEM (widget));
    if (right_justified != RIGHT_JUSTIFIED)
    {
        TEST_FAIL ("right_justified = %d, should be %d", 
                   right_justified, RIGHT_JUSTIFIED);
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RIGHT_JUSTIFIED
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_item_set_right_justified
 * Params: GtkMenuItem *menu_item, gboolean right_justified
 * Returns: void
 * Assertion: Sets whether the menu item appears justified at the right side of a menu bar.
 * Params Values: a newly created GtkMenuItem*, FALSE
 * Expected: void
 * 
 * Name: gtk_menu_item_get_right_justified
 * Params: GtkMenuItem *menu_item
 * Returns: gboolean
 * Assertion: Gets whether the menu item appears justified at the right side of the menu bar.
 * Params Values: a newly created GtkMenuItem*
 * Expected: FALSE  
 */
static void test_purpose_18()
{
    #define RIGHT_JUSTIFIED FALSE
    
    GtkWidget *widget;
    gboolean right_justified;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_item_new_with_label ("Item");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_menu_item_set_right_justified (GTK_MENU_ITEM (widget), RIGHT_JUSTIFIED);
    
    right_justified = gtk_menu_item_get_right_justified (GTK_MENU_ITEM (widget));
    if (right_justified != RIGHT_JUSTIFIED)
    {
        TEST_FAIL ("right_justified = %d, should be %d", 
                   right_justified, RIGHT_JUSTIFIED);
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RIGHT_JUSTIFIED
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_item_set_submenu
 * Params: GtkMenuItem *menu_item, GtkWidget *submenu
 * Returns: void
 * Assertion: Sets the widget submenu, or changes it.
 * Params Values: a newly created GtkMenuItem*, a newly created GtkMenu*
 * Expected: void
 * 
 * Name: gtk_menu_item_get_submenu
 * Params: GtkMenuItem *menu_item
 * Returns: GtkWidget*
 * Assertion: Gets the submenu underneath this menu item, if any.
 * Params Values: a newly created GtkMenuItem*
 * Expected: GtkWidget*  
 */
static void test_purpose_19()
{
    GtkWidget *widget;
    GtkWidget *submenu;
    GtkWidget *real_submenu;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_item_new_with_label ("Item");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    submenu = gtk_menu_new ();
    if (!submenu)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (submenu))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_menu_item_set_submenu (GTK_MENU_ITEM (widget), submenu);
    
    real_submenu = gtk_menu_item_get_submenu (GTK_MENU_ITEM (widget));
    if (real_submenu != submenu)
    {
        TEST_FAIL ("menu item submenu differs from that was set", NULL);
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (submenu);
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_item_remove_submenu
 * Params: GtkMenuItem *menu_item
 * Returns: void
 * Assertion: Removes the widget's submenu.'
 * Params Values: a newly created GtkMenuItem*
 * Expected: void  
 */
static void test_purpose_20()
{
    GtkWidget *widget;
    GtkWidget *submenu;
    GtkWidget *real_submenu;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_item_new_with_label ("Item");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    submenu = gtk_menu_new ();
    if (!submenu)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (submenu))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_menu_item_set_submenu (GTK_MENU_ITEM (widget), submenu);
    
    real_submenu = gtk_menu_item_get_submenu (GTK_MENU_ITEM (widget));
    if (real_submenu != submenu)
    {
        TEST_FAIL ("menu item submenu differs from that was set", NULL);
    }
    
    gtk_menu_item_remove_submenu (GTK_MENU_ITEM (widget));
    real_submenu = gtk_menu_item_get_submenu (GTK_MENU_ITEM (widget));
    if (real_submenu != NULL)
    {
        TEST_FAIL ("menu item submenu was removed but now it's not NULL", NULL);
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_item_select
 * Params: GtkMenuItem*
 * Returns: void
 * Assertion: Emits the "select" signal on the given item.
 * Params Values: a newly created GtkMenuItem*
 * Expected: void
 * 
 * Name: gtk_menu_item_select
 * Params: GtkMenuItem*
 * Returns: void
 * Assertion: Behaves exactly like gtk_item_select.
 * Params Values: a newly created GtkMenuItem*
 * Expected: void  
 */
static void test_purpose_21()
{
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter_select = 0;
    
    widget = gtk_menu_item_new_with_label ("Item");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "select", 
                      GTK_SIGNAL_FUNC (global_select_signal_handler), NULL);
    
    gtk_menu_item_select (GTK_MENU_ITEM (widget));
    
    if (global_counter_select == 0)
    {
        TEST_FAIL ("gtk_menu_item_select() should emit 'select' signal", NULL);
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_item_deselect
 * Params: GtkMenuItem*
 * Returns: void
 * Assertion: Emits the "deselect" signal on the given item.
 * Params Values: a newly created GtkMenuItem*
 * Expected: void
 * 
 * Name: gtk_menu_item_deselect
 * Params: GtkMenuItem*
 * Returns: void
 * Assertion: Behaves exactly like gtk_item_deselect.
 * Params Values: a newly created GtkMenuItem*
 * Expected: void  
 */
static void test_purpose_22()
{
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter_deselect = 0;
    
    widget = gtk_menu_item_new_with_label ("Item");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "deselect", 
                      GTK_SIGNAL_FUNC (global_deselect_signal_handler), NULL);
    
    gtk_menu_item_deselect (GTK_MENU_ITEM (widget));
    
    if (global_counter_deselect == 0)
    {
        TEST_FAIL ("gtk_menu_item_deselect() should emit 'deselect' signal", NULL);
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_item_activate
 * Params: GtkMenuItem*
 * Returns: void
 * Assertion: Emits the "activate" signal on the given item.
 * Params Values: a newly created GtkMenuItem*
 * Expected: void  
 */
static void test_purpose_23()
{
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter_activate = 0;
    
    widget = gtk_menu_item_new_with_label ("Item");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "activate", 
                      GTK_SIGNAL_FUNC (global_activate_signal_handler), NULL);
    
    gtk_menu_item_activate (GTK_MENU_ITEM (widget));
    
    if (global_counter_activate == 0)
    {
        TEST_FAIL ("gtk_menu_item_activate() should emit 'activate' signal", NULL);
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_item_toggle_size_request
 * Params: GtkMenuItem *menu_item, gint *requisition
 * Returns: void
 * Assertion: Emits the "toggle_size_request" signal on the given item.
 * Params Values: a newly created GtkMenuItem*, gint*
 * Expected: void  
 */
static void test_purpose_24()
{
    GtkWidget *widget;
    gint req;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter_toggle_size_request = 0;
    
    widget = gtk_menu_item_new_with_label ("Item");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "toggle_size_request", 
                      GTK_SIGNAL_FUNC (global_toggle_size_request_signal_handler), 
                      NULL);
    
    gtk_menu_item_toggle_size_request (GTK_MENU_ITEM (widget), &req);
    
    if (global_counter_toggle_size_request == 0)
    {
        TEST_FAIL ("gtk_menu_item_toggle_size_request() should emit 'toggle_size_request' signal", NULL);
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_item_toggle_size_allocate
 * Params: GtkMenuItem *menu_item, gint *requisition
 * Returns: void
 * Assertion: Emits the "toggle_size_allocate" signal on the given item.
 * Params Values: a newly created GtkMenuItem*, gint*
 * Expected: void  
 */
static void test_purpose_25()
{
    GtkWidget *widget;
    gint size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter_toggle_size_allocate = 0;
    
    widget = gtk_menu_item_new_with_label ("Item");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    g_signal_connect (G_OBJECT (widget), "toggle_size_allocate", 
                      GTK_SIGNAL_FUNC (global_toggle_size_allocate_signal_handler), 
                      NULL);
    
    gtk_menu_item_toggle_size_allocate (GTK_MENU_ITEM (widget), size);
    
    if (global_counter_toggle_size_allocate == 0)
    {
        TEST_FAIL ("gtk_menu_item_toggle_size_allocate() should emit 'toggle_size_allocate' signal", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_item_set_accel_path
 * Params: GtkMenuItem *menu_item, const gchar *accel_path
 * Returns: void
 * Assertion: Set the accelerator path on menu_item, through which runtime changes of the menu item's accelerator caused by the user can be identified and saved to persistant storage (see gtk_accel_map_save() on this).'
 * Params Values: GtkMenuItem* menu_item, const gchar *accel_path
 * Expected: void  
 */
static void test_purpose_26()
{
    #define PATH "<test>/action_A"
    #define KEY GDK_A
    #define MODS GDK_SHIFT_MASK
    
    GtkWidget *widget;
    GtkAccelKey key;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_item_new_with_label ("Item");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_accel_map_add_entry (PATH, KEY, MODS);
    gtk_menu_item_set_accel_path (GTK_MENU_ITEM (widget), PATH);
    
    if (!gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns NULL", NULL);
        return;
    }
    
    if (key.accel_key != KEY)
    {
        TEST_FAIL ("accel keys not equal", NULL);
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef KEY
    #undef MODS
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_item_set_accel_path
 * Params: GtkMenuItem *menu_item, const gchar *accel_path
 * Returns: void
 * Assertion: Set the accelerator path on menu_item, through which runtime changes of the menu item's accelerator caused by the user can be identified and saved to persistant storage (see gtk_accel_map_save() on this).'
 * Params Values: GtkMenuItem* menu_item, const gchar *accel_path
 * Expected: void  
 */
static void test_purpose_27()
{
    #define PATH "<test>/action_B"
    #define KEY GDK_B
    #define MODS GDK_SHIFT_MASK
    
    GtkWidget *widget;
    GtkAccelKey key;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_item_new_with_label ("Item");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_accel_map_add_entry (PATH, KEY, MODS);
    gtk_menu_item_set_accel_path (GTK_MENU_ITEM (widget), PATH);
    
    if (!gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns NULL", NULL);
        return;
    }
    
    if (key.accel_key != KEY)
    {
        TEST_FAIL ("accel keys not equal", NULL);
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef KEY
    #undef MODS
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_item_set_accel_path
 * Params: GtkMenuItem *menu_item, const gchar *accel_path
 * Returns: void
 * Assertion: Set the accelerator path on menu_item, through which runtime changes of the menu item's accelerator caused by the user can be identified and saved to persistant storage (see gtk_accel_map_save() on this).'
 * Params Values: GtkMenuItem* menu_item, const gchar *accel_path
 * Expected: void  
 */
static void test_purpose_28()
{
    #define PATH "<test>/action_1"
    #define KEY GDK_1
    #define MODS 0
    
    GtkWidget *widget;
    GtkAccelKey key;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_item_new_with_label ("Item");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_accel_map_add_entry (PATH, KEY, MODS);
    gtk_menu_item_set_accel_path (GTK_MENU_ITEM (widget), PATH);
    
    if (!gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns NULL", NULL);
        return;
    }
    
    if (key.accel_key != KEY)
    {
        TEST_FAIL ("accel keys not equal", NULL);
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef KEY
    #undef MODS
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkMenuItem ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {NULL,0}
};
