/*
 * GtkScale methods tests
 * Testing GtkScale methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_scale_set_digits 
 * Params: GtkScale *scale, gint digits
 * Returns: void
 * Assertion: Sets the number of decimal places that are displayed in the value.
 * Params Values: a newly created GtkScale*, -1
 * Expected: void  
 */
static void test_purpose_1()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS -1
    
    GtkWidget* scale;
    gint digits;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale),DIGITS);
    
    g_object_get(GTK_OBJECT (scale), "digits", &digits, NULL);
    if (digits != DIGITS)
    {
        TEST_FAIL ("digits is '%d', should be '%d'", digits, DIGITS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_digits 
 * Params: GtkScale *scale, gint digits
 * Returns: void
 * Assertion: Sets the number of decimal places that are displayed in the value.
 * Params Values: a newly created GtkScale*, -1
 * Expected: void  
 */
static void test_purpose_2()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS -1
    
    GtkWidget* scale;
    gint digits;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale),DIGITS);
    
    g_object_get(GTK_OBJECT (scale), "digits", &digits, NULL);
    if (digits != DIGITS)
    {
        TEST_FAIL ("digits is '%d', should be '%d'", digits, DIGITS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_digits 
 * Params: GtkScale *scale, gint digits
 * Returns: void
 * Assertion: Sets the number of decimal places that are displayed in the value.
 * Params Values: a newly created GtkScale*, 0
 * Expected: void  
 */
static void test_purpose_3()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 0
    
    GtkWidget* scale;
    gint digits;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale),DIGITS);
    
    g_object_get(GTK_OBJECT (scale), "digits", &digits, NULL);
    if (digits != DIGITS)
    {
        TEST_FAIL ("digits is '%d', should be '%d'", digits, DIGITS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_digits 
 * Params: GtkScale *scale, gint digits
 * Returns: void
 * Assertion: Sets the number of decimal places that are displayed in the value.
 * Params Values: a newly created GtkScale*, 1
 * Expected: void  
 */
static void test_purpose_4()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 1
    
    GtkWidget* scale;
    gint digits;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale),DIGITS);
    
    g_object_get(GTK_OBJECT (scale), "digits", &digits, NULL);
    if (digits != DIGITS)
    {
        TEST_FAIL ("digits is '%d', should be '%d'", digits, DIGITS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_digits 
 * Params: GtkScale *scale, gint digits
 * Returns: void
 * Assertion: Sets the number of decimal places that are displayed in the value.
 * Params Values: a newly created GtkScale*, 10
 * Expected: void  
 */
static void test_purpose_5()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 10
    
    GtkWidget* scale;
    gint digits;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale),DIGITS);
    
    g_object_get(GTK_OBJECT (scale), "digits", &digits, NULL);
    if (digits != DIGITS)
    {
        TEST_FAIL ("digits is '%d', should be '%d'", digits, DIGITS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_digits 
 * Params: GtkScale *scale, gint digits
 * Returns: void
 * Assertion: Sets the number of decimal places that are displayed in the value.
 * Params Values: a newly created GtkScale*, 16
 * Expected: void  
 */
static void test_purpose_6()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 16
    
    GtkWidget* scale;
    gint digits;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale),DIGITS);
    
    g_object_get(GTK_OBJECT (scale), "digits", &digits, NULL);
    if (digits != DIGITS)
    {
        TEST_FAIL ("digits is '%d', should be '%d'", digits, DIGITS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_digits 
 * Params: GtkScale* scale
 * Returns: gint
 * Assertion: Gets the number of decimal places that are displayed in the value
 * Params Values: GtkScale* scale
 * Expected: -1  
 */
static void test_purpose_7()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS -1
    
    GtkWidget* scale;
    gint digits;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    g_object_set(GTK_OBJECT (scale), "digits", DIGITS, NULL);
    digits = gtk_scale_get_digits (GTK_SCALE (scale));
    
    if (digits != DIGITS)
    {
        TEST_FAIL ("digits is '%d', should be '%d'", digits, DIGITS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_digits 
 * Params: GtkScale* scale
 * Returns: gint
 * Assertion: Gets the number of decimal places that are displayed in the value
 * Params Values: GtkScale* scale
 * Expected: -1  
 */
static void test_purpose_8()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS -1
    
    GtkWidget* scale;
    gint digits;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    g_object_set(GTK_OBJECT (scale), "digits", DIGITS, NULL);
    digits = gtk_scale_get_digits (GTK_SCALE (scale));
    
    if (digits != DIGITS)
    {
        TEST_FAIL ("digits is '%d', should be '%d'", digits, DIGITS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_digits 
 * Params: GtkScale* scale
 * Returns: gint
 * Assertion: Gets the number of decimal places that are displayed in the value
 * Params Values: GtkScale* scale
 * Expected: 0  
 */
static void test_purpose_9()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 0
    
    GtkWidget* scale;
    gint digits;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    g_object_set(GTK_OBJECT (scale), "digits", DIGITS, NULL);
    digits = gtk_scale_get_digits (GTK_SCALE (scale));
    
    if (digits != DIGITS)
    {
        TEST_FAIL ("digits is '%d', should be '%d'", digits, DIGITS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_digits 
 * Params: GtkScale* scale
 * Returns: gint
 * Assertion: Gets the number of decimal places that are displayed in the value
 * Params Values: GtkScale* scale
 * Expected: 1  
 */
static void test_purpose_10()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 1
    
    GtkWidget* scale;
    gint digits;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    g_object_set(GTK_OBJECT (scale), "digits", DIGITS, NULL);
    digits = gtk_scale_get_digits (GTK_SCALE (scale));
    
    if (digits != DIGITS)
    {
        TEST_FAIL ("digits is '%d', should be '%d'", digits, DIGITS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_digits 
 * Params: GtkScale* scale
 * Returns: gint
 * Assertion: Gets the number of decimal places that are displayed in the value
 * Params Values: GtkScale* scale
 * Expected: 10  
 */
static void test_purpose_11()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 10
    
    GtkWidget* scale;
    gint digits;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    g_object_set(GTK_OBJECT (scale), "digits", DIGITS, NULL);
    digits = gtk_scale_get_digits (GTK_SCALE (scale));
    
    if (digits != DIGITS)
    {
        TEST_FAIL ("digits is '%d', should be '%d'", digits, DIGITS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_digits 
 * Params: GtkScale* scale
 * Returns: gint
 * Assertion: Gets the number of decimal places that are displayed in the value
 * Params Values: GtkScale* scale
 * Expected: 16  
 */
static void test_purpose_12()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 16
    
    GtkWidget* scale;
    gint digits;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    g_object_set(GTK_OBJECT (scale), "digits", DIGITS, NULL);
    digits = gtk_scale_get_digits (GTK_SCALE (scale));
    
    if (digits != DIGITS)
    {
        TEST_FAIL ("digits is '%d', should be '%d'", digits, DIGITS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_draw_value
 * Params: GtkScale *scale, gboolean draw_value
 * Returns: void
 * Assertion: Specifies whether the current value is displayed as a string next to the slider.
 * Params Values: a newly created GtkScale*, TRUE
 * Expected: void  
 */
static void test_purpose_13()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DRAW_VALUE TRUE
    
    GtkWidget* scale;
    gboolean draw_value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_draw_value (GTK_SCALE (scale),DRAW_VALUE);
    g_object_get(GTK_OBJECT (scale), "draw_value", &draw_value, NULL);
    
    if (draw_value != DRAW_VALUE)
    {
        TEST_FAIL ("draw_value is '%s', should be '%s'", draw_value,DRAW_VALUE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DRAW_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_draw_value
 * Params: GtkScale *scale, gboolean draw_value
 * Returns: void
 * Assertion: Specifies whether the current value is displayed as a string next to the slider.
 * Params Values: a newly created GtkScale*, FALSE
 * Expected: void  
 */
static void test_purpose_14()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DRAW_VALUE FALSE
    
    GtkWidget* scale;
    gboolean draw_value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_draw_value (GTK_SCALE (scale),DRAW_VALUE);
    g_object_get(GTK_OBJECT (scale), "draw_value", &draw_value, NULL);
    
    if (draw_value != DRAW_VALUE)
    {
        TEST_FAIL ("draw_value is '%s', should be '%s'", draw_value,DRAW_VALUE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DRAW_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_draw_value
 * Params: GtkScale *scale, gboolean draw_value
 * Returns: void
 * Assertion: Specifies whether the current value is displayed as a string next to the slider.
 * Params Values: a newly created GtkScale*, TRUE
 * Expected: void  
 */
static void test_purpose_15()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DRAW_VALUE TRUE
    
    GtkWidget* scale;
    gboolean draw_value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_draw_value (GTK_SCALE (scale),DRAW_VALUE);
    g_object_get(GTK_OBJECT (scale), "draw_value", &draw_value, NULL);
    
    if (draw_value != DRAW_VALUE)
    {
        TEST_FAIL ("draw_value is '%s', should be '%s'", draw_value,DRAW_VALUE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DRAW_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_draw_value
 * Params: GtkScale *scale, gboolean draw_value
 * Returns: void
 * Assertion: Specifies whether the current value is displayed as a string next to the slider.
 * Params Values: a newly created GtkScale*, FALSE
 * Expected: void  
 */
static void test_purpose_16()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DRAW_VALUE FALSE
    
    GtkWidget* scale;
    gboolean draw_value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_draw_value (GTK_SCALE (scale),DRAW_VALUE);
    g_object_get(GTK_OBJECT (scale), "draw_value", &draw_value, NULL);
    
    if (draw_value != DRAW_VALUE)
    {
        TEST_FAIL ("draw_value is '%s', should be '%s'", draw_value,DRAW_VALUE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DRAW_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_draw_value
 * Params: GtkScale *scale
 * Returns: gboolean
 * Assertion: Returns whether the current value is displayed as a string next to the slider
 * Params Values: a newly created GtkScale*
 * Expected: TRUE  
 */
static void test_purpose_17()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DRAW_VALUE TRUE
    
    GtkWidget* scale;
    gboolean draw_value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    g_object_set (GTK_OBJECT (scale), "draw_value", (gboolean)DRAW_VALUE, NULL);
    draw_value = gtk_scale_get_draw_value (GTK_SCALE (scale));
    
    if (draw_value != DRAW_VALUE)
    {
        TEST_FAIL ("draw_value is '%s', should be '%s'", draw_value,DRAW_VALUE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DRAW_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_draw_value
 * Params: GtkScale *scale
 * Returns: gboolean
 * Assertion: Returns whether the current value is displayed as a string next to the slider
 * Params Values: a newly created GtkScale*
 * Expected: FALSE  
 */
static void test_purpose_18()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DRAW_VALUE FALSE
    
    GtkWidget* scale;
    gboolean draw_value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    g_object_set (GTK_OBJECT (scale), "draw_value", (gboolean)DRAW_VALUE, NULL);
    draw_value = gtk_scale_get_draw_value (GTK_SCALE (scale));
    
    if (draw_value != DRAW_VALUE)
    {
        TEST_FAIL ("draw_value is '%s', should be '%s'", draw_value,DRAW_VALUE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DRAW_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_draw_value
 * Params: GtkScale *scale
 * Returns: gboolean
 * Assertion: Returns whether the current value is displayed as a string next to the slider
 * Params Values: a newly created GtkScale*
 * Expected: TRUE  
 */
static void test_purpose_19()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DRAW_VALUE TRUE
    
    GtkWidget* scale;
    gboolean draw_value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    g_object_set (GTK_OBJECT (scale), "draw_value", (gboolean)DRAW_VALUE, NULL);
    draw_value = gtk_scale_get_draw_value (GTK_SCALE (scale));
    
    if (draw_value != DRAW_VALUE)
    {
        TEST_FAIL ("draw_value is '%s', should be '%s'", draw_value,DRAW_VALUE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DRAW_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_draw_value
 * Params: GtkScale *scale
 * Returns: gboolean
 * Assertion: Returns whether the current value is displayed as a string next to the slider
 * Params Values: a newly created GtkScale*
 * Expected: FALSE  
 */
static void test_purpose_20()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DRAW_VALUE FALSE
    
    GtkWidget* scale;
    gboolean draw_value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    g_object_set (GTK_OBJECT (scale), "draw_value", (gboolean)DRAW_VALUE, NULL);
    draw_value = gtk_scale_get_draw_value (GTK_SCALE (scale));
    
    if (draw_value != DRAW_VALUE)
    {
        TEST_FAIL ("draw_value is '%s', should be '%s'", draw_value,DRAW_VALUE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DRAW_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_value_pos
 * Params: GtkScale *scale, GtkPositionType pos
 * Returns: void
 * Assertion: Sets the position in which the current value is displayed.
 * Params Values: a newly created GtkScale*, 1
 * Expected: void  
 */
static void test_purpose_21()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 1
    #define POS GTK_POS_LEFT
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale),DIGITS);
    gtk_scale_set_value_pos (GTK_SCALE (scale),POS);
    
    g_object_get(GTK_OBJECT (scale), "value-pos", &pos, NULL);
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_value_pos
 * Params: GtkScale *scale, GtkPositionType pos
 * Returns: void
 * Assertion: Sets the position in which the current value is displayed.
 * Params Values: a newly created GtkScale*, 1
 * Expected: void  
 */
static void test_purpose_22()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 1
    #define POS GTK_POS_RIGHT
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale),DIGITS);
    gtk_scale_set_value_pos (GTK_SCALE (scale),POS);
    
    g_object_get(GTK_OBJECT (scale), "value-pos", &pos, NULL);
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_value_pos
 * Params: GtkScale *scale, GtkPositionType pos
 * Returns: void
 * Assertion: Sets the position in which the current value is displayed.
 * Params Values: a newly created GtkScale*, 1
 * Expected: void  
 */
static void test_purpose_23()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 1
    #define POS GTK_POS_TOP
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale),DIGITS);
    gtk_scale_set_value_pos (GTK_SCALE (scale),POS);
    
    g_object_get(GTK_OBJECT (scale), "value-pos", &pos, NULL);
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_value_pos
 * Params: GtkScale *scale, GtkPositionType pos
 * Returns: void
 * Assertion: Sets the position in which the current value is displayed.
 * Params Values: a newly created GtkScale*, 1
 * Expected: void  
 */
static void test_purpose_24()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 1
    #define POS GTK_POS_BOTTOM
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale),DIGITS);
    gtk_scale_set_value_pos (GTK_SCALE (scale),POS);
    
    g_object_get(GTK_OBJECT (scale), "value-pos", &pos, NULL);
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_value_pos
 * Params: GtkScale *scale, GtkPositionType pos
 * Returns: void
 * Assertion: Sets the position in which the current value is displayed.
 * Params Values: a newly created GtkScale*, 5
 * Expected: void  
 */
static void test_purpose_25()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 5
    #define POS GTK_POS_LEFT
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale),DIGITS);
    gtk_scale_set_value_pos (GTK_SCALE (scale),POS);
    
    g_object_get(GTK_OBJECT (scale), "value-pos", &pos, NULL);
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_value_pos
 * Params: GtkScale *scale, GtkPositionType pos
 * Returns: void
 * Assertion: Sets the position in which the current value is displayed.
 * Params Values: a newly created GtkScale*, 5
 * Expected: void  
 */
static void test_purpose_26()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 5
    #define POS GTK_POS_RIGHT
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale),DIGITS);
    gtk_scale_set_value_pos (GTK_SCALE (scale),POS);
    
    g_object_get(GTK_OBJECT (scale), "value-pos", &pos, NULL);
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_value_pos
 * Params: GtkScale *scale, GtkPositionType pos
 * Returns: void
 * Assertion: Sets the position in which the current value is displayed.
 * Params Values: a newly created GtkScale*, 5
 * Expected: void  
 */
static void test_purpose_27()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 5
    #define POS GTK_POS_TOP
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale),DIGITS);
    gtk_scale_set_value_pos (GTK_SCALE (scale),POS);
    
    g_object_get(GTK_OBJECT (scale), "value-pos", &pos, NULL);
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_value_pos
 * Params: GtkScale *scale, GtkPositionType pos
 * Returns: void
 * Assertion: Sets the position in which the current value is displayed.
 * Params Values: a newly created GtkScale*, 5
 * Expected: void  
 */
static void test_purpose_28()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 5
    #define POS GTK_POS_BOTTOM
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale),DIGITS);
    gtk_scale_set_value_pos (GTK_SCALE (scale),POS);
    
    g_object_get(GTK_OBJECT (scale), "value-pos", &pos, NULL);
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_value_pos
 * Params: GtkScale *scale, GtkPositionType pos
 * Returns: void
 * Assertion: Sets the position in which the current value is displayed.
 * Params Values: a newly created GtkScale*, 10
 * Expected: void  
 */
static void test_purpose_29()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 10
    #define POS GTK_POS_LEFT
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale),DIGITS);
    gtk_scale_set_value_pos (GTK_SCALE (scale),POS);
    
    g_object_get(GTK_OBJECT (scale), "value-pos", &pos, NULL);
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_value_pos
 * Params: GtkScale *scale, GtkPositionType pos
 * Returns: void
 * Assertion: Sets the position in which the current value is displayed.
 * Params Values: a newly created GtkScale*, 10
 * Expected: void  
 */
static void test_purpose_30()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 10
    #define POS GTK_POS_RIGHT
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale),DIGITS);
    gtk_scale_set_value_pos (GTK_SCALE (scale),POS);
    
    g_object_get(GTK_OBJECT (scale), "value-pos", &pos, NULL);
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_value_pos
 * Params: GtkScale *scale, GtkPositionType pos
 * Returns: void
 * Assertion: Sets the position in which the current value is displayed.
 * Params Values: a newly created GtkScale*, 10
 * Expected: void  
 */
static void test_purpose_31()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 10
    #define POS GTK_POS_TOP
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale),DIGITS);
    gtk_scale_set_value_pos (GTK_SCALE (scale),POS);
    
    g_object_get(GTK_OBJECT (scale), "value-pos", &pos, NULL);
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_value_pos
 * Params: GtkScale *scale, GtkPositionType pos
 * Returns: void
 * Assertion: Sets the position in which the current value is displayed.
 * Params Values: a newly created GtkScale*, 10
 * Expected: void  
 */
static void test_purpose_32()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 10
    #define POS GTK_POS_BOTTOM
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale),DIGITS);
    gtk_scale_set_value_pos (GTK_SCALE (scale),POS);
    
    g_object_get(GTK_OBJECT (scale), "value-pos", &pos, NULL);
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_value_pos
 * Params: GtkScale *scale, GtkPositionType pos
 * Returns: void
 * Assertion: Sets the position in which the current value is displayed.
 * Params Values: a newly created GtkScale*, 1
 * Expected: void  
 */
static void test_purpose_33()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 1
    #define POS GTK_POS_LEFT
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale),DIGITS);
    gtk_scale_set_value_pos (GTK_SCALE (scale),POS);
    
    g_object_get(GTK_OBJECT (scale), "value-pos", &pos, NULL);
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_value_pos
 * Params: GtkScale *scale, GtkPositionType pos
 * Returns: void
 * Assertion: Sets the position in which the current value is displayed.
 * Params Values: a newly created GtkScale*, 1
 * Expected: void  
 */
static void test_purpose_34()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 1
    #define POS GTK_POS_RIGHT
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale),DIGITS);
    gtk_scale_set_value_pos (GTK_SCALE (scale),POS);
    
    g_object_get(GTK_OBJECT (scale), "value-pos", &pos, NULL);
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_value_pos
 * Params: GtkScale *scale, GtkPositionType pos
 * Returns: void
 * Assertion: Sets the position in which the current value is displayed.
 * Params Values: a newly created GtkScale*, 1
 * Expected: void  
 */
static void test_purpose_35()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 1
    #define POS GTK_POS_TOP
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale),DIGITS);
    gtk_scale_set_value_pos (GTK_SCALE (scale),POS);
    
    g_object_get(GTK_OBJECT (scale), "value-pos", &pos, NULL);
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_value_pos
 * Params: GtkScale *scale, GtkPositionType pos
 * Returns: void
 * Assertion: Sets the position in which the current value is displayed.
 * Params Values: a newly created GtkScale*, 1
 * Expected: void  
 */
static void test_purpose_36()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 1
    #define POS GTK_POS_BOTTOM
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale),DIGITS);
    gtk_scale_set_value_pos (GTK_SCALE (scale),POS);
    
    g_object_get(GTK_OBJECT (scale), "value-pos", &pos, NULL);
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_value_pos
 * Params: GtkScale *scale, GtkPositionType pos
 * Returns: void
 * Assertion: Sets the position in which the current value is displayed.
 * Params Values: a newly created GtkScale*, 5
 * Expected: void  
 */
static void test_purpose_37()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 5
    #define POS GTK_POS_LEFT
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale),DIGITS);
    gtk_scale_set_value_pos (GTK_SCALE (scale),POS);
    
    g_object_get(GTK_OBJECT (scale), "value-pos", &pos, NULL);
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_value_pos
 * Params: GtkScale *scale, GtkPositionType pos
 * Returns: void
 * Assertion: Sets the position in which the current value is displayed.
 * Params Values: a newly created GtkScale*, 5
 * Expected: void  
 */
static void test_purpose_38()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 5
    #define POS GTK_POS_RIGHT
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale),DIGITS);
    gtk_scale_set_value_pos (GTK_SCALE (scale),POS);
    
    g_object_get(GTK_OBJECT (scale), "value-pos", &pos, NULL);
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_value_pos
 * Params: GtkScale *scale, GtkPositionType pos
 * Returns: void
 * Assertion: Sets the position in which the current value is displayed.
 * Params Values: a newly created GtkScale*, 5
 * Expected: void  
 */
static void test_purpose_39()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 5
    #define POS GTK_POS_TOP
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale),DIGITS);
    gtk_scale_set_value_pos (GTK_SCALE (scale),POS);
    
    g_object_get(GTK_OBJECT (scale), "value-pos", &pos, NULL);
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_value_pos
 * Params: GtkScale *scale, GtkPositionType pos
 * Returns: void
 * Assertion: Sets the position in which the current value is displayed.
 * Params Values: a newly created GtkScale*, 5
 * Expected: void  
 */
static void test_purpose_40()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 5
    #define POS GTK_POS_BOTTOM
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale),DIGITS);
    gtk_scale_set_value_pos (GTK_SCALE (scale),POS);
    
    g_object_get(GTK_OBJECT (scale), "value-pos", &pos, NULL);
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_value_pos
 * Params: GtkScale *scale, GtkPositionType pos
 * Returns: void
 * Assertion: Sets the position in which the current value is displayed.
 * Params Values: a newly created GtkScale*, 10
 * Expected: void  
 */
static void test_purpose_41()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 10
    #define POS GTK_POS_LEFT
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale),DIGITS);
    gtk_scale_set_value_pos (GTK_SCALE (scale),POS);
    
    g_object_get(GTK_OBJECT (scale), "value-pos", &pos, NULL);
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_value_pos
 * Params: GtkScale *scale, GtkPositionType pos
 * Returns: void
 * Assertion: Sets the position in which the current value is displayed.
 * Params Values: a newly created GtkScale*, 10
 * Expected: void  
 */
static void test_purpose_42()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 10
    #define POS GTK_POS_RIGHT
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale),DIGITS);
    gtk_scale_set_value_pos (GTK_SCALE (scale),POS);
    
    g_object_get(GTK_OBJECT (scale), "value-pos", &pos, NULL);
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_value_pos
 * Params: GtkScale *scale, GtkPositionType pos
 * Returns: void
 * Assertion: Sets the position in which the current value is displayed.
 * Params Values: a newly created GtkScale*, 10
 * Expected: void  
 */
static void test_purpose_43()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 10
    #define POS GTK_POS_TOP
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale),DIGITS);
    gtk_scale_set_value_pos (GTK_SCALE (scale),POS);
    
    g_object_get(GTK_OBJECT (scale), "value-pos", &pos, NULL);
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_set_value_pos
 * Params: GtkScale *scale, GtkPositionType pos
 * Returns: void
 * Assertion: Sets the position in which the current value is displayed.
 * Params Values: a newly created GtkScale*, 10
 * Expected: void  
 */
static void test_purpose_44()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 10
    #define POS GTK_POS_BOTTOM
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale),DIGITS);
    gtk_scale_set_value_pos (GTK_SCALE (scale),POS);
    
    g_object_get(GTK_OBJECT (scale), "value-pos", &pos, NULL);
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_value_pos
 * Params: GtkScale *scale 
 * Returns: GtkPositionType
 * Assertion: Gets the position in which the current value is displayed
 * Params Values: a newly created GtkScale*, 1
 * Expected: GtkPositionType  
 */
static void test_purpose_45()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 1
    #define POS GTK_POS_LEFT
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale), DIGITS);
    
    g_object_set (GTK_OBJECT (scale), "value-pos", POS, NULL);
    pos = gtk_scale_get_value_pos (GTK_SCALE (scale));
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_value_pos
 * Params: GtkScale *scale 
 * Returns: GtkPositionType
 * Assertion: Gets the position in which the current value is displayed
 * Params Values: a newly created GtkScale*, 1
 * Expected: GtkPositionType  
 */
static void test_purpose_46()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 1
    #define POS GTK_POS_RIGHT
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale), DIGITS);
    
    g_object_set (GTK_OBJECT (scale), "value-pos", POS, NULL);
    pos = gtk_scale_get_value_pos (GTK_SCALE (scale));
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_value_pos
 * Params: GtkScale *scale 
 * Returns: GtkPositionType
 * Assertion: Gets the position in which the current value is displayed
 * Params Values: a newly created GtkScale*, 1
 * Expected: GtkPositionType  
 */
static void test_purpose_47()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 1
    #define POS GTK_POS_TOP
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale), DIGITS);
    
    g_object_set (GTK_OBJECT (scale), "value-pos", POS, NULL);
    pos = gtk_scale_get_value_pos (GTK_SCALE (scale));
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_value_pos
 * Params: GtkScale *scale 
 * Returns: GtkPositionType
 * Assertion: Gets the position in which the current value is displayed
 * Params Values: a newly created GtkScale*, 1
 * Expected: GtkPositionType  
 */
static void test_purpose_48()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 1
    #define POS GTK_POS_BOTTOM
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale), DIGITS);
    
    g_object_set (GTK_OBJECT (scale), "value-pos", POS, NULL);
    pos = gtk_scale_get_value_pos (GTK_SCALE (scale));
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_value_pos
 * Params: GtkScale *scale 
 * Returns: GtkPositionType
 * Assertion: Gets the position in which the current value is displayed
 * Params Values: a newly created GtkScale*, 5
 * Expected: GtkPositionType  
 */
static void test_purpose_49()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 5
    #define POS GTK_POS_LEFT
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale), DIGITS);
    
    g_object_set (GTK_OBJECT (scale), "value-pos", POS, NULL);
    pos = gtk_scale_get_value_pos (GTK_SCALE (scale));
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_value_pos
 * Params: GtkScale *scale 
 * Returns: GtkPositionType
 * Assertion: Gets the position in which the current value is displayed
 * Params Values: a newly created GtkScale*, 5
 * Expected: GtkPositionType  
 */
static void test_purpose_50()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 5
    #define POS GTK_POS_RIGHT
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale), DIGITS);
    
    g_object_set (GTK_OBJECT (scale), "value-pos", POS, NULL);
    pos = gtk_scale_get_value_pos (GTK_SCALE (scale));
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_value_pos
 * Params: GtkScale *scale 
 * Returns: GtkPositionType
 * Assertion: Gets the position in which the current value is displayed
 * Params Values: a newly created GtkScale*, 5
 * Expected: GtkPositionType  
 */
static void test_purpose_51()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 5
    #define POS GTK_POS_TOP
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale), DIGITS);
    
    g_object_set (GTK_OBJECT (scale), "value-pos", POS, NULL);
    pos = gtk_scale_get_value_pos (GTK_SCALE (scale));
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_value_pos
 * Params: GtkScale *scale 
 * Returns: GtkPositionType
 * Assertion: Gets the position in which the current value is displayed
 * Params Values: a newly created GtkScale*, 5
 * Expected: GtkPositionType  
 */
static void test_purpose_52()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 5
    #define POS GTK_POS_BOTTOM
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale), DIGITS);
    
    g_object_set (GTK_OBJECT (scale), "value-pos", POS, NULL);
    pos = gtk_scale_get_value_pos (GTK_SCALE (scale));
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_value_pos
 * Params: GtkScale *scale 
 * Returns: GtkPositionType
 * Assertion: Gets the position in which the current value is displayed
 * Params Values: a newly created GtkScale*, 10
 * Expected: GtkPositionType  
 */
static void test_purpose_53()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 10
    #define POS GTK_POS_LEFT
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale), DIGITS);
    
    g_object_set (GTK_OBJECT (scale), "value-pos", POS, NULL);
    pos = gtk_scale_get_value_pos (GTK_SCALE (scale));
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_value_pos
 * Params: GtkScale *scale 
 * Returns: GtkPositionType
 * Assertion: Gets the position in which the current value is displayed
 * Params Values: a newly created GtkScale*, 10
 * Expected: GtkPositionType  
 */
static void test_purpose_54()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 10
    #define POS GTK_POS_RIGHT
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale), DIGITS);
    
    g_object_set (GTK_OBJECT (scale), "value-pos", POS, NULL);
    pos = gtk_scale_get_value_pos (GTK_SCALE (scale));
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_value_pos
 * Params: GtkScale *scale 
 * Returns: GtkPositionType
 * Assertion: Gets the position in which the current value is displayed
 * Params Values: a newly created GtkScale*, 10
 * Expected: GtkPositionType  
 */
static void test_purpose_55()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 10
    #define POS GTK_POS_TOP
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale), DIGITS);
    
    g_object_set (GTK_OBJECT (scale), "value-pos", POS, NULL);
    pos = gtk_scale_get_value_pos (GTK_SCALE (scale));
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_value_pos
 * Params: GtkScale *scale 
 * Returns: GtkPositionType
 * Assertion: Gets the position in which the current value is displayed
 * Params Values: a newly created GtkScale*, 10
 * Expected: GtkPositionType  
 */
static void test_purpose_56()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 10
    #define POS GTK_POS_BOTTOM
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale), DIGITS);
    
    g_object_set (GTK_OBJECT (scale), "value-pos", POS, NULL);
    pos = gtk_scale_get_value_pos (GTK_SCALE (scale));
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_value_pos
 * Params: GtkScale *scale 
 * Returns: GtkPositionType
 * Assertion: Gets the position in which the current value is displayed
 * Params Values: a newly created GtkScale*, 1
 * Expected: GtkPositionType  
 */
static void test_purpose_57()
{
    #define SCALE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 1
    #define POS GTK_POS_LEFT
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale), DIGITS);
    
    g_object_set (GTK_OBJECT (scale), "value-pos", POS, NULL);
    pos = gtk_scale_get_value_pos (GTK_SCALE (scale));
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_value_pos
 * Params: GtkScale *scale 
 * Returns: GtkPositionType
 * Assertion: Gets the position in which the current value is displayed
 * Params Values: a newly created GtkScale*, 1
 * Expected: GtkPositionType  
 */
static void test_purpose_58()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 1
    #define POS GTK_POS_RIGHT
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale), DIGITS);
    
    g_object_set (GTK_OBJECT (scale), "value-pos", POS, NULL);
    pos = gtk_scale_get_value_pos (GTK_SCALE (scale));
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_value_pos
 * Params: GtkScale *scale 
 * Returns: GtkPositionType
 * Assertion: Gets the position in which the current value is displayed
 * Params Values: a newly created GtkScale*, 1
 * Expected: GtkPositionType  
 */
static void test_purpose_59()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 1
    #define POS GTK_POS_TOP
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale), DIGITS);
    
    g_object_set (GTK_OBJECT (scale), "value-pos", POS, NULL);
    pos = gtk_scale_get_value_pos (GTK_SCALE (scale));
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_value_pos
 * Params: GtkScale *scale 
 * Returns: GtkPositionType
 * Assertion: Gets the position in which the current value is displayed
 * Params Values: a newly created GtkScale*, 1
 * Expected: GtkPositionType  
 */
static void test_purpose_60()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 1
    #define POS GTK_POS_BOTTOM
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale), DIGITS);
    
    g_object_set (GTK_OBJECT (scale), "value-pos", POS, NULL);
    pos = gtk_scale_get_value_pos (GTK_SCALE (scale));
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_value_pos
 * Params: GtkScale *scale 
 * Returns: GtkPositionType
 * Assertion: Gets the position in which the current value is displayed
 * Params Values: a newly created GtkScale*, 5
 * Expected: GtkPositionType  
 */
static void test_purpose_61()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 5
    #define POS GTK_POS_LEFT
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale), DIGITS);
    
    g_object_set (GTK_OBJECT (scale), "value-pos", POS, NULL);
    pos = gtk_scale_get_value_pos (GTK_SCALE (scale));
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_value_pos
 * Params: GtkScale *scale 
 * Returns: GtkPositionType
 * Assertion: Gets the position in which the current value is displayed
 * Params Values: a newly created GtkScale*, 5
 * Expected: GtkPositionType  
 */
static void test_purpose_62()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 5
    #define POS GTK_POS_RIGHT
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale), DIGITS);
    
    g_object_set (GTK_OBJECT (scale), "value-pos", POS, NULL);
    pos = gtk_scale_get_value_pos (GTK_SCALE (scale));
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_value_pos
 * Params: GtkScale *scale 
 * Returns: GtkPositionType
 * Assertion: Gets the position in which the current value is displayed
 * Params Values: a newly created GtkScale*, 5
 * Expected: GtkPositionType  
 */
static void test_purpose_63()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 5
    #define POS GTK_POS_TOP
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale), DIGITS);
    
    g_object_set (GTK_OBJECT (scale), "value-pos", POS, NULL);
    pos = gtk_scale_get_value_pos (GTK_SCALE (scale));
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_value_pos
 * Params: GtkScale *scale 
 * Returns: GtkPositionType
 * Assertion: Gets the position in which the current value is displayed
 * Params Values: a newly created GtkScale*, 5
 * Expected: GtkPositionType  
 */
static void test_purpose_64()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 5
    #define POS GTK_POS_BOTTOM
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale), DIGITS);
    
    g_object_set (GTK_OBJECT (scale), "value-pos", POS, NULL);
    pos = gtk_scale_get_value_pos (GTK_SCALE (scale));
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_value_pos
 * Params: GtkScale *scale 
 * Returns: GtkPositionType
 * Assertion: Gets the position in which the current value is displayed
 * Params Values: a newly created GtkScale*, 10
 * Expected: GtkPositionType  
 */
static void test_purpose_65()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 10
    #define POS GTK_POS_LEFT
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale), DIGITS);
    
    g_object_set (GTK_OBJECT (scale), "value-pos", POS, NULL);
    pos = gtk_scale_get_value_pos (GTK_SCALE (scale));
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_value_pos
 * Params: GtkScale *scale 
 * Returns: GtkPositionType
 * Assertion: Gets the position in which the current value is displayed
 * Params Values: a newly created GtkScale*, 10
 * Expected: GtkPositionType  
 */
static void test_purpose_66()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 10
    #define POS GTK_POS_RIGHT
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale), DIGITS);
    
    g_object_set (GTK_OBJECT (scale), "value-pos", POS, NULL);
    pos = gtk_scale_get_value_pos (GTK_SCALE (scale));
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_value_pos
 * Params: GtkScale *scale 
 * Returns: GtkPositionType
 * Assertion: Gets the position in which the current value is displayed
 * Params Values: a newly created GtkScale*, 10
 * Expected: GtkPositionType  
 */
static void test_purpose_67()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 10
    #define POS GTK_POS_TOP
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale), DIGITS);
    
    g_object_set (GTK_OBJECT (scale), "value-pos", POS, NULL);
    pos = gtk_scale_get_value_pos (GTK_SCALE (scale));
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scale_get_value_pos
 * Params: GtkScale *scale 
 * Returns: GtkPositionType
 * Assertion: Gets the position in which the current value is displayed
 * Params Values: a newly created GtkScale*, 10
 * Expected: GtkPositionType  
 */
static void test_purpose_68()
{
    #define SCALE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0,1.0,1.0,1.0,1.0,10.0)))
    #define DIGITS 10
    #define POS GTK_POS_BOTTOM
    
    GtkWidget* scale;
    GtkPositionType pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    scale = SCALE;
    if (!scale)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    gtk_scale_set_digits (GTK_SCALE (scale), DIGITS);
    
    g_object_set (GTK_OBJECT (scale), "value-pos", POS, NULL);
    pos = gtk_scale_get_value_pos (GTK_SCALE (scale));
    
    if (pos != POS)
    {
        TEST_FAIL ("value-pos is '%s', should be '%s'", pos,POS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scale);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (scale));
    
    #undef SCALE
    #undef DIGITS
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkScale ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {test_purpose_52, 1},
    {test_purpose_53, 1},
    {test_purpose_54, 1},
    {test_purpose_55, 1},
    {test_purpose_56, 1},
    {test_purpose_57, 1},
    {test_purpose_58, 1},
    {test_purpose_59, 1},
    {test_purpose_60, 1},
    {test_purpose_61, 1},
    {test_purpose_62, 1},
    {test_purpose_63, 1},
    {test_purpose_64, 1},
    {test_purpose_65, 1},
    {test_purpose_66, 1},
    {test_purpose_67, 1},
    {test_purpose_68, 1},
    {NULL,0}
};
