/*
 * GtkSizeGroup methods tests
 * Testing GtkSizeGroup methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_size_group_new
 * Params: GtkSizeGroupMode mode
 * Returns: GtkSizeGroup*
 * Assertion: Create a new GtkSizeGroup
 * Params Values: GTK_SIZE_GROUP_NONE
 * Expected: GtkSizeGroup* with 'mode' arg set to GTK_SIZE_GROUP_NONE  
 */
static void test_purpose_1()
{
    #define MODE GTK_SIZE_GROUP_NONE
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (G_OBJECT (group), "mode", &real_mode, NULL);
    if (real_mode != MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode, MODE);
    }
    
    #undef MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_new
 * Params: GtkSizeGroupMode mode
 * Returns: GtkSizeGroup*
 * Assertion: Create a new GtkSizeGroup
 * Params Values: GTK_SIZE_GROUP_HORIZONTAL
 * Expected: GtkSizeGroup* with 'mode' arg set to GTK_SIZE_GROUP_HORIZONTAL  
 */
static void test_purpose_2()
{
    #define MODE GTK_SIZE_GROUP_HORIZONTAL
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (G_OBJECT (group), "mode", &real_mode, NULL);
    if (real_mode != MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode, MODE);
    }
    
    #undef MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_new
 * Params: GtkSizeGroupMode mode
 * Returns: GtkSizeGroup*
 * Assertion: Create a new GtkSizeGroup
 * Params Values: GTK_SIZE_GROUP_VERTICAL
 * Expected: GtkSizeGroup* with 'mode' arg set to GTK_SIZE_GROUP_VERTICAL  
 */
static void test_purpose_3()
{
    #define MODE GTK_SIZE_GROUP_VERTICAL
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (G_OBJECT (group), "mode", &real_mode, NULL);
    if (real_mode != MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode, MODE);
    }
    
    #undef MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_new
 * Params: GtkSizeGroupMode mode
 * Returns: GtkSizeGroup*
 * Assertion: Create a new GtkSizeGroup
 * Params Values: GTK_SIZE_GROUP_BOTH
 * Expected: GtkSizeGroup* with 'mode' arg set to GTK_SIZE_GROUP_BOTH  
 */
static void test_purpose_4()
{
    #define MODE GTK_SIZE_GROUP_BOTH
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (G_OBJECT (group), "mode", &real_mode, NULL);
    if (real_mode != MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode, MODE);
    }
    
    #undef MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_set_mode
 * Params: GtkSizeGroup *size_group, GtkSizeGroupMode mode
 * Returns: void
 * Assertion: Sets the GtkSizeGroupMode of the size group.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_NONE, GTK_SIZE_GROUP_NONE
 * Expected: void  
 */
static void test_purpose_5()
{
    #define MODE GTK_SIZE_GROUP_NONE
    #define NEW_MODE GTK_SIZE_GROUP_NONE
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_size_group_set_mode (group, NEW_MODE);
    
    g_object_get (G_OBJECT (group), "mode", &real_mode, NULL);
    if (real_mode != NEW_MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode,NEW_MODE);
    }
    
    #undef MODE
    #undef NEW_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_set_mode
 * Params: GtkSizeGroup *size_group, GtkSizeGroupMode mode
 * Returns: void
 * Assertion: Sets the GtkSizeGroupMode of the size group.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_NONE, GTK_SIZE_GROUP_HORIZONTAL
 * Expected: void  
 */
static void test_purpose_6()
{
    #define MODE GTK_SIZE_GROUP_NONE
    #define NEW_MODE GTK_SIZE_GROUP_HORIZONTAL
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_size_group_set_mode (group, NEW_MODE);
    
    g_object_get (G_OBJECT (group), "mode", &real_mode, NULL);
    if (real_mode != NEW_MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode,NEW_MODE);
    }
    
    #undef MODE
    #undef NEW_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_set_mode
 * Params: GtkSizeGroup *size_group, GtkSizeGroupMode mode
 * Returns: void
 * Assertion: Sets the GtkSizeGroupMode of the size group.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_NONE, GTK_SIZE_GROUP_VERTICAL
 * Expected: void  
 */
static void test_purpose_7()
{
    #define MODE GTK_SIZE_GROUP_NONE
    #define NEW_MODE GTK_SIZE_GROUP_VERTICAL
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_size_group_set_mode (group, NEW_MODE);
    
    g_object_get (G_OBJECT (group), "mode", &real_mode, NULL);
    if (real_mode != NEW_MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode,NEW_MODE);
    }
    
    #undef MODE
    #undef NEW_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_set_mode
 * Params: GtkSizeGroup *size_group, GtkSizeGroupMode mode
 * Returns: void
 * Assertion: Sets the GtkSizeGroupMode of the size group.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_NONE, GTK_SIZE_GROUP_BOTH
 * Expected: void  
 */
static void test_purpose_8()
{
    #define MODE GTK_SIZE_GROUP_NONE
    #define NEW_MODE GTK_SIZE_GROUP_BOTH
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_size_group_set_mode (group, NEW_MODE);
    
    g_object_get (G_OBJECT (group), "mode", &real_mode, NULL);
    if (real_mode != NEW_MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode,NEW_MODE);
    }
    
    #undef MODE
    #undef NEW_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_set_mode
 * Params: GtkSizeGroup *size_group, GtkSizeGroupMode mode
 * Returns: void
 * Assertion: Sets the GtkSizeGroupMode of the size group.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_HORIZONTAL, GTK_SIZE_GROUP_NONE
 * Expected: void  
 */
static void test_purpose_9()
{
    #define MODE GTK_SIZE_GROUP_HORIZONTAL
    #define NEW_MODE GTK_SIZE_GROUP_NONE
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_size_group_set_mode (group, NEW_MODE);
    
    g_object_get (G_OBJECT (group), "mode", &real_mode, NULL);
    if (real_mode != NEW_MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode,NEW_MODE);
    }
    
    #undef MODE
    #undef NEW_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_set_mode
 * Params: GtkSizeGroup *size_group, GtkSizeGroupMode mode
 * Returns: void
 * Assertion: Sets the GtkSizeGroupMode of the size group.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_HORIZONTAL, GTK_SIZE_GROUP_VERTICAL
 * Expected: void  
 */
static void test_purpose_10()
{
    #define MODE GTK_SIZE_GROUP_HORIZONTAL
    #define NEW_MODE GTK_SIZE_GROUP_VERTICAL
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_size_group_set_mode (group, NEW_MODE);
    
    g_object_get (G_OBJECT (group), "mode", &real_mode, NULL);
    if (real_mode != NEW_MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode,NEW_MODE);
    }
    
    #undef MODE
    #undef NEW_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_set_mode
 * Params: GtkSizeGroup *size_group, GtkSizeGroupMode mode
 * Returns: void
 * Assertion: Sets the GtkSizeGroupMode of the size group.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_HORIZONTAL, GTK_SIZE_GROUP_BOTH
 * Expected: void  
 */
static void test_purpose_11()
{
    #define MODE GTK_SIZE_GROUP_HORIZONTAL
    #define NEW_MODE GTK_SIZE_GROUP_BOTH
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_size_group_set_mode (group, NEW_MODE);
    
    g_object_get (G_OBJECT (group), "mode", &real_mode, NULL);
    if (real_mode != NEW_MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode,NEW_MODE);
    }
    
    #undef MODE
    #undef NEW_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_set_mode
 * Params: GtkSizeGroup *size_group, GtkSizeGroupMode mode
 * Returns: void
 * Assertion: Sets the GtkSizeGroupMode of the size group.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_HORIZONTAL, GTK_SIZE_GROUP_NONE
 * Expected: void  
 */
static void test_purpose_12()
{
    #define MODE GTK_SIZE_GROUP_HORIZONTAL
    #define NEW_MODE GTK_SIZE_GROUP_NONE
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_size_group_set_mode (group, NEW_MODE);
    
    g_object_get (G_OBJECT (group), "mode", &real_mode, NULL);
    if (real_mode != NEW_MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode,NEW_MODE);
    }
    
    #undef MODE
    #undef NEW_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_set_mode
 * Params: GtkSizeGroup *size_group, GtkSizeGroupMode mode
 * Returns: void
 * Assertion: Sets the GtkSizeGroupMode of the size group.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_HORIZONTAL, GTK_SIZE_GROUP_HORIZONTAL
 * Expected: void  
 */
static void test_purpose_13()
{
    #define MODE GTK_SIZE_GROUP_HORIZONTAL
    #define NEW_MODE GTK_SIZE_GROUP_HORIZONTAL
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_size_group_set_mode (group, NEW_MODE);
    
    g_object_get (G_OBJECT (group), "mode", &real_mode, NULL);
    if (real_mode != NEW_MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode,NEW_MODE);
    }
    
    #undef MODE
    #undef NEW_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_set_mode
 * Params: GtkSizeGroup *size_group, GtkSizeGroupMode mode
 * Returns: void
 * Assertion: Sets the GtkSizeGroupMode of the size group.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_HORIZONTAL, GTK_SIZE_GROUP_VERTICAL
 * Expected: void  
 */
static void test_purpose_14()
{
    #define MODE GTK_SIZE_GROUP_HORIZONTAL
    #define NEW_MODE GTK_SIZE_GROUP_VERTICAL
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_size_group_set_mode (group, NEW_MODE);
    
    g_object_get (G_OBJECT (group), "mode", &real_mode, NULL);
    if (real_mode != NEW_MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode,NEW_MODE);
    }
    
    #undef MODE
    #undef NEW_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_set_mode
 * Params: GtkSizeGroup *size_group, GtkSizeGroupMode mode
 * Returns: void
 * Assertion: Sets the GtkSizeGroupMode of the size group.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_VERTICAL, GTK_SIZE_GROUP_BOTH
 * Expected: void  
 */
static void test_purpose_15()
{
    #define MODE GTK_SIZE_GROUP_VERTICAL
    #define NEW_MODE GTK_SIZE_GROUP_BOTH
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_size_group_set_mode (group, NEW_MODE);
    
    g_object_get (G_OBJECT (group), "mode", &real_mode, NULL);
    if (real_mode != NEW_MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode,NEW_MODE);
    }
    
    #undef MODE
    #undef NEW_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_set_mode
 * Params: GtkSizeGroup *size_group, GtkSizeGroupMode mode
 * Returns: void
 * Assertion: Sets the GtkSizeGroupMode of the size group.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_BOTH, GTK_SIZE_GROUP_NONE
 * Expected: void  
 */
static void test_purpose_16()
{
    #define MODE GTK_SIZE_GROUP_BOTH
    #define NEW_MODE GTK_SIZE_GROUP_NONE
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_size_group_set_mode (group, NEW_MODE);
    
    g_object_get (G_OBJECT (group), "mode", &real_mode, NULL);
    if (real_mode != NEW_MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode,NEW_MODE);
    }
    
    #undef MODE
    #undef NEW_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_set_mode
 * Params: GtkSizeGroup *size_group, GtkSizeGroupMode mode
 * Returns: void
 * Assertion: Sets the GtkSizeGroupMode of the size group.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_BOTH, GTK_SIZE_GROUP_HORIZONTAL
 * Expected: void  
 */
static void test_purpose_17()
{
    #define MODE GTK_SIZE_GROUP_BOTH
    #define NEW_MODE GTK_SIZE_GROUP_HORIZONTAL
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_size_group_set_mode (group, NEW_MODE);
    
    g_object_get (G_OBJECT (group), "mode", &real_mode, NULL);
    if (real_mode != NEW_MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode,NEW_MODE);
    }
    
    #undef MODE
    #undef NEW_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_set_mode
 * Params: GtkSizeGroup *size_group, GtkSizeGroupMode mode
 * Returns: void
 * Assertion: Sets the GtkSizeGroupMode of the size group.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_BOTH, GTK_SIZE_GROUP_VERTICAL
 * Expected: void  
 */
static void test_purpose_18()
{
    #define MODE GTK_SIZE_GROUP_BOTH
    #define NEW_MODE GTK_SIZE_GROUP_VERTICAL
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_size_group_set_mode (group, NEW_MODE);
    
    g_object_get (G_OBJECT (group), "mode", &real_mode, NULL);
    if (real_mode != NEW_MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode,NEW_MODE);
    }
    
    #undef MODE
    #undef NEW_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_set_mode
 * Params: GtkSizeGroup *size_group, GtkSizeGroupMode mode
 * Returns: void
 * Assertion: Sets the GtkSizeGroupMode of the size group.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_BOTH, GTK_SIZE_GROUP_BOTH
 * Expected: void  
 */
static void test_purpose_19()
{
    #define MODE GTK_SIZE_GROUP_BOTH
    #define NEW_MODE GTK_SIZE_GROUP_BOTH
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_size_group_set_mode (group, NEW_MODE);
    
    g_object_get (G_OBJECT (group), "mode", &real_mode, NULL);
    if (real_mode != NEW_MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode,NEW_MODE);
    }
    
    #undef MODE
    #undef NEW_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_get_mode
 * Params: GtkSizeGroup *size_group
 * Returns: , GtkSizeGroupMode
 * Assertion: Gets the current mode of the size group.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_NONE
 * Expected: GTK_SIZE_GROUP_NONE  
 */
static void test_purpose_20()
{
    #define MODE GTK_SIZE_GROUP_NONE
    #define NEW_MODE GTK_SIZE_GROUP_NONE
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (G_OBJECT (group), "mode", NEW_MODE, NULL);
    
    real_mode = gtk_size_group_get_mode (group);
    if (real_mode != NEW_MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode,NEW_MODE);
    }
    
    #undef MODE
    #undef NEW_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_get_mode
 * Params: GtkSizeGroup *size_group
 * Returns: , GtkSizeGroupMode
 * Assertion: Gets the current mode of the size group.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_NONE
 * Expected: GTK_SIZE_GROUP_HORIZONTAL  
 */
static void test_purpose_21()
{
    #define MODE GTK_SIZE_GROUP_NONE
    #define NEW_MODE GTK_SIZE_GROUP_HORIZONTAL
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (G_OBJECT (group), "mode", NEW_MODE, NULL);
    
    real_mode = gtk_size_group_get_mode (group);
    if (real_mode != NEW_MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode,NEW_MODE);
    }
    
    #undef MODE
    #undef NEW_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_get_mode
 * Params: GtkSizeGroup *size_group
 * Returns: , GtkSizeGroupMode
 * Assertion: Gets the current mode of the size group.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_NONE
 * Expected: GTK_SIZE_GROUP_VERTICAL  
 */
static void test_purpose_22()
{
    #define MODE GTK_SIZE_GROUP_NONE
    #define NEW_MODE GTK_SIZE_GROUP_VERTICAL
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (G_OBJECT (group), "mode", NEW_MODE, NULL);
    
    real_mode = gtk_size_group_get_mode (group);
    if (real_mode != NEW_MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode,NEW_MODE);
    }
    
    #undef MODE
    #undef NEW_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_get_mode
 * Params: GtkSizeGroup *size_group
 * Returns: , GtkSizeGroupMode
 * Assertion: Gets the current mode of the size group.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_NONE
 * Expected: GTK_SIZE_GROUP_BOTH  
 */
static void test_purpose_23()
{
    #define MODE GTK_SIZE_GROUP_NONE
    #define NEW_MODE GTK_SIZE_GROUP_BOTH
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (G_OBJECT (group), "mode", NEW_MODE, NULL);
    
    real_mode = gtk_size_group_get_mode (group);
    if (real_mode != NEW_MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode,NEW_MODE);
    }
    
    #undef MODE
    #undef NEW_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_get_mode
 * Params: GtkSizeGroup *size_group
 * Returns: , GtkSizeGroupMode
 * Assertion: Gets the current mode of the size group.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_HORIZONTAL
 * Expected: GTK_SIZE_GROUP_NONE  
 */
static void test_purpose_24()
{
    #define MODE GTK_SIZE_GROUP_HORIZONTAL
    #define NEW_MODE GTK_SIZE_GROUP_NONE
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (G_OBJECT (group), "mode", NEW_MODE, NULL);
    
    real_mode = gtk_size_group_get_mode (group);
    if (real_mode != NEW_MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode,NEW_MODE);
    }
    
    #undef MODE
    #undef NEW_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_get_mode
 * Params: GtkSizeGroup *size_group
 * Returns: , GtkSizeGroupMode
 * Assertion: Gets the current mode of the size group.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_HORIZONTAL
 * Expected: GTK_SIZE_GROUP_VERTICAL  
 */
static void test_purpose_25()
{
    #define MODE GTK_SIZE_GROUP_HORIZONTAL
    #define NEW_MODE GTK_SIZE_GROUP_VERTICAL
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (G_OBJECT (group), "mode", NEW_MODE, NULL);
    
    real_mode = gtk_size_group_get_mode (group);
    if (real_mode != NEW_MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode,NEW_MODE);
    }
    
    #undef MODE
    #undef NEW_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_get_mode
 * Params: GtkSizeGroup *size_group
 * Returns: , GtkSizeGroupMode
 * Assertion: Gets the current mode of the size group.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_HORIZONTAL
 * Expected: GTK_SIZE_GROUP_BOTH  
 */
static void test_purpose_26()
{
    #define MODE GTK_SIZE_GROUP_HORIZONTAL
    #define NEW_MODE GTK_SIZE_GROUP_BOTH
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (G_OBJECT (group), "mode", NEW_MODE, NULL);
    
    real_mode = gtk_size_group_get_mode (group);
    if (real_mode != NEW_MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode,NEW_MODE);
    }
    
    #undef MODE
    #undef NEW_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_get_mode
 * Params: GtkSizeGroup *size_group
 * Returns: , GtkSizeGroupMode
 * Assertion: Gets the current mode of the size group.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_HORIZONTAL
 * Expected: GTK_SIZE_GROUP_NONE  
 */
static void test_purpose_27()
{
    #define MODE GTK_SIZE_GROUP_HORIZONTAL
    #define NEW_MODE GTK_SIZE_GROUP_NONE
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (G_OBJECT (group), "mode", NEW_MODE, NULL);
    
    real_mode = gtk_size_group_get_mode (group);
    if (real_mode != NEW_MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode,NEW_MODE);
    }
    
    #undef MODE
    #undef NEW_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_get_mode
 * Params: GtkSizeGroup *size_group
 * Returns: , GtkSizeGroupMode
 * Assertion: Gets the current mode of the size group.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_HORIZONTAL
 * Expected: GTK_SIZE_GROUP_HORIZONTAL  
 */
static void test_purpose_28()
{
    #define MODE GTK_SIZE_GROUP_HORIZONTAL
    #define NEW_MODE GTK_SIZE_GROUP_HORIZONTAL
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (G_OBJECT (group), "mode", NEW_MODE, NULL);
    
    real_mode = gtk_size_group_get_mode (group);
    if (real_mode != NEW_MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode,NEW_MODE);
    }
    
    #undef MODE
    #undef NEW_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_get_mode
 * Params: GtkSizeGroup *size_group
 * Returns: , GtkSizeGroupMode
 * Assertion: Gets the current mode of the size group.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_HORIZONTAL
 * Expected: GTK_SIZE_GROUP_VERTICAL  
 */
static void test_purpose_29()
{
    #define MODE GTK_SIZE_GROUP_HORIZONTAL
    #define NEW_MODE GTK_SIZE_GROUP_VERTICAL
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (G_OBJECT (group), "mode", NEW_MODE, NULL);
    
    real_mode = gtk_size_group_get_mode (group);
    if (real_mode != NEW_MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode,NEW_MODE);
    }
    
    #undef MODE
    #undef NEW_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_get_mode
 * Params: GtkSizeGroup *size_group
 * Returns: , GtkSizeGroupMode
 * Assertion: Gets the current mode of the size group.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_VERTICAL
 * Expected: GTK_SIZE_GROUP_BOTH  
 */
static void test_purpose_30()
{
    #define MODE GTK_SIZE_GROUP_VERTICAL
    #define NEW_MODE GTK_SIZE_GROUP_BOTH
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (G_OBJECT (group), "mode", NEW_MODE, NULL);
    
    real_mode = gtk_size_group_get_mode (group);
    if (real_mode != NEW_MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode,NEW_MODE);
    }
    
    #undef MODE
    #undef NEW_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_get_mode
 * Params: GtkSizeGroup *size_group
 * Returns: , GtkSizeGroupMode
 * Assertion: Gets the current mode of the size group.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_BOTH
 * Expected: GTK_SIZE_GROUP_NONE  
 */
static void test_purpose_31()
{
    #define MODE GTK_SIZE_GROUP_BOTH
    #define NEW_MODE GTK_SIZE_GROUP_NONE
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (G_OBJECT (group), "mode", NEW_MODE, NULL);
    
    real_mode = gtk_size_group_get_mode (group);
    if (real_mode != NEW_MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode,NEW_MODE);
    }
    
    #undef MODE
    #undef NEW_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_get_mode
 * Params: GtkSizeGroup *size_group
 * Returns: , GtkSizeGroupMode
 * Assertion: Gets the current mode of the size group.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_BOTH
 * Expected: GTK_SIZE_GROUP_HORIZONTAL  
 */
static void test_purpose_32()
{
    #define MODE GTK_SIZE_GROUP_BOTH
    #define NEW_MODE GTK_SIZE_GROUP_HORIZONTAL
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (G_OBJECT (group), "mode", NEW_MODE, NULL);
    
    real_mode = gtk_size_group_get_mode (group);
    if (real_mode != NEW_MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode,NEW_MODE);
    }
    
    #undef MODE
    #undef NEW_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_get_mode
 * Params: GtkSizeGroup *size_group
 * Returns: , GtkSizeGroupMode
 * Assertion: Gets the current mode of the size group.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_BOTH
 * Expected: GTK_SIZE_GROUP_VERTICAL  
 */
static void test_purpose_33()
{
    #define MODE GTK_SIZE_GROUP_BOTH
    #define NEW_MODE GTK_SIZE_GROUP_VERTICAL
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (G_OBJECT (group), "mode", NEW_MODE, NULL);
    
    real_mode = gtk_size_group_get_mode (group);
    if (real_mode != NEW_MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode,NEW_MODE);
    }
    
    #undef MODE
    #undef NEW_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_get_mode
 * Params: GtkSizeGroup *size_group
 * Returns: , GtkSizeGroupMode
 * Assertion: Gets the current mode of the size group.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_BOTH
 * Expected: GTK_SIZE_GROUP_BOTH  
 */
static void test_purpose_34()
{
    #define MODE GTK_SIZE_GROUP_BOTH
    #define NEW_MODE GTK_SIZE_GROUP_BOTH
    
    GtkSizeGroup* group;
    GtkSizeGroupMode real_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (G_OBJECT (group), "mode", NEW_MODE, NULL);
    
    real_mode = gtk_size_group_get_mode (group);
    if (real_mode != NEW_MODE)
    {
        TEST_FAIL ("real_mode = %d, should be %d", real_mode,NEW_MODE);
    }
    
    #undef MODE
    #undef NEW_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_add_widget
 * Params: GtkSizeGroup *size_group, GtkWidget *widget
 * Returns: void
 * Assertion: Adds a widget to a GtkSizeGroup.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_NONE, 'gtk_button_new ()'
 * Expected: void  
 */
static void test_purpose_35()
{
    #define MODE GTK_SIZE_GROUP_NONE
    #define WIDGET gtk_button_new ()
    
    GtkSizeGroup* group;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_size_group_add_widget (group, WIDGET);
    
    #undef MODE
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_add_widget
 * Params: GtkSizeGroup *size_group, GtkWidget *widget
 * Returns: void
 * Assertion: Adds a widget to a GtkSizeGroup.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_HORIZONTAL, 'gtk_label_new ("qwerty")'
 * Expected: void  
 */
static void test_purpose_36()
{
    #define MODE GTK_SIZE_GROUP_HORIZONTAL
    #define WIDGET gtk_label_new ("qwerty")
    
    GtkSizeGroup* group;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_size_group_add_widget (group, WIDGET);
    
    #undef MODE
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_add_widget
 * Params: GtkSizeGroup *size_group, GtkWidget *widget
 * Returns: void
 * Assertion: Adds a widget to a GtkSizeGroup.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_VERTICAL, 'gtk_calendar_new ()'
 * Expected: void  
 */
static void test_purpose_37()
{
    #define MODE GTK_SIZE_GROUP_VERTICAL
    #define WIDGET gtk_calendar_new ()
    
    GtkSizeGroup* group;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_size_group_add_widget (group, WIDGET);
    
    #undef MODE
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_add_widget
 * Params: GtkSizeGroup *size_group, GtkWidget *widget
 * Returns: void
 * Assertion: Adds a widget to a GtkSizeGroup.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_BOTH, 'gtk_drawing_area_new ()'
 * Expected: void  
 */
static void test_purpose_38()
{
    #define MODE GTK_SIZE_GROUP_BOTH
    #define WIDGET gtk_drawing_area_new ()
    
    GtkSizeGroup* group;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_size_group_add_widget (group, WIDGET);
    
    #undef MODE
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_remove_widget
 * Params: GtkSizeGroup *size_group
 * Returns: GtkWidget*
 * Assertion: Removes a widget from a GtkSizeGroup.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_NONE, GtkWidget*
 * Expected: void  
 */
static void test_purpose_39()
{
    #define MODE GTK_SIZE_GROUP_NONE
    #define WIDGET gtk_button_new ()
    
    GtkSizeGroup* group;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_size_group_add_widget (group, widget);
    gtk_size_group_remove_widget (group, widget);
    
    #undef MODE
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_remove_widget
 * Params: GtkSizeGroup *size_group
 * Returns: GtkWidget*
 * Assertion: Removes a widget from a GtkSizeGroup.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_HORIZONTAL, GtkWidget*
 * Expected: void  
 */
static void test_purpose_40()
{
    #define MODE GTK_SIZE_GROUP_HORIZONTAL
    #define WIDGET gtk_label_new ("qwerty")
    
    GtkSizeGroup* group;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_size_group_add_widget (group, widget);
    gtk_size_group_remove_widget (group, widget);
    
    #undef MODE
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_remove_widget
 * Params: GtkSizeGroup *size_group
 * Returns: GtkWidget*
 * Assertion: Removes a widget from a GtkSizeGroup.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_VERTICAL, GtkWidget*
 * Expected: void  
 */
static void test_purpose_41()
{
    #define MODE GTK_SIZE_GROUP_VERTICAL
    #define WIDGET gtk_calendar_new ()
    
    GtkSizeGroup* group;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_size_group_add_widget (group, widget);
    gtk_size_group_remove_widget (group, widget);
    
    #undef MODE
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_size_group_remove_widget
 * Params: GtkSizeGroup *size_group
 * Returns: GtkWidget*
 * Assertion: Removes a widget from a GtkSizeGroup.
 * Params Values: a newly created size group with mode set to GTK_SIZE_GROUP_BOTH, GtkWidget*
 * Expected: void  
 */
static void test_purpose_42()
{
    #define MODE GTK_SIZE_GROUP_BOTH
    #define WIDGET gtk_drawing_area_new ()
    
    GtkSizeGroup* group;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    group = gtk_size_group_new (MODE);
    
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_SIZE_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_size_group_add_widget (group, widget);
    gtk_size_group_remove_widget (group, widget);
    
    #undef MODE
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkSizeGroup ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {NULL,0}
};
