/*
 * GtkTextTag methods tests
 * Testing GtkTextTag methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
gboolean event_handler (GtkTextTag *tag, GObject *arg1, GdkEvent *event, 
                        GtkTextIter arg2, gpointer user_data)
{
    return TRUE;
}

/*
 * Name: gtk_text_tag_new
 * Params: const gchar* name
 * Returns: GtkTag*
 * Assertion: Creates a GtkTextTag.
 * Params Values: NULL
 * Expected: GtkTextTag*  
 */
static void test_purpose_1()
{
    #define NAME NULL
    
    gchararray name;
    /*  GdkColor background_gdk; */
    gboolean background_full_height;
    /*  GdkColor foreground_gdk; */
    GtkTextDirection direction;
    gboolean editable;
    gchararray font;
    PangoFontDescription *font_desc;
    gchararray family;
    PangoStyle style;
    PangoVariant variant;
    gint weight;
    PangoStretch stretch;
    gint size;
    gdouble scale;
    gdouble size_points;
    GtkJustification justification;
    gchararray language;
    gint left_margin;
    gint right_margin;
    gint indent;
    gint rise;
    gint pixels_above_lines;
    gint pixels_below_lines;
    gint pixels_inside_wrap;
    gboolean strikethrough;
    PangoUnderline underline;
    GtkWrapMode wrap_mode;
    /*PangoTabArray tabs;*/
    gboolean invisible;
    gboolean background_set;
    gboolean background_full_height_set;
    gboolean background_stipple_set;
    gboolean foreground_set;
    gboolean foreground_stipple_set;
    gboolean editable_set;
    gboolean family_set;
    gboolean style_set;
    gboolean variant_set;
    gboolean weight_set;
    gboolean stretch_set;
    gboolean size_set;
    gboolean scale_set;
    gboolean justification_set;
    gboolean language_set;
    gboolean left_margin_set;
    gboolean indent_set;
    gboolean rise_set;
    gboolean pixels_above_lines_set;
    gboolean pixels_below_lines_set;
    gboolean pixels_inside_wrap_set;
    gboolean strikethrough_set;
    gboolean right_margin_set;
    gboolean underline_set;
    gboolean wrap_mode_set;
    gboolean tabs_set;
    gboolean invisible_set;
    
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new (NAME);
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_get (tag, "name", &name, NULL);
    if (NAME)
    {
        if (strcmp (name, (char*)NAME)) 
        {
        TEST_FAIL ("name is '%s', should be '%s'", name, (gchar*)NAME);
        }
    } else {
        if (name)
        {
            TEST_FAIL ("name should be NULL but it is not", NULL);
        }
    }
    
    g_object_get (tag, "background-full-height", 
                   &background_full_height, NULL);
    if (background_full_height != FALSE) 
    {
        TEST_FAIL ("background_full_height = %d, should be %d", 
                   background_full_height, FALSE);
    }
    
    g_object_get (tag, "direction", &direction, NULL);
    if (direction != GTK_TEXT_DIR_NONE) 
    {
        TEST_FAIL ("direction = %d, should be %d", 
                   direction, GTK_TEXT_DIR_NONE);
    }
    
    g_object_get (tag, "editable", &editable, NULL);
    if (editable != TRUE) 
    {
        TEST_FAIL ("editable = %d, should be %d", 
                   editable, TRUE);
    }
    
    g_object_get (tag, "font", &font, NULL);
    if (font == NULL) 
    {
        TEST_FAIL ("font = %d, should be %d", 
                   font, NULL);
    }
    
    g_object_get (tag, "font-desc", &font_desc, NULL);
    if (font_desc == NULL) 
    {
        TEST_FAIL ("font-desc = %d, should be %d", 
                   font_desc, NULL);
    }
    
    g_object_get (tag, "family", &family, NULL);
    if (family != NULL) 
    {
        TEST_FAIL ("family = %d, should be %d", 
                   family , NULL);
    }
    
    g_object_get (tag, "style", &style, NULL);
    if (style != PANGO_STYLE_NORMAL) 
    {
        TEST_FAIL ("style = %d, should be %d", 
                   style , PANGO_STYLE_NORMAL);
    }
    
    g_object_get (tag, "variant", &variant, NULL);
    if (variant != PANGO_VARIANT_NORMAL) 
    {
        TEST_FAIL ("variant = %d, should be %d", 
                   variant , PANGO_VARIANT_NORMAL);
    }
    
    g_object_get (tag, "weight", &weight, NULL);
    if (weight != 400) 
    {
        TEST_FAIL ("weight = %d, should be %d", 
                   weight, 0);
    }
    
    g_object_get (tag, "stretch", &stretch, NULL);
    if (stretch != PANGO_STRETCH_NORMAL) 
    {
        TEST_FAIL ("stretch = %d, should be %d", 
                   stretch, PANGO_STRETCH_ULTRA_CONDENSED);
    }
    
    g_object_get (tag, "size", &size, NULL);
    if (size != 0) 
    {
        TEST_FAIL ("size = %d, should be %d", 
                   size, 0);
    }
    
    g_object_get (tag, "scale", &scale, NULL);
    if (scale != 1.0) 
    {
        TEST_FAIL ("scale = %d, should be %d", 
                   scale, 1.0);
    }
    
    g_object_get (tag, "size-points", &size_points, NULL);
    if (size_points != 0.0) 
    {
        TEST_FAIL ("size_points = %d, should be %d", 
                   size_points, 0.0);
    }
    
    g_object_get (tag, "justification", &justification, NULL);
    if (justification != GTK_JUSTIFY_LEFT) 
    {
        TEST_FAIL ("justification = %d, should be %d", 
                   justification, GTK_JUSTIFY_LEFT);
    }
    
    /* language is locale dependent
    g_object_get (tag, "language", &language, NULL);
    if (strcmp (language, "c")) 
    {
        TEST_FAIL ("language = '%s', should be '%s'", 
                   language, "c");
    }
    */
    
    g_object_get (tag, "left-margin", &left_margin, NULL);
    if (left_margin != 0) 
    {
        TEST_FAIL ("left_margin = %d, should be %d", 
                   left_margin, 0);
    }
    
    g_object_get (tag, "right-margin", &right_margin, NULL);
    if (right_margin != 0) 
    {
        TEST_FAIL ("right_margin = %d, should be %d", 
                   right_margin, 0);
    }
    
    g_object_get (tag, "indent", &indent, NULL);
    if (indent != 0) 
    {
        TEST_FAIL ("indent = %d, should be %d", 
                   indent, 0);
    }
    
    g_object_get (tag, "rise", &rise, NULL);
    if (rise != 0) 
    {
        TEST_FAIL ("rise = %d, should be %d", 
                   rise, 0);
    }
    
    g_object_get (tag, "pixels-above-lines", 
                   &pixels_above_lines, NULL);
    if (pixels_above_lines != 0) 
    {
        TEST_FAIL ("pixels-above-lines = %d, should be %d", 
                   pixels_above_lines, 0);
    }
    
    g_object_get (tag, "pixels-below-lines", 
                   &pixels_below_lines, NULL);
    if (pixels_below_lines != 0) 
    {
        TEST_FAIL ("pixels-below-lines = %d, should be %d", 
                   pixels_below_lines, 0);
    }
    
    g_object_get (tag, "pixels-inside-wrap", 
                   &pixels_inside_wrap, NULL);
    if (pixels_inside_wrap != 0) 
    {
        TEST_FAIL ("pixels-inside-wrap = %d, should be %d", 
                   pixels_inside_wrap, 0);
    }
    
    g_object_get (tag, "strikethrough", 
                   &strikethrough, NULL);
    if (strikethrough != FALSE) 
    {
        TEST_FAIL ("strikethrough = %d, should be %d", 
                   strikethrough, NULL);
    }
    
    g_object_get (tag, "underline", &underline, NULL);
    if (underline != PANGO_UNDERLINE_NONE) 
    {
        TEST_FAIL ("underline = %d, should be %d", 
                   underline, PANGO_UNDERLINE_NONE);
    }
    
    g_object_get (tag, "wrap-mode", &wrap_mode, NULL);
    if (wrap_mode != GTK_WRAP_NONE) 
    {
        TEST_FAIL ("wrap_mode = %d, should be %d", 
                   wrap_mode, GTK_WRAP_NONE);
    }
    
    g_object_get (tag, "invisible", &invisible, NULL);
    if (invisible != FALSE) 
    {
        TEST_FAIL ("invisible = %d, should be %d", 
                   invisible, FALSE);
    }
    
    g_object_get (tag, "background-set", &background_set, NULL);
    if (background_set != FALSE) 
    {
        TEST_FAIL ("background-set = %d, should be %d", 
                   background_set, FALSE);
    }
    
    g_object_get (tag, "background-full-height-set", 
                   &background_full_height_set, NULL);
    if (background_full_height_set != FALSE) 
    {
        TEST_FAIL ("background-full-height_set = %d, should be %d", 
                   background_full_height_set, FALSE);
    }
    
    g_object_get (tag, "background-stipple-set", 
                   &background_stipple_set, NULL);
    if (background_stipple_set != FALSE) 
    {
        TEST_FAIL ("background-stipple-set = %d, should be %d", 
                   background_stipple_set, FALSE);
    }
    
    g_object_get (tag, "foreground-set", &foreground_set, NULL);
    if (foreground_set != FALSE) 
    {
        TEST_FAIL ("foreground-set = %d, should be %d", 
                   foreground_set, FALSE);
    }
    
    g_object_get (tag, "foreground-stipple-set", 
                   &foreground_stipple_set, NULL);
    if (foreground_stipple_set != FALSE) 
    {
        TEST_FAIL ("foreground-stipple-set = %d, should be %d", 
                   foreground_stipple_set, FALSE);
    }
    
    g_object_get (tag, "editable-set", &editable_set, NULL);
    if (editable_set != FALSE) 
    {
        TEST_FAIL ("editable-set = %d, should be %d", 
                   editable_set, FALSE);
    }
    
    g_object_get (tag, "family-set", &family_set, NULL);
    if (family_set != FALSE) 
    {
        TEST_FAIL ("family-set = %d, should be %d", 
                   family_set, FALSE);
    }
    
    g_object_get (tag, "style-set", &style_set, NULL);
    if (style_set != FALSE) 
    {
        TEST_FAIL ("style-set = %d, should be %d", 
                   style_set, FALSE);
    }
    
    g_object_get (tag, "variant-set", &variant_set, NULL);
    if (variant_set != FALSE) 
    {
        TEST_FAIL ("variant-set = %d, should be %d", 
                   variant_set, FALSE);
    }
    
    g_object_get (tag, "weight-set", &weight_set, NULL);
    if (weight_set != FALSE) 
    {
        TEST_FAIL ("weight-set = %d, should be %d", 
                   weight_set, FALSE);
    }
    
    g_object_get (tag, "stretch-set", &stretch_set, NULL);
    if (stretch_set != FALSE) 
    {
        TEST_FAIL ("stretch-set = %d, should be %d", 
                   stretch_set, FALSE);
    }
    
    g_object_get (tag, "size-set", &size_set, NULL);
    if (size_set != FALSE) 
    {
        TEST_FAIL ("size-set = %d, should be %d", 
                   size_set, FALSE);
    }
    
    g_object_get (tag, "scale-set", &scale_set, NULL);
    if (scale_set != FALSE) 
    {
        TEST_FAIL ("scale-set = %d, should be %d", 
                   scale_set, FALSE);
    }
    
    g_object_get (tag, "justification-set", 
                   &justification_set, NULL);
    if (justification_set != FALSE) 
    {
        TEST_FAIL ("justification-set = %d, should be %d", 
                   justification_set, FALSE);
    }
    
    g_object_get (tag, "language-set", 
                   &language_set, NULL);
    if (language_set != FALSE) 
    {
        TEST_FAIL ("language-set = %d, should be %d", 
                   language_set, FALSE);
    }
    
    g_object_get (tag, "left-margin-set", 
                   &left_margin_set, NULL);
    if (left_margin_set != FALSE) 
    {
        TEST_FAIL ("left_margin-set = %d, should be %d", 
                   left_margin_set, FALSE);
    }
    
    g_object_get (tag, "indent-set",  &indent_set, NULL);
    if (indent_set != FALSE) 
    {
        TEST_FAIL ("indent-set = %d, should be %d", 
                   indent_set, FALSE);
    }
    
    g_object_get (tag, "rise-set",  &rise_set, NULL);
    if (rise_set != FALSE) 
    {
        TEST_FAIL ("rise-set = %d, should be %d", 
                   rise_set, FALSE);
    }
    
    g_object_get (tag, "pixels-above-lines-set",  
                   &pixels_above_lines_set, NULL);
    if (pixels_above_lines_set != FALSE) 
    {
        TEST_FAIL ("pixels-above-lines-set = %d, should be %d", 
                   pixels_above_lines_set, FALSE);
    }
    
    g_object_get (tag, "pixels-below-lines-set",  
                   &pixels_below_lines_set, NULL);
    if (pixels_below_lines_set != FALSE) 
    {
        TEST_FAIL ("pixels-below-lines-set = %d, should be %d", 
                   pixels_above_lines_set, FALSE);
    }
    
    g_object_get (tag, "pixels-inside-wrap-set",  
                   &pixels_inside_wrap_set, NULL);
    if (pixels_inside_wrap_set != FALSE) 
    {
        TEST_FAIL ("pixels-inside-wrap-set = %d, should be %d", 
                   pixels_inside_wrap_set, FALSE);
    }
    
    g_object_get (tag, "strikethrough-set",  
                   &strikethrough_set, NULL);
    if (strikethrough_set != FALSE) 
    {
        TEST_FAIL ("strikethrough-set = %d, should be %d", 
                   strikethrough_set, FALSE);
    }
    
    g_object_get (tag, "right-margin-set", 
                   &right_margin_set, NULL);
    if (right_margin_set != FALSE) 
    {
        TEST_FAIL ("right-margin-set = %d, should be %d", 
                   right_margin_set, FALSE);
    }
    
    g_object_get (tag, "underline-set", 
                   &underline_set, NULL);
    if (underline_set != FALSE) 
    {
        TEST_FAIL ("underline-set = %d, should be %d", 
                   underline_set, FALSE);
    }
    
    g_object_get (tag, "wrap-mode-set", 
                   &wrap_mode_set, NULL);
    if (wrap_mode_set != FALSE) 
    {
        TEST_FAIL ("wrap-mode-set = %d, should be %d", 
                   wrap_mode_set, FALSE);
    }
    
    g_object_get (tag, "tabs-set", &tabs_set, NULL);
    if (tabs_set != FALSE) 
    {
        TEST_FAIL ("tabs-set = %d, should be %d", 
                   tabs_set, FALSE);
    }
    
    g_object_get (tag, "invisible-set", &invisible_set, NULL);
    if (invisible_set != FALSE) 
    {
        TEST_FAIL ("invisible-set = %d, should be %d", 
                   invisible_set, FALSE);
    }
    
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_new
 * Params: const gchar* name
 * Returns: GtkTag*
 * Assertion: Creates a GtkTextTag.
 * Params Values: ""
 * Expected: GtkTextTag*  
 */
static void test_purpose_2()
{
    #define NAME ""
    
    gchararray name;
    /*  GdkColor background_gdk; */
    gboolean background_full_height;
    /*  GdkColor foreground_gdk; */
    GtkTextDirection direction;
    gboolean editable;
    gchararray font;
    PangoFontDescription *font_desc;
    gchararray family;
    PangoStyle style;
    PangoVariant variant;
    gint weight;
    PangoStretch stretch;
    gint size;
    gdouble scale;
    gdouble size_points;
    GtkJustification justification;
    gchararray language;
    gint left_margin;
    gint right_margin;
    gint indent;
    gint rise;
    gint pixels_above_lines;
    gint pixels_below_lines;
    gint pixels_inside_wrap;
    gboolean strikethrough;
    PangoUnderline underline;
    GtkWrapMode wrap_mode;
    /*PangoTabArray tabs;*/
    gboolean invisible;
    gboolean background_set;
    gboolean background_full_height_set;
    gboolean background_stipple_set;
    gboolean foreground_set;
    gboolean foreground_stipple_set;
    gboolean editable_set;
    gboolean family_set;
    gboolean style_set;
    gboolean variant_set;
    gboolean weight_set;
    gboolean stretch_set;
    gboolean size_set;
    gboolean scale_set;
    gboolean justification_set;
    gboolean language_set;
    gboolean left_margin_set;
    gboolean indent_set;
    gboolean rise_set;
    gboolean pixels_above_lines_set;
    gboolean pixels_below_lines_set;
    gboolean pixels_inside_wrap_set;
    gboolean strikethrough_set;
    gboolean right_margin_set;
    gboolean underline_set;
    gboolean wrap_mode_set;
    gboolean tabs_set;
    gboolean invisible_set;
    
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new (NAME);
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_get (tag, "name", &name, NULL);
    if (NAME)
    {
        if (strcmp (name, (char*)NAME)) 
        {
        TEST_FAIL ("name is '%s', should be '%s'", name, (gchar*)NAME);
        }
    } else {
        if (name)
        {
            TEST_FAIL ("name should be NULL but it is not", NULL);
        }
    }
    
    g_object_get (tag, "background-full-height", 
                   &background_full_height, NULL);
    if (background_full_height != FALSE) 
    {
        TEST_FAIL ("background_full_height = %d, should be %d", 
                   background_full_height, FALSE);
    }
    
    g_object_get (tag, "direction", &direction, NULL);
    if (direction != GTK_TEXT_DIR_NONE) 
    {
        TEST_FAIL ("direction = %d, should be %d", 
                   direction, GTK_TEXT_DIR_NONE);
    }
    
    g_object_get (tag, "editable", &editable, NULL);
    if (editable != TRUE) 
    {
        TEST_FAIL ("editable = %d, should be %d", 
                   editable, TRUE);
    }
    
    g_object_get (tag, "font", &font, NULL);
    if (font == NULL) 
    {
        TEST_FAIL ("font = %d, should be %d", 
                   font, NULL);
    }
    
    g_object_get (tag, "font-desc", &font_desc, NULL);
    if (font_desc == NULL) 
    {
        TEST_FAIL ("font-desc = %d, should be %d", 
                   font_desc, NULL);
    }
    
    g_object_get (tag, "family", &family, NULL);
    if (family != NULL) 
    {
        TEST_FAIL ("family = %d, should be %d", 
                   family , NULL);
    }
    
    g_object_get (tag, "style", &style, NULL);
    if (style != PANGO_STYLE_NORMAL) 
    {
        TEST_FAIL ("style = %d, should be %d", 
                   style , PANGO_STYLE_NORMAL);
    }
    
    g_object_get (tag, "variant", &variant, NULL);
    if (variant != PANGO_VARIANT_NORMAL) 
    {
        TEST_FAIL ("variant = %d, should be %d", 
                   variant , PANGO_VARIANT_NORMAL);
    }
    
    g_object_get (tag, "weight", &weight, NULL);
    if (weight != 400) 
    {
        TEST_FAIL ("weight = %d, should be %d", 
                   weight, 0);
    }
    
    g_object_get (tag, "stretch", &stretch, NULL);
    if (stretch != PANGO_STRETCH_NORMAL) 
    {
        TEST_FAIL ("stretch = %d, should be %d", 
                   stretch, PANGO_STRETCH_ULTRA_CONDENSED);
    }
    
    g_object_get (tag, "size", &size, NULL);
    if (size != 0) 
    {
        TEST_FAIL ("size = %d, should be %d", 
                   size, 0);
    }
    
    g_object_get (tag, "scale", &scale, NULL);
    if (scale != 1.0) 
    {
        TEST_FAIL ("scale = %d, should be %d", 
                   scale, 1.0);
    }
    
    g_object_get (tag, "size-points", &size_points, NULL);
    if (size_points != 0.0) 
    {
        TEST_FAIL ("size_points = %d, should be %d", 
                   size_points, 0.0);
    }
    
    g_object_get (tag, "justification", &justification, NULL);
    if (justification != GTK_JUSTIFY_LEFT) 
    {
        TEST_FAIL ("justification = %d, should be %d", 
                   justification, GTK_JUSTIFY_LEFT);
    }
    
    /* language is locale dependent
    g_object_get (tag, "language", &language, NULL);
    if (strcmp (language, "c")) 
    {
        TEST_FAIL ("language = '%s', should be '%s'", 
                   language, "c");
    }
    */
    
    g_object_get (tag, "left-margin", &left_margin, NULL);
    if (left_margin != 0) 
    {
        TEST_FAIL ("left_margin = %d, should be %d", 
                   left_margin, 0);
    }
    
    g_object_get (tag, "right-margin", &right_margin, NULL);
    if (right_margin != 0) 
    {
        TEST_FAIL ("right_margin = %d, should be %d", 
                   right_margin, 0);
    }
    
    g_object_get (tag, "indent", &indent, NULL);
    if (indent != 0) 
    {
        TEST_FAIL ("indent = %d, should be %d", 
                   indent, 0);
    }
    
    g_object_get (tag, "rise", &rise, NULL);
    if (rise != 0) 
    {
        TEST_FAIL ("rise = %d, should be %d", 
                   rise, 0);
    }
    
    g_object_get (tag, "pixels-above-lines", 
                   &pixels_above_lines, NULL);
    if (pixels_above_lines != 0) 
    {
        TEST_FAIL ("pixels-above-lines = %d, should be %d", 
                   pixels_above_lines, 0);
    }
    
    g_object_get (tag, "pixels-below-lines", 
                   &pixels_below_lines, NULL);
    if (pixels_below_lines != 0) 
    {
        TEST_FAIL ("pixels-below-lines = %d, should be %d", 
                   pixels_below_lines, 0);
    }
    
    g_object_get (tag, "pixels-inside-wrap", 
                   &pixels_inside_wrap, NULL);
    if (pixels_inside_wrap != 0) 
    {
        TEST_FAIL ("pixels-inside-wrap = %d, should be %d", 
                   pixels_inside_wrap, 0);
    }
    
    g_object_get (tag, "strikethrough", 
                   &strikethrough, NULL);
    if (strikethrough != FALSE) 
    {
        TEST_FAIL ("strikethrough = %d, should be %d", 
                   strikethrough, NULL);
    }
    
    g_object_get (tag, "underline", &underline, NULL);
    if (underline != PANGO_UNDERLINE_NONE) 
    {
        TEST_FAIL ("underline = %d, should be %d", 
                   underline, PANGO_UNDERLINE_NONE);
    }
    
    g_object_get (tag, "wrap-mode", &wrap_mode, NULL);
    if (wrap_mode != GTK_WRAP_NONE) 
    {
        TEST_FAIL ("wrap_mode = %d, should be %d", 
                   wrap_mode, GTK_WRAP_NONE);
    }
    
    g_object_get (tag, "invisible", &invisible, NULL);
    if (invisible != FALSE) 
    {
        TEST_FAIL ("invisible = %d, should be %d", 
                   invisible, FALSE);
    }
    
    g_object_get (tag, "background-set", &background_set, NULL);
    if (background_set != FALSE) 
    {
        TEST_FAIL ("background-set = %d, should be %d", 
                   background_set, FALSE);
    }
    
    g_object_get (tag, "background-full-height-set", 
                   &background_full_height_set, NULL);
    if (background_full_height_set != FALSE) 
    {
        TEST_FAIL ("background-full-height_set = %d, should be %d", 
                   background_full_height_set, FALSE);
    }
    
    g_object_get (tag, "background-stipple-set", 
                   &background_stipple_set, NULL);
    if (background_stipple_set != FALSE) 
    {
        TEST_FAIL ("background-stipple-set = %d, should be %d", 
                   background_stipple_set, FALSE);
    }
    
    g_object_get (tag, "foreground-set", &foreground_set, NULL);
    if (foreground_set != FALSE) 
    {
        TEST_FAIL ("foreground-set = %d, should be %d", 
                   foreground_set, FALSE);
    }
    
    g_object_get (tag, "foreground-stipple-set", 
                   &foreground_stipple_set, NULL);
    if (foreground_stipple_set != FALSE) 
    {
        TEST_FAIL ("foreground-stipple-set = %d, should be %d", 
                   foreground_stipple_set, FALSE);
    }
    
    g_object_get (tag, "editable-set", &editable_set, NULL);
    if (editable_set != FALSE) 
    {
        TEST_FAIL ("editable-set = %d, should be %d", 
                   editable_set, FALSE);
    }
    
    g_object_get (tag, "family-set", &family_set, NULL);
    if (family_set != FALSE) 
    {
        TEST_FAIL ("family-set = %d, should be %d", 
                   family_set, FALSE);
    }
    
    g_object_get (tag, "style-set", &style_set, NULL);
    if (style_set != FALSE) 
    {
        TEST_FAIL ("style-set = %d, should be %d", 
                   style_set, FALSE);
    }
    
    g_object_get (tag, "variant-set", &variant_set, NULL);
    if (variant_set != FALSE) 
    {
        TEST_FAIL ("variant-set = %d, should be %d", 
                   variant_set, FALSE);
    }
    
    g_object_get (tag, "weight-set", &weight_set, NULL);
    if (weight_set != FALSE) 
    {
        TEST_FAIL ("weight-set = %d, should be %d", 
                   weight_set, FALSE);
    }
    
    g_object_get (tag, "stretch-set", &stretch_set, NULL);
    if (stretch_set != FALSE) 
    {
        TEST_FAIL ("stretch-set = %d, should be %d", 
                   stretch_set, FALSE);
    }
    
    g_object_get (tag, "size-set", &size_set, NULL);
    if (size_set != FALSE) 
    {
        TEST_FAIL ("size-set = %d, should be %d", 
                   size_set, FALSE);
    }
    
    g_object_get (tag, "scale-set", &scale_set, NULL);
    if (scale_set != FALSE) 
    {
        TEST_FAIL ("scale-set = %d, should be %d", 
                   scale_set, FALSE);
    }
    
    g_object_get (tag, "justification-set", 
                   &justification_set, NULL);
    if (justification_set != FALSE) 
    {
        TEST_FAIL ("justification-set = %d, should be %d", 
                   justification_set, FALSE);
    }
    
    g_object_get (tag, "language-set", 
                   &language_set, NULL);
    if (language_set != FALSE) 
    {
        TEST_FAIL ("language-set = %d, should be %d", 
                   language_set, FALSE);
    }
    
    g_object_get (tag, "left-margin-set", 
                   &left_margin_set, NULL);
    if (left_margin_set != FALSE) 
    {
        TEST_FAIL ("left_margin-set = %d, should be %d", 
                   left_margin_set, FALSE);
    }
    
    g_object_get (tag, "indent-set",  &indent_set, NULL);
    if (indent_set != FALSE) 
    {
        TEST_FAIL ("indent-set = %d, should be %d", 
                   indent_set, FALSE);
    }
    
    g_object_get (tag, "rise-set",  &rise_set, NULL);
    if (rise_set != FALSE) 
    {
        TEST_FAIL ("rise-set = %d, should be %d", 
                   rise_set, FALSE);
    }
    
    g_object_get (tag, "pixels-above-lines-set",  
                   &pixels_above_lines_set, NULL);
    if (pixels_above_lines_set != FALSE) 
    {
        TEST_FAIL ("pixels-above-lines-set = %d, should be %d", 
                   pixels_above_lines_set, FALSE);
    }
    
    g_object_get (tag, "pixels-below-lines-set",  
                   &pixels_below_lines_set, NULL);
    if (pixels_below_lines_set != FALSE) 
    {
        TEST_FAIL ("pixels-below-lines-set = %d, should be %d", 
                   pixels_above_lines_set, FALSE);
    }
    
    g_object_get (tag, "pixels-inside-wrap-set",  
                   &pixels_inside_wrap_set, NULL);
    if (pixels_inside_wrap_set != FALSE) 
    {
        TEST_FAIL ("pixels-inside-wrap-set = %d, should be %d", 
                   pixels_inside_wrap_set, FALSE);
    }
    
    g_object_get (tag, "strikethrough-set",  
                   &strikethrough_set, NULL);
    if (strikethrough_set != FALSE) 
    {
        TEST_FAIL ("strikethrough-set = %d, should be %d", 
                   strikethrough_set, FALSE);
    }
    
    g_object_get (tag, "right-margin-set", 
                   &right_margin_set, NULL);
    if (right_margin_set != FALSE) 
    {
        TEST_FAIL ("right-margin-set = %d, should be %d", 
                   right_margin_set, FALSE);
    }
    
    g_object_get (tag, "underline-set", 
                   &underline_set, NULL);
    if (underline_set != FALSE) 
    {
        TEST_FAIL ("underline-set = %d, should be %d", 
                   underline_set, FALSE);
    }
    
    g_object_get (tag, "wrap-mode-set", 
                   &wrap_mode_set, NULL);
    if (wrap_mode_set != FALSE) 
    {
        TEST_FAIL ("wrap-mode-set = %d, should be %d", 
                   wrap_mode_set, FALSE);
    }
    
    g_object_get (tag, "tabs-set", &tabs_set, NULL);
    if (tabs_set != FALSE) 
    {
        TEST_FAIL ("tabs-set = %d, should be %d", 
                   tabs_set, FALSE);
    }
    
    g_object_get (tag, "invisible-set", &invisible_set, NULL);
    if (invisible_set != FALSE) 
    {
        TEST_FAIL ("invisible-set = %d, should be %d", 
                   invisible_set, FALSE);
    }
    
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_new
 * Params: const gchar* name
 * Returns: GtkTag*
 * Assertion: Creates a GtkTextTag.
 * Params Values: " "
 * Expected: GtkTextTag*  
 */
static void test_purpose_3()
{
    #define NAME " "
    
    gchararray name;
    /*  GdkColor background_gdk; */
    gboolean background_full_height;
    /*  GdkColor foreground_gdk; */
    GtkTextDirection direction;
    gboolean editable;
    gchararray font;
    PangoFontDescription *font_desc;
    gchararray family;
    PangoStyle style;
    PangoVariant variant;
    gint weight;
    PangoStretch stretch;
    gint size;
    gdouble scale;
    gdouble size_points;
    GtkJustification justification;
    gchararray language;
    gint left_margin;
    gint right_margin;
    gint indent;
    gint rise;
    gint pixels_above_lines;
    gint pixels_below_lines;
    gint pixels_inside_wrap;
    gboolean strikethrough;
    PangoUnderline underline;
    GtkWrapMode wrap_mode;
    /*PangoTabArray tabs;*/
    gboolean invisible;
    gboolean background_set;
    gboolean background_full_height_set;
    gboolean background_stipple_set;
    gboolean foreground_set;
    gboolean foreground_stipple_set;
    gboolean editable_set;
    gboolean family_set;
    gboolean style_set;
    gboolean variant_set;
    gboolean weight_set;
    gboolean stretch_set;
    gboolean size_set;
    gboolean scale_set;
    gboolean justification_set;
    gboolean language_set;
    gboolean left_margin_set;
    gboolean indent_set;
    gboolean rise_set;
    gboolean pixels_above_lines_set;
    gboolean pixels_below_lines_set;
    gboolean pixels_inside_wrap_set;
    gboolean strikethrough_set;
    gboolean right_margin_set;
    gboolean underline_set;
    gboolean wrap_mode_set;
    gboolean tabs_set;
    gboolean invisible_set;
    
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new (NAME);
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_get (tag, "name", &name, NULL);
    if (NAME)
    {
        if (strcmp (name, (char*)NAME)) 
        {
        TEST_FAIL ("name is '%s', should be '%s'", name, (gchar*)NAME);
        }
    } else {
        if (name)
        {
            TEST_FAIL ("name should be NULL but it is not", NULL);
        }
    }
    
    g_object_get (tag, "background-full-height", 
                   &background_full_height, NULL);
    if (background_full_height != FALSE) 
    {
        TEST_FAIL ("background_full_height = %d, should be %d", 
                   background_full_height, FALSE);
    }
    
    g_object_get (tag, "direction", &direction, NULL);
    if (direction != GTK_TEXT_DIR_NONE) 
    {
        TEST_FAIL ("direction = %d, should be %d", 
                   direction, GTK_TEXT_DIR_NONE);
    }
    
    g_object_get (tag, "editable", &editable, NULL);
    if (editable != TRUE) 
    {
        TEST_FAIL ("editable = %d, should be %d", 
                   editable, TRUE);
    }
    
    g_object_get (tag, "font", &font, NULL);
    if (font == NULL) 
    {
        TEST_FAIL ("font = %d, should be %d", 
                   font, NULL);
    }
    
    g_object_get (tag, "font-desc", &font_desc, NULL);
    if (font_desc == NULL) 
    {
        TEST_FAIL ("font-desc = %d, should be %d", 
                   font_desc, NULL);
    }
    
    g_object_get (tag, "family", &family, NULL);
    if (family != NULL) 
    {
        TEST_FAIL ("family = %d, should be %d", 
                   family , NULL);
    }
    
    g_object_get (tag, "style", &style, NULL);
    if (style != PANGO_STYLE_NORMAL) 
    {
        TEST_FAIL ("style = %d, should be %d", 
                   style , PANGO_STYLE_NORMAL);
    }
    
    g_object_get (tag, "variant", &variant, NULL);
    if (variant != PANGO_VARIANT_NORMAL) 
    {
        TEST_FAIL ("variant = %d, should be %d", 
                   variant , PANGO_VARIANT_NORMAL);
    }
    
    g_object_get (tag, "weight", &weight, NULL);
    if (weight != 400) 
    {
        TEST_FAIL ("weight = %d, should be %d", 
                   weight, 0);
    }
    
    g_object_get (tag, "stretch", &stretch, NULL);
    if (stretch != PANGO_STRETCH_NORMAL) 
    {
        TEST_FAIL ("stretch = %d, should be %d", 
                   stretch, PANGO_STRETCH_ULTRA_CONDENSED);
    }
    
    g_object_get (tag, "size", &size, NULL);
    if (size != 0) 
    {
        TEST_FAIL ("size = %d, should be %d", 
                   size, 0);
    }
    
    g_object_get (tag, "scale", &scale, NULL);
    if (scale != 1.0) 
    {
        TEST_FAIL ("scale = %d, should be %d", 
                   scale, 1.0);
    }
    
    g_object_get (tag, "size-points", &size_points, NULL);
    if (size_points != 0.0) 
    {
        TEST_FAIL ("size_points = %d, should be %d", 
                   size_points, 0.0);
    }
    
    g_object_get (tag, "justification", &justification, NULL);
    if (justification != GTK_JUSTIFY_LEFT) 
    {
        TEST_FAIL ("justification = %d, should be %d", 
                   justification, GTK_JUSTIFY_LEFT);
    }
    
    /* language is locale dependent
    g_object_get (tag, "language", &language, NULL);
    if (strcmp (language, "c")) 
    {
        TEST_FAIL ("language = '%s', should be '%s'", 
                   language, "c");
    }
    */
    
    g_object_get (tag, "left-margin", &left_margin, NULL);
    if (left_margin != 0) 
    {
        TEST_FAIL ("left_margin = %d, should be %d", 
                   left_margin, 0);
    }
    
    g_object_get (tag, "right-margin", &right_margin, NULL);
    if (right_margin != 0) 
    {
        TEST_FAIL ("right_margin = %d, should be %d", 
                   right_margin, 0);
    }
    
    g_object_get (tag, "indent", &indent, NULL);
    if (indent != 0) 
    {
        TEST_FAIL ("indent = %d, should be %d", 
                   indent, 0);
    }
    
    g_object_get (tag, "rise", &rise, NULL);
    if (rise != 0) 
    {
        TEST_FAIL ("rise = %d, should be %d", 
                   rise, 0);
    }
    
    g_object_get (tag, "pixels-above-lines", 
                   &pixels_above_lines, NULL);
    if (pixels_above_lines != 0) 
    {
        TEST_FAIL ("pixels-above-lines = %d, should be %d", 
                   pixels_above_lines, 0);
    }
    
    g_object_get (tag, "pixels-below-lines", 
                   &pixels_below_lines, NULL);
    if (pixels_below_lines != 0) 
    {
        TEST_FAIL ("pixels-below-lines = %d, should be %d", 
                   pixels_below_lines, 0);
    }
    
    g_object_get (tag, "pixels-inside-wrap", 
                   &pixels_inside_wrap, NULL);
    if (pixels_inside_wrap != 0) 
    {
        TEST_FAIL ("pixels-inside-wrap = %d, should be %d", 
                   pixels_inside_wrap, 0);
    }
    
    g_object_get (tag, "strikethrough", 
                   &strikethrough, NULL);
    if (strikethrough != FALSE) 
    {
        TEST_FAIL ("strikethrough = %d, should be %d", 
                   strikethrough, NULL);
    }
    
    g_object_get (tag, "underline", &underline, NULL);
    if (underline != PANGO_UNDERLINE_NONE) 
    {
        TEST_FAIL ("underline = %d, should be %d", 
                   underline, PANGO_UNDERLINE_NONE);
    }
    
    g_object_get (tag, "wrap-mode", &wrap_mode, NULL);
    if (wrap_mode != GTK_WRAP_NONE) 
    {
        TEST_FAIL ("wrap_mode = %d, should be %d", 
                   wrap_mode, GTK_WRAP_NONE);
    }
    
    g_object_get (tag, "invisible", &invisible, NULL);
    if (invisible != FALSE) 
    {
        TEST_FAIL ("invisible = %d, should be %d", 
                   invisible, FALSE);
    }
    
    g_object_get (tag, "background-set", &background_set, NULL);
    if (background_set != FALSE) 
    {
        TEST_FAIL ("background-set = %d, should be %d", 
                   background_set, FALSE);
    }
    
    g_object_get (tag, "background-full-height-set", 
                   &background_full_height_set, NULL);
    if (background_full_height_set != FALSE) 
    {
        TEST_FAIL ("background-full-height_set = %d, should be %d", 
                   background_full_height_set, FALSE);
    }
    
    g_object_get (tag, "background-stipple-set", 
                   &background_stipple_set, NULL);
    if (background_stipple_set != FALSE) 
    {
        TEST_FAIL ("background-stipple-set = %d, should be %d", 
                   background_stipple_set, FALSE);
    }
    
    g_object_get (tag, "foreground-set", &foreground_set, NULL);
    if (foreground_set != FALSE) 
    {
        TEST_FAIL ("foreground-set = %d, should be %d", 
                   foreground_set, FALSE);
    }
    
    g_object_get (tag, "foreground-stipple-set", 
                   &foreground_stipple_set, NULL);
    if (foreground_stipple_set != FALSE) 
    {
        TEST_FAIL ("foreground-stipple-set = %d, should be %d", 
                   foreground_stipple_set, FALSE);
    }
    
    g_object_get (tag, "editable-set", &editable_set, NULL);
    if (editable_set != FALSE) 
    {
        TEST_FAIL ("editable-set = %d, should be %d", 
                   editable_set, FALSE);
    }
    
    g_object_get (tag, "family-set", &family_set, NULL);
    if (family_set != FALSE) 
    {
        TEST_FAIL ("family-set = %d, should be %d", 
                   family_set, FALSE);
    }
    
    g_object_get (tag, "style-set", &style_set, NULL);
    if (style_set != FALSE) 
    {
        TEST_FAIL ("style-set = %d, should be %d", 
                   style_set, FALSE);
    }
    
    g_object_get (tag, "variant-set", &variant_set, NULL);
    if (variant_set != FALSE) 
    {
        TEST_FAIL ("variant-set = %d, should be %d", 
                   variant_set, FALSE);
    }
    
    g_object_get (tag, "weight-set", &weight_set, NULL);
    if (weight_set != FALSE) 
    {
        TEST_FAIL ("weight-set = %d, should be %d", 
                   weight_set, FALSE);
    }
    
    g_object_get (tag, "stretch-set", &stretch_set, NULL);
    if (stretch_set != FALSE) 
    {
        TEST_FAIL ("stretch-set = %d, should be %d", 
                   stretch_set, FALSE);
    }
    
    g_object_get (tag, "size-set", &size_set, NULL);
    if (size_set != FALSE) 
    {
        TEST_FAIL ("size-set = %d, should be %d", 
                   size_set, FALSE);
    }
    
    g_object_get (tag, "scale-set", &scale_set, NULL);
    if (scale_set != FALSE) 
    {
        TEST_FAIL ("scale-set = %d, should be %d", 
                   scale_set, FALSE);
    }
    
    g_object_get (tag, "justification-set", 
                   &justification_set, NULL);
    if (justification_set != FALSE) 
    {
        TEST_FAIL ("justification-set = %d, should be %d", 
                   justification_set, FALSE);
    }
    
    g_object_get (tag, "language-set", 
                   &language_set, NULL);
    if (language_set != FALSE) 
    {
        TEST_FAIL ("language-set = %d, should be %d", 
                   language_set, FALSE);
    }
    
    g_object_get (tag, "left-margin-set", 
                   &left_margin_set, NULL);
    if (left_margin_set != FALSE) 
    {
        TEST_FAIL ("left_margin-set = %d, should be %d", 
                   left_margin_set, FALSE);
    }
    
    g_object_get (tag, "indent-set",  &indent_set, NULL);
    if (indent_set != FALSE) 
    {
        TEST_FAIL ("indent-set = %d, should be %d", 
                   indent_set, FALSE);
    }
    
    g_object_get (tag, "rise-set",  &rise_set, NULL);
    if (rise_set != FALSE) 
    {
        TEST_FAIL ("rise-set = %d, should be %d", 
                   rise_set, FALSE);
    }
    
    g_object_get (tag, "pixels-above-lines-set",  
                   &pixels_above_lines_set, NULL);
    if (pixels_above_lines_set != FALSE) 
    {
        TEST_FAIL ("pixels-above-lines-set = %d, should be %d", 
                   pixels_above_lines_set, FALSE);
    }
    
    g_object_get (tag, "pixels-below-lines-set",  
                   &pixels_below_lines_set, NULL);
    if (pixels_below_lines_set != FALSE) 
    {
        TEST_FAIL ("pixels-below-lines-set = %d, should be %d", 
                   pixels_above_lines_set, FALSE);
    }
    
    g_object_get (tag, "pixels-inside-wrap-set",  
                   &pixels_inside_wrap_set, NULL);
    if (pixels_inside_wrap_set != FALSE) 
    {
        TEST_FAIL ("pixels-inside-wrap-set = %d, should be %d", 
                   pixels_inside_wrap_set, FALSE);
    }
    
    g_object_get (tag, "strikethrough-set",  
                   &strikethrough_set, NULL);
    if (strikethrough_set != FALSE) 
    {
        TEST_FAIL ("strikethrough-set = %d, should be %d", 
                   strikethrough_set, FALSE);
    }
    
    g_object_get (tag, "right-margin-set", 
                   &right_margin_set, NULL);
    if (right_margin_set != FALSE) 
    {
        TEST_FAIL ("right-margin-set = %d, should be %d", 
                   right_margin_set, FALSE);
    }
    
    g_object_get (tag, "underline-set", 
                   &underline_set, NULL);
    if (underline_set != FALSE) 
    {
        TEST_FAIL ("underline-set = %d, should be %d", 
                   underline_set, FALSE);
    }
    
    g_object_get (tag, "wrap-mode-set", 
                   &wrap_mode_set, NULL);
    if (wrap_mode_set != FALSE) 
    {
        TEST_FAIL ("wrap-mode-set = %d, should be %d", 
                   wrap_mode_set, FALSE);
    }
    
    g_object_get (tag, "tabs-set", &tabs_set, NULL);
    if (tabs_set != FALSE) 
    {
        TEST_FAIL ("tabs-set = %d, should be %d", 
                   tabs_set, FALSE);
    }
    
    g_object_get (tag, "invisible-set", &invisible_set, NULL);
    if (invisible_set != FALSE) 
    {
        TEST_FAIL ("invisible-set = %d, should be %d", 
                   invisible_set, FALSE);
    }
    
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_new
 * Params: const gchar* name
 * Returns: GtkTag*
 * Assertion: Creates a GtkTextTag.
 * Params Values: "Label"
 * Expected: GtkTextTag*  
 */
static void test_purpose_4()
{
    #define NAME "Label"
    
    gchararray name;
    /*  GdkColor background_gdk; */
    gboolean background_full_height;
    /*  GdkColor foreground_gdk; */
    GtkTextDirection direction;
    gboolean editable;
    gchararray font;
    PangoFontDescription *font_desc;
    gchararray family;
    PangoStyle style;
    PangoVariant variant;
    gint weight;
    PangoStretch stretch;
    gint size;
    gdouble scale;
    gdouble size_points;
    GtkJustification justification;
    gchararray language;
    gint left_margin;
    gint right_margin;
    gint indent;
    gint rise;
    gint pixels_above_lines;
    gint pixels_below_lines;
    gint pixels_inside_wrap;
    gboolean strikethrough;
    PangoUnderline underline;
    GtkWrapMode wrap_mode;
    /*PangoTabArray tabs;*/
    gboolean invisible;
    gboolean background_set;
    gboolean background_full_height_set;
    gboolean background_stipple_set;
    gboolean foreground_set;
    gboolean foreground_stipple_set;
    gboolean editable_set;
    gboolean family_set;
    gboolean style_set;
    gboolean variant_set;
    gboolean weight_set;
    gboolean stretch_set;
    gboolean size_set;
    gboolean scale_set;
    gboolean justification_set;
    gboolean language_set;
    gboolean left_margin_set;
    gboolean indent_set;
    gboolean rise_set;
    gboolean pixels_above_lines_set;
    gboolean pixels_below_lines_set;
    gboolean pixels_inside_wrap_set;
    gboolean strikethrough_set;
    gboolean right_margin_set;
    gboolean underline_set;
    gboolean wrap_mode_set;
    gboolean tabs_set;
    gboolean invisible_set;
    
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new (NAME);
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_get (tag, "name", &name, NULL);
    if (NAME)
    {
        if (strcmp (name, (char*)NAME)) 
        {
        TEST_FAIL ("name is '%s', should be '%s'", name, (gchar*)NAME);
        }
    } else {
        if (name)
        {
            TEST_FAIL ("name should be NULL but it is not", NULL);
        }
    }
    
    g_object_get (tag, "background-full-height", 
                   &background_full_height, NULL);
    if (background_full_height != FALSE) 
    {
        TEST_FAIL ("background_full_height = %d, should be %d", 
                   background_full_height, FALSE);
    }
    
    g_object_get (tag, "direction", &direction, NULL);
    if (direction != GTK_TEXT_DIR_NONE) 
    {
        TEST_FAIL ("direction = %d, should be %d", 
                   direction, GTK_TEXT_DIR_NONE);
    }
    
    g_object_get (tag, "editable", &editable, NULL);
    if (editable != TRUE) 
    {
        TEST_FAIL ("editable = %d, should be %d", 
                   editable, TRUE);
    }
    
    g_object_get (tag, "font", &font, NULL);
    if (font == NULL) 
    {
        TEST_FAIL ("font = %d, should be %d", 
                   font, NULL);
    }
    
    g_object_get (tag, "font-desc", &font_desc, NULL);
    if (font_desc == NULL) 
    {
        TEST_FAIL ("font-desc = %d, should be %d", 
                   font_desc, NULL);
    }
    
    g_object_get (tag, "family", &family, NULL);
    if (family != NULL) 
    {
        TEST_FAIL ("family = %d, should be %d", 
                   family , NULL);
    }
    
    g_object_get (tag, "style", &style, NULL);
    if (style != PANGO_STYLE_NORMAL) 
    {
        TEST_FAIL ("style = %d, should be %d", 
                   style , PANGO_STYLE_NORMAL);
    }
    
    g_object_get (tag, "variant", &variant, NULL);
    if (variant != PANGO_VARIANT_NORMAL) 
    {
        TEST_FAIL ("variant = %d, should be %d", 
                   variant , PANGO_VARIANT_NORMAL);
    }
    
    g_object_get (tag, "weight", &weight, NULL);
    if (weight != 400) 
    {
        TEST_FAIL ("weight = %d, should be %d", 
                   weight, 0);
    }
    
    g_object_get (tag, "stretch", &stretch, NULL);
    if (stretch != PANGO_STRETCH_NORMAL) 
    {
        TEST_FAIL ("stretch = %d, should be %d", 
                   stretch, PANGO_STRETCH_ULTRA_CONDENSED);
    }
    
    g_object_get (tag, "size", &size, NULL);
    if (size != 0) 
    {
        TEST_FAIL ("size = %d, should be %d", 
                   size, 0);
    }
    
    g_object_get (tag, "scale", &scale, NULL);
    if (scale != 1.0) 
    {
        TEST_FAIL ("scale = %d, should be %d", 
                   scale, 1.0);
    }
    
    g_object_get (tag, "size-points", &size_points, NULL);
    if (size_points != 0.0) 
    {
        TEST_FAIL ("size_points = %d, should be %d", 
                   size_points, 0.0);
    }
    
    g_object_get (tag, "justification", &justification, NULL);
    if (justification != GTK_JUSTIFY_LEFT) 
    {
        TEST_FAIL ("justification = %d, should be %d", 
                   justification, GTK_JUSTIFY_LEFT);
    }
    
    /* language is locale dependent
    g_object_get (tag, "language", &language, NULL);
    if (strcmp (language, "c")) 
    {
        TEST_FAIL ("language = '%s', should be '%s'", 
                   language, "c");
    }
    */
    
    g_object_get (tag, "left-margin", &left_margin, NULL);
    if (left_margin != 0) 
    {
        TEST_FAIL ("left_margin = %d, should be %d", 
                   left_margin, 0);
    }
    
    g_object_get (tag, "right-margin", &right_margin, NULL);
    if (right_margin != 0) 
    {
        TEST_FAIL ("right_margin = %d, should be %d", 
                   right_margin, 0);
    }
    
    g_object_get (tag, "indent", &indent, NULL);
    if (indent != 0) 
    {
        TEST_FAIL ("indent = %d, should be %d", 
                   indent, 0);
    }
    
    g_object_get (tag, "rise", &rise, NULL);
    if (rise != 0) 
    {
        TEST_FAIL ("rise = %d, should be %d", 
                   rise, 0);
    }
    
    g_object_get (tag, "pixels-above-lines", 
                   &pixels_above_lines, NULL);
    if (pixels_above_lines != 0) 
    {
        TEST_FAIL ("pixels-above-lines = %d, should be %d", 
                   pixels_above_lines, 0);
    }
    
    g_object_get (tag, "pixels-below-lines", 
                   &pixels_below_lines, NULL);
    if (pixels_below_lines != 0) 
    {
        TEST_FAIL ("pixels-below-lines = %d, should be %d", 
                   pixels_below_lines, 0);
    }
    
    g_object_get (tag, "pixels-inside-wrap", 
                   &pixels_inside_wrap, NULL);
    if (pixels_inside_wrap != 0) 
    {
        TEST_FAIL ("pixels-inside-wrap = %d, should be %d", 
                   pixels_inside_wrap, 0);
    }
    
    g_object_get (tag, "strikethrough", 
                   &strikethrough, NULL);
    if (strikethrough != FALSE) 
    {
        TEST_FAIL ("strikethrough = %d, should be %d", 
                   strikethrough, NULL);
    }
    
    g_object_get (tag, "underline", &underline, NULL);
    if (underline != PANGO_UNDERLINE_NONE) 
    {
        TEST_FAIL ("underline = %d, should be %d", 
                   underline, PANGO_UNDERLINE_NONE);
    }
    
    g_object_get (tag, "wrap-mode", &wrap_mode, NULL);
    if (wrap_mode != GTK_WRAP_NONE) 
    {
        TEST_FAIL ("wrap_mode = %d, should be %d", 
                   wrap_mode, GTK_WRAP_NONE);
    }
    
    g_object_get (tag, "invisible", &invisible, NULL);
    if (invisible != FALSE) 
    {
        TEST_FAIL ("invisible = %d, should be %d", 
                   invisible, FALSE);
    }
    
    g_object_get (tag, "background-set", &background_set, NULL);
    if (background_set != FALSE) 
    {
        TEST_FAIL ("background-set = %d, should be %d", 
                   background_set, FALSE);
    }
    
    g_object_get (tag, "background-full-height-set", 
                   &background_full_height_set, NULL);
    if (background_full_height_set != FALSE) 
    {
        TEST_FAIL ("background-full-height_set = %d, should be %d", 
                   background_full_height_set, FALSE);
    }
    
    g_object_get (tag, "background-stipple-set", 
                   &background_stipple_set, NULL);
    if (background_stipple_set != FALSE) 
    {
        TEST_FAIL ("background-stipple-set = %d, should be %d", 
                   background_stipple_set, FALSE);
    }
    
    g_object_get (tag, "foreground-set", &foreground_set, NULL);
    if (foreground_set != FALSE) 
    {
        TEST_FAIL ("foreground-set = %d, should be %d", 
                   foreground_set, FALSE);
    }
    
    g_object_get (tag, "foreground-stipple-set", 
                   &foreground_stipple_set, NULL);
    if (foreground_stipple_set != FALSE) 
    {
        TEST_FAIL ("foreground-stipple-set = %d, should be %d", 
                   foreground_stipple_set, FALSE);
    }
    
    g_object_get (tag, "editable-set", &editable_set, NULL);
    if (editable_set != FALSE) 
    {
        TEST_FAIL ("editable-set = %d, should be %d", 
                   editable_set, FALSE);
    }
    
    g_object_get (tag, "family-set", &family_set, NULL);
    if (family_set != FALSE) 
    {
        TEST_FAIL ("family-set = %d, should be %d", 
                   family_set, FALSE);
    }
    
    g_object_get (tag, "style-set", &style_set, NULL);
    if (style_set != FALSE) 
    {
        TEST_FAIL ("style-set = %d, should be %d", 
                   style_set, FALSE);
    }
    
    g_object_get (tag, "variant-set", &variant_set, NULL);
    if (variant_set != FALSE) 
    {
        TEST_FAIL ("variant-set = %d, should be %d", 
                   variant_set, FALSE);
    }
    
    g_object_get (tag, "weight-set", &weight_set, NULL);
    if (weight_set != FALSE) 
    {
        TEST_FAIL ("weight-set = %d, should be %d", 
                   weight_set, FALSE);
    }
    
    g_object_get (tag, "stretch-set", &stretch_set, NULL);
    if (stretch_set != FALSE) 
    {
        TEST_FAIL ("stretch-set = %d, should be %d", 
                   stretch_set, FALSE);
    }
    
    g_object_get (tag, "size-set", &size_set, NULL);
    if (size_set != FALSE) 
    {
        TEST_FAIL ("size-set = %d, should be %d", 
                   size_set, FALSE);
    }
    
    g_object_get (tag, "scale-set", &scale_set, NULL);
    if (scale_set != FALSE) 
    {
        TEST_FAIL ("scale-set = %d, should be %d", 
                   scale_set, FALSE);
    }
    
    g_object_get (tag, "justification-set", 
                   &justification_set, NULL);
    if (justification_set != FALSE) 
    {
        TEST_FAIL ("justification-set = %d, should be %d", 
                   justification_set, FALSE);
    }
    
    g_object_get (tag, "language-set", 
                   &language_set, NULL);
    if (language_set != FALSE) 
    {
        TEST_FAIL ("language-set = %d, should be %d", 
                   language_set, FALSE);
    }
    
    g_object_get (tag, "left-margin-set", 
                   &left_margin_set, NULL);
    if (left_margin_set != FALSE) 
    {
        TEST_FAIL ("left_margin-set = %d, should be %d", 
                   left_margin_set, FALSE);
    }
    
    g_object_get (tag, "indent-set",  &indent_set, NULL);
    if (indent_set != FALSE) 
    {
        TEST_FAIL ("indent-set = %d, should be %d", 
                   indent_set, FALSE);
    }
    
    g_object_get (tag, "rise-set",  &rise_set, NULL);
    if (rise_set != FALSE) 
    {
        TEST_FAIL ("rise-set = %d, should be %d", 
                   rise_set, FALSE);
    }
    
    g_object_get (tag, "pixels-above-lines-set",  
                   &pixels_above_lines_set, NULL);
    if (pixels_above_lines_set != FALSE) 
    {
        TEST_FAIL ("pixels-above-lines-set = %d, should be %d", 
                   pixels_above_lines_set, FALSE);
    }
    
    g_object_get (tag, "pixels-below-lines-set",  
                   &pixels_below_lines_set, NULL);
    if (pixels_below_lines_set != FALSE) 
    {
        TEST_FAIL ("pixels-below-lines-set = %d, should be %d", 
                   pixels_above_lines_set, FALSE);
    }
    
    g_object_get (tag, "pixels-inside-wrap-set",  
                   &pixels_inside_wrap_set, NULL);
    if (pixels_inside_wrap_set != FALSE) 
    {
        TEST_FAIL ("pixels-inside-wrap-set = %d, should be %d", 
                   pixels_inside_wrap_set, FALSE);
    }
    
    g_object_get (tag, "strikethrough-set",  
                   &strikethrough_set, NULL);
    if (strikethrough_set != FALSE) 
    {
        TEST_FAIL ("strikethrough-set = %d, should be %d", 
                   strikethrough_set, FALSE);
    }
    
    g_object_get (tag, "right-margin-set", 
                   &right_margin_set, NULL);
    if (right_margin_set != FALSE) 
    {
        TEST_FAIL ("right-margin-set = %d, should be %d", 
                   right_margin_set, FALSE);
    }
    
    g_object_get (tag, "underline-set", 
                   &underline_set, NULL);
    if (underline_set != FALSE) 
    {
        TEST_FAIL ("underline-set = %d, should be %d", 
                   underline_set, FALSE);
    }
    
    g_object_get (tag, "wrap-mode-set", 
                   &wrap_mode_set, NULL);
    if (wrap_mode_set != FALSE) 
    {
        TEST_FAIL ("wrap-mode-set = %d, should be %d", 
                   wrap_mode_set, FALSE);
    }
    
    g_object_get (tag, "tabs-set", &tabs_set, NULL);
    if (tabs_set != FALSE) 
    {
        TEST_FAIL ("tabs-set = %d, should be %d", 
                   tabs_set, FALSE);
    }
    
    g_object_get (tag, "invisible-set", &invisible_set, NULL);
    if (invisible_set != FALSE) 
    {
        TEST_FAIL ("invisible-set = %d, should be %d", 
                   invisible_set, FALSE);
    }
    
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_new
 * Params: const gchar* name
 * Returns: GtkTag*
 * Assertion: Creates a GtkTextTag.
 * Params Values: "\b\t\n"
 * Expected: GtkTextTag*  
 */
static void test_purpose_5()
{
    #define NAME "\b\t\n"
    
    gchararray name;
    /*  GdkColor background_gdk; */
    gboolean background_full_height;
    /*  GdkColor foreground_gdk; */
    GtkTextDirection direction;
    gboolean editable;
    gchararray font;
    PangoFontDescription *font_desc;
    gchararray family;
    PangoStyle style;
    PangoVariant variant;
    gint weight;
    PangoStretch stretch;
    gint size;
    gdouble scale;
    gdouble size_points;
    GtkJustification justification;
    gchararray language;
    gint left_margin;
    gint right_margin;
    gint indent;
    gint rise;
    gint pixels_above_lines;
    gint pixels_below_lines;
    gint pixels_inside_wrap;
    gboolean strikethrough;
    PangoUnderline underline;
    GtkWrapMode wrap_mode;
    /*PangoTabArray tabs;*/
    gboolean invisible;
    gboolean background_set;
    gboolean background_full_height_set;
    gboolean background_stipple_set;
    gboolean foreground_set;
    gboolean foreground_stipple_set;
    gboolean editable_set;
    gboolean family_set;
    gboolean style_set;
    gboolean variant_set;
    gboolean weight_set;
    gboolean stretch_set;
    gboolean size_set;
    gboolean scale_set;
    gboolean justification_set;
    gboolean language_set;
    gboolean left_margin_set;
    gboolean indent_set;
    gboolean rise_set;
    gboolean pixels_above_lines_set;
    gboolean pixels_below_lines_set;
    gboolean pixels_inside_wrap_set;
    gboolean strikethrough_set;
    gboolean right_margin_set;
    gboolean underline_set;
    gboolean wrap_mode_set;
    gboolean tabs_set;
    gboolean invisible_set;
    
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new (NAME);
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_get (tag, "name", &name, NULL);
    if (NAME)
    {
        if (strcmp (name, (char*)NAME)) 
        {
        TEST_FAIL ("name is '%s', should be '%s'", name, (gchar*)NAME);
        }
    } else {
        if (name)
        {
            TEST_FAIL ("name should be NULL but it is not", NULL);
        }
    }
    
    g_object_get (tag, "background-full-height", 
                   &background_full_height, NULL);
    if (background_full_height != FALSE) 
    {
        TEST_FAIL ("background_full_height = %d, should be %d", 
                   background_full_height, FALSE);
    }
    
    g_object_get (tag, "direction", &direction, NULL);
    if (direction != GTK_TEXT_DIR_NONE) 
    {
        TEST_FAIL ("direction = %d, should be %d", 
                   direction, GTK_TEXT_DIR_NONE);
    }
    
    g_object_get (tag, "editable", &editable, NULL);
    if (editable != TRUE) 
    {
        TEST_FAIL ("editable = %d, should be %d", 
                   editable, TRUE);
    }
    
    g_object_get (tag, "font", &font, NULL);
    if (font == NULL) 
    {
        TEST_FAIL ("font = %d, should be %d", 
                   font, NULL);
    }
    
    g_object_get (tag, "font-desc", &font_desc, NULL);
    if (font_desc == NULL) 
    {
        TEST_FAIL ("font-desc = %d, should be %d", 
                   font_desc, NULL);
    }
    
    g_object_get (tag, "family", &family, NULL);
    if (family != NULL) 
    {
        TEST_FAIL ("family = %d, should be %d", 
                   family , NULL);
    }
    
    g_object_get (tag, "style", &style, NULL);
    if (style != PANGO_STYLE_NORMAL) 
    {
        TEST_FAIL ("style = %d, should be %d", 
                   style , PANGO_STYLE_NORMAL);
    }
    
    g_object_get (tag, "variant", &variant, NULL);
    if (variant != PANGO_VARIANT_NORMAL) 
    {
        TEST_FAIL ("variant = %d, should be %d", 
                   variant , PANGO_VARIANT_NORMAL);
    }
    
    g_object_get (tag, "weight", &weight, NULL);
    if (weight != 400) 
    {
        TEST_FAIL ("weight = %d, should be %d", 
                   weight, 0);
    }
    
    g_object_get (tag, "stretch", &stretch, NULL);
    if (stretch != PANGO_STRETCH_NORMAL) 
    {
        TEST_FAIL ("stretch = %d, should be %d", 
                   stretch, PANGO_STRETCH_ULTRA_CONDENSED);
    }
    
    g_object_get (tag, "size", &size, NULL);
    if (size != 0) 
    {
        TEST_FAIL ("size = %d, should be %d", 
                   size, 0);
    }
    
    g_object_get (tag, "scale", &scale, NULL);
    if (scale != 1.0) 
    {
        TEST_FAIL ("scale = %d, should be %d", 
                   scale, 1.0);
    }
    
    g_object_get (tag, "size-points", &size_points, NULL);
    if (size_points != 0.0) 
    {
        TEST_FAIL ("size_points = %d, should be %d", 
                   size_points, 0.0);
    }
    
    g_object_get (tag, "justification", &justification, NULL);
    if (justification != GTK_JUSTIFY_LEFT) 
    {
        TEST_FAIL ("justification = %d, should be %d", 
                   justification, GTK_JUSTIFY_LEFT);
    }
    
    /* language is locale dependent
    g_object_get (tag, "language", &language, NULL);
    if (strcmp (language, "c")) 
    {
        TEST_FAIL ("language = '%s', should be '%s'", 
                   language, "c");
    }
    */
    
    g_object_get (tag, "left-margin", &left_margin, NULL);
    if (left_margin != 0) 
    {
        TEST_FAIL ("left_margin = %d, should be %d", 
                   left_margin, 0);
    }
    
    g_object_get (tag, "right-margin", &right_margin, NULL);
    if (right_margin != 0) 
    {
        TEST_FAIL ("right_margin = %d, should be %d", 
                   right_margin, 0);
    }
    
    g_object_get (tag, "indent", &indent, NULL);
    if (indent != 0) 
    {
        TEST_FAIL ("indent = %d, should be %d", 
                   indent, 0);
    }
    
    g_object_get (tag, "rise", &rise, NULL);
    if (rise != 0) 
    {
        TEST_FAIL ("rise = %d, should be %d", 
                   rise, 0);
    }
    
    g_object_get (tag, "pixels-above-lines", 
                   &pixels_above_lines, NULL);
    if (pixels_above_lines != 0) 
    {
        TEST_FAIL ("pixels-above-lines = %d, should be %d", 
                   pixels_above_lines, 0);
    }
    
    g_object_get (tag, "pixels-below-lines", 
                   &pixels_below_lines, NULL);
    if (pixels_below_lines != 0) 
    {
        TEST_FAIL ("pixels-below-lines = %d, should be %d", 
                   pixels_below_lines, 0);
    }
    
    g_object_get (tag, "pixels-inside-wrap", 
                   &pixels_inside_wrap, NULL);
    if (pixels_inside_wrap != 0) 
    {
        TEST_FAIL ("pixels-inside-wrap = %d, should be %d", 
                   pixels_inside_wrap, 0);
    }
    
    g_object_get (tag, "strikethrough", 
                   &strikethrough, NULL);
    if (strikethrough != FALSE) 
    {
        TEST_FAIL ("strikethrough = %d, should be %d", 
                   strikethrough, NULL);
    }
    
    g_object_get (tag, "underline", &underline, NULL);
    if (underline != PANGO_UNDERLINE_NONE) 
    {
        TEST_FAIL ("underline = %d, should be %d", 
                   underline, PANGO_UNDERLINE_NONE);
    }
    
    g_object_get (tag, "wrap-mode", &wrap_mode, NULL);
    if (wrap_mode != GTK_WRAP_NONE) 
    {
        TEST_FAIL ("wrap_mode = %d, should be %d", 
                   wrap_mode, GTK_WRAP_NONE);
    }
    
    g_object_get (tag, "invisible", &invisible, NULL);
    if (invisible != FALSE) 
    {
        TEST_FAIL ("invisible = %d, should be %d", 
                   invisible, FALSE);
    }
    
    g_object_get (tag, "background-set", &background_set, NULL);
    if (background_set != FALSE) 
    {
        TEST_FAIL ("background-set = %d, should be %d", 
                   background_set, FALSE);
    }
    
    g_object_get (tag, "background-full-height-set", 
                   &background_full_height_set, NULL);
    if (background_full_height_set != FALSE) 
    {
        TEST_FAIL ("background-full-height_set = %d, should be %d", 
                   background_full_height_set, FALSE);
    }
    
    g_object_get (tag, "background-stipple-set", 
                   &background_stipple_set, NULL);
    if (background_stipple_set != FALSE) 
    {
        TEST_FAIL ("background-stipple-set = %d, should be %d", 
                   background_stipple_set, FALSE);
    }
    
    g_object_get (tag, "foreground-set", &foreground_set, NULL);
    if (foreground_set != FALSE) 
    {
        TEST_FAIL ("foreground-set = %d, should be %d", 
                   foreground_set, FALSE);
    }
    
    g_object_get (tag, "foreground-stipple-set", 
                   &foreground_stipple_set, NULL);
    if (foreground_stipple_set != FALSE) 
    {
        TEST_FAIL ("foreground-stipple-set = %d, should be %d", 
                   foreground_stipple_set, FALSE);
    }
    
    g_object_get (tag, "editable-set", &editable_set, NULL);
    if (editable_set != FALSE) 
    {
        TEST_FAIL ("editable-set = %d, should be %d", 
                   editable_set, FALSE);
    }
    
    g_object_get (tag, "family-set", &family_set, NULL);
    if (family_set != FALSE) 
    {
        TEST_FAIL ("family-set = %d, should be %d", 
                   family_set, FALSE);
    }
    
    g_object_get (tag, "style-set", &style_set, NULL);
    if (style_set != FALSE) 
    {
        TEST_FAIL ("style-set = %d, should be %d", 
                   style_set, FALSE);
    }
    
    g_object_get (tag, "variant-set", &variant_set, NULL);
    if (variant_set != FALSE) 
    {
        TEST_FAIL ("variant-set = %d, should be %d", 
                   variant_set, FALSE);
    }
    
    g_object_get (tag, "weight-set", &weight_set, NULL);
    if (weight_set != FALSE) 
    {
        TEST_FAIL ("weight-set = %d, should be %d", 
                   weight_set, FALSE);
    }
    
    g_object_get (tag, "stretch-set", &stretch_set, NULL);
    if (stretch_set != FALSE) 
    {
        TEST_FAIL ("stretch-set = %d, should be %d", 
                   stretch_set, FALSE);
    }
    
    g_object_get (tag, "size-set", &size_set, NULL);
    if (size_set != FALSE) 
    {
        TEST_FAIL ("size-set = %d, should be %d", 
                   size_set, FALSE);
    }
    
    g_object_get (tag, "scale-set", &scale_set, NULL);
    if (scale_set != FALSE) 
    {
        TEST_FAIL ("scale-set = %d, should be %d", 
                   scale_set, FALSE);
    }
    
    g_object_get (tag, "justification-set", 
                   &justification_set, NULL);
    if (justification_set != FALSE) 
    {
        TEST_FAIL ("justification-set = %d, should be %d", 
                   justification_set, FALSE);
    }
    
    g_object_get (tag, "language-set", 
                   &language_set, NULL);
    if (language_set != FALSE) 
    {
        TEST_FAIL ("language-set = %d, should be %d", 
                   language_set, FALSE);
    }
    
    g_object_get (tag, "left-margin-set", 
                   &left_margin_set, NULL);
    if (left_margin_set != FALSE) 
    {
        TEST_FAIL ("left_margin-set = %d, should be %d", 
                   left_margin_set, FALSE);
    }
    
    g_object_get (tag, "indent-set",  &indent_set, NULL);
    if (indent_set != FALSE) 
    {
        TEST_FAIL ("indent-set = %d, should be %d", 
                   indent_set, FALSE);
    }
    
    g_object_get (tag, "rise-set",  &rise_set, NULL);
    if (rise_set != FALSE) 
    {
        TEST_FAIL ("rise-set = %d, should be %d", 
                   rise_set, FALSE);
    }
    
    g_object_get (tag, "pixels-above-lines-set",  
                   &pixels_above_lines_set, NULL);
    if (pixels_above_lines_set != FALSE) 
    {
        TEST_FAIL ("pixels-above-lines-set = %d, should be %d", 
                   pixels_above_lines_set, FALSE);
    }
    
    g_object_get (tag, "pixels-below-lines-set",  
                   &pixels_below_lines_set, NULL);
    if (pixels_below_lines_set != FALSE) 
    {
        TEST_FAIL ("pixels-below-lines-set = %d, should be %d", 
                   pixels_above_lines_set, FALSE);
    }
    
    g_object_get (tag, "pixels-inside-wrap-set",  
                   &pixels_inside_wrap_set, NULL);
    if (pixels_inside_wrap_set != FALSE) 
    {
        TEST_FAIL ("pixels-inside-wrap-set = %d, should be %d", 
                   pixels_inside_wrap_set, FALSE);
    }
    
    g_object_get (tag, "strikethrough-set",  
                   &strikethrough_set, NULL);
    if (strikethrough_set != FALSE) 
    {
        TEST_FAIL ("strikethrough-set = %d, should be %d", 
                   strikethrough_set, FALSE);
    }
    
    g_object_get (tag, "right-margin-set", 
                   &right_margin_set, NULL);
    if (right_margin_set != FALSE) 
    {
        TEST_FAIL ("right-margin-set = %d, should be %d", 
                   right_margin_set, FALSE);
    }
    
    g_object_get (tag, "underline-set", 
                   &underline_set, NULL);
    if (underline_set != FALSE) 
    {
        TEST_FAIL ("underline-set = %d, should be %d", 
                   underline_set, FALSE);
    }
    
    g_object_get (tag, "wrap-mode-set", 
                   &wrap_mode_set, NULL);
    if (wrap_mode_set != FALSE) 
    {
        TEST_FAIL ("wrap-mode-set = %d, should be %d", 
                   wrap_mode_set, FALSE);
    }
    
    g_object_get (tag, "tabs-set", &tabs_set, NULL);
    if (tabs_set != FALSE) 
    {
        TEST_FAIL ("tabs-set = %d, should be %d", 
                   tabs_set, FALSE);
    }
    
    g_object_get (tag, "invisible-set", &invisible_set, NULL);
    if (invisible_set != FALSE) 
    {
        TEST_FAIL ("invisible-set = %d, should be %d", 
                   invisible_set, FALSE);
    }
    
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_new
 * Params: const gchar* name
 * Returns: GtkTag*
 * Assertion: Creates a GtkTextTag.
 * Params Values: "!@#$%^&*"
 * Expected: GtkTextTag*  
 */
static void test_purpose_6()
{
    #define NAME "!@#$%^&*"
    
    gchararray name;
    /*  GdkColor background_gdk; */
    gboolean background_full_height;
    /*  GdkColor foreground_gdk; */
    GtkTextDirection direction;
    gboolean editable;
    gchararray font;
    PangoFontDescription *font_desc;
    gchararray family;
    PangoStyle style;
    PangoVariant variant;
    gint weight;
    PangoStretch stretch;
    gint size;
    gdouble scale;
    gdouble size_points;
    GtkJustification justification;
    gchararray language;
    gint left_margin;
    gint right_margin;
    gint indent;
    gint rise;
    gint pixels_above_lines;
    gint pixels_below_lines;
    gint pixels_inside_wrap;
    gboolean strikethrough;
    PangoUnderline underline;
    GtkWrapMode wrap_mode;
    /*PangoTabArray tabs;*/
    gboolean invisible;
    gboolean background_set;
    gboolean background_full_height_set;
    gboolean background_stipple_set;
    gboolean foreground_set;
    gboolean foreground_stipple_set;
    gboolean editable_set;
    gboolean family_set;
    gboolean style_set;
    gboolean variant_set;
    gboolean weight_set;
    gboolean stretch_set;
    gboolean size_set;
    gboolean scale_set;
    gboolean justification_set;
    gboolean language_set;
    gboolean left_margin_set;
    gboolean indent_set;
    gboolean rise_set;
    gboolean pixels_above_lines_set;
    gboolean pixels_below_lines_set;
    gboolean pixels_inside_wrap_set;
    gboolean strikethrough_set;
    gboolean right_margin_set;
    gboolean underline_set;
    gboolean wrap_mode_set;
    gboolean tabs_set;
    gboolean invisible_set;
    
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new (NAME);
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_get (tag, "name", &name, NULL);
    if (NAME)
    {
        if (strcmp (name, (char*)NAME)) 
        {
        TEST_FAIL ("name is '%s', should be '%s'", name, (gchar*)NAME);
        }
    } else {
        if (name)
        {
            TEST_FAIL ("name should be NULL but it is not", NULL);
        }
    }
    
    g_object_get (tag, "background-full-height", 
                   &background_full_height, NULL);
    if (background_full_height != FALSE) 
    {
        TEST_FAIL ("background_full_height = %d, should be %d", 
                   background_full_height, FALSE);
    }
    
    g_object_get (tag, "direction", &direction, NULL);
    if (direction != GTK_TEXT_DIR_NONE) 
    {
        TEST_FAIL ("direction = %d, should be %d", 
                   direction, GTK_TEXT_DIR_NONE);
    }
    
    g_object_get (tag, "editable", &editable, NULL);
    if (editable != TRUE) 
    {
        TEST_FAIL ("editable = %d, should be %d", 
                   editable, TRUE);
    }
    
    g_object_get (tag, "font", &font, NULL);
    if (font == NULL) 
    {
        TEST_FAIL ("font = %d, should be %d", 
                   font, NULL);
    }
    
    g_object_get (tag, "font-desc", &font_desc, NULL);
    if (font_desc == NULL) 
    {
        TEST_FAIL ("font-desc = %d, should be %d", 
                   font_desc, NULL);
    }
    
    g_object_get (tag, "family", &family, NULL);
    if (family != NULL) 
    {
        TEST_FAIL ("family = %d, should be %d", 
                   family , NULL);
    }
    
    g_object_get (tag, "style", &style, NULL);
    if (style != PANGO_STYLE_NORMAL) 
    {
        TEST_FAIL ("style = %d, should be %d", 
                   style , PANGO_STYLE_NORMAL);
    }
    
    g_object_get (tag, "variant", &variant, NULL);
    if (variant != PANGO_VARIANT_NORMAL) 
    {
        TEST_FAIL ("variant = %d, should be %d", 
                   variant , PANGO_VARIANT_NORMAL);
    }
    
    g_object_get (tag, "weight", &weight, NULL);
    if (weight != 400) 
    {
        TEST_FAIL ("weight = %d, should be %d", 
                   weight, 0);
    }
    
    g_object_get (tag, "stretch", &stretch, NULL);
    if (stretch != PANGO_STRETCH_NORMAL) 
    {
        TEST_FAIL ("stretch = %d, should be %d", 
                   stretch, PANGO_STRETCH_ULTRA_CONDENSED);
    }
    
    g_object_get (tag, "size", &size, NULL);
    if (size != 0) 
    {
        TEST_FAIL ("size = %d, should be %d", 
                   size, 0);
    }
    
    g_object_get (tag, "scale", &scale, NULL);
    if (scale != 1.0) 
    {
        TEST_FAIL ("scale = %d, should be %d", 
                   scale, 1.0);
    }
    
    g_object_get (tag, "size-points", &size_points, NULL);
    if (size_points != 0.0) 
    {
        TEST_FAIL ("size_points = %d, should be %d", 
                   size_points, 0.0);
    }
    
    g_object_get (tag, "justification", &justification, NULL);
    if (justification != GTK_JUSTIFY_LEFT) 
    {
        TEST_FAIL ("justification = %d, should be %d", 
                   justification, GTK_JUSTIFY_LEFT);
    }
    
    /* language is locale dependent
    g_object_get (tag, "language", &language, NULL);
    if (strcmp (language, "c")) 
    {
        TEST_FAIL ("language = '%s', should be '%s'", 
                   language, "c");
    }
    */
    
    g_object_get (tag, "left-margin", &left_margin, NULL);
    if (left_margin != 0) 
    {
        TEST_FAIL ("left_margin = %d, should be %d", 
                   left_margin, 0);
    }
    
    g_object_get (tag, "right-margin", &right_margin, NULL);
    if (right_margin != 0) 
    {
        TEST_FAIL ("right_margin = %d, should be %d", 
                   right_margin, 0);
    }
    
    g_object_get (tag, "indent", &indent, NULL);
    if (indent != 0) 
    {
        TEST_FAIL ("indent = %d, should be %d", 
                   indent, 0);
    }
    
    g_object_get (tag, "rise", &rise, NULL);
    if (rise != 0) 
    {
        TEST_FAIL ("rise = %d, should be %d", 
                   rise, 0);
    }
    
    g_object_get (tag, "pixels-above-lines", 
                   &pixels_above_lines, NULL);
    if (pixels_above_lines != 0) 
    {
        TEST_FAIL ("pixels-above-lines = %d, should be %d", 
                   pixels_above_lines, 0);
    }
    
    g_object_get (tag, "pixels-below-lines", 
                   &pixels_below_lines, NULL);
    if (pixels_below_lines != 0) 
    {
        TEST_FAIL ("pixels-below-lines = %d, should be %d", 
                   pixels_below_lines, 0);
    }
    
    g_object_get (tag, "pixels-inside-wrap", 
                   &pixels_inside_wrap, NULL);
    if (pixels_inside_wrap != 0) 
    {
        TEST_FAIL ("pixels-inside-wrap = %d, should be %d", 
                   pixels_inside_wrap, 0);
    }
    
    g_object_get (tag, "strikethrough", 
                   &strikethrough, NULL);
    if (strikethrough != FALSE) 
    {
        TEST_FAIL ("strikethrough = %d, should be %d", 
                   strikethrough, NULL);
    }
    
    g_object_get (tag, "underline", &underline, NULL);
    if (underline != PANGO_UNDERLINE_NONE) 
    {
        TEST_FAIL ("underline = %d, should be %d", 
                   underline, PANGO_UNDERLINE_NONE);
    }
    
    g_object_get (tag, "wrap-mode", &wrap_mode, NULL);
    if (wrap_mode != GTK_WRAP_NONE) 
    {
        TEST_FAIL ("wrap_mode = %d, should be %d", 
                   wrap_mode, GTK_WRAP_NONE);
    }
    
    g_object_get (tag, "invisible", &invisible, NULL);
    if (invisible != FALSE) 
    {
        TEST_FAIL ("invisible = %d, should be %d", 
                   invisible, FALSE);
    }
    
    g_object_get (tag, "background-set", &background_set, NULL);
    if (background_set != FALSE) 
    {
        TEST_FAIL ("background-set = %d, should be %d", 
                   background_set, FALSE);
    }
    
    g_object_get (tag, "background-full-height-set", 
                   &background_full_height_set, NULL);
    if (background_full_height_set != FALSE) 
    {
        TEST_FAIL ("background-full-height_set = %d, should be %d", 
                   background_full_height_set, FALSE);
    }
    
    g_object_get (tag, "background-stipple-set", 
                   &background_stipple_set, NULL);
    if (background_stipple_set != FALSE) 
    {
        TEST_FAIL ("background-stipple-set = %d, should be %d", 
                   background_stipple_set, FALSE);
    }
    
    g_object_get (tag, "foreground-set", &foreground_set, NULL);
    if (foreground_set != FALSE) 
    {
        TEST_FAIL ("foreground-set = %d, should be %d", 
                   foreground_set, FALSE);
    }
    
    g_object_get (tag, "foreground-stipple-set", 
                   &foreground_stipple_set, NULL);
    if (foreground_stipple_set != FALSE) 
    {
        TEST_FAIL ("foreground-stipple-set = %d, should be %d", 
                   foreground_stipple_set, FALSE);
    }
    
    g_object_get (tag, "editable-set", &editable_set, NULL);
    if (editable_set != FALSE) 
    {
        TEST_FAIL ("editable-set = %d, should be %d", 
                   editable_set, FALSE);
    }
    
    g_object_get (tag, "family-set", &family_set, NULL);
    if (family_set != FALSE) 
    {
        TEST_FAIL ("family-set = %d, should be %d", 
                   family_set, FALSE);
    }
    
    g_object_get (tag, "style-set", &style_set, NULL);
    if (style_set != FALSE) 
    {
        TEST_FAIL ("style-set = %d, should be %d", 
                   style_set, FALSE);
    }
    
    g_object_get (tag, "variant-set", &variant_set, NULL);
    if (variant_set != FALSE) 
    {
        TEST_FAIL ("variant-set = %d, should be %d", 
                   variant_set, FALSE);
    }
    
    g_object_get (tag, "weight-set", &weight_set, NULL);
    if (weight_set != FALSE) 
    {
        TEST_FAIL ("weight-set = %d, should be %d", 
                   weight_set, FALSE);
    }
    
    g_object_get (tag, "stretch-set", &stretch_set, NULL);
    if (stretch_set != FALSE) 
    {
        TEST_FAIL ("stretch-set = %d, should be %d", 
                   stretch_set, FALSE);
    }
    
    g_object_get (tag, "size-set", &size_set, NULL);
    if (size_set != FALSE) 
    {
        TEST_FAIL ("size-set = %d, should be %d", 
                   size_set, FALSE);
    }
    
    g_object_get (tag, "scale-set", &scale_set, NULL);
    if (scale_set != FALSE) 
    {
        TEST_FAIL ("scale-set = %d, should be %d", 
                   scale_set, FALSE);
    }
    
    g_object_get (tag, "justification-set", 
                   &justification_set, NULL);
    if (justification_set != FALSE) 
    {
        TEST_FAIL ("justification-set = %d, should be %d", 
                   justification_set, FALSE);
    }
    
    g_object_get (tag, "language-set", 
                   &language_set, NULL);
    if (language_set != FALSE) 
    {
        TEST_FAIL ("language-set = %d, should be %d", 
                   language_set, FALSE);
    }
    
    g_object_get (tag, "left-margin-set", 
                   &left_margin_set, NULL);
    if (left_margin_set != FALSE) 
    {
        TEST_FAIL ("left_margin-set = %d, should be %d", 
                   left_margin_set, FALSE);
    }
    
    g_object_get (tag, "indent-set",  &indent_set, NULL);
    if (indent_set != FALSE) 
    {
        TEST_FAIL ("indent-set = %d, should be %d", 
                   indent_set, FALSE);
    }
    
    g_object_get (tag, "rise-set",  &rise_set, NULL);
    if (rise_set != FALSE) 
    {
        TEST_FAIL ("rise-set = %d, should be %d", 
                   rise_set, FALSE);
    }
    
    g_object_get (tag, "pixels-above-lines-set",  
                   &pixels_above_lines_set, NULL);
    if (pixels_above_lines_set != FALSE) 
    {
        TEST_FAIL ("pixels-above-lines-set = %d, should be %d", 
                   pixels_above_lines_set, FALSE);
    }
    
    g_object_get (tag, "pixels-below-lines-set",  
                   &pixels_below_lines_set, NULL);
    if (pixels_below_lines_set != FALSE) 
    {
        TEST_FAIL ("pixels-below-lines-set = %d, should be %d", 
                   pixels_above_lines_set, FALSE);
    }
    
    g_object_get (tag, "pixels-inside-wrap-set",  
                   &pixels_inside_wrap_set, NULL);
    if (pixels_inside_wrap_set != FALSE) 
    {
        TEST_FAIL ("pixels-inside-wrap-set = %d, should be %d", 
                   pixels_inside_wrap_set, FALSE);
    }
    
    g_object_get (tag, "strikethrough-set",  
                   &strikethrough_set, NULL);
    if (strikethrough_set != FALSE) 
    {
        TEST_FAIL ("strikethrough-set = %d, should be %d", 
                   strikethrough_set, FALSE);
    }
    
    g_object_get (tag, "right-margin-set", 
                   &right_margin_set, NULL);
    if (right_margin_set != FALSE) 
    {
        TEST_FAIL ("right-margin-set = %d, should be %d", 
                   right_margin_set, FALSE);
    }
    
    g_object_get (tag, "underline-set", 
                   &underline_set, NULL);
    if (underline_set != FALSE) 
    {
        TEST_FAIL ("underline-set = %d, should be %d", 
                   underline_set, FALSE);
    }
    
    g_object_get (tag, "wrap-mode-set", 
                   &wrap_mode_set, NULL);
    if (wrap_mode_set != FALSE) 
    {
        TEST_FAIL ("wrap-mode-set = %d, should be %d", 
                   wrap_mode_set, FALSE);
    }
    
    g_object_get (tag, "tabs-set", &tabs_set, NULL);
    if (tabs_set != FALSE) 
    {
        TEST_FAIL ("tabs-set = %d, should be %d", 
                   tabs_set, FALSE);
    }
    
    g_object_get (tag, "invisible-set", &invisible_set, NULL);
    if (invisible_set != FALSE) 
    {
        TEST_FAIL ("invisible-set = %d, should be %d", 
                   invisible_set, FALSE);
    }
    
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_new
 * Params: const gchar* name
 * Returns: GtkTag*
 * Assertion: Creates a GtkTextTag.
 * Params Values: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
 * Expected: GtkTextTag*  
 */
static void test_purpose_7()
{
    #define NAME "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    
    gchararray name;
    /*  GdkColor background_gdk; */
    gboolean background_full_height;
    /*  GdkColor foreground_gdk; */
    GtkTextDirection direction;
    gboolean editable;
    gchararray font;
    PangoFontDescription *font_desc;
    gchararray family;
    PangoStyle style;
    PangoVariant variant;
    gint weight;
    PangoStretch stretch;
    gint size;
    gdouble scale;
    gdouble size_points;
    GtkJustification justification;
    gchararray language;
    gint left_margin;
    gint right_margin;
    gint indent;
    gint rise;
    gint pixels_above_lines;
    gint pixels_below_lines;
    gint pixels_inside_wrap;
    gboolean strikethrough;
    PangoUnderline underline;
    GtkWrapMode wrap_mode;
    /*PangoTabArray tabs;*/
    gboolean invisible;
    gboolean background_set;
    gboolean background_full_height_set;
    gboolean background_stipple_set;
    gboolean foreground_set;
    gboolean foreground_stipple_set;
    gboolean editable_set;
    gboolean family_set;
    gboolean style_set;
    gboolean variant_set;
    gboolean weight_set;
    gboolean stretch_set;
    gboolean size_set;
    gboolean scale_set;
    gboolean justification_set;
    gboolean language_set;
    gboolean left_margin_set;
    gboolean indent_set;
    gboolean rise_set;
    gboolean pixels_above_lines_set;
    gboolean pixels_below_lines_set;
    gboolean pixels_inside_wrap_set;
    gboolean strikethrough_set;
    gboolean right_margin_set;
    gboolean underline_set;
    gboolean wrap_mode_set;
    gboolean tabs_set;
    gboolean invisible_set;
    
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new (NAME);
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_get (tag, "name", &name, NULL);
    if (NAME)
    {
        if (strcmp (name, (char*)NAME)) 
        {
        TEST_FAIL ("name is '%s', should be '%s'", name, (gchar*)NAME);
        }
    } else {
        if (name)
        {
            TEST_FAIL ("name should be NULL but it is not", NULL);
        }
    }
    
    g_object_get (tag, "background-full-height", 
                   &background_full_height, NULL);
    if (background_full_height != FALSE) 
    {
        TEST_FAIL ("background_full_height = %d, should be %d", 
                   background_full_height, FALSE);
    }
    
    g_object_get (tag, "direction", &direction, NULL);
    if (direction != GTK_TEXT_DIR_NONE) 
    {
        TEST_FAIL ("direction = %d, should be %d", 
                   direction, GTK_TEXT_DIR_NONE);
    }
    
    g_object_get (tag, "editable", &editable, NULL);
    if (editable != TRUE) 
    {
        TEST_FAIL ("editable = %d, should be %d", 
                   editable, TRUE);
    }
    
    g_object_get (tag, "font", &font, NULL);
    if (font == NULL) 
    {
        TEST_FAIL ("font = %d, should be %d", 
                   font, NULL);
    }
    
    g_object_get (tag, "font-desc", &font_desc, NULL);
    if (font_desc == NULL) 
    {
        TEST_FAIL ("font-desc = %d, should be %d", 
                   font_desc, NULL);
    }
    
    g_object_get (tag, "family", &family, NULL);
    if (family != NULL) 
    {
        TEST_FAIL ("family = %d, should be %d", 
                   family , NULL);
    }
    
    g_object_get (tag, "style", &style, NULL);
    if (style != PANGO_STYLE_NORMAL) 
    {
        TEST_FAIL ("style = %d, should be %d", 
                   style , PANGO_STYLE_NORMAL);
    }
    
    g_object_get (tag, "variant", &variant, NULL);
    if (variant != PANGO_VARIANT_NORMAL) 
    {
        TEST_FAIL ("variant = %d, should be %d", 
                   variant , PANGO_VARIANT_NORMAL);
    }
    
    g_object_get (tag, "weight", &weight, NULL);
    if (weight != 400) 
    {
        TEST_FAIL ("weight = %d, should be %d", 
                   weight, 0);
    }
    
    g_object_get (tag, "stretch", &stretch, NULL);
    if (stretch != PANGO_STRETCH_NORMAL) 
    {
        TEST_FAIL ("stretch = %d, should be %d", 
                   stretch, PANGO_STRETCH_ULTRA_CONDENSED);
    }
    
    g_object_get (tag, "size", &size, NULL);
    if (size != 0) 
    {
        TEST_FAIL ("size = %d, should be %d", 
                   size, 0);
    }
    
    g_object_get (tag, "scale", &scale, NULL);
    if (scale != 1.0) 
    {
        TEST_FAIL ("scale = %d, should be %d", 
                   scale, 1.0);
    }
    
    g_object_get (tag, "size-points", &size_points, NULL);
    if (size_points != 0.0) 
    {
        TEST_FAIL ("size_points = %d, should be %d", 
                   size_points, 0.0);
    }
    
    g_object_get (tag, "justification", &justification, NULL);
    if (justification != GTK_JUSTIFY_LEFT) 
    {
        TEST_FAIL ("justification = %d, should be %d", 
                   justification, GTK_JUSTIFY_LEFT);
    }
    
    /* language is locale dependent
    g_object_get (tag, "language", &language, NULL);
    if (strcmp (language, "c")) 
    {
        TEST_FAIL ("language = '%s', should be '%s'", 
                   language, "c");
    }
    */
    
    g_object_get (tag, "left-margin", &left_margin, NULL);
    if (left_margin != 0) 
    {
        TEST_FAIL ("left_margin = %d, should be %d", 
                   left_margin, 0);
    }
    
    g_object_get (tag, "right-margin", &right_margin, NULL);
    if (right_margin != 0) 
    {
        TEST_FAIL ("right_margin = %d, should be %d", 
                   right_margin, 0);
    }
    
    g_object_get (tag, "indent", &indent, NULL);
    if (indent != 0) 
    {
        TEST_FAIL ("indent = %d, should be %d", 
                   indent, 0);
    }
    
    g_object_get (tag, "rise", &rise, NULL);
    if (rise != 0) 
    {
        TEST_FAIL ("rise = %d, should be %d", 
                   rise, 0);
    }
    
    g_object_get (tag, "pixels-above-lines", 
                   &pixels_above_lines, NULL);
    if (pixels_above_lines != 0) 
    {
        TEST_FAIL ("pixels-above-lines = %d, should be %d", 
                   pixels_above_lines, 0);
    }
    
    g_object_get (tag, "pixels-below-lines", 
                   &pixels_below_lines, NULL);
    if (pixels_below_lines != 0) 
    {
        TEST_FAIL ("pixels-below-lines = %d, should be %d", 
                   pixels_below_lines, 0);
    }
    
    g_object_get (tag, "pixels-inside-wrap", 
                   &pixels_inside_wrap, NULL);
    if (pixels_inside_wrap != 0) 
    {
        TEST_FAIL ("pixels-inside-wrap = %d, should be %d", 
                   pixels_inside_wrap, 0);
    }
    
    g_object_get (tag, "strikethrough", 
                   &strikethrough, NULL);
    if (strikethrough != FALSE) 
    {
        TEST_FAIL ("strikethrough = %d, should be %d", 
                   strikethrough, NULL);
    }
    
    g_object_get (tag, "underline", &underline, NULL);
    if (underline != PANGO_UNDERLINE_NONE) 
    {
        TEST_FAIL ("underline = %d, should be %d", 
                   underline, PANGO_UNDERLINE_NONE);
    }
    
    g_object_get (tag, "wrap-mode", &wrap_mode, NULL);
    if (wrap_mode != GTK_WRAP_NONE) 
    {
        TEST_FAIL ("wrap_mode = %d, should be %d", 
                   wrap_mode, GTK_WRAP_NONE);
    }
    
    g_object_get (tag, "invisible", &invisible, NULL);
    if (invisible != FALSE) 
    {
        TEST_FAIL ("invisible = %d, should be %d", 
                   invisible, FALSE);
    }
    
    g_object_get (tag, "background-set", &background_set, NULL);
    if (background_set != FALSE) 
    {
        TEST_FAIL ("background-set = %d, should be %d", 
                   background_set, FALSE);
    }
    
    g_object_get (tag, "background-full-height-set", 
                   &background_full_height_set, NULL);
    if (background_full_height_set != FALSE) 
    {
        TEST_FAIL ("background-full-height_set = %d, should be %d", 
                   background_full_height_set, FALSE);
    }
    
    g_object_get (tag, "background-stipple-set", 
                   &background_stipple_set, NULL);
    if (background_stipple_set != FALSE) 
    {
        TEST_FAIL ("background-stipple-set = %d, should be %d", 
                   background_stipple_set, FALSE);
    }
    
    g_object_get (tag, "foreground-set", &foreground_set, NULL);
    if (foreground_set != FALSE) 
    {
        TEST_FAIL ("foreground-set = %d, should be %d", 
                   foreground_set, FALSE);
    }
    
    g_object_get (tag, "foreground-stipple-set", 
                   &foreground_stipple_set, NULL);
    if (foreground_stipple_set != FALSE) 
    {
        TEST_FAIL ("foreground-stipple-set = %d, should be %d", 
                   foreground_stipple_set, FALSE);
    }
    
    g_object_get (tag, "editable-set", &editable_set, NULL);
    if (editable_set != FALSE) 
    {
        TEST_FAIL ("editable-set = %d, should be %d", 
                   editable_set, FALSE);
    }
    
    g_object_get (tag, "family-set", &family_set, NULL);
    if (family_set != FALSE) 
    {
        TEST_FAIL ("family-set = %d, should be %d", 
                   family_set, FALSE);
    }
    
    g_object_get (tag, "style-set", &style_set, NULL);
    if (style_set != FALSE) 
    {
        TEST_FAIL ("style-set = %d, should be %d", 
                   style_set, FALSE);
    }
    
    g_object_get (tag, "variant-set", &variant_set, NULL);
    if (variant_set != FALSE) 
    {
        TEST_FAIL ("variant-set = %d, should be %d", 
                   variant_set, FALSE);
    }
    
    g_object_get (tag, "weight-set", &weight_set, NULL);
    if (weight_set != FALSE) 
    {
        TEST_FAIL ("weight-set = %d, should be %d", 
                   weight_set, FALSE);
    }
    
    g_object_get (tag, "stretch-set", &stretch_set, NULL);
    if (stretch_set != FALSE) 
    {
        TEST_FAIL ("stretch-set = %d, should be %d", 
                   stretch_set, FALSE);
    }
    
    g_object_get (tag, "size-set", &size_set, NULL);
    if (size_set != FALSE) 
    {
        TEST_FAIL ("size-set = %d, should be %d", 
                   size_set, FALSE);
    }
    
    g_object_get (tag, "scale-set", &scale_set, NULL);
    if (scale_set != FALSE) 
    {
        TEST_FAIL ("scale-set = %d, should be %d", 
                   scale_set, FALSE);
    }
    
    g_object_get (tag, "justification-set", 
                   &justification_set, NULL);
    if (justification_set != FALSE) 
    {
        TEST_FAIL ("justification-set = %d, should be %d", 
                   justification_set, FALSE);
    }
    
    g_object_get (tag, "language-set", 
                   &language_set, NULL);
    if (language_set != FALSE) 
    {
        TEST_FAIL ("language-set = %d, should be %d", 
                   language_set, FALSE);
    }
    
    g_object_get (tag, "left-margin-set", 
                   &left_margin_set, NULL);
    if (left_margin_set != FALSE) 
    {
        TEST_FAIL ("left_margin-set = %d, should be %d", 
                   left_margin_set, FALSE);
    }
    
    g_object_get (tag, "indent-set",  &indent_set, NULL);
    if (indent_set != FALSE) 
    {
        TEST_FAIL ("indent-set = %d, should be %d", 
                   indent_set, FALSE);
    }
    
    g_object_get (tag, "rise-set",  &rise_set, NULL);
    if (rise_set != FALSE) 
    {
        TEST_FAIL ("rise-set = %d, should be %d", 
                   rise_set, FALSE);
    }
    
    g_object_get (tag, "pixels-above-lines-set",  
                   &pixels_above_lines_set, NULL);
    if (pixels_above_lines_set != FALSE) 
    {
        TEST_FAIL ("pixels-above-lines-set = %d, should be %d", 
                   pixels_above_lines_set, FALSE);
    }
    
    g_object_get (tag, "pixels-below-lines-set",  
                   &pixels_below_lines_set, NULL);
    if (pixels_below_lines_set != FALSE) 
    {
        TEST_FAIL ("pixels-below-lines-set = %d, should be %d", 
                   pixels_above_lines_set, FALSE);
    }
    
    g_object_get (tag, "pixels-inside-wrap-set",  
                   &pixels_inside_wrap_set, NULL);
    if (pixels_inside_wrap_set != FALSE) 
    {
        TEST_FAIL ("pixels-inside-wrap-set = %d, should be %d", 
                   pixels_inside_wrap_set, FALSE);
    }
    
    g_object_get (tag, "strikethrough-set",  
                   &strikethrough_set, NULL);
    if (strikethrough_set != FALSE) 
    {
        TEST_FAIL ("strikethrough-set = %d, should be %d", 
                   strikethrough_set, FALSE);
    }
    
    g_object_get (tag, "right-margin-set", 
                   &right_margin_set, NULL);
    if (right_margin_set != FALSE) 
    {
        TEST_FAIL ("right-margin-set = %d, should be %d", 
                   right_margin_set, FALSE);
    }
    
    g_object_get (tag, "underline-set", 
                   &underline_set, NULL);
    if (underline_set != FALSE) 
    {
        TEST_FAIL ("underline-set = %d, should be %d", 
                   underline_set, FALSE);
    }
    
    g_object_get (tag, "wrap-mode-set", 
                   &wrap_mode_set, NULL);
    if (wrap_mode_set != FALSE) 
    {
        TEST_FAIL ("wrap-mode-set = %d, should be %d", 
                   wrap_mode_set, FALSE);
    }
    
    g_object_get (tag, "tabs-set", &tabs_set, NULL);
    if (tabs_set != FALSE) 
    {
        TEST_FAIL ("tabs-set = %d, should be %d", 
                   tabs_set, FALSE);
    }
    
    g_object_get (tag, "invisible-set", &invisible_set, NULL);
    if (invisible_set != FALSE) 
    {
        TEST_FAIL ("invisible-set = %d, should be %d", 
                   invisible_set, FALSE);
    }
    
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_get_priority
 * Params: GtkTextTag *tag
 * Returns: qint
 * Assertion:Get the tag priority.
 * Params Values: a newly created GtkTextTag*
 * Expected: qint  
 */
static void test_purpose_8()
{
    #define PRIORITY 0    
    
    gint priority;
    GtkTextTag* tag;
    GtkTextTagTable* table;
    gchar buff[100];
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new ("aaaa");
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    table = gtk_text_tag_table_new ();
    gtk_text_tag_table_add (table, tag);
    
    priority = PRIORITY;
    for (i = 0; i <= priority; i++)
    {
        sprintf (buff, "Tag %i", i);
        gtk_text_tag_table_add (tag->table, gtk_text_tag_new (buff));
    } 
    
    gtk_text_tag_set_priority (GTK_TEXT_TAG (tag), priority);
    if (gtk_text_tag_get_priority (GTK_TEXT_TAG (tag)) != priority)
    {
        TEST_FAIL ("priority is '%s', should be '%s'", gtk_text_tag_get_priority (GTK_TEXT_TAG (tag)), priority);
    }
    
    #undef PRIORITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_get_priority
 * Params: GtkTextTag *tag
 * Returns: qint
 * Assertion:Get the tag priority.
 * Params Values: a newly created GtkTextTag*
 * Expected: qint  
 */
static void test_purpose_9()
{
    #define PRIORITY 10    
    
    gint priority;
    GtkTextTag* tag;
    GtkTextTagTable* table;
    gchar buff[100];
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new ("aaaa");
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    table = gtk_text_tag_table_new ();
    gtk_text_tag_table_add (table, tag);
    
    priority = PRIORITY;
    for (i = 0; i <= priority; i++)
    {
        sprintf (buff, "Tag %i", i);
        gtk_text_tag_table_add (tag->table, gtk_text_tag_new (buff));
    } 
    
    gtk_text_tag_set_priority (GTK_TEXT_TAG (tag), priority);
    if (gtk_text_tag_get_priority (GTK_TEXT_TAG (tag)) != priority)
    {
        TEST_FAIL ("priority is '%s', should be '%s'", gtk_text_tag_get_priority (GTK_TEXT_TAG (tag)), priority);
    }
    
    #undef PRIORITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_get_priority
 * Params: GtkTextTag *tag
 * Returns: qint
 * Assertion:Get the tag priority.
 * Params Values: a newly created GtkTextTag*
 * Expected: qint  
 */
static void test_purpose_10()
{
    #define PRIORITY gtk_text_tag_table_get_size (tag->table)
    
    gint priority;
    GtkTextTag* tag;
    GtkTextTagTable* table;
    gchar buff[100];
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new ("aaaa");
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    table = gtk_text_tag_table_new ();
    gtk_text_tag_table_add (table, tag);
    
    priority = PRIORITY;
    for (i = 0; i <= priority; i++)
    {
        sprintf (buff, "Tag %i", i);
        gtk_text_tag_table_add (tag->table, gtk_text_tag_new (buff));
    } 
    
    gtk_text_tag_set_priority (GTK_TEXT_TAG (tag), priority);
    if (gtk_text_tag_get_priority (GTK_TEXT_TAG (tag)) != priority)
    {
        TEST_FAIL ("priority is '%s', should be '%s'", gtk_text_tag_get_priority (GTK_TEXT_TAG (tag)), priority);
    }
    
    #undef PRIORITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_set_priority
 * Params: GtkTextTag *tag, qint priority
 * Returns: void
 * Assertion: Sets the priority of a GtkTextTag. 
 * Params Values: a newly created GtkTextTag*, 1    
 * Expected: void
 * 
 * Name: gtk_text_tag_set_priority
 * Params: GtkTextTag *tag, qint priority
 * Returns: void
 * Assertion: Higher priority tags "win" if two tags both set the same text attribute. 
 * Params Values: a newly created GtkTextTag*, 1    
 * Expected: void  
 */
static void test_purpose_11()
{
    #define PRIORITY 1    
    
    gint priority;
    GtkTextTag* tag;
    GtkTextTag* low;
    GtkTextTagTable* table;
    gboolean editable;
    gchar buff[100];
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new ("aaaa");
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    table = gtk_text_tag_table_new ();
    if (!table)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    priority = PRIORITY;
    for (i = 0; i <= priority; i++)
    {
        sprintf (buff, "Tag %i", i);
        gtk_text_tag_table_add (table, gtk_text_tag_new (buff));
    } 
    
    low =  gtk_text_tag_new ("low");
    gtk_text_tag_table_add (table, low);
    g_object_set (G_OBJECT (low), "editable", FALSE, NULL);
    gtk_text_tag_set_priority (GTK_TEXT_TAG (low), PRIORITY-1);
    
    gtk_text_tag_table_add (table, tag);
    g_object_set (G_OBJECT (tag), "editable", TRUE, NULL);
    gtk_text_tag_set_priority (GTK_TEXT_TAG (tag), PRIORITY);
    
    if (gtk_text_tag_get_priority (GTK_TEXT_TAG (tag)) != PRIORITY)
    {
        TEST_FAIL ("priority is '%s', should be '%s'", gtk_text_tag_get_priority (GTK_TEXT_TAG (tag)), PRIORITY);
    }
    
    
    #undef PRIORITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_set_priority
 * Params: GtkTextTag *tag, qint priority
 * Returns: void
 * Assertion: Sets the priority of a GtkTextTag. 
 * Params Values: a newly created GtkTextTag*, 10    
 * Expected: void
 * 
 * Name: gtk_text_tag_set_priority
 * Params: GtkTextTag *tag, qint priority
 * Returns: void
 * Assertion: Higher priority tags "win" if two tags both set the same text attribute. 
 * Params Values: a newly created GtkTextTag*, 10    
 * Expected: void  
 */
static void test_purpose_12()
{
    #define PRIORITY 10    
    
    gint priority;
    GtkTextTag* tag;
    GtkTextTag* low;
    GtkTextTagTable* table;
    gboolean editable;
    gchar buff[100];
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new ("aaaa");
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    table = gtk_text_tag_table_new ();
    if (!table)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    priority = PRIORITY;
    for (i = 0; i <= priority; i++)
    {
        sprintf (buff, "Tag %i", i);
        gtk_text_tag_table_add (table, gtk_text_tag_new (buff));
    } 
    
    low =  gtk_text_tag_new ("low");
    gtk_text_tag_table_add (table, low);
    g_object_set (G_OBJECT (low), "editable", FALSE, NULL);
    gtk_text_tag_set_priority (GTK_TEXT_TAG (low), PRIORITY-1);
    
    gtk_text_tag_table_add (table, tag);
    g_object_set (G_OBJECT (tag), "editable", TRUE, NULL);
    gtk_text_tag_set_priority (GTK_TEXT_TAG (tag), PRIORITY);
    
    if (gtk_text_tag_get_priority (GTK_TEXT_TAG (tag)) != PRIORITY)
    {
        TEST_FAIL ("priority is '%s', should be '%s'", gtk_text_tag_get_priority (GTK_TEXT_TAG (tag)), PRIORITY);
    }
    
    
    #undef PRIORITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_set_priority
 * Params: GtkTextTag *tag, qint priority
 * Returns: void
 * Assertion: Sets the priority of a GtkTextTag. 
 * Params Values: a newly created GtkTextTag*, 100
 * Expected: void
 * 
 * Name: gtk_text_tag_set_priority
 * Params: GtkTextTag *tag, qint priority
 * Returns: void
 * Assertion: Higher priority tags "win" if two tags both set the same text attribute. 
 * Params Values: a newly created GtkTextTag*, 100
 * Expected: void  
 */
static void test_purpose_13()
{
    #define PRIORITY 100
    
    gint priority;
    GtkTextTag* tag;
    GtkTextTag* low;
    GtkTextTagTable* table;
    gboolean editable;
    gchar buff[100];
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new ("aaaa");
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    table = gtk_text_tag_table_new ();
    if (!table)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    priority = PRIORITY;
    for (i = 0; i <= priority; i++)
    {
        sprintf (buff, "Tag %i", i);
        gtk_text_tag_table_add (table, gtk_text_tag_new (buff));
    } 
    
    low =  gtk_text_tag_new ("low");
    gtk_text_tag_table_add (table, low);
    g_object_set (G_OBJECT (low), "editable", FALSE, NULL);
    gtk_text_tag_set_priority (GTK_TEXT_TAG (low), PRIORITY-1);
    
    gtk_text_tag_table_add (table, tag);
    g_object_set (G_OBJECT (tag), "editable", TRUE, NULL);
    gtk_text_tag_set_priority (GTK_TEXT_TAG (tag), PRIORITY);
    
    if (gtk_text_tag_get_priority (GTK_TEXT_TAG (tag)) != PRIORITY)
    {
        TEST_FAIL ("priority is '%s', should be '%s'", gtk_text_tag_get_priority (GTK_TEXT_TAG (tag)), PRIORITY);
    }
    
    
    #undef PRIORITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_set_priority
 * Params: GtkTextTag *tag, qint priority
 * Returns: void
 * Assertion: Each tag in a table has a unique priority; setting the priority of one tag shifts the priorities of all the other tags in the table to maintain a unique priority for each tag.
 * Params Values: a newly created GtkTextTag*, 3
 * Expected: void  
 */
static void test_purpose_14()
{
    #define NUMBER 5
    #define PRIORITY 3
    
    GtkTextTag* tag;
    GtkTextTag* tag1;
    GtkTextTag* tag2;
    GtkTextTagTable* table;
    gchar buff[100];
    gint i;
    gint j;
    gint k;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new ("aaaa");
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    table = gtk_text_tag_table_new ();
    gtk_text_tag_table_add (table, tag);
    
    for (k = 0; k <= NUMBER; k++)
    {
        sprintf (buff, "Tag %d", k);
        gtk_text_tag_table_add (table, gtk_text_tag_new (buff));
    } 
    
    gtk_text_tag_set_priority (GTK_TEXT_TAG (tag), PRIORITY);
    for (i = 0; i < NUMBER + 1; i++)
    {
        sprintf (buff, "Tag %d", i);
        tag1 = gtk_text_tag_table_lookup (table, buff);
        if (!tag1)
        {
            TEST_FAIL ("can't find tag named 'Tag %d'", i);
            continue;
        }
    
        for (j = i + 1; j < NUMBER + 1; j++)
        {
            sprintf (buff, "Tag %d", j);
            tag2 = gtk_text_tag_table_lookup (table, buff);
            if (!tag2)
            {
                TEST_FAIL ("can't find tag named 'Tag %d'", j);
                continue;
            }
    
            if (gtk_text_tag_get_priority (tag1) == gtk_text_tag_get_priority (tag2))
            {
                TEST_FAIL ("tags named 'Tag %d' and 'Tag %d' both have the same priority %d", i, j, gtk_text_tag_get_priority (tag2));
            }
                           
        }
    }
            
    #undef NUMBER
    #undef PRIORITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_set_priority
 * Params: GtkTextTag *tag, qint priority
 * Returns: void
 * Assertion: Each tag in a table has a unique priority; setting the priority of one tag shifts the priorities of all the other tags in the table to maintain a unique priority for each tag.
 * Params Values: a newly created GtkTextTag*, 5
 * Expected: void  
 */
static void test_purpose_15()
{
    #define NUMBER 5
    #define PRIORITY 5
    
    GtkTextTag* tag;
    GtkTextTag* tag1;
    GtkTextTag* tag2;
    GtkTextTagTable* table;
    gchar buff[100];
    gint i;
    gint j;
    gint k;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new ("aaaa");
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    table = gtk_text_tag_table_new ();
    gtk_text_tag_table_add (table, tag);
    
    for (k = 0; k <= NUMBER; k++)
    {
        sprintf (buff, "Tag %d", k);
        gtk_text_tag_table_add (table, gtk_text_tag_new (buff));
    } 
    
    gtk_text_tag_set_priority (GTK_TEXT_TAG (tag), PRIORITY);
    for (i = 0; i < NUMBER + 1; i++)
    {
        sprintf (buff, "Tag %d", i);
        tag1 = gtk_text_tag_table_lookup (table, buff);
        if (!tag1)
        {
            TEST_FAIL ("can't find tag named 'Tag %d'", i);
            continue;
        }
    
        for (j = i + 1; j < NUMBER + 1; j++)
        {
            sprintf (buff, "Tag %d", j);
            tag2 = gtk_text_tag_table_lookup (table, buff);
            if (!tag2)
            {
                TEST_FAIL ("can't find tag named 'Tag %d'", j);
                continue;
            }
    
            if (gtk_text_tag_get_priority (tag1) == gtk_text_tag_get_priority (tag2))
            {
                TEST_FAIL ("tags named 'Tag %d' and 'Tag %d' both have the same priority %d", i, j, gtk_text_tag_get_priority (tag2));
            }
                           
        }
    }
            
    #undef NUMBER
    #undef PRIORITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_set_priority
 * Params: GtkTextTag *tag, qint priority
 * Returns: void
 * Assertion: Each tag in a table has a unique priority; setting the priority of one tag shifts the priorities of all the other tags in the table to maintain a unique priority for each tag.
 * Params Values: a newly created GtkTextTag*, 10
 * Expected: void  
 */
static void test_purpose_16()
{
    #define NUMBER 10
    #define PRIORITY 10
    
    GtkTextTag* tag;
    GtkTextTag* tag1;
    GtkTextTag* tag2;
    GtkTextTagTable* table;
    gchar buff[100];
    gint i;
    gint j;
    gint k;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new ("aaaa");
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    table = gtk_text_tag_table_new ();
    gtk_text_tag_table_add (table, tag);
    
    for (k = 0; k <= NUMBER; k++)
    {
        sprintf (buff, "Tag %d", k);
        gtk_text_tag_table_add (table, gtk_text_tag_new (buff));
    } 
    
    gtk_text_tag_set_priority (GTK_TEXT_TAG (tag), PRIORITY);
    for (i = 0; i < NUMBER + 1; i++)
    {
        sprintf (buff, "Tag %d", i);
        tag1 = gtk_text_tag_table_lookup (table, buff);
        if (!tag1)
        {
            TEST_FAIL ("can't find tag named 'Tag %d'", i);
            continue;
        }
    
        for (j = i + 1; j < NUMBER + 1; j++)
        {
            sprintf (buff, "Tag %d", j);
            tag2 = gtk_text_tag_table_lookup (table, buff);
            if (!tag2)
            {
                TEST_FAIL ("can't find tag named 'Tag %d'", j);
                continue;
            }
    
            if (gtk_text_tag_get_priority (tag1) == gtk_text_tag_get_priority (tag2))
            {
                TEST_FAIL ("tags named 'Tag %d' and 'Tag %d' both have the same priority %d", i, j, gtk_text_tag_get_priority (tag2));
            }
                           
        }
    }
            
    #undef NUMBER
    #undef PRIORITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_set_priority
 * Params: GtkTextTag *tag, qint priority
 * Returns: void
 * Assertion: Each tag in a table has a unique priority; setting the priority of one tag shifts the priorities of all the other tags in the table to maintain a unique priority for each tag.
 * Params Values: a newly created GtkTextTag*, 0
 * Expected: void  
 */
static void test_purpose_17()
{
    #define NUMBER 10
    #define PRIORITY 0
    
    GtkTextTag* tag;
    GtkTextTag* tag1;
    GtkTextTag* tag2;
    GtkTextTagTable* table;
    gchar buff[100];
    gint i;
    gint j;
    gint k;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new ("aaaa");
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    table = gtk_text_tag_table_new ();
    gtk_text_tag_table_add (table, tag);
    
    for (k = 0; k <= NUMBER; k++)
    {
        sprintf (buff, "Tag %d", k);
        gtk_text_tag_table_add (table, gtk_text_tag_new (buff));
    } 
    
    gtk_text_tag_set_priority (GTK_TEXT_TAG (tag), PRIORITY);
    for (i = 0; i < NUMBER + 1; i++)
    {
        sprintf (buff, "Tag %d", i);
        tag1 = gtk_text_tag_table_lookup (table, buff);
        if (!tag1)
        {
            TEST_FAIL ("can't find tag named 'Tag %d'", i);
            continue;
        }
    
        for (j = i + 1; j < NUMBER + 1; j++)
        {
            sprintf (buff, "Tag %d", j);
            tag2 = gtk_text_tag_table_lookup (table, buff);
            if (!tag2)
            {
                TEST_FAIL ("can't find tag named 'Tag %d'", j);
                continue;
            }
    
            if (gtk_text_tag_get_priority (tag1) == gtk_text_tag_get_priority (tag2))
            {
                TEST_FAIL ("tags named 'Tag %d' and 'Tag %d' both have the same priority %d", i, j, gtk_text_tag_get_priority (tag2));
            }
                           
        }
    }
            
    #undef NUMBER
    #undef PRIORITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_set_priority
 * Params: GtkTextTag *tag, qint priority
 * Returns: void
 * Assertion: When adding a tag to a tag table, it will be assigned the highest priority in the table by default; so normally the precedence of a set of tags is the order in which they were added to the table, or created with gtk_text_buffer_create_tag(), which adds the tag to the buffer's table automatically.'
 * Params Values: a newly created GtkTextTag*, <%1%>
 * Expected: void  
 */
static void test_purpose_18()
{
    #define NUMBER 5
    
    GtkTextTag* tag;
    GtkTextTag* tag1;
    GtkTextTagTable* table;
    gchar buff[100];
    gint i;
    gint k;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new ("aaaa");
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    table = gtk_text_tag_table_new ();
    
    for (k = 0; k <= NUMBER; k++)
    {
        sprintf (buff, "Tag %d", k);
        gtk_text_tag_table_add (table, gtk_text_tag_new (buff));
    } 
    
    gtk_text_tag_table_add (table, tag);
    
    for (i = 0; i < NUMBER + 1; i++)
    {
        sprintf (buff, "Tag %d", i);
        tag1 = gtk_text_tag_table_lookup (table, buff);
        if (!tag1)
        {
            TEST_FAIL ("can't find tag named 'Tag %d'", i);
            continue;
        }
    
        if (gtk_text_tag_get_priority (tag) <= gtk_text_tag_get_priority (tag1))
        {
            TEST_FAIL ("tag named 'Tag %d' priority which is '%d' should be less than tag priority which is '%d'", 
                       i, gtk_text_tag_get_priority (tag1), 
                       gtk_text_tag_get_priority (tag));
        }
    }
            
    #undef NUMBER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_set_priority
 * Params: GtkTextTag *tag, qint priority
 * Returns: void
 * Assertion: When adding a tag to a tag table, it will be assigned the highest priority in the table by default; so normally the precedence of a set of tags is the order in which they were added to the table, or created with gtk_text_buffer_create_tag(), which adds the tag to the buffer's table automatically.'
 * Params Values: a newly created GtkTextTag*, <%1%>
 * Expected: void  
 */
static void test_purpose_19()
{
    #define NUMBER 49
    
    GtkTextTag* tag;
    GtkTextTag* tag1;
    GtkTextTagTable* table;
    gchar buff[100];
    gint i;
    gint k;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new ("aaaa");
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    table = gtk_text_tag_table_new ();
    
    for (k = 0; k <= NUMBER; k++)
    {
        sprintf (buff, "Tag %d", k);
        gtk_text_tag_table_add (table, gtk_text_tag_new (buff));
    } 
    
    gtk_text_tag_table_add (table, tag);
    
    for (i = 0; i < NUMBER + 1; i++)
    {
        sprintf (buff, "Tag %d", i);
        tag1 = gtk_text_tag_table_lookup (table, buff);
        if (!tag1)
        {
            TEST_FAIL ("can't find tag named 'Tag %d'", i);
            continue;
        }
    
        if (gtk_text_tag_get_priority (tag) <= gtk_text_tag_get_priority (tag1))
        {
            TEST_FAIL ("tag named 'Tag %d' priority which is '%d' should be less than tag priority which is '%d'", 
                       i, gtk_text_tag_get_priority (tag1), 
                       gtk_text_tag_get_priority (tag));
        }
    }
            
    #undef NUMBER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_set_priority
 * Params: GtkTextTag *tag, qint priority
 * Returns: void
 * Assertion: When adding a tag to a tag table, it will be assigned the highest priority in the table by default; so normally the precedence of a set of tags is the order in which they were added to the table, or created with gtk_text_buffer_create_tag(), which adds the tag to the buffer's table automatically.'
 * Params Values: a newly created GtkTextTag*, <%1%>
 * Expected: void  
 */
static void test_purpose_20()
{
    #define NUMBER 1000
    
    GtkTextTag* tag;
    GtkTextTag* tag1;
    GtkTextTagTable* table;
    gchar buff[100];
    gint i;
    gint k;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new ("aaaa");
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    table = gtk_text_tag_table_new ();
    
    for (k = 0; k <= NUMBER; k++)
    {
        sprintf (buff, "Tag %d", k);
        gtk_text_tag_table_add (table, gtk_text_tag_new (buff));
    } 
    
    gtk_text_tag_table_add (table, tag);
    
    for (i = 0; i < NUMBER + 1; i++)
    {
        sprintf (buff, "Tag %d", i);
        tag1 = gtk_text_tag_table_lookup (table, buff);
        if (!tag1)
        {
            TEST_FAIL ("can't find tag named 'Tag %d'", i);
            continue;
        }
    
        if (gtk_text_tag_get_priority (tag) <= gtk_text_tag_get_priority (tag1))
        {
            TEST_FAIL ("tag named 'Tag %d' priority which is '%d' should be less than tag priority which is '%d'", 
                       i, gtk_text_tag_get_priority (tag1), 
                       gtk_text_tag_get_priority (tag));
        }
    }
            
    #undef NUMBER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_event
 * Params: GtkTextTag *tag, GObject *event_object, GdkEvent *event, const GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Emits the "event" signal on the GtkTextTag.
 * Params Values: a newly created GtkTextTag*, GObject *event_object, GdkEvent *event, const GtkTextIter *iter
 * Expected: TRUE  
 */
static void test_purpose_21()
{
    GtkTextTag* tag;
    GtkTextTagTable* table;
    GtkTextBuffer* buffer;
    GtkTextIter iter;
    gboolean res;
    GdkEvent event;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new ("aaaa");
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    table = gtk_text_tag_table_new ();
    gtk_text_tag_table_add (table, tag);
    
    buffer = gtk_text_buffer_new (table);
    gtk_text_buffer_set_text (buffer, "qwerty", strlen ("qwerty"));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 2);
    
    g_signal_connect (G_OBJECT (tag), "event",
                      GTK_SIGNAL_FUNC (event_handler), NULL);
    res = gtk_text_tag_event (tag, G_OBJECT (buffer), &event, &iter);
    if (!res)
    {
        TEST_FAIL ("event was not handled", NULL);
    }
            
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_attributes_new
 * Params: void
 * Returns: GtkTextAttributes*
 * Assertion: Creates a GtkTextAttributes, which describes a set of properties on some text.
 * Params Values: void 
 * Expected: a newly created GtkTextAttributes*  
 */
static void test_purpose_22()
{
    GtkTextAttributes* attr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    attr =  gtk_text_attributes_new ();
    
    if (!attr)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_attributes_copy
 * Params: GtkTextAttributes *src
 * Returns: GtkTextAttributes*
 * Assertion: Copies src and returns a new GtkTextAttributes
 * Params Values: GtkTextAttributes *src
 * Expected: a newly created GtkTextAttributes* with the same values as src  
 */
static void test_purpose_23()
{
    GtkTextAttributes* attr;
    GtkTextAttributes* copy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    attr =  gtk_text_attributes_new ();
    if (!attr)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    attr->refcount = 10;
    attr->appearance.rise = -49;
    attr->justification = GTK_JUSTIFY_FILL;
    attr->direction = GTK_TEXT_DIR_RTL;
    attr->font_scale = 45.6789;
    attr->left_margin = 5;
    attr->indent = 4;
    attr->right_margin = 3;
    attr->pixels_above_lines = 101;
    attr->pixels_below_lines = 102;
    attr->pixels_inside_wrap = 28;
    attr->tabs = NULL;
    attr->wrap_mode = GTK_WRAP_CHAR;
    attr->language = NULL;
    attr->invisible = 0;
    attr->bg_full_height = 1;
    attr->editable = 0;
    attr->realized = 1;
    attr->pad1 = 0;
    attr->pad2 = 1;
    attr->pad3 = 0;
    attr->pad4 = 1;
    
    copy = gtk_text_attributes_copy (attr);
    if (!copy)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (copy->appearance.rise != attr->appearance.rise)
    {
        TEST_FAIL ("copy->appearance.rise is %d, attr->appearance.rise is %d",
                   copy->appearance.rise, attr->appearance.rise);
    }
    if (copy->justification != attr->justification)
    {
        TEST_FAIL ("copy->justification is %d, attr->justification is %d", 
                   copy->justification, attr->justification);
    }
    if (copy->direction != attr->direction)
    {
        TEST_FAIL ("copy->direction is %d, attr->direction is %d",
                   copy->direction, attr->direction);
    }
    if (copy->font_scale != attr->font_scale)
    {
        TEST_FAIL ("copy->font_scale is %d, attr->font_scale is %d",
                   copy->font_scale, attr->font_scale);
    }
    if (copy->left_margin != attr->left_margin)
    {
        TEST_FAIL ("copy->font_scale is %lf, attr->font_scale is %lf",
                   copy->font_scale, attr->font_scale);
    }
    if (copy->left_margin != attr->left_margin)
    {
        TEST_FAIL ("copy->font_scale is %d, attr->font_scale is %d",
                   copy->font_scale, attr->font_scale);
    }
    if (copy->indent != attr->indent)
    {
        TEST_FAIL ("copy->indent is %d, attr->indent is %d",
                   copy->indent, attr->indent);
    }
    if (copy->right_margin != attr->right_margin)
    {
        TEST_FAIL ("copy->right_margin is %d, attr->right_margin is %d",
                   copy->right_margin, attr->right_margin);
    }
    if (copy->pixels_above_lines != attr->pixels_above_lines)
    {
        TEST_FAIL ("copy->pixels_above_lines is %d, attr->pixels_above_lines is %d",
                   copy->pixels_above_lines, attr->pixels_above_lines);
    }
    if (copy->pixels_below_lines != attr->pixels_below_lines)
    {
        TEST_FAIL ("copy->pixels_below_lines is %d, attr->pixels_below_lines is %d",
                   copy->pixels_below_lines, attr->pixels_below_lines);
    }
    if (copy->pixels_inside_wrap != attr->pixels_inside_wrap)
    {
        TEST_FAIL ("copy->pixels_inside_wrap is %d, attr->pixels_inside_wrap is %d", 
                   copy->pixels_inside_wrap, attr->pixels_inside_wrap);
    }
    if (copy->tabs != attr->tabs)
    {
        TEST_FAIL ("copy->tabs is %d, attr->tabs is %d",
                   copy->tabs, attr->tabs);
    }
    if (copy->wrap_mode != attr->wrap_mode)
    {
        TEST_FAIL ("copy->wrap_mode is %d, attr->wrap_mode is %d",
                   copy->wrap_mode, attr->wrap_mode);
    }
    if (copy->language != attr->language)
    {
        TEST_FAIL ("copy->language is %d, attr->language is %d",
                   copy->language, attr->language);
    }
    if (copy->invisible != attr->invisible)
    {
        TEST_FAIL ("copy->invisible is %d, attr->invisible is %d",
                   copy->invisible, attr->invisible);
    }
    if (copy->bg_full_height != attr->bg_full_height)
    {
        TEST_FAIL ("copy->bg_full_height is %d, attr->bg_full_height is %d",
                   copy->bg_full_height, attr->bg_full_height);
    }
    if (copy->editable != attr->editable)
    {
        TEST_FAIL ("copy->editable is %d, attr->editable is %d",
                   copy->editable, attr->editable);
    }
    if (copy->pad1 != attr->pad1)
    {
        TEST_FAIL ("copy->pad1 is %d, attr->pad1 is %d",
                   copy->pad1, attr->pad1);
    }
    if (copy->pad2 != attr->pad2)
    {
        TEST_FAIL ("copy->pad2 is %d, attr->pad2 is %d",
                   copy->pad2, attr->pad2);
    }
    if (copy->pad3 != attr->pad3)
    {
        TEST_FAIL ("copy->pad3 is %d, attr->pad3 is %d",
                   copy->pad3, attr->pad3);
    }
    if (copy->pad4 != attr->pad4)
    {
        TEST_FAIL ("copy->pad4 is %d, attr->pad4 is %d",
                   copy->pad4, attr->pad4);
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_attributes_copy_values
 * Params: GtkTextAttributes *src, GtkTextAttributes *dest
 * Returns: void
 * Assertion: Copies the values from src to dest so that dest has the same values as src.
 * Params Values: GtkTextAttributes *src, GtkTextAttributes *dest
 * Expected: void  
 */
static void test_purpose_24()
{
    GtkTextAttributes* attr;
    GtkTextAttributes* copy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    attr =  gtk_text_attributes_new ();
    if (!attr)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    copy =  gtk_text_attributes_new ();
    if (!copy)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    attr->refcount = 10;
    attr->appearance.rise = -49;
    attr->justification = GTK_JUSTIFY_FILL;
    attr->direction = GTK_TEXT_DIR_RTL;
    attr->font_scale = 45.6789;
    attr->left_margin = 5;
    attr->indent = 4;
    attr->right_margin = 3;
    attr->pixels_above_lines = 101;
    attr->pixels_below_lines = 102;
    attr->pixels_inside_wrap = 28;
    attr->tabs = NULL;
    attr->wrap_mode = GTK_WRAP_CHAR;
    attr->language = NULL;
    attr->invisible = 0;
    attr->bg_full_height = 1;
    attr->editable = 0;
    attr->realized = 1;
    attr->pad1 = 0;
    attr->pad2 = 1;
    attr->pad3 = 0;
    attr->pad4 = 1;
    
    gtk_text_attributes_copy_values (attr, copy);
    
    if (copy->appearance.rise != attr->appearance.rise)
    {
        TEST_FAIL ("copy->appearance.rise is %d, attr->appearance.rise is %d",
                   copy->appearance.rise, attr->appearance.rise);
    }
    if (copy->justification != attr->justification)
    {
        TEST_FAIL ("copy->justification is %d, attr->justification is %d", 
                   copy->justification, attr->justification);
    }
    if (copy->direction != attr->direction)
    {
        TEST_FAIL ("copy->direction is %d, attr->direction is %d",
                   copy->direction, attr->direction);
    }
    if (copy->font_scale != attr->font_scale)
    {
        TEST_FAIL ("copy->font_scale is %d, attr->font_scale is %d",
                   copy->font_scale, attr->font_scale);
    }
    if (copy->left_margin != attr->left_margin)
    {
        TEST_FAIL ("copy->font_scale is %lf, attr->font_scale is %lf",
                   copy->font_scale, attr->font_scale);
    }
    if (copy->left_margin != attr->left_margin)
    {
        TEST_FAIL ("copy->font_scale is %d, attr->font_scale is %d",
                   copy->font_scale, attr->font_scale);
    }
    if (copy->indent != attr->indent)
    {
        TEST_FAIL ("copy->indent is %d, attr->indent is %d",
                   copy->indent, attr->indent);
    }
    if (copy->right_margin != attr->right_margin)
    {
        TEST_FAIL ("copy->right_margin is %d, attr->right_margin is %d",
                   copy->right_margin, attr->right_margin);
    }
    if (copy->pixels_above_lines != attr->pixels_above_lines)
    {
        TEST_FAIL ("copy->pixels_above_lines is %d, attr->pixels_above_lines is %d",
                   copy->pixels_above_lines, attr->pixels_above_lines);
    }
    if (copy->pixels_below_lines != attr->pixels_below_lines)
    {
        TEST_FAIL ("copy->pixels_below_lines is %d, attr->pixels_below_lines is %d",
                   copy->pixels_below_lines, attr->pixels_below_lines);
    }
    if (copy->pixels_inside_wrap != attr->pixels_inside_wrap)
    {
        TEST_FAIL ("copy->pixels_inside_wrap is %d, attr->pixels_inside_wrap is %d", 
                   copy->pixels_inside_wrap, attr->pixels_inside_wrap);
    }
    if (copy->tabs != attr->tabs)
    {
        TEST_FAIL ("copy->tabs is %d, attr->tabs is %d",
                   copy->tabs, attr->tabs);
    }
    if (copy->wrap_mode != attr->wrap_mode)
    {
        TEST_FAIL ("copy->wrap_mode is %d, attr->wrap_mode is %d",
                   copy->wrap_mode, attr->wrap_mode);
    }
    if (copy->language != attr->language)
    {
        TEST_FAIL ("copy->language is %d, attr->language is %d",
                   copy->language, attr->language);
    }
    if (copy->invisible != attr->invisible)
    {
        TEST_FAIL ("copy->invisible is %d, attr->invisible is %d",
                   copy->invisible, attr->invisible);
    }
    if (copy->bg_full_height != attr->bg_full_height)
    {
        TEST_FAIL ("copy->bg_full_height is %d, attr->bg_full_height is %d",
                   copy->bg_full_height, attr->bg_full_height);
    }
    if (copy->editable != attr->editable)
    {
        TEST_FAIL ("copy->editable is %d, attr->editable is %d",
                   copy->editable, attr->editable);
    }
    if (copy->pad1 != attr->pad1)
    {
        TEST_FAIL ("copy->pad1 is %d, attr->pad1 is %d",
                   copy->pad1, attr->pad1);
    }
    if (copy->pad2 != attr->pad2)
    {
        TEST_FAIL ("copy->pad2 is %d, attr->pad2 is %d",
                   copy->pad2, attr->pad2);
    }
    if (copy->pad3 != attr->pad3)
    {
        TEST_FAIL ("copy->pad3 is %d, attr->pad3 is %d",
                   copy->pad3, attr->pad3);
    }
    if (copy->pad4 != attr->pad4)
    {
        TEST_FAIL ("copy->pad4 is %d, attr->pad4 is %d",
                   copy->pad4, attr->pad4);
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_attributes_unref
 * Params: GtkTextAttributes *values
 * Returns: void
 * Assertion: Decrements the reference count on values, freeing the structure if the reference count reaches 0.
 * Params Values: GtkTextAttributes *values
 * Expected: void  
 */
static void test_purpose_25()
{
    GtkTextAttributes* attr;
    gint i;
    
    #define INITIAL_REF_COUNT 100
    #define UNREF_TIMES 5
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    attr =  gtk_text_attributes_new ();
    if (!attr)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    attr->refcount = INITIAL_REF_COUNT;
    for (i = 0; i < UNREF_TIMES; i++)
    {
        gtk_text_attributes_unref(attr);
    }
    
    if (attr->refcount != INITIAL_REF_COUNT - UNREF_TIMES)
    {
        TEST_FAIL ("refcount = %d, should be %d", attr->refcount,
                   INITIAL_REF_COUNT - UNREF_TIMES);
    }
    
    #undef INITIAL_REF_COUNT
    #undef UNREF_TIMES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_attributes_unref
 * Params: GtkTextAttributes *values
 * Returns: void
 * Assertion: Decrements the reference count on values, freeing the structure if the reference count reaches 0.
 * Params Values: GtkTextAttributes *values
 * Expected: void  
 */
static void test_purpose_26()
{
    GtkTextAttributes* attr;
    gint i;
    
    #define INITIAL_REF_COUNT 10
    #define UNREF_TIMES 9
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    attr =  gtk_text_attributes_new ();
    if (!attr)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    attr->refcount = INITIAL_REF_COUNT;
    for (i = 0; i < UNREF_TIMES; i++)
    {
        gtk_text_attributes_unref(attr);
    }
    
    if (attr->refcount != INITIAL_REF_COUNT - UNREF_TIMES)
    {
        TEST_FAIL ("refcount = %d, should be %d", attr->refcount,
                   INITIAL_REF_COUNT - UNREF_TIMES);
    }
    
    #undef INITIAL_REF_COUNT
    #undef UNREF_TIMES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_attributes_ref
 * Params: GtkTextAttributes *values
 * Returns: void
 * Assertion: Increments the reference count on values.
 * Params Values: GtkTextAttributes *values
 * Expected: void  
 */
static void test_purpose_27()
{
    GtkTextAttributes* attr;
    gint i;
    
    #define INITIAL_REF_COUNT 100
    #define REF_TIMES 5
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    attr =  gtk_text_attributes_new ();
    if (!attr)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    attr->refcount = INITIAL_REF_COUNT;
    for (i = 0; i < REF_TIMES; i++)
    {
        gtk_text_attributes_ref(attr);
    }
    
    if (attr->refcount != INITIAL_REF_COUNT + REF_TIMES)
    {
        TEST_FAIL ("refcount = %d, should be %d", attr->refcount,
                   INITIAL_REF_COUNT + REF_TIMES);
    }
    
    #undef INITIAL_REF_COUNT
    #undef REF_TIMES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_attributes_ref
 * Params: GtkTextAttributes *values
 * Returns: void
 * Assertion: Increments the reference count on values.
 * Params Values: GtkTextAttributes *values
 * Expected: void  
 */
static void test_purpose_28()
{
    GtkTextAttributes* attr;
    gint i;
    
    #define INITIAL_REF_COUNT 10
    #define REF_TIMES 11
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    attr =  gtk_text_attributes_new ();
    if (!attr)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    attr->refcount = INITIAL_REF_COUNT;
    for (i = 0; i < REF_TIMES; i++)
    {
        gtk_text_attributes_ref(attr);
    }
    
    if (attr->refcount != INITIAL_REF_COUNT + REF_TIMES)
    {
        TEST_FAIL ("refcount = %d, should be %d", attr->refcount,
                   INITIAL_REF_COUNT + REF_TIMES);
    }
    
    #undef INITIAL_REF_COUNT
    #undef REF_TIMES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_attributes_ref
 * Params: GtkTextAttributes *values
 * Returns: void
 * Assertion: Increments the reference count on values.
 * Params Values: GtkTextAttributes *values
 * Expected: void  
 */
static void test_purpose_29()
{
    GtkTextAttributes* attr;
    gint i;
    
    #define INITIAL_REF_COUNT 0
    #define REF_TIMES 4574
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    attr =  gtk_text_attributes_new ();
    if (!attr)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    attr->refcount = INITIAL_REF_COUNT;
    for (i = 0; i < REF_TIMES; i++)
    {
        gtk_text_attributes_ref(attr);
    }
    
    if (attr->refcount != INITIAL_REF_COUNT + REF_TIMES)
    {
        TEST_FAIL ("refcount = %d, should be %d", attr->refcount,
                   INITIAL_REF_COUNT + REF_TIMES);
    }
    
    #undef INITIAL_REF_COUNT
    #undef REF_TIMES
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkTextTag ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {NULL,0}
};
