/*
 * Keyboard_Accelerator_Groups methods tests
 * Testing Keyboard_Accelerator_Groups methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

static gint global_result;

gboolean
global_set_result ()
{
    global_result++;
    return TRUE;
}  

gboolean 
global_find (GtkAccelKey *key, GClosure *closure, gpointer data)
{
    gint* count = data;
    global_result++;
    if (global_result == *count)
        return TRUE;
    return FALSE;
}


/*
 * Name:gtk_accel_group_new
 * Params: void
 * Returns: GtkAccelGroup*
 * Assertion: Creates a new GtkAccelGroup.
 * Params Values: void
 * Expected: GtkAccelGroup*  
 */
static void test_purpose_1()
{
    GtkAccelGroup* group;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_accel_group_new ();
    if (!group)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_ACCEL_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_group_connect
 * Params: GtkAccelGroup *accel_group, guint accel_key, GdkModifierType accel_mods, GtkAccelFlags accel_flags, GClosure *closure
 * Returns: void
 * Assertion: Installs an accelerator in this group.
 * Params Values: GtkAccelGroup *accel_group, guint accel_key, GdkModifierType accel_mods, GtkAccelFlags accel_flags, GClosure *closure
 * Expected: void
 * 
 * Name: gtk_accel_group_connect
 * Params: GtkAccelGroup *accel_group, guint accel_key, GdkModifierType accel_mods, GtkAccelFlags accel_flags, GClosure *closure
 * Returns: void
 * Assertion: When accel_group is being activated in response to a call to gtk_accel_groups_activate(), closure will be invoked if the accel_key and accel_mods from gtk_accel_groups_activate() match those of this connection. 
 * Params Values: GtkAccelGroup *accel_group, guint accel_key, GdkModifierType accel_mods, GtkAccelFlags accel_flags, GClosure *closure
 * Expected: void  
 */
static void test_purpose_2()
{
    #define KEY GDK_A
    #define MODS 0
    #define FLAGS GTK_ACCEL_VISIBLE
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    group = gtk_accel_group_new ();
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    closure = g_cclosure_new ((GCallback)global_set_result, NULL, NULL);
    
    gtk_accel_group_connect (group, KEY, MODS, FLAGS, closure);
    gtk_accel_groups_activate  (G_OBJECT (window), KEY, MODS);
    
    if (!global_result)
    {
        TEST_FAIL ("global_result = 0", NULL);
    }
    
    gtk_widget_destroy (window);
    
    #undef KEY
    #undef MODS
    #undef FLAGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_group_connect
 * Params: GtkAccelGroup *accel_group, guint accel_key, GdkModifierType accel_mods, GtkAccelFlags accel_flags, GClosure *closure
 * Returns: void
 * Assertion: Installs an accelerator in this group.
 * Params Values: GtkAccelGroup *accel_group, guint accel_key, GdkModifierType accel_mods, GtkAccelFlags accel_flags, GClosure *closure
 * Expected: void
 * 
 * Name: gtk_accel_group_connect
 * Params: GtkAccelGroup *accel_group, guint accel_key, GdkModifierType accel_mods, GtkAccelFlags accel_flags, GClosure *closure
 * Returns: void
 * Assertion: When accel_group is being activated in response to a call to gtk_accel_groups_activate(), closure will be invoked if the accel_key and accel_mods from gtk_accel_groups_activate() match those of this connection. 
 * Params Values: GtkAccelGroup *accel_group, guint accel_key, GdkModifierType accel_mods, GtkAccelFlags accel_flags, GClosure *closure
 * Expected: void  
 */
static void test_purpose_3()
{
    #define KEY GDK_B
    #define MODS 0
    #define FLAGS GTK_ACCEL_VISIBLE
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    group = gtk_accel_group_new ();
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    closure = g_cclosure_new ((GCallback)global_set_result, NULL, NULL);
    
    gtk_accel_group_connect (group, KEY, MODS, FLAGS, closure);
    gtk_accel_groups_activate  (G_OBJECT (window), KEY, MODS);
    
    if (!global_result)
    {
        TEST_FAIL ("global_result = 0", NULL);
    }
    
    gtk_widget_destroy (window);
    
    #undef KEY
    #undef MODS
    #undef FLAGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_group_connect_by_path
 * Params: GtkAccelGroup *accel_group, const gchar *accel_path, GClosure *closure
 * Returns: void
 * Assertion: Installs an accelerator in this group, using an accelerator path to look up the appropriate key and modifiers (see gtk_accel_map_add_entry()).
 * Params Values: GtkAccelGroup *accel_group, const gchar *accel_path, GClosure *closure
 * Expected: void
 * 
 * Name: gtk_accel_group_connect_by_path
 * Params: GtkAccelGroup *accel_group, const gchar *accel_path, GClosure *closure
 * Returns: void
 * Assertion: When accel_group is being activated in response to a call to gtk_accel_groups_activate(), closure will be invoked if the accel_key and accel_mods from gtk_accel_groups_activate() match the key and modifiers for the path.
 * Params Values: GtkAccelGroup *accel_group, const gchar *accel_path, GClosure *closure
 * Expected: void  
 */
static void test_purpose_4()
{
    #define KEY GDK_B
    #define MODS 0
    #define FLAGS GTK_ACCEL_VISIBLE
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    gchar path[] = "<test>/action";
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    group = gtk_accel_group_new ();
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    closure = g_cclosure_new ((GCallback)global_set_result, NULL, NULL);
    
    gtk_accel_map_add_entry (path, KEY, MODS);
    gtk_accel_group_connect_by_path (group, path, closure);
    gtk_accel_groups_activate  (G_OBJECT (window), KEY, MODS);
    
    
    if (!global_result)
    {
        TEST_FAIL ("'connect_by_path' global_result = 0, KEY = %i", KEY);
    }
    
    gtk_widget_destroy (window);
    
    #undef KEY
    #undef MODS
    #undef FLAGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_group_disconnect
 * Params: GtkAccelGroup *accel_group, GClosure *closure
 * Returns: void
 * Assertion: Removes an accelerator previously installed through gtk_accel_group_connect().
 * Params Values: GtkAccelGroup *accel_group, GClosure *closure
 * Expected: void  
 */
static void test_purpose_5()
{
    #define KEY GDK_A
    #define MODS 0
    #define FLAGS GTK_ACCEL_VISIBLE
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    group = gtk_accel_group_new ();
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    closure = g_cclosure_new ((GCallback)global_set_result, NULL, NULL);
    
    gtk_accel_group_connect (group, KEY, MODS, FLAGS, closure);
    gtk_accel_group_disconnect (group, closure);
    gtk_accel_groups_activate  (G_OBJECT (window), KEY, MODS);
    
    if (global_result)
    {
        TEST_FAIL ("global_result = %i", global_result);
    }
    
    gtk_widget_destroy (window);
    
    #undef KEY
    #undef MODS
    #undef FLAGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_group_disconnect
 * Params: GtkAccelGroup *accel_group, GClosure *closure
 * Returns: void
 * Assertion: Removes an accelerator previously installed through gtk_accel_group_connect().
 * Params Values: GtkAccelGroup *accel_group, GClosure *closure
 * Expected: void  
 */
static void test_purpose_6()
{
    #define KEY GDK_B
    #define MODS 0
    #define FLAGS GTK_ACCEL_VISIBLE
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    group = gtk_accel_group_new ();
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    closure = g_cclosure_new ((GCallback)global_set_result, NULL, NULL);
    
    gtk_accel_group_connect (group, KEY, MODS, FLAGS, closure);
    gtk_accel_group_disconnect (group, closure);
    gtk_accel_groups_activate  (G_OBJECT (window), KEY, MODS);
    
    if (global_result)
    {
        TEST_FAIL ("global_result = %i", global_result);
    }
    
    gtk_widget_destroy (window);
    
    #undef KEY
    #undef MODS
    #undef FLAGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_group_disconnect_key
 * Params: GtkAccelGroup *accel_group, guint accel_key, GdkModifierType accel_mods
 * Returns: void
 * Assertion: Removes an accelerator previously installed through gtk_accel_group_connect().
 * Params Values: GtkAccelGroup *accel_group, guint accel_key, GdkModifierType accel_mods
 * Expected: void  
 */
static void test_purpose_7()
{
    #define KEY GDK_A
    #define MODS 0
    #define FLAGS GTK_ACCEL_VISIBLE
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    group = gtk_accel_group_new ();
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    closure = g_cclosure_new ((GCallback)global_set_result, NULL, NULL);
    
    gtk_accel_group_connect (group, KEY, MODS, FLAGS, closure);
    gtk_accel_group_disconnect_key (group, KEY, MODS);
    gtk_accel_groups_activate  (G_OBJECT (window), KEY, MODS);
    
    if (global_result)
    {
        TEST_FAIL ("global_result = %i", global_result);
    }
    
    gtk_widget_destroy (window);
    
    #undef KEY
    #undef MODS
    #undef FLAGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_group_disconnect_key
 * Params: GtkAccelGroup *accel_group, guint accel_key, GdkModifierType accel_mods
 * Returns: void
 * Assertion: Removes an accelerator previously installed through gtk_accel_group_connect().
 * Params Values: GtkAccelGroup *accel_group, guint accel_key, GdkModifierType accel_mods
 * Expected: void  
 */
static void test_purpose_8()
{
    #define KEY GDK_B
    #define MODS 0
    #define FLAGS GTK_ACCEL_VISIBLE
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    group = gtk_accel_group_new ();
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    closure = g_cclosure_new ((GCallback)global_set_result, NULL, NULL);
    
    gtk_accel_group_connect (group, KEY, MODS, FLAGS, closure);
    gtk_accel_group_disconnect_key (group, KEY, MODS);
    gtk_accel_groups_activate  (G_OBJECT (window), KEY, MODS);
    
    if (global_result)
    {
        TEST_FAIL ("global_result = %i", global_result);
    }
    
    gtk_widget_destroy (window);
    
    #undef KEY
    #undef MODS
    #undef FLAGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_groups_activate
 * Params: GObject *acceleratable, guint accel_key, GdkModifierType accel_mods
 * Returns: void
 * Assertion: Finds the first accelerator in any GtkAccelGroup attached to object that matches accel_key and accel_mods, and activates that accelerator. 
 * Params Values: GObject *acceleratable, guint accel_key, GdkModifierType accel_mods
 * Expected: void
 * 
 * Name: gtk_accel_groups_activate
 * Params: GObject *acceleratable, guint accel_key, GdkModifierType accel_mods
 * Returns: gboolean
 * Assertion: If an accelerator was activated and handled this keypress, TRUE is returned.
 * Params Values: GObject *acceleratable, guint accel_key, GdkModifierType accel_mods
 * Expected: TRUE  
 */
static void test_purpose_9()
{
    #define KEY GDK_A
    #define MODS GDK_SHIFT_MASK 
    #define FLAGS GTK_ACCEL_VISIBLE
    #define HANDLED TRUE
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    group = gtk_accel_group_new ();
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    if (HANDLED)
    {
        closure = g_cclosure_new ((GCallback)global_set_result, NULL, NULL);
        gtk_accel_group_connect (group, KEY, MODS, FLAGS, closure);
    }
    
    result = gtk_accel_groups_activate (G_OBJECT (window), KEY, MODS);
    
    if ((global_result != result) || (result != HANDLED))
    {
        TEST_FAIL ("global_result = %i, result = %i, HANDLED = %i", global_result, result, HANDLED);
    }
    
    gtk_widget_destroy (window);
    
    #undef KEY
    #undef MODS
    #undef FLAGS
    #undef HANDLED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_groups_activate
 * Params: GObject *acceleratable, guint accel_key, GdkModifierType accel_mods
 * Returns: void
 * Assertion: Finds the first accelerator in any GtkAccelGroup attached to object that matches accel_key and accel_mods, and activates that accelerator. 
 * Params Values: GObject *acceleratable, guint accel_key, GdkModifierType accel_mods
 * Expected: void
 * 
 * Name: gtk_accel_groups_activate
 * Params: GObject *acceleratable, guint accel_key, GdkModifierType accel_mods
 * Returns: gboolean
 * Assertion: If an accelerator was activated and handled this keypress, TRUE is returned.
 * Params Values: GObject *acceleratable, guint accel_key, GdkModifierType accel_mods
 * Expected: FALSE  
 */
static void test_purpose_10()
{
    #define KEY GDK_B
    #define MODS GDK_SHIFT_MASK 
    #define FLAGS GTK_ACCEL_VISIBLE
    #define HANDLED FALSE
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    group = gtk_accel_group_new ();
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    if (HANDLED)
    {
        closure = g_cclosure_new ((GCallback)global_set_result, NULL, NULL);
        gtk_accel_group_connect (group, KEY, MODS, FLAGS, closure);
    }
    
    result = gtk_accel_groups_activate (G_OBJECT (window), KEY, MODS);
    
    if ((global_result != result) || (result != HANDLED))
    {
        TEST_FAIL ("global_result = %i, result = %i, HANDLED = %i", global_result, result, HANDLED);
    }
    
    gtk_widget_destroy (window);
    
    #undef KEY
    #undef MODS
    #undef FLAGS
    #undef HANDLED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_groups_activate
 * Params: GObject *acceleratable, guint accel_key, GdkModifierType accel_mods
 * Returns: void
 * Assertion: Finds the first accelerator in any GtkAccelGroup attached to object that matches accel_key and accel_mods, and activates that accelerator. 
 * Params Values: GObject *acceleratable, guint accel_key, GdkModifierType accel_mods
 * Expected: void
 * 
 * Name: gtk_accel_groups_activate
 * Params: GObject *acceleratable, guint accel_key, GdkModifierType accel_mods
 * Returns: gboolean
 * Assertion: If an accelerator was activated and handled this keypress, TRUE is returned.
 * Params Values: GObject *acceleratable, guint accel_key, GdkModifierType accel_mods
 * Expected: FALSE  
 */
static void test_purpose_11()
{
    #define KEY GDK_y
    #define MODS GDK_CONTROL_MASK 
    #define FLAGS GTK_ACCEL_VISIBLE
    #define HANDLED FALSE
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    group = gtk_accel_group_new ();
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    if (HANDLED)
    {
        closure = g_cclosure_new ((GCallback)global_set_result, NULL, NULL);
        gtk_accel_group_connect (group, KEY, MODS, FLAGS, closure);
    }
    
    result = gtk_accel_groups_activate (G_OBJECT (window), KEY, MODS);
    
    if ((global_result != result) || (result != HANDLED))
    {
        TEST_FAIL ("global_result = %i, result = %i, HANDLED = %i", global_result, result, HANDLED);
    }
    
    gtk_widget_destroy (window);
    
    #undef KEY
    #undef MODS
    #undef FLAGS
    #undef HANDLED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_group_lock
 * Params: GtkAccelGroup *accel_group
 * Returns: void
 * Assertion: Locks the given accelerator group.
 * Params Values: GtkAccelGroup *accel_group
 * Expected: void
 * 
 * Name: gtk_accel_group_lock
 * Params: GtkAccelGroup *accel_group
 * Returns: void
 * Assertion: Locking an acelerator group prevents the accelerators contained within it to be changed during runtime.
 * Params Values: GtkAccelGroup *accel_group
 * Expected: void
 * 
 * Name: gtk_accel_group_lock
 * Params: GtkAccelGroup *accel_group
 * Returns: void
 * Assertion: If called more than once, accel_group remains locked until gtk_accel_group_unlock() has been called an equivalent number of times
 * Params Values: GtkAccelGroup *accel_group
 * Expected: void  
 */
static void test_purpose_12()
{
    #define KEY GDK_g
    #define MODS 0
    #define FLAGS GTK_ACCEL_VISIBLE
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    gchar path[] = "<test>/action";
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    group = gtk_accel_group_new ();
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    closure = g_closure_new_simple (sizeof (GClosure), NULL);
    gtk_accel_group_connect (group, KEY, MODS, FLAGS, closure);
    gtk_accel_map_change_entry (path, KEY, MODS, TRUE);
    
    
    gtk_accel_group_lock (group);
    gtk_accel_group_lock (group);
    
    gtk_accel_group_unlock (group);
    
    if (gtk_accel_map_change_entry (path, KEY, MODS, FALSE))
    {
        TEST_FAIL ("'gtk_accel_map_change_entry' returns TRUE for locked group", NULL);
    }
    gtk_accel_group_unlock (group);
    
    if (gtk_accel_map_change_entry (path, KEY, MODS, FALSE))
    {
        TEST_FAIL ("'gtk_accel_map_change_entry' returns TRUE for same key", NULL);
    }
    
    if (!gtk_accel_map_change_entry (path, KEY+1, 0, FALSE))
    {
        TEST_FAIL ("'gtk_accel_map_change_entry' returns FALSE for unlocked group", NULL);
    }
    
    gtk_widget_destroy (window);
    
    #undef KEY
    #undef MODS
    #undef FLAGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_group_lock
 * Params: GtkAccelGroup *accel_group
 * Returns: void
 * Assertion: Locks the given accelerator group.
 * Params Values: GtkAccelGroup *accel_group
 * Expected: void
 * 
 * Name: gtk_accel_group_lock
 * Params: GtkAccelGroup *accel_group
 * Returns: void
 * Assertion: Locking an acelerator group prevents the accelerators contained within it to be changed during runtime.
 * Params Values: GtkAccelGroup *accel_group
 * Expected: void
 * 
 * Name: gtk_accel_group_lock
 * Params: GtkAccelGroup *accel_group
 * Returns: void
 * Assertion: If called more than once, accel_group remains locked until gtk_accel_group_unlock() has been called an equivalent number of times
 * Params Values: GtkAccelGroup *accel_group
 * Expected: void  
 */
static void test_purpose_13()
{
    #define KEY GDK_1
    #define MODS 0
    #define FLAGS GTK_ACCEL_VISIBLE
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    gchar path[] = "<test>/action";
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    group = gtk_accel_group_new ();
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    closure = g_closure_new_simple (sizeof (GClosure), NULL);
    gtk_accel_group_connect (group, KEY, MODS, FLAGS, closure);
    gtk_accel_map_change_entry (path, KEY, MODS, TRUE);
    
    
    gtk_accel_group_lock (group);
    gtk_accel_group_lock (group);
    
    gtk_accel_group_unlock (group);
    
    if (gtk_accel_map_change_entry (path, KEY, MODS, FALSE))
    {
        TEST_FAIL ("'gtk_accel_map_change_entry' returns TRUE for locked group", NULL);
    }
    gtk_accel_group_unlock (group);
    
    if (gtk_accel_map_change_entry (path, KEY, MODS, FALSE))
    {
        TEST_FAIL ("'gtk_accel_map_change_entry' returns TRUE for same key", NULL);
    }
    
    if (!gtk_accel_map_change_entry (path, KEY+1, 0, FALSE))
    {
        TEST_FAIL ("'gtk_accel_map_change_entry' returns FALSE for unlocked group", NULL);
    }
    
    gtk_widget_destroy (window);
    
    #undef KEY
    #undef MODS
    #undef FLAGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_group_lock
 * Params: GtkAccelGroup *accel_group
 * Returns: void
 * Assertion: Locks the given accelerator group.
 * Params Values: GtkAccelGroup *accel_group
 * Expected: void
 * 
 * Name: gtk_accel_group_lock
 * Params: GtkAccelGroup *accel_group
 * Returns: void
 * Assertion: Locking an acelerator group prevents the accelerators contained within it to be changed during runtime.
 * Params Values: GtkAccelGroup *accel_group
 * Expected: void
 * 
 * Name: gtk_accel_group_lock
 * Params: GtkAccelGroup *accel_group
 * Returns: void
 * Assertion: If called more than once, accel_group remains locked until gtk_accel_group_unlock() has been called an equivalent number of times
 * Params Values: GtkAccelGroup *accel_group
 * Expected: void  
 */
static void test_purpose_14()
{
    #define KEY GDK_5
    #define MODS 0
    #define FLAGS GTK_ACCEL_VISIBLE
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    gchar path[] = "<test>/action";
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    group = gtk_accel_group_new ();
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    closure = g_closure_new_simple (sizeof (GClosure), NULL);
    gtk_accel_group_connect (group, KEY, MODS, FLAGS, closure);
    gtk_accel_map_change_entry (path, KEY, MODS, TRUE);
    
    
    gtk_accel_group_lock (group);
    gtk_accel_group_lock (group);
    
    gtk_accel_group_unlock (group);
    
    if (gtk_accel_map_change_entry (path, KEY, MODS, FALSE))
    {
        TEST_FAIL ("'gtk_accel_map_change_entry' returns TRUE for locked group", NULL);
    }
    gtk_accel_group_unlock (group);
    
    if (gtk_accel_map_change_entry (path, KEY, MODS, FALSE))
    {
        TEST_FAIL ("'gtk_accel_map_change_entry' returns TRUE for same key", NULL);
    }
    
    if (!gtk_accel_map_change_entry (path, KEY+1, 0, FALSE))
    {
        TEST_FAIL ("'gtk_accel_map_change_entry' returns FALSE for unlocked group", NULL);
    }
    
    gtk_widget_destroy (window);
    
    #undef KEY
    #undef MODS
    #undef FLAGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_group_lock
 * Params: GtkAccelGroup *accel_group
 * Returns: void
 * Assertion: Locks the given accelerator group.
 * Params Values: GtkAccelGroup *accel_group
 * Expected: void
 * 
 * Name: gtk_accel_group_lock
 * Params: GtkAccelGroup *accel_group
 * Returns: void
 * Assertion: Locking an acelerator group prevents the accelerators contained within it to be changed during runtime.
 * Params Values: GtkAccelGroup *accel_group
 * Expected: void
 * 
 * Name: gtk_accel_group_lock
 * Params: GtkAccelGroup *accel_group
 * Returns: void
 * Assertion: If called more than once, accel_group remains locked until gtk_accel_group_unlock() has been called an equivalent number of times
 * Params Values: GtkAccelGroup *accel_group
 * Expected: void  
 */
static void test_purpose_15()
{
    #define KEY GDK_F1
    #define MODS 0
    #define FLAGS GTK_ACCEL_VISIBLE
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    gchar path[] = "<test>/action";
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    group = gtk_accel_group_new ();
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    closure = g_closure_new_simple (sizeof (GClosure), NULL);
    gtk_accel_group_connect (group, KEY, MODS, FLAGS, closure);
    gtk_accel_map_change_entry (path, KEY, MODS, TRUE);
    
    
    gtk_accel_group_lock (group);
    gtk_accel_group_lock (group);
    
    gtk_accel_group_unlock (group);
    
    if (gtk_accel_map_change_entry (path, KEY, MODS, FALSE))
    {
        TEST_FAIL ("'gtk_accel_map_change_entry' returns TRUE for locked group", NULL);
    }
    gtk_accel_group_unlock (group);
    
    if (gtk_accel_map_change_entry (path, KEY, MODS, FALSE))
    {
        TEST_FAIL ("'gtk_accel_map_change_entry' returns TRUE for same key", NULL);
    }
    
    if (!gtk_accel_map_change_entry (path, KEY+1, 0, FALSE))
    {
        TEST_FAIL ("'gtk_accel_map_change_entry' returns FALSE for unlocked group", NULL);
    }
    
    gtk_widget_destroy (window);
    
    #undef KEY
    #undef MODS
    #undef FLAGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_group_lock
 * Params: GtkAccelGroup *accel_group
 * Returns: void
 * Assertion: Locks the given accelerator group.
 * Params Values: GtkAccelGroup *accel_group
 * Expected: void
 * 
 * Name: gtk_accel_group_lock
 * Params: GtkAccelGroup *accel_group
 * Returns: void
 * Assertion: Locking an acelerator group prevents the accelerators contained within it to be changed during runtime.
 * Params Values: GtkAccelGroup *accel_group
 * Expected: void
 * 
 * Name: gtk_accel_group_lock
 * Params: GtkAccelGroup *accel_group
 * Returns: void
 * Assertion: If called more than once, accel_group remains locked until gtk_accel_group_unlock() has been called an equivalent number of times
 * Params Values: GtkAccelGroup *accel_group
 * Expected: void  
 */
static void test_purpose_16()
{
    #define KEY GDK_A
    #define MODS 0
    #define FLAGS GTK_ACCEL_VISIBLE
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    gchar path[] = "<test>/action";
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    group = gtk_accel_group_new ();
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    closure = g_closure_new_simple (sizeof (GClosure), NULL);
    gtk_accel_group_connect (group, KEY, MODS, FLAGS, closure);
    gtk_accel_map_change_entry (path, KEY, MODS, TRUE);
    
    
    gtk_accel_group_lock (group);
    gtk_accel_group_lock (group);
    
    gtk_accel_group_unlock (group);
    
    if (gtk_accel_map_change_entry (path, KEY, MODS, FALSE))
    {
        TEST_FAIL ("'gtk_accel_map_change_entry' returns TRUE for locked group", NULL);
    }
    gtk_accel_group_unlock (group);
    
    if (gtk_accel_map_change_entry (path, KEY, MODS, FALSE))
    {
        TEST_FAIL ("'gtk_accel_map_change_entry' returns TRUE for same key", NULL);
    }
    
    if (!gtk_accel_map_change_entry (path, KEY+1, 0, FALSE))
    {
        TEST_FAIL ("'gtk_accel_map_change_entry' returns FALSE for unlocked group", NULL);
    }
    
    gtk_widget_destroy (window);
    
    #undef KEY
    #undef MODS
    #undef FLAGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_group_lock
 * Params: GtkAccelGroup *accel_group
 * Returns: void
 * Assertion: Locks the given accelerator group.
 * Params Values: GtkAccelGroup *accel_group
 * Expected: void
 * 
 * Name: gtk_accel_group_lock
 * Params: GtkAccelGroup *accel_group
 * Returns: void
 * Assertion: Locking an acelerator group prevents the accelerators contained within it to be changed during runtime.
 * Params Values: GtkAccelGroup *accel_group
 * Expected: void
 * 
 * Name: gtk_accel_group_lock
 * Params: GtkAccelGroup *accel_group
 * Returns: void
 * Assertion: If called more than once, accel_group remains locked until gtk_accel_group_unlock() has been called an equivalent number of times
 * Params Values: GtkAccelGroup *accel_group
 * Expected: void  
 */
static void test_purpose_17()
{
    #define KEY GDK_z
    #define MODS 0
    #define FLAGS GTK_ACCEL_VISIBLE
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    gchar path[] = "<test>/action";
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    group = gtk_accel_group_new ();
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    closure = g_closure_new_simple (sizeof (GClosure), NULL);
    gtk_accel_group_connect (group, KEY, MODS, FLAGS, closure);
    gtk_accel_map_change_entry (path, KEY, MODS, TRUE);
    
    
    gtk_accel_group_lock (group);
    gtk_accel_group_lock (group);
    
    gtk_accel_group_unlock (group);
    
    if (gtk_accel_map_change_entry (path, KEY, MODS, FALSE))
    {
        TEST_FAIL ("'gtk_accel_map_change_entry' returns TRUE for locked group", NULL);
    }
    gtk_accel_group_unlock (group);
    
    if (gtk_accel_map_change_entry (path, KEY, MODS, FALSE))
    {
        TEST_FAIL ("'gtk_accel_map_change_entry' returns TRUE for same key", NULL);
    }
    
    if (!gtk_accel_map_change_entry (path, KEY+1, 0, FALSE))
    {
        TEST_FAIL ("'gtk_accel_map_change_entry' returns FALSE for unlocked group", NULL);
    }
    
    gtk_widget_destroy (window);
    
    #undef KEY
    #undef MODS
    #undef FLAGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_group_unlock
 * Params: GtkAccelGroup *accel_group
 * Returns: void
 * Assertion: Undoes the last call to gtk_accel_group_lock() on this accel_group.
 * Params Values: GtkAccelGroup *accel_group
 * Expected: void  
 */
static void test_purpose_18()
{
    #define KEY GDK_a
    #define MODS 0
    #define FLAGS GTK_ACCEL_VISIBLE
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    gchar path[] = "<test>/action";
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    group = gtk_accel_group_new ();
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    closure = g_cclosure_new ((GCallback)global_set_result, NULL, NULL);
    gtk_accel_group_connect (group, KEY, MODS, FLAGS, closure);
    //gtk_accel_map_add_notifer  (path, NULL, global_set_result, group);
    
    gtk_accel_group_lock (group);
    gtk_accel_group_unlock (group);
    
    if (!gtk_accel_map_change_entry (path, KEY, MODS, TRUE))
    {
        TEST_FAIL ("'gtk_accel_map_change_entry' returns FALSE for unlocked group", NULL);
    }
    
    gtk_widget_destroy (window);
    
    #undef KEY
    #undef MODS
    #undef FLAGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_group_unlock
 * Params: GtkAccelGroup *accel_group
 * Returns: void
 * Assertion: Undoes the last call to gtk_accel_group_lock() on this accel_group.
 * Params Values: GtkAccelGroup *accel_group
 * Expected: void  
 */
static void test_purpose_19()
{
    #define KEY GDK_b
    #define MODS 0
    #define FLAGS GTK_ACCEL_VISIBLE
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    gchar path[] = "<test>/action";
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    group = gtk_accel_group_new ();
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    closure = g_cclosure_new ((GCallback)global_set_result, NULL, NULL);
    gtk_accel_group_connect (group, KEY, MODS, FLAGS, closure);
    //gtk_accel_map_add_notifer  (path, NULL, global_set_result, group);
    
    gtk_accel_group_lock (group);
    gtk_accel_group_unlock (group);
    
    if (!gtk_accel_map_change_entry (path, KEY, MODS, TRUE))
    {
        TEST_FAIL ("'gtk_accel_map_change_entry' returns FALSE for unlocked group", NULL);
    }
    
    gtk_widget_destroy (window);
    
    #undef KEY
    #undef MODS
    #undef FLAGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accelerator_valid
 * Params: guint keyval, GdkModifierType modifiers
 * Returns: gboolean
 * Assertion: Determines whether a given keyval and modifier mask constitute a valid keyboard accelerator. 
 * Params Values:  GDK_a , GDK_CONTROL_MASK 
 * Expected: TRUE  
 */
static void test_purpose_20()
{
    #define KEY GDK_a 
    #define MODS GDK_CONTROL_MASK 
    #define RESULT TRUE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (RESULT != gtk_accelerator_valid (KEY, MODS))
    {
        TEST_FAIL ("Test fails", NULL);
    }
    
    #undef KEY
    #undef MODS
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accelerator_valid
 * Params: guint keyval, GdkModifierType modifiers
 * Returns: gboolean
 * Assertion: Determines whether a given keyval and modifier mask constitute a valid keyboard accelerator. 
 * Params Values:  GDK_1 , GDK_CONTROL_MASK 
 * Expected: TRUE  
 */
static void test_purpose_21()
{
    #define KEY GDK_1 
    #define MODS GDK_CONTROL_MASK 
    #define RESULT TRUE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (RESULT != gtk_accelerator_valid (KEY, MODS))
    {
        TEST_FAIL ("Test fails", NULL);
    }
    
    #undef KEY
    #undef MODS
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accelerator_valid
 * Params: guint keyval, GdkModifierType modifiers
 * Returns: gboolean
 * Assertion: Determines whether a given keyval and modifier mask constitute a valid keyboard accelerator. 
 * Params Values:  GDK_F11 , GDK_SHIFT_MASK | GDK_CONTROL_MASK
 * Expected: TRUE  
 */
static void test_purpose_22()
{
    #define KEY GDK_F11 
    #define MODS GDK_SHIFT_MASK | GDK_CONTROL_MASK
    #define RESULT TRUE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (RESULT != gtk_accelerator_valid (KEY, MODS))
    {
        TEST_FAIL ("Test fails", NULL);
    }
    
    #undef KEY
    #undef MODS
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accelerator_valid
 * Params: guint keyval, GdkModifierType modifiers
 * Returns: gboolean
 * Assertion: Determines whether a given keyval and modifier mask constitute a valid keyboard accelerator. 
 * Params Values:  GDK_a , GDK_SHIFT_MASK | GDK_CONTROL_MASK
 * Expected: TRUE  
 */
static void test_purpose_23()
{
    #define KEY GDK_a 
    #define MODS GDK_SHIFT_MASK | GDK_CONTROL_MASK
    #define RESULT TRUE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (RESULT != gtk_accelerator_valid (KEY, MODS))
    {
        TEST_FAIL ("Test fails", NULL);
    }
    
    #undef KEY
    #undef MODS
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accelerator_valid
 * Params: guint keyval, GdkModifierType modifiers
 * Returns: gboolean
 * Assertion: Determines whether a given keyval and modifier mask constitute a valid keyboard accelerator. 
 * Params Values:  GDK_Scroll_Lock, GDK_LOCK_MASK 
 * Expected: FALSE  
 */
static void test_purpose_24()
{
    #define KEY GDK_Scroll_Lock
    #define MODS GDK_LOCK_MASK 
    #define RESULT FALSE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (RESULT != gtk_accelerator_valid (KEY, MODS))
    {
        TEST_FAIL ("Test fails", NULL);
    }
    
    #undef KEY
    #undef MODS
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accelerator_valid
 * Params: guint keyval, GdkModifierType modifiers
 * Returns: gboolean
 * Assertion: Determines whether a given keyval and modifier mask constitute a valid keyboard accelerator. 
 * Params Values:  GDK_Delete, GDK_SHIFT_MASK 
 * Expected: TRUE  
 */
static void test_purpose_25()
{
    #define KEY GDK_Delete
    #define MODS GDK_SHIFT_MASK 
    #define RESULT TRUE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (RESULT != gtk_accelerator_valid (KEY, MODS))
    {
        TEST_FAIL ("Test fails", NULL);
    }
    
    #undef KEY
    #undef MODS
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accelerator_valid
 * Params: guint keyval, GdkModifierType modifiers
 * Returns: gboolean
 * Assertion: Determines whether a given keyval and modifier mask constitute a valid keyboard accelerator. 
 * Params Values:  GDK_Return, GDK_SHIFT_MASK 
 * Expected: TRUE  
 */
static void test_purpose_26()
{
    #define KEY GDK_Return
    #define MODS GDK_SHIFT_MASK 
    #define RESULT TRUE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (RESULT != gtk_accelerator_valid (KEY, MODS))
    {
        TEST_FAIL ("Test fails", NULL);
    }
    
    #undef KEY
    #undef MODS
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accelerator_name
 * Params: guint accelerator_key, GdkModifierType accelerator_mods
 * Returns: gchar*
 * Assertion: Converts an accelerator keyval and modifier mask into a string parseable by gtk_accelerator_parse().
 * Params Values: GDK_a , GDK_SHIFT_MASK | GDK_MOD1_MASK
 * Expected: "<Shift><Alt>a"  
 */
static void test_purpose_27()
{
    #define KEY GDK_a 
    #define MODS GDK_SHIFT_MASK | GDK_MOD1_MASK
    #define ACCEL "<Shift><Alt>a"
    
    gchar* name = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    name = gtk_accelerator_name (KEY, MODS);
    if (strcmp (name, ACCEL))
    {
        TEST_FAIL ("Accelerator = '%s'", name);
    }
    free (name);
    
    #undef KEY
    #undef MODS
    #undef ACCEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accelerator_name
 * Params: guint accelerator_key, GdkModifierType accelerator_mods
 * Returns: gchar*
 * Assertion: Converts an accelerator keyval and modifier mask into a string parseable by gtk_accelerator_parse().
 * Params Values: GDK_Scroll_Lock, 0 
 * Expected: "Scroll_Lock"  
 */
static void test_purpose_28()
{
    #define KEY GDK_Scroll_Lock
    #define MODS 0 
    #define ACCEL "Scroll_Lock"
    
    gchar* name = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    name = gtk_accelerator_name (KEY, MODS);
    if (strcmp (name, ACCEL))
    {
        TEST_FAIL ("Accelerator = '%s'", name);
    }
    free (name);
    
    #undef KEY
    #undef MODS
    #undef ACCEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accelerator_name
 * Params: guint accelerator_key, GdkModifierType accelerator_mods
 * Returns: gchar*
 * Assertion: Converts an accelerator keyval and modifier mask into a string parseable by gtk_accelerator_parse().
 * Params Values: GDK_Delete, GDK_SHIFT_MASK 
 * Expected: "<Shift>Delete"  
 */
static void test_purpose_29()
{
    #define KEY GDK_Delete
    #define MODS GDK_SHIFT_MASK 
    #define ACCEL "<Shift>Delete"
    
    gchar* name = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    name = gtk_accelerator_name (KEY, MODS);
    if (strcmp (name, ACCEL))
    {
        TEST_FAIL ("Accelerator = '%s'", name);
    }
    free (name);
    
    #undef KEY
    #undef MODS
    #undef ACCEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accelerator_name
 * Params: guint accelerator_key, GdkModifierType accelerator_mods
 * Returns: gchar*
 * Assertion: Converts an accelerator keyval and modifier mask into a string parseable by gtk_accelerator_parse().
 * Params Values: GDK_Return, GDK_SHIFT_MASK 
 * Expected: "<Shift>Return"  
 */
static void test_purpose_30()
{
    #define KEY GDK_Return
    #define MODS GDK_SHIFT_MASK 
    #define ACCEL "<Shift>Return"
    
    gchar* name = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    name = gtk_accelerator_name (KEY, MODS);
    if (strcmp (name, ACCEL))
    {
        TEST_FAIL ("Accelerator = '%s'", name);
    }
    free (name);
    
    #undef KEY
    #undef MODS
    #undef ACCEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accelerator_parse
 * Params: const gchar *accelerator, guint *accelerator_key, GdkModifierType *accelerator_mods
 * Returns: void
 * Assertion: Parses a string representing an accelerator.
 * Params Values:  "<Ctl>q", GDK_q, GDK_CONTROL_MASK
 * Expected: void
 * 
 * Name: gtk_accelerator_parse
 * Params: const gchar *accelerator, guint *accelerator_key, GdkModifierType *accelerator_mods
 * Returns: void
 * Assertion: The parser is fairly liberal and allows lower or upper case, and also abbreviations such as "<Ctl>" and "<Ctrl>"
 * Params Values:  "<Ctl>q", GDK_q, GDK_CONTROL_MASK
 * Expected: void
 * 
 * Name: gtk_accelerator_parse
 * Params: const gchar *accelerator, guint *accelerator_key, GdkModifierType *accelerator_mods
 * Returns: void
 * Assertion: If the parse fails, accelerator_key and accelerator_mods will be set to 0 (zero).
 * Params Values:  "<Ctl>q", GDK_q, GDK_CONTROL_MASK
 * Expected: void  
 */
static void test_purpose_31()
{
    #define KEY GDK_q
    #define MODS GDK_CONTROL_MASK
    #define ACCEL "<Ctl>q"
    
    guint key = 0;
    GdkModifierType mods = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accelerator_parse (ACCEL, &key, &mods);
    
    if ((key != KEY) ||  (mods != (MODS)))
    {
        TEST_FAIL ("Accelerator = '%s', key = %i/%i, mods = %i/%i", ACCEL, key, KEY, mods, MODS);
    }
    
    #undef KEY
    #undef MODS
    #undef ACCEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accelerator_parse
 * Params: const gchar *accelerator, guint *accelerator_key, GdkModifierType *accelerator_mods
 * Returns: void
 * Assertion: Parses a string representing an accelerator.
 * Params Values:  "<Control>a", GDK_a , GDK_CONTROL_MASK 
 * Expected: void
 * 
 * Name: gtk_accelerator_parse
 * Params: const gchar *accelerator, guint *accelerator_key, GdkModifierType *accelerator_mods
 * Returns: void
 * Assertion: The parser is fairly liberal and allows lower or upper case, and also abbreviations such as "<Ctl>" and "<Ctrl>"
 * Params Values:  "<Control>a", GDK_a , GDK_CONTROL_MASK 
 * Expected: void
 * 
 * Name: gtk_accelerator_parse
 * Params: const gchar *accelerator, guint *accelerator_key, GdkModifierType *accelerator_mods
 * Returns: void
 * Assertion: If the parse fails, accelerator_key and accelerator_mods will be set to 0 (zero).
 * Params Values:  "<Control>a", GDK_a , GDK_CONTROL_MASK 
 * Expected: void  
 */
static void test_purpose_32()
{
    #define KEY GDK_a 
    #define MODS GDK_CONTROL_MASK 
    #define ACCEL "<Control>a"
    
    guint key = 0;
    GdkModifierType mods = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accelerator_parse (ACCEL, &key, &mods);
    
    if ((key != KEY) ||  (mods != (MODS)))
    {
        TEST_FAIL ("Accelerator = '%s', key = %i/%i, mods = %i/%i", ACCEL, key, KEY, mods, MODS);
    }
    
    #undef KEY
    #undef MODS
    #undef ACCEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accelerator_parse
 * Params: const gchar *accelerator, guint *accelerator_key, GdkModifierType *accelerator_mods
 * Returns: void
 * Assertion: Parses a string representing an accelerator.
 * Params Values:  "<Alt><Shift>F11", GDK_F11 , GDK_SHIFT_MASK | GDK_MOD1_MASK
 * Expected: void
 * 
 * Name: gtk_accelerator_parse
 * Params: const gchar *accelerator, guint *accelerator_key, GdkModifierType *accelerator_mods
 * Returns: void
 * Assertion: The parser is fairly liberal and allows lower or upper case, and also abbreviations such as "<Ctl>" and "<Ctrl>"
 * Params Values:  "<Alt><Shift>F11", GDK_F11 , GDK_SHIFT_MASK | GDK_MOD1_MASK
 * Expected: void
 * 
 * Name: gtk_accelerator_parse
 * Params: const gchar *accelerator, guint *accelerator_key, GdkModifierType *accelerator_mods
 * Returns: void
 * Assertion: If the parse fails, accelerator_key and accelerator_mods will be set to 0 (zero).
 * Params Values:  "<Alt><Shift>F11", GDK_F11 , GDK_SHIFT_MASK | GDK_MOD1_MASK
 * Expected: void  
 */
static void test_purpose_33()
{
    #define KEY GDK_F11 
    #define MODS GDK_SHIFT_MASK | GDK_MOD1_MASK
    #define ACCEL "<Alt><Shift>F11"
    
    guint key = 0;
    GdkModifierType mods = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accelerator_parse (ACCEL, &key, &mods);
    
    if ((key != KEY) ||  (mods != (MODS)))
    {
        TEST_FAIL ("Accelerator = '%s', key = %i/%i, mods = %i/%i", ACCEL, key, KEY, mods, MODS);
    }
    
    #undef KEY
    #undef MODS
    #undef ACCEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accelerator_parse
 * Params: const gchar *accelerator, guint *accelerator_key, GdkModifierType *accelerator_mods
 * Returns: void
 * Assertion: Parses a string representing an accelerator.
 * Params Values:  "<Shift><Control>a", GDK_a , GDK_SHIFT_MASK | GDK_CONTROL_MASK
 * Expected: void
 * 
 * Name: gtk_accelerator_parse
 * Params: const gchar *accelerator, guint *accelerator_key, GdkModifierType *accelerator_mods
 * Returns: void
 * Assertion: The parser is fairly liberal and allows lower or upper case, and also abbreviations such as "<Ctl>" and "<Ctrl>"
 * Params Values:  "<Shift><Control>a", GDK_a , GDK_SHIFT_MASK | GDK_CONTROL_MASK
 * Expected: void
 * 
 * Name: gtk_accelerator_parse
 * Params: const gchar *accelerator, guint *accelerator_key, GdkModifierType *accelerator_mods
 * Returns: void
 * Assertion: If the parse fails, accelerator_key and accelerator_mods will be set to 0 (zero).
 * Params Values:  "<Shift><Control>a", GDK_a , GDK_SHIFT_MASK | GDK_CONTROL_MASK
 * Expected: void  
 */
static void test_purpose_34()
{
    #define KEY GDK_a 
    #define MODS GDK_SHIFT_MASK | GDK_CONTROL_MASK
    #define ACCEL "<Shift><Control>a"
    
    guint key = 0;
    GdkModifierType mods = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accelerator_parse (ACCEL, &key, &mods);
    
    if ((key != KEY) ||  (mods != (MODS)))
    {
        TEST_FAIL ("Accelerator = '%s', key = %i/%i, mods = %i/%i", ACCEL, key, KEY, mods, MODS);
    }
    
    #undef KEY
    #undef MODS
    #undef ACCEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accelerator_parse
 * Params: const gchar *accelerator, guint *accelerator_key, GdkModifierType *accelerator_mods
 * Returns: void
 * Assertion: Parses a string representing an accelerator.
 * Params Values:  "Scroll_Lock", GDK_Scroll_Lock, 0 
 * Expected: void
 * 
 * Name: gtk_accelerator_parse
 * Params: const gchar *accelerator, guint *accelerator_key, GdkModifierType *accelerator_mods
 * Returns: void
 * Assertion: The parser is fairly liberal and allows lower or upper case, and also abbreviations such as "<Ctl>" and "<Ctrl>"
 * Params Values:  "Scroll_Lock", GDK_Scroll_Lock, 0 
 * Expected: void
 * 
 * Name: gtk_accelerator_parse
 * Params: const gchar *accelerator, guint *accelerator_key, GdkModifierType *accelerator_mods
 * Returns: void
 * Assertion: If the parse fails, accelerator_key and accelerator_mods will be set to 0 (zero).
 * Params Values:  "Scroll_Lock", GDK_Scroll_Lock, 0 
 * Expected: void  
 */
static void test_purpose_35()
{
    #define KEY GDK_Scroll_Lock
    #define MODS 0 
    #define ACCEL "Scroll_Lock"
    
    guint key = 0;
    GdkModifierType mods = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accelerator_parse (ACCEL, &key, &mods);
    
    if ((key != KEY) ||  (mods != (MODS)))
    {
        TEST_FAIL ("Accelerator = '%s', key = %i/%i, mods = %i/%i", ACCEL, key, KEY, mods, MODS);
    }
    
    #undef KEY
    #undef MODS
    #undef ACCEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accelerator_parse
 * Params: const gchar *accelerator, guint *accelerator_key, GdkModifierType *accelerator_mods
 * Returns: void
 * Assertion: Parses a string representing an accelerator.
 * Params Values:  "<Shift>Delete", GDK_Delete, GDK_SHIFT_MASK 
 * Expected: void
 * 
 * Name: gtk_accelerator_parse
 * Params: const gchar *accelerator, guint *accelerator_key, GdkModifierType *accelerator_mods
 * Returns: void
 * Assertion: The parser is fairly liberal and allows lower or upper case, and also abbreviations such as "<Ctl>" and "<Ctrl>"
 * Params Values:  "<Shift>Delete", GDK_Delete, GDK_SHIFT_MASK 
 * Expected: void
 * 
 * Name: gtk_accelerator_parse
 * Params: const gchar *accelerator, guint *accelerator_key, GdkModifierType *accelerator_mods
 * Returns: void
 * Assertion: If the parse fails, accelerator_key and accelerator_mods will be set to 0 (zero).
 * Params Values:  "<Shift>Delete", GDK_Delete, GDK_SHIFT_MASK 
 * Expected: void  
 */
static void test_purpose_36()
{
    #define KEY GDK_Delete
    #define MODS GDK_SHIFT_MASK 
    #define ACCEL "<Shift>Delete"
    
    guint key = 0;
    GdkModifierType mods = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accelerator_parse (ACCEL, &key, &mods);
    
    if ((key != KEY) ||  (mods != (MODS)))
    {
        TEST_FAIL ("Accelerator = '%s', key = %i/%i, mods = %i/%i", ACCEL, key, KEY, mods, MODS);
    }
    
    #undef KEY
    #undef MODS
    #undef ACCEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accelerator_parse
 * Params: const gchar *accelerator, guint *accelerator_key, GdkModifierType *accelerator_mods
 * Returns: void
 * Assertion: Parses a string representing an accelerator.
 * Params Values:  "<Shift>Return", GDK_Return, GDK_SHIFT_MASK 
 * Expected: void
 * 
 * Name: gtk_accelerator_parse
 * Params: const gchar *accelerator, guint *accelerator_key, GdkModifierType *accelerator_mods
 * Returns: void
 * Assertion: The parser is fairly liberal and allows lower or upper case, and also abbreviations such as "<Ctl>" and "<Ctrl>"
 * Params Values:  "<Shift>Return", GDK_Return, GDK_SHIFT_MASK 
 * Expected: void
 * 
 * Name: gtk_accelerator_parse
 * Params: const gchar *accelerator, guint *accelerator_key, GdkModifierType *accelerator_mods
 * Returns: void
 * Assertion: If the parse fails, accelerator_key and accelerator_mods will be set to 0 (zero).
 * Params Values:  "<Shift>Return", GDK_Return, GDK_SHIFT_MASK 
 * Expected: void  
 */
static void test_purpose_37()
{
    #define KEY GDK_Return
    #define MODS GDK_SHIFT_MASK 
    #define ACCEL "<Shift>Return"
    
    guint key = 0;
    GdkModifierType mods = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accelerator_parse (ACCEL, &key, &mods);
    
    if ((key != KEY) ||  (mods != (MODS)))
    {
        TEST_FAIL ("Accelerator = '%s', key = %i/%i, mods = %i/%i", ACCEL, key, KEY, mods, MODS);
    }
    
    #undef KEY
    #undef MODS
    #undef ACCEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accelerator_parse
 * Params: const gchar *accelerator, guint *accelerator_key, GdkModifierType *accelerator_mods
 * Returns: void
 * Assertion: Parses a string representing an accelerator.
 * Params Values:  "<ShifContro>Retur", 0, 0 
 * Expected: void
 * 
 * Name: gtk_accelerator_parse
 * Params: const gchar *accelerator, guint *accelerator_key, GdkModifierType *accelerator_mods
 * Returns: void
 * Assertion: The parser is fairly liberal and allows lower or upper case, and also abbreviations such as "<Ctl>" and "<Ctrl>"
 * Params Values:  "<ShifContro>Retur", 0, 0 
 * Expected: void
 * 
 * Name: gtk_accelerator_parse
 * Params: const gchar *accelerator, guint *accelerator_key, GdkModifierType *accelerator_mods
 * Returns: void
 * Assertion: If the parse fails, accelerator_key and accelerator_mods will be set to 0 (zero).
 * Params Values:  "<ShifContro>Retur", 0, 0 
 * Expected: void  
 */
static void test_purpose_38()
{
    #define KEY 0
    #define MODS 0 
    #define ACCEL "<ShifContro>Retur"
    
    guint key = 0;
    GdkModifierType mods = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accelerator_parse (ACCEL, &key, &mods);
    
    if ((key != KEY) ||  (mods != (MODS)))
    {
        TEST_FAIL ("Accelerator = '%s', key = %i/%i, mods = %i/%i", ACCEL, key, KEY, mods, MODS);
    }
    
    #undef KEY
    #undef MODS
    #undef ACCEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accelerator_set_default_mod_mask
 * Params: GdkModifierType default_mod_mask
 * Returns: void
 * Assertion: Sets the modifiers that will be considered significant for keyboard accelerators. 
 * Params Values: GDK_CONTROL_MASK | GDK_SHIFT_MASK | GDK_MOD1_MASK
 * Expected: void
 * 
 * Name: gtk_accelerator_set_default_mod_mask
 * Params: GdkModifierType default_mod_mask
 * Returns: void
 * Assertion: You must include at least the three default modifiers in any value you pass to this function.
 * Params Values: GDK_CONTROL_MASK | GDK_SHIFT_MASK | GDK_MOD1_MASK
 * Expected: void
 * 
 * Name: gtk_accelerator_get_default_mod_mask
 * Params: void
 * Returns: GdkModifierType default_mod_mask
 * Assertion: Gets the value set by gtk_accelerator_set_default_mod_mask().
 * Params Values: void
 * Expected: GDK_CONTROL_MASK | GDK_SHIFT_MASK | GDK_MOD1_MASK  
 */
static void test_purpose_39()
{
    #define MODS GDK_CONTROL_MASK | GDK_SHIFT_MASK | GDK_MOD1_MASK
    
    GdkModifierType mods = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accelerator_set_default_mod_mask (MODS);
    
    mods = gtk_accelerator_get_default_mod_mask ();
    
    if (mods != ((MODS & GDK_MODIFIER_MASK) | GDK_CONTROL_MASK | GDK_SHIFT_MASK | GDK_MOD1_MASK))
    {
        TEST_FAIL ("mods = %d, should be %d", mods, 
                   (MODS & GDK_MODIFIER_MASK) | GDK_CONTROL_MASK | GDK_SHIFT_MASK | GDK_MOD1_MASK);
    }
    #undef MODS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accelerator_set_default_mod_mask
 * Params: GdkModifierType default_mod_mask
 * Returns: void
 * Assertion: Sets the modifiers that will be considered significant for keyboard accelerators. 
 * Params Values: GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_MOD2_MASK
 * Expected: void
 * 
 * Name: gtk_accelerator_set_default_mod_mask
 * Params: GdkModifierType default_mod_mask
 * Returns: void
 * Assertion: You must include at least the three default modifiers in any value you pass to this function.
 * Params Values: GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_MOD2_MASK
 * Expected: void
 * 
 * Name: gtk_accelerator_get_default_mod_mask
 * Params: void
 * Returns: GdkModifierType default_mod_mask
 * Assertion: Gets the value set by gtk_accelerator_set_default_mod_mask().
 * Params Values: void
 * Expected: GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_MOD2_MASK  
 */
static void test_purpose_40()
{
    #define MODS GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_MOD2_MASK
    
    GdkModifierType mods = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accelerator_set_default_mod_mask (MODS);
    
    mods = gtk_accelerator_get_default_mod_mask ();
    
    if (mods != ((MODS & GDK_MODIFIER_MASK) | GDK_CONTROL_MASK | GDK_SHIFT_MASK | GDK_MOD1_MASK))
    {
        TEST_FAIL ("mods = %d, should be %d", mods, 
                   (MODS & GDK_MODIFIER_MASK) | GDK_CONTROL_MASK | GDK_SHIFT_MASK | GDK_MOD1_MASK);
    }
    #undef MODS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accelerator_set_default_mod_mask
 * Params: GdkModifierType default_mod_mask
 * Returns: void
 * Assertion: Sets the modifiers that will be considered significant for keyboard accelerators. 
 * Params Values: GDK_SHIFT_MASK | GDK_MOD1_MASK | GDK_CONTROL_MASK | GDK_BUTTON5_MASK
 * Expected: void
 * 
 * Name: gtk_accelerator_set_default_mod_mask
 * Params: GdkModifierType default_mod_mask
 * Returns: void
 * Assertion: You must include at least the three default modifiers in any value you pass to this function.
 * Params Values: GDK_SHIFT_MASK | GDK_MOD1_MASK | GDK_CONTROL_MASK | GDK_BUTTON5_MASK
 * Expected: void
 * 
 * Name: gtk_accelerator_get_default_mod_mask
 * Params: void
 * Returns: GdkModifierType default_mod_mask
 * Assertion: Gets the value set by gtk_accelerator_set_default_mod_mask().
 * Params Values: void
 * Expected: GDK_SHIFT_MASK | GDK_MOD1_MASK | GDK_CONTROL_MASK | GDK_BUTTON5_MASK  
 */
static void test_purpose_41()
{
    #define MODS GDK_SHIFT_MASK | GDK_MOD1_MASK | GDK_CONTROL_MASK | GDK_BUTTON5_MASK
    
    GdkModifierType mods = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accelerator_set_default_mod_mask (MODS);
    
    mods = gtk_accelerator_get_default_mod_mask ();
    
    if (mods != ((MODS & GDK_MODIFIER_MASK) | GDK_CONTROL_MASK | GDK_SHIFT_MASK | GDK_MOD1_MASK))
    {
        TEST_FAIL ("mods = %d, should be %d", mods, 
                   (MODS & GDK_MODIFIER_MASK) | GDK_CONTROL_MASK | GDK_SHIFT_MASK | GDK_MOD1_MASK);
    }
    #undef MODS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accelerator_set_default_mod_mask
 * Params: GdkModifierType default_mod_mask
 * Returns: void
 * Assertion: Sets the modifiers that will be considered significant for keyboard accelerators. 
 * Params Values: GDK_LOCK_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_SHIFT_MASK
 * Expected: void
 * 
 * Name: gtk_accelerator_set_default_mod_mask
 * Params: GdkModifierType default_mod_mask
 * Returns: void
 * Assertion: You must include at least the three default modifiers in any value you pass to this function.
 * Params Values: GDK_LOCK_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_SHIFT_MASK
 * Expected: void
 * 
 * Name: gtk_accelerator_get_default_mod_mask
 * Params: void
 * Returns: GdkModifierType default_mod_mask
 * Assertion: Gets the value set by gtk_accelerator_set_default_mod_mask().
 * Params Values: void
 * Expected: GDK_LOCK_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_SHIFT_MASK  
 */
static void test_purpose_42()
{
    #define MODS GDK_LOCK_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_SHIFT_MASK
    
    GdkModifierType mods = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accelerator_set_default_mod_mask (MODS);
    
    mods = gtk_accelerator_get_default_mod_mask ();
    
    if (mods != ((MODS & GDK_MODIFIER_MASK) | GDK_CONTROL_MASK | GDK_SHIFT_MASK | GDK_MOD1_MASK))
    {
        TEST_FAIL ("mods = %d, should be %d", mods, 
                   (MODS & GDK_MODIFIER_MASK) | GDK_CONTROL_MASK | GDK_SHIFT_MASK | GDK_MOD1_MASK);
    }
    #undef MODS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accelerator_set_default_mod_mask
 * Params: GdkModifierType default_mod_mask
 * Returns: void
 * Assertion: Sets the modifiers that will be considered significant for keyboard accelerators. 
 * Params Values: GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_LOCK_MASK | GDK_MOD2_MASK | GDK_MOD3_MASK | GDK_MOD4_MASK | GDK_MOD5_MASK | GDK_BUTTON1_MASK | GDK_BUTTON2_MASK | GDK_BUTTON3_MASK | GDK_BUTTON4_MASK | GDK_BUTTON5_MASK | GDK_RELEASE_MASK | GDK_MODIFIER_MASK
 * Expected: void
 * 
 * Name: gtk_accelerator_set_default_mod_mask
 * Params: GdkModifierType default_mod_mask
 * Returns: void
 * Assertion: You must include at least the three default modifiers in any value you pass to this function.
 * Params Values: GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_LOCK_MASK | GDK_MOD2_MASK | GDK_MOD3_MASK | GDK_MOD4_MASK | GDK_MOD5_MASK | GDK_BUTTON1_MASK | GDK_BUTTON2_MASK | GDK_BUTTON3_MASK | GDK_BUTTON4_MASK | GDK_BUTTON5_MASK | GDK_RELEASE_MASK | GDK_MODIFIER_MASK
 * Expected: void
 * 
 * Name: gtk_accelerator_get_default_mod_mask
 * Params: void
 * Returns: GdkModifierType default_mod_mask
 * Assertion: Gets the value set by gtk_accelerator_set_default_mod_mask().
 * Params Values: void
 * Expected: GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_LOCK_MASK | GDK_MOD2_MASK | GDK_MOD3_MASK | GDK_MOD4_MASK | GDK_MOD5_MASK | GDK_BUTTON1_MASK | GDK_BUTTON2_MASK | GDK_BUTTON3_MASK | GDK_BUTTON4_MASK | GDK_BUTTON5_MASK | GDK_RELEASE_MASK | GDK_MODIFIER_MASK  
 */
static void test_purpose_43()
{
    #define MODS GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_LOCK_MASK | GDK_MOD2_MASK | GDK_MOD3_MASK | GDK_MOD4_MASK | GDK_MOD5_MASK | GDK_BUTTON1_MASK | GDK_BUTTON2_MASK | GDK_BUTTON3_MASK | GDK_BUTTON4_MASK | GDK_BUTTON5_MASK | GDK_RELEASE_MASK | GDK_MODIFIER_MASK
    
    GdkModifierType mods = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accelerator_set_default_mod_mask (MODS);
    
    mods = gtk_accelerator_get_default_mod_mask ();
    
    if (mods != ((MODS & GDK_MODIFIER_MASK) | GDK_CONTROL_MASK | GDK_SHIFT_MASK | GDK_MOD1_MASK))
    {
        TEST_FAIL ("mods = %d, should be %d", mods, 
                   (MODS & GDK_MODIFIER_MASK) | GDK_CONTROL_MASK | GDK_SHIFT_MASK | GDK_MOD1_MASK);
    }
    #undef MODS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_group_from_accel_closure
 * Params: GClosure *closure
 * Returns: GtkAccelGroup* 
 * Assertion: Finds the GtkAccelGroup to which closure is connected; see gtk_accel_group_connect().
 * Params Values:  GClosure *closure
 * Expected: GtkAccelGroup*   
 */
static void test_purpose_44()
{
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    group = gtk_accel_group_new ();
    if (!group)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    closure = g_cclosure_new ((GCallback)global_set_result, NULL, NULL);
    gtk_accel_group_connect (group, GDK_a, 0, GTK_ACCEL_VISIBLE, closure);
    
    if (gtk_accel_group_from_accel_closure (closure) != group)
    {
        TEST_FAIL ("'gtk_accel_group_from_accel_closure' returns wrong group", NULL);
    }
    
    gtk_widget_destroy (window);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_groups_from_object
 * Params: GObject *object
 * Returns: GSList*
 * Assertion: Gets a list of all accel groups which are attached to object.
 * Params Values: GObject *object
 * Expected: GSList*  
 */
static void test_purpose_45()
{
    #define COUNT 0
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    GSList* list;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    for (i = 0; i < COUNT; i++)
    {
        group = gtk_accel_group_new ();
        gtk_window_add_accel_group (GTK_WINDOW (window), group);
    }
    
    list = gtk_accel_groups_from_object (G_OBJECT (window));
    
    if (list && (g_slist_length (list) != COUNT))
    {
        TEST_FAIL ("found %i groups, should be %i", g_slist_length (list), COUNT);
    }
    
    if (!list && (COUNT != 0))
    {
        TEST_FAIL ("'gtk_accel_group_from_object' returns NULL, but %i entries were connected", COUNT);
    }
    
    gtk_widget_destroy (window);
    
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_groups_from_object
 * Params: GObject *object
 * Returns: GSList*
 * Assertion: Gets a list of all accel groups which are attached to object.
 * Params Values: GObject *object
 * Expected: GSList*  
 */
static void test_purpose_46()
{
    #define COUNT 10
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    GSList* list;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    for (i = 0; i < COUNT; i++)
    {
        group = gtk_accel_group_new ();
        gtk_window_add_accel_group (GTK_WINDOW (window), group);
    }
    
    list = gtk_accel_groups_from_object (G_OBJECT (window));
    
    if (list && (g_slist_length (list) != COUNT))
    {
        TEST_FAIL ("found %i groups, should be %i", g_slist_length (list), COUNT);
    }
    
    if (!list && (COUNT != 0))
    {
        TEST_FAIL ("'gtk_accel_group_from_object' returns NULL, but %i entries were connected", COUNT);
    }
    
    gtk_widget_destroy (window);
    
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_groups_from_object
 * Params: GObject *object
 * Returns: GSList*
 * Assertion: Gets a list of all accel groups which are attached to object.
 * Params Values: GObject *object
 * Expected: GSList*  
 */
static void test_purpose_47()
{
    #define COUNT 1000
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    GSList* list;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    for (i = 0; i < COUNT; i++)
    {
        group = gtk_accel_group_new ();
        gtk_window_add_accel_group (GTK_WINDOW (window), group);
    }
    
    list = gtk_accel_groups_from_object (G_OBJECT (window));
    
    if (list && (g_slist_length (list) != COUNT))
    {
        TEST_FAIL ("found %i groups, should be %i", g_slist_length (list), COUNT);
    }
    
    if (!list && (COUNT != 0))
    {
        TEST_FAIL ("'gtk_accel_group_from_object' returns NULL, but %i entries were connected", COUNT);
    }
    
    gtk_widget_destroy (window);
    
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_group_query
 * Params: GtkAccelGroup *accel_group, guint accel_key, GdkModifierType accel_mods, guint *n_entries
 * Returns: GtkAccelGroupEntry*
 * Assertion: Queries an accelerator group for all entries matching accel_key and accel_mods.
 * Params Values: GtkAccelGroup *accel_group, GDK_q, GDK_CONTROL_MASK, 2
 * Expected: GtkAccelGroupEntry*   
 */
static void test_purpose_48()
{
    #define KEY GDK_q
    #define MODS GDK_CONTROL_MASK
    #define COUNT 2
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    gint i;
    gint count;
    GtkAccelGroupEntry* entries;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    group = gtk_accel_group_new ();
    if (!group)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    for (i = 0; i < COUNT; i++)
    {
        closure = g_cclosure_new ((GCallback)global_set_result, NULL, NULL);
        gtk_accel_group_connect (group, KEY, MODS, GTK_ACCEL_VISIBLE, closure);
    }
    
    entries = gtk_accel_group_query (group, KEY, MODS, &count);
    
    if (entries && (count != COUNT))
    {
        TEST_FAIL ("found %i entries, should be %i", count, COUNT);
    }
    
    if (!entries && (count != 0))
    {
        TEST_FAIL ("'gtk_accel_group_query' returns NULL, but %i entries were connected", count);
    }
    
    gtk_widget_destroy (window);
    
    #undef KEY
    #undef MODS
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_group_query
 * Params: GtkAccelGroup *accel_group, guint accel_key, GdkModifierType accel_mods, guint *n_entries
 * Returns: GtkAccelGroupEntry*
 * Assertion: Queries an accelerator group for all entries matching accel_key and accel_mods.
 * Params Values: GtkAccelGroup *accel_group, GDK_a , GDK_CONTROL_MASK , 10
 * Expected: GtkAccelGroupEntry*   
 */
static void test_purpose_49()
{
    #define KEY GDK_a 
    #define MODS GDK_CONTROL_MASK 
    #define COUNT 10
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    gint i;
    gint count;
    GtkAccelGroupEntry* entries;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    group = gtk_accel_group_new ();
    if (!group)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    for (i = 0; i < COUNT; i++)
    {
        closure = g_cclosure_new ((GCallback)global_set_result, NULL, NULL);
        gtk_accel_group_connect (group, KEY, MODS, GTK_ACCEL_VISIBLE, closure);
    }
    
    entries = gtk_accel_group_query (group, KEY, MODS, &count);
    
    if (entries && (count != COUNT))
    {
        TEST_FAIL ("found %i entries, should be %i", count, COUNT);
    }
    
    if (!entries && (count != 0))
    {
        TEST_FAIL ("'gtk_accel_group_query' returns NULL, but %i entries were connected", count);
    }
    
    gtk_widget_destroy (window);
    
    #undef KEY
    #undef MODS
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_group_query
 * Params: GtkAccelGroup *accel_group, guint accel_key, GdkModifierType accel_mods, guint *n_entries
 * Returns: GtkAccelGroupEntry*
 * Assertion: Queries an accelerator group for all entries matching accel_key and accel_mods.
 * Params Values: GtkAccelGroup *accel_group, GDK_F11 , GDK_SHIFT_MASK | GDK_MOD1_MASK, 0
 * Expected: GtkAccelGroupEntry*   
 */
static void test_purpose_50()
{
    #define KEY GDK_F11 
    #define MODS GDK_SHIFT_MASK | GDK_MOD1_MASK
    #define COUNT 0
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    gint i;
    gint count;
    GtkAccelGroupEntry* entries;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    group = gtk_accel_group_new ();
    if (!group)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    for (i = 0; i < COUNT; i++)
    {
        closure = g_cclosure_new ((GCallback)global_set_result, NULL, NULL);
        gtk_accel_group_connect (group, KEY, MODS, GTK_ACCEL_VISIBLE, closure);
    }
    
    entries = gtk_accel_group_query (group, KEY, MODS, &count);
    
    if (entries && (count != COUNT))
    {
        TEST_FAIL ("found %i entries, should be %i", count, COUNT);
    }
    
    if (!entries && (count != 0))
    {
        TEST_FAIL ("'gtk_accel_group_query' returns NULL, but %i entries were connected", count);
    }
    
    gtk_widget_destroy (window);
    
    #undef KEY
    #undef MODS
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_group_query
 * Params: GtkAccelGroup *accel_group, guint accel_key, GdkModifierType accel_mods, guint *n_entries
 * Returns: GtkAccelGroupEntry*
 * Assertion: Queries an accelerator group for all entries matching accel_key and accel_mods.
 * Params Values: GtkAccelGroup *accel_group, GDK_a , GDK_SHIFT_MASK | GDK_CONTROL_MASK, 0
 * Expected: GtkAccelGroupEntry*   
 */
static void test_purpose_51()
{
    #define KEY GDK_a 
    #define MODS GDK_SHIFT_MASK | GDK_CONTROL_MASK
    #define COUNT 0
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    gint i;
    gint count;
    GtkAccelGroupEntry* entries;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    group = gtk_accel_group_new ();
    if (!group)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    for (i = 0; i < COUNT; i++)
    {
        closure = g_cclosure_new ((GCallback)global_set_result, NULL, NULL);
        gtk_accel_group_connect (group, KEY, MODS, GTK_ACCEL_VISIBLE, closure);
    }
    
    entries = gtk_accel_group_query (group, KEY, MODS, &count);
    
    if (entries && (count != COUNT))
    {
        TEST_FAIL ("found %i entries, should be %i", count, COUNT);
    }
    
    if (!entries && (count != 0))
    {
        TEST_FAIL ("'gtk_accel_group_query' returns NULL, but %i entries were connected", count);
    }
    
    gtk_widget_destroy (window);
    
    #undef KEY
    #undef MODS
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_group_query
 * Params: GtkAccelGroup *accel_group, guint accel_key, GdkModifierType accel_mods, guint *n_entries
 * Returns: GtkAccelGroupEntry*
 * Assertion: Queries an accelerator group for all entries matching accel_key and accel_mods.
 * Params Values: GtkAccelGroup *accel_group, GDK_a , GDK_SHIFT_MASK | GDK_CONTROL_MASK, 1000
 * Expected: GtkAccelGroupEntry*   
 */
static void test_purpose_52()
{
    #define KEY GDK_a 
    #define MODS GDK_SHIFT_MASK | GDK_CONTROL_MASK
    #define COUNT 1000
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    gint i;
    gint count;
    GtkAccelGroupEntry* entries;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    group = gtk_accel_group_new ();
    if (!group)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    for (i = 0; i < COUNT; i++)
    {
        closure = g_cclosure_new ((GCallback)global_set_result, NULL, NULL);
        gtk_accel_group_connect (group, KEY, MODS, GTK_ACCEL_VISIBLE, closure);
    }
    
    entries = gtk_accel_group_query (group, KEY, MODS, &count);
    
    if (entries && (count != COUNT))
    {
        TEST_FAIL ("found %i entries, should be %i", count, COUNT);
    }
    
    if (!entries && (count != 0))
    {
        TEST_FAIL ("'gtk_accel_group_query' returns NULL, but %i entries were connected", count);
    }
    
    gtk_widget_destroy (window);
    
    #undef KEY
    #undef MODS
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_group_find
 * Params: GtkAccelGroup *accel_group, gboolean (*find_func) (GtkAccelKey *key, GClosure *closure, gpointer data), gpointer data
 * Returns: GtkAccelKey*
 * Assertion: Finds the first entry in an accelerator group for which find_func returns TRUE and returns its GtkAccelKey.
 * Params Values: GtkAccelGroup *accel_group, gboolean (*find_func) (GtkAccelKey *key, GClosure *closure, gpointer data), gpointer data
 * Expected: GtkAccelKey*   
 */
static void test_purpose_53()
{
    #define KEY GDK_q
    #define MODS GDK_CONTROL_MASK
    #define COUNT 2
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    gint i;
    gint count;
    GtkAccelKey* key;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    group = gtk_accel_group_new ();
    if (!group)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    for (i = 0; i < COUNT; i++)
    {
        closure = g_cclosure_new ((GCallback)global_set_result, NULL, NULL);
        gtk_accel_group_connect (group, KEY, MODS, GTK_ACCEL_VISIBLE, closure);
    }
    
    count = COUNT;
    key = gtk_accel_group_find (group, global_find, &count);
    
    if (key && (global_result != COUNT))
    {
        TEST_FAIL ("found %i entries, should be %i", global_result, COUNT);
    }
    
    if (!key && (global_result != 0))
    {
        TEST_FAIL ("'gtk_accel_group_query' returns NULL, but %i entries were connected", global_result);
    }
    
    gtk_widget_destroy (window);
    
    #undef KEY
    #undef MODS
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_group_find
 * Params: GtkAccelGroup *accel_group, gboolean (*find_func) (GtkAccelKey *key, GClosure *closure, gpointer data), gpointer data
 * Returns: GtkAccelKey*
 * Assertion: Finds the first entry in an accelerator group for which find_func returns TRUE and returns its GtkAccelKey.
 * Params Values: GtkAccelGroup *accel_group, gboolean (*find_func) (GtkAccelKey *key, GClosure *closure, gpointer data), gpointer data
 * Expected: GtkAccelKey*   
 */
static void test_purpose_54()
{
    #define KEY GDK_a 
    #define MODS GDK_CONTROL_MASK 
    #define COUNT 10
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    gint i;
    gint count;
    GtkAccelKey* key;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    group = gtk_accel_group_new ();
    if (!group)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    for (i = 0; i < COUNT; i++)
    {
        closure = g_cclosure_new ((GCallback)global_set_result, NULL, NULL);
        gtk_accel_group_connect (group, KEY, MODS, GTK_ACCEL_VISIBLE, closure);
    }
    
    count = COUNT;
    key = gtk_accel_group_find (group, global_find, &count);
    
    if (key && (global_result != COUNT))
    {
        TEST_FAIL ("found %i entries, should be %i", global_result, COUNT);
    }
    
    if (!key && (global_result != 0))
    {
        TEST_FAIL ("'gtk_accel_group_query' returns NULL, but %i entries were connected", global_result);
    }
    
    gtk_widget_destroy (window);
    
    #undef KEY
    #undef MODS
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_group_find
 * Params: GtkAccelGroup *accel_group, gboolean (*find_func) (GtkAccelKey *key, GClosure *closure, gpointer data), gpointer data
 * Returns: GtkAccelKey*
 * Assertion: Finds the first entry in an accelerator group for which find_func returns TRUE and returns its GtkAccelKey.
 * Params Values: GtkAccelGroup *accel_group, gboolean (*find_func) (GtkAccelKey *key, GClosure *closure, gpointer data), gpointer data
 * Expected: GtkAccelKey*   
 */
static void test_purpose_55()
{
    #define KEY GDK_F11 
    #define MODS GDK_SHIFT_MASK | GDK_MOD1_MASK
    #define COUNT 0
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    gint i;
    gint count;
    GtkAccelKey* key;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    group = gtk_accel_group_new ();
    if (!group)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    for (i = 0; i < COUNT; i++)
    {
        closure = g_cclosure_new ((GCallback)global_set_result, NULL, NULL);
        gtk_accel_group_connect (group, KEY, MODS, GTK_ACCEL_VISIBLE, closure);
    }
    
    count = COUNT;
    key = gtk_accel_group_find (group, global_find, &count);
    
    if (key && (global_result != COUNT))
    {
        TEST_FAIL ("found %i entries, should be %i", global_result, COUNT);
    }
    
    if (!key && (global_result != 0))
    {
        TEST_FAIL ("'gtk_accel_group_query' returns NULL, but %i entries were connected", global_result);
    }
    
    gtk_widget_destroy (window);
    
    #undef KEY
    #undef MODS
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_group_find
 * Params: GtkAccelGroup *accel_group, gboolean (*find_func) (GtkAccelKey *key, GClosure *closure, gpointer data), gpointer data
 * Returns: GtkAccelKey*
 * Assertion: Finds the first entry in an accelerator group for which find_func returns TRUE and returns its GtkAccelKey.
 * Params Values: GtkAccelGroup *accel_group, gboolean (*find_func) (GtkAccelKey *key, GClosure *closure, gpointer data), gpointer data
 * Expected: GtkAccelKey*   
 */
static void test_purpose_56()
{
    #define KEY GDK_a 
    #define MODS GDK_SHIFT_MASK | GDK_CONTROL_MASK
    #define COUNT 0
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    gint i;
    gint count;
    GtkAccelKey* key;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    group = gtk_accel_group_new ();
    if (!group)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    for (i = 0; i < COUNT; i++)
    {
        closure = g_cclosure_new ((GCallback)global_set_result, NULL, NULL);
        gtk_accel_group_connect (group, KEY, MODS, GTK_ACCEL_VISIBLE, closure);
    }
    
    count = COUNT;
    key = gtk_accel_group_find (group, global_find, &count);
    
    if (key && (global_result != COUNT))
    {
        TEST_FAIL ("found %i entries, should be %i", global_result, COUNT);
    }
    
    if (!key && (global_result != 0))
    {
        TEST_FAIL ("'gtk_accel_group_query' returns NULL, but %i entries were connected", global_result);
    }
    
    gtk_widget_destroy (window);
    
    #undef KEY
    #undef MODS
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_group_find
 * Params: GtkAccelGroup *accel_group, gboolean (*find_func) (GtkAccelKey *key, GClosure *closure, gpointer data), gpointer data
 * Returns: GtkAccelKey*
 * Assertion: Finds the first entry in an accelerator group for which find_func returns TRUE and returns its GtkAccelKey.
 * Params Values: GtkAccelGroup *accel_group, gboolean (*find_func) (GtkAccelKey *key, GClosure *closure, gpointer data), gpointer data
 * Expected: GtkAccelKey*   
 */
static void test_purpose_57()
{
    #define KEY GDK_a 
    #define MODS GDK_SHIFT_MASK | GDK_CONTROL_MASK
    #define COUNT 1000
    
    GtkWidget* window;
    GClosure* closure;
    GtkAccelGroup* group;
    gint i;
    gint count;
    GtkAccelKey* key;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    group = gtk_accel_group_new ();
    if (!group)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    for (i = 0; i < COUNT; i++)
    {
        closure = g_cclosure_new ((GCallback)global_set_result, NULL, NULL);
        gtk_accel_group_connect (group, KEY, MODS, GTK_ACCEL_VISIBLE, closure);
    }
    
    count = COUNT;
    key = gtk_accel_group_find (group, global_find, &count);
    
    if (key && (global_result != COUNT))
    {
        TEST_FAIL ("found %i entries, should be %i", global_result, COUNT);
    }
    
    if (!key && (global_result != 0))
    {
        TEST_FAIL ("'gtk_accel_group_query' returns NULL, but %i entries were connected", global_result);
    }
    
    gtk_widget_destroy (window);
    
    #undef KEY
    #undef MODS
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for Keyboard_Accelerator_Groups ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {test_purpose_52, 1},
    {test_purpose_53, 1},
    {test_purpose_54, 1},
    {test_purpose_55, 1},
    {test_purpose_56, 1},
    {test_purpose_57, 1},
    {NULL,0}
};
