/*
 * StringUtil methods tests
 * Testing StringUtil methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
// used for forcing g_strerror to C locale
#include <locale.h>

/* The length includes the nul-terminated */
static gint cal_length(gchar *str)
{
    gint n = 0;
    while(*(str+n)){
        n ++;
    }
    return n + 1;
}

static gboolean
strv_check (gchar **strv, ...)
{
    gboolean ok = TRUE;
    gint i = 0;
    va_list list;

    va_start (list, strv);
    while (ok){
        const gchar *str = va_arg (list, const char *);
        if (strv[i] == NULL){
            ok = str == NULL;
            break;
        }
        if (str == NULL)
            ok = FALSE;
        else if (strcmp (strv[i], str) != 0)
            ok = FALSE;
        i++;
    }
    va_end (list);

    g_strfreev (strv);

    return ok;
}

/*
 * Name: g_strdup
 * Params: const gchar *str
 * Returns: gchar*
 * Assertion: Duplicates a string. If str is NULL it returns NULL. The returned string should be freed when no longer needed.
 *            str : the string to duplicate.
 *            Returns : a newly-allocated copy of str. 
 * Params Values: "Hello, LSB"
 * Expected: "Hello, LSB"  
 */
static void test_purpose_1()
{
    #define STR    "Hello, LSB"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar *str;
    str = g_strdup(STR);
    if (g_ascii_strcasecmp(str, STR) != 0){
        TEST_FAIL("g_ascii_strcasecmp: failed", NULL);
    }
    g_free(str);
    
    #undef STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strdup
 * Params: const gchar *str
 * Returns: gchar*
 * Assertion: Duplicates a string. If str is NULL it returns NULL. The returned string should be freed when no longer needed.
 *            str : the string to duplicate.
 *            Returns : a newly-allocated copy of str. 
 * Params Values: NULL
 * Expected: NULL  
 */
static void test_purpose_2()
{
    #define STR    NULL
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar *str;
    str = g_strdup(STR);
    if (g_ascii_strcasecmp(str, STR) != 0){
        TEST_FAIL("g_ascii_strcasecmp: failed", NULL);
    }
    g_free(str);
    
    #undef STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strdup_printf
 * Params: const gchar *format, ...
 * Returns: gchar*
 * Assertion: Similar to the standard C sprintf() function but safer, since it calculates the maximum space required and allocates memory to hold the result. The returned string should be freed when no longer needed.
 *            format : a standard printf() format string, but notice string precision pitfalls.
 *            ... : the parameters to insert into the format string.
 *            Returns : a newly-allocated string holding the result. 
 * Params Values: "%s", "Hello, LSB"
 * Expected: <%2%>  
 */
static void test_purpose_3()
{
    #define FORMAT    "%s"
    #define ARGS      "Hello, LSB"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar *result = g_strdup_printf(FORMAT, ARGS);
    if (ARGS == 1){
        if (result[0] != '1'){
            TEST_FAIL("g_strdup_printf: failed", NULL);
        }
    }
    else{
        if (g_ascii_strcasecmp(result, ARGS) != 0){
            TEST_FAIL("g_strdup_printf: failed", NULL);
        }
    }
    
    g_free(result);
    
    #undef FORMAT
    #undef ARGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strdup_printf
 * Params: const gchar *format, ...
 * Returns: gchar*
 * Assertion: Similar to the standard C sprintf() function but safer, since it calculates the maximum space required and allocates memory to hold the result. The returned string should be freed when no longer needed.
 *            format : a standard printf() format string, but notice string precision pitfalls.
 *            ... : the parameters to insert into the format string.
 *            Returns : a newly-allocated string holding the result. 
 * Params Values: "%d", 1
 * Expected: <%2%>  
 */
static void test_purpose_4()
{
    #define FORMAT    "%d"
    #define ARGS      1
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar *result = g_strdup_printf(FORMAT, ARGS);
    if (ARGS == 1){
        if (result[0] != '1'){
            TEST_FAIL("g_strdup_printf: failed", NULL);
        }
    }
    else{
        if (g_ascii_strcasecmp(result, ARGS) != 0){
            TEST_FAIL("g_strdup_printf: failed", NULL);
        }
    }
    
    g_free(result);
    
    #undef FORMAT
    #undef ARGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_ascii_strcasecmp
 * Params: const gchar *s1, const gchar *s2
 * Returns: gint
 * Assertion: Compare two strings, ignoring the case of ASCII characters.
 * Unlike the BSD strcasecmp() function, this only recognizes standard ASCII letters and ignores the locale, treating all non-ASCII characters as if they are not letters.
 *            s1 :	string to compare with s2.
 *            s2 :	string to compare with s1.
 *            Returns : an integer less than, equal to, or greater than zero if s1 is found, respectively, to be less than, to match, or to be greater than s2.
 * Params Values: "Hello", "Hello"
 * Expected: 0  
 */
static void test_purpose_5()
{
    #define S1    "Hello"
    #define S2    "Hello"
    #define RET   0
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (g_ascii_strcasecmp(S1, S2) != RET){
        TEST_FAIL("g_ascii_strcasecmp: failed", NULL);
    }
    #undef S1
    #undef S2
    #undef RET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_ascii_strcasecmp
 * Params: const gchar *s1, const gchar *s2
 * Returns: gint
 * Assertion: Compare two strings, ignoring the case of ASCII characters.
 * Unlike the BSD strcasecmp() function, this only recognizes standard ASCII letters and ignores the locale, treating all non-ASCII characters as if they are not letters.
 *            s1 :	string to compare with s2.
 *            s2 :	string to compare with s1.
 *            Returns : an integer less than, equal to, or greater than zero if s1 is found, respectively, to be less than, to match, or to be greater than s2.
 * Params Values: "HELLO", "hello"
 * Expected: 0  
 */
static void test_purpose_6()
{
    #define S1    "HELLO"
    #define S2    "hello"
    #define RET   0
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (g_ascii_strcasecmp(S1, S2) != RET){
        TEST_FAIL("g_ascii_strcasecmp: failed", NULL);
    }
    #undef S1
    #undef S2
    #undef RET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_ascii_strcasecmp
 * Params: const gchar *s1, const gchar *s2
 * Returns: gint
 * Assertion: Compare two strings, ignoring the case of ASCII characters.
 * Unlike the BSD strcasecmp() function, this only recognizes standard ASCII letters and ignores the locale, treating all non-ASCII characters as if they are not letters.
 *            s1 :	string to compare with s2.
 *            s2 :	string to compare with s1.
 *            Returns : an integer less than, equal to, or greater than zero if s1 is found, respectively, to be less than, to match, or to be greater than s2.
 * Params Values: "world", "HELLO"
 * Expected: 15  
 */
static void test_purpose_7()
{
    #define S1    "world"
    #define S2    "HELLO"
    #define RET   15
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (g_ascii_strcasecmp(S1, S2) != RET){
        TEST_FAIL("g_ascii_strcasecmp: failed", NULL);
    }
    #undef S1
    #undef S2
    #undef RET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_ascii_strcasecmp
 * Params: const gchar *s1, const gchar *s2
 * Returns: gint
 * Assertion: Compare two strings, ignoring the case of ASCII characters.
 * Unlike the BSD strcasecmp() function, this only recognizes standard ASCII letters and ignores the locale, treating all non-ASCII characters as if they are not letters.
 *            s1 :	string to compare with s2.
 *            s2 :	string to compare with s1.
 *            Returns : an integer less than, equal to, or greater than zero if s1 is found, respectively, to be less than, to match, or to be greater than s2.
 * Params Values: "HELLO", "world"
 * Expected: -15  
 */
static void test_purpose_8()
{
    #define S1    "HELLO"
    #define S2    "world"
    #define RET   -15
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (g_ascii_strcasecmp(S1, S2) != RET){
        TEST_FAIL("g_ascii_strcasecmp: failed", NULL);
    }
    #undef S1
    #undef S2
    #undef RET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strconcat
 * Params: const gchar *string1, ...
 * Returns: gchar*
 * Assertion: Concatenates all of the given strings into one long string. The returned string should be freed when no longer needed.
 * Warning
 * The variable argument list must end with NULL. If you forget the NULL, g_strconcat() will start appending random memory junk to your string.
 *            string1 : The first string to add, which must not be NULL.
 *            ... : a NULL-terminated list of strings to append to the string.
 *            Returns : a newly-allocated string containing all the string arguments. 
 * Params Values: "Hello, ", "LSB"
 * Expected: "Hello, LSB"  
 */
static void test_purpose_9()
{
    #define S1    "Hello, "
    #define S2    "LSB"
    #define RET   "Hello, LSB"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar *s = g_strconcat(S1, S2, NULL);
    if (g_ascii_strcasecmp(s, RET) != 0){
        TEST_FAIL("g_strconcat: failed", NULL);
    }
    
    g_free(s);
    #undef S1
    #undef S2
    #undef RET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strsplit
 * Params: const gchar *string, const gchar *delimiter, gint max_tokens
 * Returns: gchar**
 * Assertion: Splits a string into a maximum of max_tokens pieces, using the given delimiter. If max_tokens is reached, the remainder of string is appended to the last token.
 *            string : a string to split.
 *            delimiter : a string which specifies the places at which to split the string. The delimiter is not included in any of the resulting strings, unless max_tokens is reached.
 *            max_tokens :	the maximum number of pieces to split string into. If this is less than 1, the string is split completely.
 *            Returns : a newly-allocated NULL-terminated array of strings. Use g_strfreev() to free it 
 * Params Values: "Hello, LSB", ",", 5
 * Expected: "Hello"  
 */
static void test_purpose_10()
{
    #define STR    "Hello, LSB"
    #define DELIM  ","
    #define TOKEN  5
    #define RETSTR "Hello"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar **str = g_strsplit(STR, DELIM, TOKEN);
    if (g_ascii_strncasecmp(RETSTR, *str, 5) != 0){
        TEST_FAIL("g_strsplit: failed", NULL);
    }
    g_strfreev(str);
    
    #undef STR
    #undef DELIM
    #undef TOKEN
    #undef RETSTR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strsplit
 * Params: const gchar *string, const gchar *delimiter, gint max_tokens
 * Returns: gchar**
 * Assertion: Splits a string into a maximum of max_tokens pieces, using the given delimiter. If max_tokens is reached, the remainder of string is appended to the last token.
 *            string : a string to split.
 *            delimiter : a string which specifies the places at which to split the string. The delimiter is not included in any of the resulting strings, unless max_tokens is reached.
 *            max_tokens :	the maximum number of pieces to split string into. If this is less than 1, the string is split completely.
 *            Returns : a newly-allocated NULL-terminated array of strings. Use g_strfreev() to free it 
 * Params Values: "Hello, LSB", ",", 3
 * Expected: "Hello"  
 */
static void test_purpose_11()
{
    #define STR    "Hello, LSB"
    #define DELIM  ","
    #define TOKEN  3
    #define RETSTR "Hello"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar **str = g_strsplit(STR, DELIM, TOKEN);
    if (g_ascii_strncasecmp(RETSTR, *str, 5) != 0){
        TEST_FAIL("g_strsplit: failed", NULL);
    }
    g_strfreev(str);
    
    #undef STR
    #undef DELIM
    #undef TOKEN
    #undef RETSTR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strsplit
 * Params: const gchar *string, const gchar *delimiter, gint max_tokens
 * Returns: gchar**
 * Assertion: Splits a string into a maximum of max_tokens pieces, using the given delimiter. If max_tokens is reached, the remainder of string is appended to the last token.
 *            string : a string to split.
 *            delimiter : a string which specifies the places at which to split the string. The delimiter is not included in any of the resulting strings, unless max_tokens is reached.
 *            max_tokens :	the maximum number of pieces to split string into. If this is less than 1, the string is split completely.
 *            Returns : a newly-allocated NULL-terminated array of strings. Use g_strfreev() to free it 
 * Params Values: "Hello, LSB", ",", 6
 * Expected: "Hello"  
 */
static void test_purpose_12()
{
    #define STR    "Hello, LSB"
    #define DELIM  ","
    #define TOKEN  6
    #define RETSTR "Hello"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar **str = g_strsplit(STR, DELIM, TOKEN);
    if (g_ascii_strncasecmp(RETSTR, *str, 5) != 0){
        TEST_FAIL("g_strsplit: failed", NULL);
    }
    g_strfreev(str);
    
    #undef STR
    #undef DELIM
    #undef TOKEN
    #undef RETSTR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strndup
 * Params: const gchar *str, gsize n
 * Returns: gchar*
 * Assertion: Duplicates the first n characters of a string, returning a newly-allocated buffer n + 1 characters long which will always be nul-terminated. If str is less than n characters long the buffer is padded with nuls. If str is NULL it returns NULL. The returned value should be freed when no longer needed.
 *            str : the string to duplicate part of.
 *            n : the maximum number of characters to copy from str.
 *            Returns : a newly-allocated buffer containing the first n characters of str, nul-terminated.
 * Params Values: "Hello, LSB", 2
 * Expected: "He"  
 */
static void test_purpose_13()
{
    #define STR    "Hello, LSB"
    #define SIZE   2
    #define RETSTR "He"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar *str = g_strndup(STR, SIZE);
    if (g_ascii_strcasecmp(str, RETSTR) != 0){
        TEST_FAIL("g_strndup: failed", NULL);
    }
    else if (STR == NULL){
        if (str != NULL){
            TEST_FAIL("g_strndup: failed", NULL);
        }
    }
    else{
        if (SIZE < 10){
            if (cal_length(str) != (SIZE + 1)){
                TEST_FAIL("g_strndup: failed", NULL);
            }
            else{
                if (str[cal_length(str) - 1] != NULL){
                    TEST_FAIL("g_strndup: failed", NULL);
                }
            }
        }
    }
    g_free(str);
    #undef STR
    #undef SIZE
    #undef RETSTR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strndup
 * Params: const gchar *str, gsize n
 * Returns: gchar*
 * Assertion: Duplicates the first n characters of a string, returning a newly-allocated buffer n + 1 characters long which will always be nul-terminated. If str is less than n characters long the buffer is padded with nuls. If str is NULL it returns NULL. The returned value should be freed when no longer needed.
 *            str : the string to duplicate part of.
 *            n : the maximum number of characters to copy from str.
 *            Returns : a newly-allocated buffer containing the first n characters of str, nul-terminated.
 * Params Values: "Hello, LSB", 12
 * Expected: "Hello, LSB"  
 */
static void test_purpose_14()
{
    #define STR    "Hello, LSB"
    #define SIZE   12
    #define RETSTR "Hello, LSB"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar *str = g_strndup(STR, SIZE);
    if (g_ascii_strcasecmp(str, RETSTR) != 0){
        TEST_FAIL("g_strndup: failed", NULL);
    }
    else if (STR == NULL){
        if (str != NULL){
            TEST_FAIL("g_strndup: failed", NULL);
        }
    }
    else{
        if (SIZE < 10){
            if (cal_length(str) != (SIZE + 1)){
                TEST_FAIL("g_strndup: failed", NULL);
            }
            else{
                if (str[cal_length(str) - 1] != NULL){
                    TEST_FAIL("g_strndup: failed", NULL);
                }
            }
        }
    }
    g_free(str);
    #undef STR
    #undef SIZE
    #undef RETSTR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strndup
 * Params: const gchar *str, gsize n
 * Returns: gchar*
 * Assertion: Duplicates the first n characters of a string, returning a newly-allocated buffer n + 1 characters long which will always be nul-terminated. If str is less than n characters long the buffer is padded with nuls. If str is NULL it returns NULL. The returned value should be freed when no longer needed.
 *            str : the string to duplicate part of.
 *            n : the maximum number of characters to copy from str.
 *            Returns : a newly-allocated buffer containing the first n characters of str, nul-terminated.
 * Params Values: NULL, 2
 * Expected: NULL  
 */
static void test_purpose_15()
{
    #define STR    NULL
    #define SIZE   2
    #define RETSTR NULL
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar *str = g_strndup(STR, SIZE);
    if (g_ascii_strcasecmp(str, RETSTR) != 0){
        TEST_FAIL("g_strndup: failed", NULL);
    }
    else if (STR == NULL){
        if (str != NULL){
            TEST_FAIL("g_strndup: failed", NULL);
        }
    }
    else{
        if (SIZE < 10){
            if (cal_length(str) != (SIZE + 1)){
                TEST_FAIL("g_strndup: failed", NULL);
            }
            else{
                if (str[cal_length(str) - 1] != NULL){
                    TEST_FAIL("g_strndup: failed", NULL);
                }
            }
        }
    }
    g_free(str);
    #undef STR
    #undef SIZE
    #undef RETSTR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_snprintf
 * Params: gchar *string, gulong n, gchar const *format, ...
 * Returns: gint
 * Assertion: A safer form of the standard sprintf() function. The output is guaranteed to not exceed n characters (including the terminating nul character), so it is easy to ensure that a buffer overflow cannot occur.
 * The return value of g_snprintf() conforms to the snprintf() function as standardized in ISO C99. Note that this is different from traditional snprintf(), which returns the length of the output string.
 * The format string may contain positional parameters, as specified in the Single Unix Specification.
 *            string : the buffer to hold the output.
 *            n : the maximum number of characters to produce (including the terminating nul character).
 *            format :	a standard printf() format string, but notice string precision pitfalls.
 *            ... : the arguments to insert in the output.
 *            Returns : the number of characters which would be produced if the buffer was large enough.           
 * Params Values: 6, "%s", "Hello, LSB"
 * Expected: "Hello"  
 */
static void test_purpose_16()
{
    #define LEN    6
    #define FORMAT "%s"
    #define STR    "Hello, LSB"
    #define RETSTR "Hello"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar *str = g_new(gchar, 16*sizeof(gchar));
    gint len = g_snprintf(str, LEN, FORMAT, STR);
    if (g_ascii_strcasecmp(str, RETSTR) != 0){
        TEST_FAIL("g_snprintf: failed", NULL);
    }
    else{
        if (len != (cal_length(STR) - 1)){
           TEST_FAIL("g_snprintf: failed", NULL); 
        }
    }
    #undef LEN    
    #undef FORMAT 
    #undef STR    
    #undef RETSTR 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strlcpy
 * Params: gchar *dest, const gchar *src, gsize dest_size
 * Returns: gsize
 * Assertion: Portability wrapper that calls strlcpy() on systems which have it, and emulates strlcpy() otherwise. Copies src to dest; dest is guaranteed to be nul-terminated; src must be nul-terminated; dest_size is the buffer size, not the number of chars to copy. Caveat: strlcpy() is supposedly more secure than strcpy() or strncpy(), but if you really want to avoid screwups, g_strdup() is an even better idea.
 *            dest : destination buffer
 *            src : source buffer
 *            dest_size : length of dest in bytes
 *            Returns : length of src           
 * Params Values: "Hello, LSB", 6
 * Expected: "Hello"  
 */
static void test_purpose_17()
{
    #define SRC     "Hello, LSB"
    #define SIZE    6
    #define RETSTR  "Hello"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    // +1 for NULL termination.
    gchar *dest = g_new(gchar, SIZE + 1);
    gint len = g_strlcpy(dest, SRC, SIZE);
    if (len != 10){
        TEST_FAIL("g_strlcpy: the return length should be 10", NULL);
    }
    else{
        if (g_ascii_strcasecmp(dest, RETSTR) != 0){
            TEST_FAIL("g_strlcpy: the dest string should be %s", RETSTR);
        }
    }
    g_free(dest);
    #undef SRC 
    #undef SIZE    
    #undef RETSTR 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strlcpy
 * Params: gchar *dest, const gchar *src, gsize dest_size
 * Returns: gsize
 * Assertion: Portability wrapper that calls strlcpy() on systems which have it, and emulates strlcpy() otherwise. Copies src to dest; dest is guaranteed to be nul-terminated; src must be nul-terminated; dest_size is the buffer size, not the number of chars to copy. Caveat: strlcpy() is supposedly more secure than strcpy() or strncpy(), but if you really want to avoid screwups, g_strdup() is an even better idea.
 *            dest : destination buffer
 *            src : source buffer
 *            dest_size : length of dest in bytes
 *            Returns : length of src           
 * Params Values: "Hello, LSB", 15
 * Expected: "Hello, LSB"  
 */
static void test_purpose_18()
{
    #define SRC     "Hello, LSB"
    #define SIZE    15
    #define RETSTR  "Hello, LSB"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    // +1 for NULL termination.
    gchar *dest = g_new(gchar, SIZE + 1);
    gint len = g_strlcpy(dest, SRC, SIZE);
    if (len != 10){
        TEST_FAIL("g_strlcpy: the return length should be 10", NULL);
    }
    else{
        if (g_ascii_strcasecmp(dest, RETSTR) != 0){
            TEST_FAIL("g_strlcpy: the dest string should be %s", RETSTR);
        }
    }
    g_free(dest);
    #undef SRC 
    #undef SIZE    
    #undef RETSTR 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strchug
 * Params: gchar *string
 * Returns: gchar*
 * Assertion: Removes leading whitespace from a string, by moving the rest of the characters forward.
 *            string : a string to remove the leading whitespace from.
 *            Returns : string.        
 * Params Values: " Hello, LSB"
 * Expected: "Hello, LSB"  
 */
static void test_purpose_19()
{
    #define STR     " Hello, LSB"
    #define RETSTR  "Hello, LSB"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar *str = g_strdup(STR);
    gchar *retstr = g_strchug(str);
    
    if (g_ascii_strcasecmp(retstr, RETSTR) != 0){
        TEST_FAIL("g_strchug: failed", NULL);
    }
    
    g_free(retstr);
    #undef STR 
    #undef RETSTR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strchomp
 * Params: gchar *string
 * Returns: gchar*
 * Assertion: Removes trailing whitespace from a string.
 *            string : a string to remove the leading whitespace from.
 *            Returns : string.        
 * Params Values: "Hello, LSB "
 * Expected: "Hello, LSB"  
 */
static void test_purpose_20()
{
    #define STR     "Hello, LSB "
    #define RETSTR  "Hello, LSB"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar *str = g_strdup(STR);
    gchar *retstr = g_strchomp(str);
    
    if (g_ascii_strcasecmp(retstr, RETSTR) != 0){
        TEST_FAIL("g_strchomp: failed", NULL);
    }
    
    g_free(retstr);
    #undef STR 
    #undef RETSTR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_ascii_strncasecmp
 * Params: const gchar *s1,const gchar *s2, gsize n
 * Returns: gint
 * Assertion: Compare s1 and s2, ignoring the case of ASCII characters and any characters after the first n in each string.
 * Unlike the BSD strcasecmp() function, this only recognizes standard ASCII letters and ignores the locale, treating all non-ASCII characters as if they are not letters.
 *            s1 :	string to compare with s2.
 *            s2 :	string to compare with s1.
 *            n : number of characters to compare.
 *            Returns : an integer less than, equal to, or greater than zero if the first n bytes of s1 is found, respectively, to be less than, to match, or to be greater than the first n bytes of s2.        
 * Params Values: "Hello, LSB", "Hello, Qiu", 10
 * Expected: -5  
 */
static void test_purpose_21()
{
    #define STR1    "Hello, LSB"
    #define STR2    "Hello, Qiu"
    #define SIZE    10
    #define RETV    -5
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint ret = g_ascii_strncasecmp(STR1, STR2, SIZE);
    if (ret != RETV){
        TEST_FAIL("g_ascii_strncasecmp: failed", NULL);
    }
    
    #undef STR1
    #undef STR2
    #undef SIZE
    #undef RETV
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_ascii_strncasecmp
 * Params: const gchar *s1,const gchar *s2, gsize n
 * Returns: gint
 * Assertion: Compare s1 and s2, ignoring the case of ASCII characters and any characters after the first n in each string.
 * Unlike the BSD strcasecmp() function, this only recognizes standard ASCII letters and ignores the locale, treating all non-ASCII characters as if they are not letters.
 *            s1 :	string to compare with s2.
 *            s2 :	string to compare with s1.
 *            n : number of characters to compare.
 *            Returns : an integer less than, equal to, or greater than zero if the first n bytes of s1 is found, respectively, to be less than, to match, or to be greater than the first n bytes of s2.        
 * Params Values: "FSG", "fsg", 5
 * Expected: 0  
 */
static void test_purpose_22()
{
    #define STR1    "FSG"
    #define STR2    "fsg"
    #define SIZE    5
    #define RETV    0
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint ret = g_ascii_strncasecmp(STR1, STR2, SIZE);
    if (ret != RETV){
        TEST_FAIL("g_ascii_strncasecmp: failed", NULL);
    }
    
    #undef STR1
    #undef STR2
    #undef SIZE
    #undef RETV
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_ascii_strncasecmp
 * Params: const gchar *s1,const gchar *s2, gsize n
 * Returns: gint
 * Assertion: Compare s1 and s2, ignoring the case of ASCII characters and any characters after the first n in each string.
 * Unlike the BSD strcasecmp() function, this only recognizes standard ASCII letters and ignores the locale, treating all non-ASCII characters as if they are not letters.
 *            s1 :	string to compare with s2.
 *            s2 :	string to compare with s1.
 *            n : number of characters to compare.
 *            Returns : an integer less than, equal to, or greater than zero if the first n bytes of s1 is found, respectively, to be less than, to match, or to be greater than the first n bytes of s2.        
 * Params Values: "Hello, Qiu", "Hello, LSB", 8
 * Expected: 5  
 */
static void test_purpose_23()
{
    #define STR1    "Hello, Qiu"
    #define STR2    "Hello, LSB"
    #define SIZE    8
    #define RETV    5
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint ret = g_ascii_strncasecmp(STR1, STR2, SIZE);
    if (ret != RETV){
        TEST_FAIL("g_ascii_strncasecmp: failed", NULL);
    }
    
    #undef STR1
    #undef STR2
    #undef SIZE
    #undef RETV
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strrstr
 * Params: const gchar *haystack, const gchar *needle
 * Returns: gchar*
 * Assertion: Searches the string haystack for the last occurrence of the string needle.
 *            haystack : a nul-terminated string.
 *            needle :	the nul-terminated string to search for.
 *            Returns : a pointer to the found occurrence, or NULL if not found.       
 * Params Values: "Fo1BarFo2BarFo3", "Bar"
 * Expected: "BarFo3"  
 */
static void test_purpose_24()
{
    #define HAYS     "Fo1BarFo2BarFo3"
    #define NEEDLE   "Bar"
    #define RETSTR   "BarFo3"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar *str = g_strrstr (HAYS, NEEDLE);
    if (g_ascii_strcasecmp(str, RETSTR) != 0){
        TEST_FAIL("g_strrstr: failed", NULL);
    }
    
    #undef HAYS
    #undef NEEDLE
    #undef RETSTR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strrstr
 * Params: const gchar *haystack, const gchar *needle
 * Returns: gchar*
 * Assertion: Searches the string haystack for the last occurrence of the string needle.
 *            haystack : a nul-terminated string.
 *            needle :	the nul-terminated string to search for.
 *            Returns : a pointer to the found occurrence, or NULL if not found.       
 * Params Values: "Fo1BarFo2BarFo3", "Bar3"
 * Expected: NULL  
 */
static void test_purpose_25()
{
    #define HAYS     "Fo1BarFo2BarFo3"
    #define NEEDLE   "Bar3"
    #define RETSTR   NULL
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar *str = g_strrstr (HAYS, NEEDLE);
    if (g_ascii_strcasecmp(str, RETSTR) != 0){
        TEST_FAIL("g_strrstr: failed", NULL);
    }
    
    #undef HAYS
    #undef NEEDLE
    #undef RETSTR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strjoinv
 * Params: const gchar *separator, gchar **str_array
 * Returns: gchar*
 * Assertion: Joins a number of strings together to form one long string, with the optional separator inserted between each of them.
 *            separator : a string to insert between each of the strings, or NULL.
 *            str_array : a NULL-terminated array of strings to join.
 *            Returns : a newly-allocated string containing all of the strings joined together, with separator between them.        
 * Params Values: sepatator = " "
 * Expected: "Hello FSG LSB"  
 */
static void test_purpose_26()
{
    #define SEPA    " "
    #define RETV    "Hello FSG LSB" 
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar **str = g_strsplit("Hello,FSG,LSB", ",", 4);
    gchar *retv = g_strjoinv(SEPA, str);
    if (g_ascii_strcasecmp(retv, RETV) != 0){
        TEST_FAIL("g_strjoinv: failed", NULL);
    }    
    g_strfreev(str);
    g_free(retv);
    
    #undef SEPA 
    #undef RETV
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strjoinv
 * Params: const gchar *separator, gchar **str_array
 * Returns: gchar*
 * Assertion: Joins a number of strings together to form one long string, with the optional separator inserted between each of them.
 *            separator : a string to insert between each of the strings, or NULL.
 *            str_array : a NULL-terminated array of strings to join.
 *            Returns : a newly-allocated string containing all of the strings joined together, with separator between them.        
 * Params Values: sepatator = ":"
 * Expected: "Hello:FSG:LSB"  
 */
static void test_purpose_27()
{
    #define SEPA    ":"
    #define RETV    "Hello:FSG:LSB" 
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar **str = g_strsplit("Hello,FSG,LSB", ",", 4);
    gchar *retv = g_strjoinv(SEPA, str);
    if (g_ascii_strcasecmp(retv, RETV) != 0){
        TEST_FAIL("g_strjoinv: failed", NULL);
    }    
    g_strfreev(str);
    g_free(retv);
    
    #undef SEPA 
    #undef RETV
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  g_ascii_tolower & g_ascii_toupper
 * Params: gchar c
 * Returns: gchar
 * Assertion: Convert a character to ASCII lower case. & Convert a character to ASCII upper case.
 *            c : any character.
 *            Returns:  the result of converting c to lower case or upper case. If c is not an ASCII upper case or lower case letter, c is returned unchanged.
 * Params Values: 'C'
 * Expected: Convert correctly  
 */
static void test_purpose_28()
{
    #define CH      'C'
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar retc;
    retc = g_ascii_tolower(CH);
    if ((CH <= 'Z') && (CH >= 'A')){
        if (retc != (CH + ('a' - 'A'))){
            TEST_FAIL("g_ascii_tolower: failed", NULL);
        }
        else{
            retc = g_ascii_toupper(retc);
            if (retc != CH){
                TEST_FAIL("g_ascii_toupper: failed", NULL);
            }
        }
    }
    else{
        if (retc != CH){
            TEST_FAIL("g_ascii_tolower: failed", NULL);
        }
        else{
            retc = g_ascii_toupper(CH);
            if (retc != (CH - ('a' - 'A'))){
                TEST_FAIL("g_ascii_toupper: failed", NULL);
            }
        }
    }
    #undef CH 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strescape
 * Params: const gchar *source, const gchar *exceptions
 * Returns: gchar*
 * Assertion: Escapes the special characters '\b', '\f', '\n', '\r', '\t', '\' and '"' in the string source by inserting a '\' before them. Additionally all characters in the range 0x01-0x1F (everything below SPACE) and in the range 0x7F-0xFF (all non-ASCII chars) are replaced with a '\' followed by their octal representation. Characters supplied in exceptions are not escaped.
 *            source :	a string to escape.
 *            exceptions :	a string of characters not to escape in source.
 *            Returns : a newly-allocated copy of source with certain characters escaped. See above.          
 * Params Values: "abc\\\"\b\f\n\r\t\003\177\234\313", NULL
 * Expected: "abc\\\\\\\"\\b\\f\\n\\r\\t\\003\\177\\234\\313"  
 */
static void test_purpose_29()
{
    #define SRC    "abc\\\"\b\f\n\r\t\003\177\234\313"
    #define EXP    NULL
    #define RETSTR "abc\\\\\\\"\\b\\f\\n\\r\\t\\003\\177\\234\\313"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar *str = g_strescape(SRC, EXP);
    if (strcmp(str, RETSTR) != 0){
        TEST_FAIL("g_strescape: failed", NULL);
    }
    g_free(str);
    
    #undef SRC 
    #undef EXP    
    #undef RETSTR 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strescape
 * Params: const gchar *source, const gchar *exceptions
 * Returns: gchar*
 * Assertion: Escapes the special characters '\b', '\f', '\n', '\r', '\t', '\' and '"' in the string source by inserting a '\' before them. Additionally all characters in the range 0x01-0x1F (everything below SPACE) and in the range 0x7F-0xFF (all non-ASCII chars) are replaced with a '\' followed by their octal representation. Characters supplied in exceptions are not escaped.
 *            source :	a string to escape.
 *            exceptions :	a string of characters not to escape in source.
 *            Returns : a newly-allocated copy of source with certain characters escaped. See above.          
 * Params Values: "abc\\\"\b\f\n\r\t\003\177\234\313", "\n"
 * Expected: "abc\\\\\\\"\\b\\f\n\\r\\t\\003\\177\\234\\313"  
 */
static void test_purpose_30()
{
    #define SRC    "abc\\\"\b\f\n\r\t\003\177\234\313"
    #define EXP    "\n"
    #define RETSTR "abc\\\\\\\"\\b\\f\n\\r\\t\\003\\177\\234\\313"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar *str = g_strescape(SRC, EXP);
    if (strcmp(str, RETSTR) != 0){
        TEST_FAIL("g_strescape: failed", NULL);
    }
    g_free(str);
    
    #undef SRC 
    #undef EXP    
    #undef RETSTR 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strstr_len
 * Params: const gchar *haystack, gssize haystack_len, const gchar *needle
 * Returns: gchar*
 * Assertion: Searches the string haystack for the first occurrence of the string needle, limiting the length of the search to haystack_len.
 *            haystack :	a string.
 *            haystack_len :	the maximum length of haystack.
 *            needle :	the string to search for.
 *            Returns :	a pointer to the found occurrence, or NULL if not found.
 * Params Values: "FooBarFooBarFoo", 6, "Bar"
 * Expected: "BarFooBarFoo"  
 */
static void test_purpose_31()
{
    #define HAYS     "FooBarFooBarFoo"
    #define LEN      6
    #define NEEDLE   "Bar"
    #define RETSTR   "BarFooBarFoo"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (g_ascii_strcasecmp(g_strstr_len(HAYS, LEN, NEEDLE), RETSTR) != 0){
        TEST_FAIL("g_strstr_len: failed", NULL);
    }
    
    #undef HAYS
    #undef LEN
    #undef NEEDLE
    #undef RETSTR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_str_has_suffix
 * Params: const gchar *str, const gchar *suffix
 * Returns: gboolean
 * Assertion: Looks whether the string str ends with suffix.
 *            str : a nul-terminated string.
 *            suffix :	the nul-terminated suffix to look for.
 *            Returns : TRUE if str end with suffix, FALSE otherwise.
 * Params Values: "Hello, LSB", "LSB"
 * Expected: TRUE  
 */
static void test_purpose_32()
{
    #define STR     "Hello, LSB"
    #define SUFFIX  "LSB"
    #define RET     TRUE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (g_str_has_suffix(STR, SUFFIX) != RET){
        TEST_FAIL("g_str_has_suffix: failed", NULL);
    }
    
    #undef STR   
    #undef SUFFIX          
    #undef RET             
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_str_has_suffix
 * Params: const gchar *str, const gchar *suffix
 * Returns: gboolean
 * Assertion: Looks whether the string str ends with suffix.
 *            str : a nul-terminated string.
 *            suffix :	the nul-terminated suffix to look for.
 *            Returns : TRUE if str end with suffix, FALSE otherwise.
 * Params Values: "Hello, LSB", "lsb"
 * Expected: FALSE  
 */
static void test_purpose_33()
{
    #define STR     "Hello, LSB"
    #define SUFFIX  "lsb"
    #define RET     FALSE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (g_str_has_suffix(STR, SUFFIX) != RET){
        TEST_FAIL("g_str_has_suffix: failed", NULL);
    }
    
    #undef STR   
    #undef SUFFIX          
    #undef RET             
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_str_has_prefix
 * Params: const gchar *str, const gchar *prefix
 * Returns: gboolean
 * Assertion: Looks whether the string str begins with prefix.
 *            str : a nul-terminated string.
 *            prefix : the nul-terminated prefix to look for.
 *            Returns : TRUE if str begins with prefix, FALSE otherwise.
 * Params Values: "Hello, LSB", "Hello"
 * Expected: TRUE  
 */
static void test_purpose_34()
{
    #define STR     "Hello, LSB"
    #define PREFIX  "Hello"
    #define RET     TRUE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (g_str_has_prefix(STR, PREFIX) != RET){
        TEST_FAIL("g_str_has_prefix: failed", NULL);
    }
    
    #undef STR   
    #undef PREFIX          
    #undef RET             
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_str_has_prefix
 * Params: const gchar *str, const gchar *prefix
 * Returns: gboolean
 * Assertion: Looks whether the string str begins with prefix.
 *            str : a nul-terminated string.
 *            prefix : the nul-terminated prefix to look for.
 *            Returns : TRUE if str begins with prefix, FALSE otherwise.
 * Params Values: "Hello, LSB", "hellO"
 * Expected: FALSE  
 */
static void test_purpose_35()
{
    #define STR     "Hello, LSB"
    #define PREFIX  "hellO"
    #define RET     FALSE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (g_str_has_prefix(STR, PREFIX) != RET){
        TEST_FAIL("g_str_has_prefix: failed", NULL);
    }
    
    #undef STR   
    #undef PREFIX          
    #undef RET             
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strdelimit
 * Params: gchar *string, const gchar *delimiters, gchar new_delimiter
 * Returns: gchar*
 * Assertion: Converts any delimiter characters in string to new_delimiter. Any characters in string which are found in delimiters are changed to the new_delimiter character. Modifies string in place, and returns string itself, not a copy. The return value is to allow nesting such as g_ascii_strup (g_strdelimit (str, "abc", '?')).
 *            string :	the string to convert.
 *            delimiters :	a string containing the current delimiters, or NULL to use the standard delimiters defined in G_STR_DELIMITERS.
 *            new_delimiter : the new delimiter character.
 *            Returns : string.
 * Params Values: "1>2>3", ">", '<'
 * Expected: "1<2<3"  
 */
static void test_purpose_36()
{
    #define STR         "1>2>3"
    #define DELIM       ">"
    #define NEW_DELIM   '<'
    #define NEW_STR     "1<2<3"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar *str = g_strdup(STR);
    if (strcmp(g_strdelimit(str, DELIM, NEW_DELIM), NEW_STR) != 0){
        TEST_FAIL("g_strdelimit: failed", NULL);
    }
    g_free(str);
    
    #undef STR      
    #undef DELIM    
    #undef NEW_DELIM
    #undef NEW_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strdelimit
 * Params: gchar *string, const gchar *delimiters, gchar new_delimiter
 * Returns: gchar*
 * Assertion: Converts any delimiter characters in string to new_delimiter. Any characters in string which are found in delimiters are changed to the new_delimiter character. Modifies string in place, and returns string itself, not a copy. The return value is to allow nesting such as g_ascii_strup (g_strdelimit (str, "abc", '?')).
 *            string :	the string to convert.
 *            delimiters :	a string containing the current delimiters, or NULL to use the standard delimiters defined in G_STR_DELIMITERS.
 *            new_delimiter : the new delimiter character.
 *            Returns : string.
 * Params Values: "1>2.3-4", NULL, '<'
 * Expected: "1<2<3<4"  
 */
static void test_purpose_37()
{
    #define STR         "1>2.3-4"
    #define DELIM       NULL
    #define NEW_DELIM   '<'
    #define NEW_STR     "1<2<3<4"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar *str = g_strdup(STR);
    if (strcmp(g_strdelimit(str, DELIM, NEW_DELIM), NEW_STR) != 0){
        TEST_FAIL("g_strdelimit: failed", NULL);
    }
    g_free(str);
    
    #undef STR      
    #undef DELIM    
    #undef NEW_DELIM
    #undef NEW_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_stpcpy
 * Params: gchar *dest, const char *src
 * Returns: gchar*
 * Assertion: Copies a nul-terminated string into the dest buffer, include the trailing nul, and return a pointer to the trailing nul byte. This is useful for concatenating multiple strings together without having to repeatedly scan for the end.
 *            dest : destination buffer.
 *            src : source string.
 *            Returns : a pointer to trailing nul byte.
 * Params Values: "Hello, LSB"
 * Expected: NULL  
 */
static void test_purpose_38()
{
    #define SRC     "Hello, LSB"
    #define RETS    NULL
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar *dest = g_new(gchar, sizeof(SRC));
    if (*(g_stpcpy(dest, SRC)) != RETS){
        TEST_FAIL("g_stpcpy: failed", NULL);
    }
    else{
        if (strcmp(dest, SRC) != 0){
            TEST_FAIL("g_stpcpy: failed", NULL);
        }
    }
    
    g_free(dest);
    
    #undef SRC 
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_ascii_xdigit_value
 * Params: gchar c
 * Returns: gint
 * Assertion: Determines the numeric value of a character as a hexidecimal digit. Differs from g_unichar_xdigit_value() because it takes a char, so there's no worry about sign extension if characters are signed.
 *            c : an ASCII character.
 *            Returns : If c is a hex digit (according to g_ascii_isxdigit()), its numeric value. Otherwise, -1.
 * Params Values: 'F'
 * Expected: 15  
 */
static void test_purpose_39()
{
    #define CH     'F'
    #define RETC   15
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (g_ascii_xdigit_value(CH) != RETC){
        TEST_FAIL("g_ascii_xdigit_value: failed", NULL);
    }
    
    #undef CH 
    #undef RETC
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_ascii_xdigit_value
 * Params: gchar c
 * Returns: gint
 * Assertion: Determines the numeric value of a character as a hexidecimal digit. Differs from g_unichar_xdigit_value() because it takes a char, so there's no worry about sign extension if characters are signed.
 *            c : an ASCII character.
 *            Returns : If c is a hex digit (according to g_ascii_isxdigit()), its numeric value. Otherwise, -1.
 * Params Values: 20
 * Expected: -1  
 */
static void test_purpose_40()
{
    #define CH     20
    #define RETC   -1
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (g_ascii_xdigit_value(CH) != RETC){
        TEST_FAIL("g_ascii_xdigit_value: failed", NULL);
    }
    
    #undef CH 
    #undef RETC
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_ascii_strup
 * Params: const gchar *str, gssize len
 * Returns: gchar*
 * Assertion: Converts all lower case ASCII letters to upper case ASCII letters.
 *            str : a string.
 *            len : length of str in bytes, or -1 if str is nul-terminated.
 *            Returns : a newly allocated string, with all the lower case characters in str converted to upper case, with semantics that exactly match g_ascii_toupper(). (Note that this is unlike the old g_strup(), which modified the string in place.)
 * Params Values: "Hello, lsb", -1
 * Expected: "HELLO, LSB"  
 */
static void test_purpose_41()
{
    #define STR   "Hello, lsb"
    #define LEN   -1
    #define RETS  "HELLO, LSB"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (strcmp(g_ascii_strup(STR, LEN), RETS) != 0){
        TEST_FAIL("g_ascii_strup: failed", NULL);
    }
    
    #undef STR 
    #undef LEN
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_ascii_strup
 * Params: const gchar *str, gssize len
 * Returns: gchar*
 * Assertion: Converts all lower case ASCII letters to upper case ASCII letters.
 *            str : a string.
 *            len : length of str in bytes, or -1 if str is nul-terminated.
 *            Returns : a newly allocated string, with all the lower case characters in str converted to upper case, with semantics that exactly match g_ascii_toupper(). (Note that this is unlike the old g_strup(), which modified the string in place.)
 * Params Values: "Hello, lsb", 3
 * Expected: "HEL"  
 */
static void test_purpose_42()
{
    #define STR   "Hello, lsb"
    #define LEN   3
    #define RETS  "HEL"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (strcmp(g_ascii_strup(STR, LEN), RETS) != 0){
        TEST_FAIL("g_ascii_strup: failed", NULL);
    }
    
    #undef STR 
    #undef LEN
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strsplit_set
 * Params: const gchar *string, const gchar *delimiters, gint max_tokens
 * Returns: gchar**
 * Assertion: Splits string into a number of tokens not containing any of the characters in delimiter. A token is the (possibly empty) longest string that does not contain any of the characters in delimiters. If max_tokens is reached, the remainder is appended to the last token.
 * Note that this function works on bytes not characters, so it can't be used to delimit UTF-8 strings for anything but ASCII characters.
 *            string :	 The string to be tokenized
 *            delimiters :	A nul-terminated string containing bytes that are used to split the string.
 *            max_tokens :	The maximum number of tokens to split string into. If this is less than 1, the string is split completely
 *            Returns :	a newly-allocated NULL-terminated array of strings. Use g_strfreev() to free it.
 * Params Values: "", ",/", 0
 * Expected: NULL  
 */
static void test_purpose_43()
{
    #define STR   ""
    #define DELI  ",/"
    #define TOKEN 0
    #define RETV  NULL
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (!strv_check(g_strsplit_set(STR, DELI, TOKEN), RETV)){
        TEST_FAIL("g_strsplit_set: failed", NULL);
    }
    
    #undef STR 
    #undef DELI
    #undef TOKEN
    #undef RETV
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strsplit_set
 * Params: const gchar *string, const gchar *delimiters, gint max_tokens
 * Returns: gchar**
 * Assertion: Splits string into a number of tokens not containing any of the characters in delimiter. A token is the (possibly empty) longest string that does not contain any of the characters in delimiters. If max_tokens is reached, the remainder is appended to the last token.
 * Note that this function works on bytes not characters, so it can't be used to delimit UTF-8 strings for anything but ASCII characters.
 *            string :	 The string to be tokenized
 *            delimiters :	A nul-terminated string containing bytes that are used to split the string.
 *            max_tokens :	The maximum number of tokens to split string into. If this is less than 1, the string is split completely
 *            Returns :	a newly-allocated NULL-terminated array of strings. Use g_strfreev() to free it.
 * Params Values: ":def/ghi:", ":/", -1
 * Expected: "", "def", "ghi", "", NULL  
 */
static void test_purpose_44()
{
    #define STR   ":def/ghi:"
    #define DELI  ":/"
    #define TOKEN -1
    #define RETV  "", "def", "ghi", "", NULL
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (!strv_check(g_strsplit_set(STR, DELI, TOKEN), RETV)){
        TEST_FAIL("g_strsplit_set: failed", NULL);
    }
    
    #undef STR 
    #undef DELI
    #undef TOKEN
    #undef RETV
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strnfill
 * Params: gsize length, gchar fill_char
 * Returns: gchar*
 * Assertion: Creates a new string length characters long filled with fill_char. The returned string should be freed when no longer needed.
 *            length :	the length of the new string.
 *            fill_char : the character to fill the string with.
 *            Returns : a newly-allocated string filled the fill_char.
 * Params Values: 5, 'l'
 * Expected: "lllll"  
 */
static void test_purpose_45()
{
    #define LEN   5
    #define CH    'l'
    #define RETS  "lllll"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (strcmp(g_strnfill(LEN, CH), RETS) != 0){
        TEST_FAIL("g_strnfill: failed", NULL);
    }
    
    #undef LEN 
    #undef CH
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strlcat
 * Params: gchar *dest, const gchar *src, gsize dest_size
 * Returns: gsize
 * Assertion: Portability wrapper that calls strlcat() on systems which have it, and emulates it otherwise. Appends nul-terminated src string to dest, guaranteeing nul-termination for dest. The total size of dest won't exceed dest_size. Caveat: this is supposedly a more secure alternative to strcat() or strncat(), but for real security g_strconcat() is harder to mess up.
 *            dest : destination buffer, already containing one nul-terminated string
 *            src : source buffer
 *            dest_size : length of dest buffer in bytes (not length of existing string inside dest)
 *            Returns : length of src plus initial length of string in dest
 * Params Values: "Hello, LSB", 11  
 */
static void test_purpose_46()
{
    #define SRC   "Hello, LSB"
    #define LEN   11
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar *dest = g_new(gchar, LEN);
    dest[0] = '\0';
    if (g_strlcat(dest, SRC, LEN) != LEN - 1){
        TEST_FAIL("g_strlcat: failed", NULL);
    }
    else{
        if (dest[LEN - 1] != '\0'){
            TEST_FAIL("g_strlcat: failed", NULL);
        }
    }
    
    #undef SRC
    #undef LEN 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_ascii_strdown
 * Params: const gchar *str, gssize len
 * Returns: gchar*
 * Assertion: Converts all upper case ASCII letters to lower case ASCII letters.
 *            str : a string.
 *            len : length of str in bytes, or -1 if str is nul-terminated.
 *            Returns :  a newly-allocated string, with all the upper case characters in str converted to lower case, with semantics that exactly match g_ascii_tolower(). (Note that this is unlike the old g_strdown(), which modified the string in place.)
 * Params Values: "HELLO, lSB", -1
 * Expected: "hello, lsb"  
 */
static void test_purpose_47()
{
    #define STR   "HELLO, lSB"
    #define LEN   -1
    #define RETS  "hello, lsb"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (strcmp(g_ascii_strdown(STR, LEN), RETS) != 0){
        TEST_FAIL("g_ascii_strdown: failed", NULL);
    }
    
    #undef STR 
    #undef LEN
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_ascii_strdown
 * Params: const gchar *str, gssize len
 * Returns: gchar*
 * Assertion: Converts all upper case ASCII letters to lower case ASCII letters.
 *            str : a string.
 *            len : length of str in bytes, or -1 if str is nul-terminated.
 *            Returns :  a newly-allocated string, with all the upper case characters in str converted to lower case, with semantics that exactly match g_ascii_tolower(). (Note that this is unlike the old g_strdown(), which modified the string in place.)
 * Params Values: "hELLO, LSB", 3
 * Expected: "hel"  
 */
static void test_purpose_48()
{
    #define STR   "hELLO, LSB"
    #define LEN   3
    #define RETS  "hel"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (strcmp(g_ascii_strdown(STR, LEN), RETS) != 0){
        TEST_FAIL("g_ascii_strdown: failed", NULL);
    }
    
    #undef STR 
    #undef LEN
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strreverse
 * Params: gchar *string
 * Returns: gchar*
 * Assertion: Reverses all of the bytes in a string. For example, g_strreverse ("abcdef") will result in "fedcba".
 * Note that g_strreverse() doesn't work on UTF-8 strings containing multibyte characters. For that purpose, use g_utf8_strreverse().
 *           string : the string to reverse.
 *           Returns : the same pointer passed in as string.
 * Params Values: "HeLLo"
 * Expected: "oLLeH"  
 */
static void test_purpose_49()
{
    #define STR   "HeLLo"
    #define RETS  "oLLeH"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar *str = g_strdup(STR);
    if (strcmp(g_strreverse(str), RETS) != 0){
        TEST_FAIL("g_strreverse: failed", NULL);
    }
    g_free(str);
    #undef STR 
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strcompress
 * Params: const gchar *source
 * Returns: gchar*
 * Assertion: Replaces all escaped characters with their one byte equivalent. It does the reverse conversion of g_strescape().
 *            source :	a string to compress.
 *            Returns : a newly-allocated copy of source with all escaped character compressed.
 * Params Values: "abc\\\\\\\"\\b\\f\\n\\r\\t\\003\\177\\234\\313"
 * Expected: "abc\\\"\b\f\n\r\t\003\177\234\313"  
 */
static void test_purpose_50()
{
    #define SRC    "abc\\\\\\\"\\b\\f\\n\\r\\t\\003\\177\\234\\313"
    #define RETSTR "abc\\\"\b\f\n\r\t\003\177\234\313"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar *str = g_strcompress(SRC);
    if (strcmp(str, RETSTR) != 0){
        TEST_FAIL("g_strcompress: failed", NULL);
    }
    g_free(str);
    
    #undef SRC
    #undef RETSTR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_sprintf
 * Params: gchar *string, gchar const *format, ...
 * Returns: gint
 * Assertion: An implementation of the standard sprintf() function which supports positional parameters, as specified in the Single Unix Specification.
 *            string :	the buffer to hold the output.
 *            format :	a standard printf() format string, but notice string precision pitfalls.
 *            ... : the arguments to insert in the output.
 *            Returns : the number of characters printed.
 * Params Values: "%s%d", "lsb", 1
 * Expected: "lsb1"  
 */
static void test_purpose_51()
{
    #define FORMAT    "%s%d"
    #define SRC1      "lsb"
    #define SRC2      1
    #define RETSTR    "lsb1"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar *str = g_new(gchar, sizeof(RETSTR));
    if (g_sprintf(str, FORMAT, SRC1, SRC2) != sizeof(RETSTR) - 1){
        TEST_FAIL("g_sprintf: length failed", NULL);
    }
    else{
        if (strcmp(str, RETSTR) != 0){
            TEST_FAIL("g_sprintf: string failed", NULL);
        }
    }
    g_free(str);
    
    #undef FORMAT
    #undef SRC1
    #undef SRC2
    #undef RETSTR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strerror
 * Params: gint errnum
 * Returns: const gchar*
 * Assertion: Returns a string corresponding to the given error code, e.g. "no such process". This function is included since not all platforms support the strerror() function.
 *            errnum : the system error number. See the standard C errno documentation.
 *            Returns : a string describing the error code. If the error code is unknown, it returns "unknown error (<code>)". The string can only be used until the next call to g_strerror(). 
 * Params Values: E2BIG
 * Expected: "argument list too long"  
 */
static void test_purpose_52()
{
    #define ERRNUM    E2BIG
    #define RETS      "argument list too long"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    // save locale
    int ret = 0;
    char *cur_locale = NULL;
    cur_locale = setlocale(LC_ALL, "C");
    ret = g_ascii_strcasecmp(RETS, g_strerror(ERRNUM));
    setlocale(LC_ALL, cur_locale);
    if (ret != 0) {
        TEST_FAIL("g_strerror: error num %d", ERRNUM);
    }
    #undef ERRNUM
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strerror
 * Params: gint errnum
 * Returns: const gchar*
 * Assertion: Returns a string corresponding to the given error code, e.g. "no such process". This function is included since not all platforms support the strerror() function.
 *            errnum : the system error number. See the standard C errno documentation.
 *            Returns : a string describing the error code. If the error code is unknown, it returns "unknown error (<code>)". The string can only be used until the next call to g_strerror(). 
 * Params Values: EACCES
 * Expected: "permission denied"  
 */
static void test_purpose_53()
{
    #define ERRNUM    EACCES
    #define RETS      "permission denied"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    // save locale
    int ret = 0;
    char *cur_locale = NULL;
    cur_locale = setlocale(LC_ALL, "C");
    ret = g_ascii_strcasecmp(RETS, g_strerror(ERRNUM));
    setlocale(LC_ALL, cur_locale);
    if (ret != 0) {
        TEST_FAIL("g_strerror: error num %d", ERRNUM);
    }
    #undef ERRNUM
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strerror
 * Params: gint errnum
 * Returns: const gchar*
 * Assertion: Returns a string corresponding to the given error code, e.g. "no such process". This function is included since not all platforms support the strerror() function.
 *            errnum : the system error number. See the standard C errno documentation.
 *            Returns : a string describing the error code. If the error code is unknown, it returns "unknown error (<code>)". The string can only be used until the next call to g_strerror(). 
 * Params Values: EADDRINUSE
 * Expected: "address already in use"  
 */
static void test_purpose_54()
{
    #define ERRNUM    EADDRINUSE
    #define RETS      "address already in use"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    // save locale
    int ret = 0;
    char *cur_locale = NULL;
    cur_locale = setlocale(LC_ALL, "C");
    ret = g_ascii_strcasecmp(RETS, g_strerror(ERRNUM));
    setlocale(LC_ALL, cur_locale);
    if (ret != 0) {
        TEST_FAIL("g_strerror: error num %d", ERRNUM);
    }
    #undef ERRNUM
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strerror
 * Params: gint errnum
 * Returns: const gchar*
 * Assertion: Returns a string corresponding to the given error code, e.g. "no such process". This function is included since not all platforms support the strerror() function.
 *            errnum : the system error number. See the standard C errno documentation.
 *            Returns : a string describing the error code. If the error code is unknown, it returns "unknown error (<code>)". The string can only be used until the next call to g_strerror(). 
 * Params Values: EADDRNOTAVAIL
 * Expected: "cannot assign requested address"  
 */
static void test_purpose_55()
{
    #define ERRNUM    EADDRNOTAVAIL
    #define RETS      "cannot assign requested address"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    // save locale
    int ret = 0;
    char *cur_locale = NULL;
    cur_locale = setlocale(LC_ALL, "C");
    ret = g_ascii_strcasecmp(RETS, g_strerror(ERRNUM));
    setlocale(LC_ALL, cur_locale);
    if (ret != 0) {
        TEST_FAIL("g_strerror: error num %d", ERRNUM);
    }
    #undef ERRNUM
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strerror
 * Params: gint errnum
 * Returns: const gchar*
 * Assertion: Returns a string corresponding to the given error code, e.g. "no such process". This function is included since not all platforms support the strerror() function.
 *            errnum : the system error number. See the standard C errno documentation.
 *            Returns : a string describing the error code. If the error code is unknown, it returns "unknown error (<code>)". The string can only be used until the next call to g_strerror(). 
 * Params Values: EADV
 * Expected: "advertise error"  
 */
static void test_purpose_56()
{
    #define ERRNUM    EADV
    #define RETS      "advertise error"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    // save locale
    int ret = 0;
    char *cur_locale = NULL;
    cur_locale = setlocale(LC_ALL, "C");
    ret = g_ascii_strcasecmp(RETS, g_strerror(ERRNUM));
    setlocale(LC_ALL, cur_locale);
    if (ret != 0) {
        TEST_FAIL("g_strerror: error num %d", ERRNUM);
    }
    #undef ERRNUM
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strerror
 * Params: gint errnum
 * Returns: const gchar*
 * Assertion: Returns a string corresponding to the given error code, e.g. "no such process". This function is included since not all platforms support the strerror() function.
 *            errnum : the system error number. See the standard C errno documentation.
 *            Returns : a string describing the error code. If the error code is unknown, it returns "unknown error (<code>)". The string can only be used until the next call to g_strerror(). 
 * Params Values: EAFNOSUPPORT
 * Expected: "address family not supported by protocol"  
 */
static void test_purpose_57()
{
    #define ERRNUM    EAFNOSUPPORT
    #define RETS      "address family not supported by protocol"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    // save locale
    int ret = 0;
    char *cur_locale = NULL;
    cur_locale = setlocale(LC_ALL, "C");
    ret = g_ascii_strcasecmp(RETS, g_strerror(ERRNUM));
    setlocale(LC_ALL, cur_locale);
    if (ret != 0) {
        TEST_FAIL("g_strerror: error num %d", ERRNUM);
    }
    #undef ERRNUM
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strerror
 * Params: gint errnum
 * Returns: const gchar*
 * Assertion: Returns a string corresponding to the given error code, e.g. "no such process". This function is included since not all platforms support the strerror() function.
 *            errnum : the system error number. See the standard C errno documentation.
 *            Returns : a string describing the error code. If the error code is unknown, it returns "unknown error (<code>)". The string can only be used until the next call to g_strerror(). 
 * Params Values: EAGAIN
 * Expected: "Resource temporarily unavailable"  
 */
static void test_purpose_58()
{
    #define ERRNUM    EAGAIN
    #define RETS      "Resource temporarily unavailable"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    // save locale
    int ret = 0;
    char *cur_locale = NULL;
    cur_locale = setlocale(LC_ALL, "C");
    ret = g_ascii_strcasecmp(RETS, g_strerror(ERRNUM));
    setlocale(LC_ALL, cur_locale);
    if (ret != 0) {
        TEST_FAIL("g_strerror: error num %d", ERRNUM);
    }
    #undef ERRNUM
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_ascii_strtod
 * Params: const gchar *nptr, gchar **endptr
 * Returns: gdouble
 * Assertion: Converts a string to a gdouble value. This function behaves like the standard strtod() function does in the C locale. It does this without actually changing the current locale, since that would not be thread-safe.
 *            nptr :  the string to convert to a numeric value.
 *            endptr : if non-NULL, it returns the character after the last character used in the conversion.
 *            Returns : the gdouble value. 
 * Params Values: 3.141593
 * Expected: 3.141593  
 */
static void test_purpose_59()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gdouble gd = g_ascii_strtod("3.141593", NULL);
    if ((gd > 3.141593) || (gd < 3.141593)){
        TEST_FAIL("g_ascii_strtod: %f", gd);
    }
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_ascii_dtostr
 * Params: gchar *buffer, gint buf_len, gdouble d
 * Returns: gchar*
 * Assertion: Converts a gdouble to a string, using the '.' as decimal point.
 *            buffer :  A buffer to place the resulting string in
 *            buf_len : The length of the buffer.
 *            d : The gdouble to convert
 *            Returns : The pointer to the buffer with the converted string. 
 * Params Values: 3.141593
 * Expected: 3.141593  
 */
static void test_purpose_60()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar *buf = g_new(gchar, 1024 * sizeof(gchar));
    buf = g_ascii_dtostr(buf, 1024, 3.1415923);
    if (strncmp(buf, "3.1415923", 9) != 0){
        TEST_FAIL("g_ascii_dtostr: failed", NULL);
    }
    g_free(buf);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_strtod
 * Params: const gchar *nptr, gchar **endptr
 * Returns: gdouble
 * Assertion: Converts a string to a gdouble value. It calls the standard strtod() function to handle the conversion, but if the string is not completely converted it attempts the conversion again with g_ascii_strtod(), and returns the best match. 
 *            nptr :  the string to convert to a numeric value.
 *            endptr : if non-NULL, it returns the character after the last character used in the conversion.
 *            Returns : the gdouble value. 
 * Params Values: 3.141593
 * Expected: 3.141593  
 */
static void test_purpose_61()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gdouble gd = g_strtod("3.141593", NULL);
    if ((gd > 3.141593) || (gd < 3.141593)){
        TEST_FAIL("g_strtod: %f", gd);
    }
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_ascii_formatd
 * Params: gchar *buffer, gint buf_len, const gchar *format, gdouble d
 * Returns: gchar*
 * Assertion: Converts a gdouble to a string, using the '.' as decimal point. To format the number you pass in a printf()-style format string. Allowed conversion specifiers are 'e', 'E', 'f', 'F', 'g' and 'G'. 
 *                buffer :	A buffer to place the resulting string in
 *                buf_len : The length of the buffer.
 *                format :	The printf()-style format to use for the code to use for converting.
 *                d : The gdouble to convert
 *                Returns : The pointer to the buffer with the converted string.
 * Params Values: 3141.5923
 * Expected: "3.141592e+03"  
 */
static void test_purpose_62()
{
    #define DG    3141.5923
    #define RETS  "3.141592e+03"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar *buf = g_new(gchar, 1024*sizeof(gchar));
    buf = g_ascii_formatd(buf, 1024, "%e", DG);
    if (strcmp(buf, RETS) != 0){
        TEST_FAIL("g_ascii_formatd: %s", buf);
    }
    g_free(buf);
    #undef DG
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for StringUtil ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {test_purpose_52, 1},
    {test_purpose_53, 1},
    {test_purpose_54, 1},
    {test_purpose_55, 1},
    {test_purpose_56, 1},
    {test_purpose_57, 1},
    {test_purpose_58, 1},
    {test_purpose_59, 1},
    {test_purpose_60, 1},
    {test_purpose_61, 1},
    {test_purpose_62, 1},
    {NULL,0}
};
