/*
 * pango_font methods tests
 * Testing pango_font methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
struct _PangoFontMetrics
{
  guint ref_count;

  int ascent;
  int descent;
  int approximate_char_width;
  int approximate_digit_width;
  int underline_position;
  int underline_thickness;
  int strikethrough_position;
  int strikethrough_thickness;
};

int struc_cmp (char *str1,char *str2,int size)
{
    int i;
    for (i = 0;i < size;i++)
        if (str1[i] != str2[i])
            return 0;    
    return 1;
}


/*
 * Name: pango_font_metrics_unref
 * Params: PangoFontMetrics *metrics
 * Returns: void 
 * Assertion: Decreases the reference count of a font metrics structure. 
 *     If the result is zero, frees the structure and any associated memory.
 * Params Values: matrix
 * Expected: decreases the reference count of font matrix matrix by 1 
 *   
 */
static void test_purpose_1()
{
    #define MATRIX matrix
    
    PangoFontDescription *font_desc;
    PangoContext *context_new;
    PangoFont *font_new;
    PangoFontMap* font_ft2_map;
    PangoFontMetrics *matrix;
    
    guint ref_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new ft2 font map.*/
    font_ft2_map = pango_ft2_font_map_new();
    
    /*Create a new context from the new created ft2 font map.*/
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    
    /*Get the font description of the created context.*/
    font_desc = pango_context_get_font_description(context_new);
    
    /*Load the font in the font map.*/ 
    font_new = pango_font_map_load_font(font_ft2_map,context_new,font_desc);
    matrix = pango_context_get_metrics(context_new,font_desc,pango_language_from_string("en"));
    
    /*Increase the refernence number of matrix.*/
    matrix = pango_font_metrics_ref(matrix);
    ref_num = matrix->ref_count;
    
    /*Decease the reference number of matrix.*/
    pango_font_metrics_unref(MATRIX);
        
    /*g_printf("After unref,the reference number is %d\n",matrix->ref_count);*/
    
    /*If the reference num is not changed as wanted,test fail.*/    
    if (ref_num != MATRIX->ref_count+1)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
        pango_font_metrics_unref(matrix);
        pango_font_description_free(font_desc);
        g_object_unref(font_new);
        return;
    }
            
    pango_font_description_free(font_desc);
    pango_font_metrics_unref(matrix);
    g_object_unref(font_new);
    g_object_unref(font_ft2_map);
    
    #undef MATRIX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_font_get_metrics
 * Params: PangoFont *font, PangoLanguage *language
 * Returns: a PangoFontMetrics object. The caller must call pango_font_metrics_unref() when finished using the object.
 * Assertion: Gets overall metric information for a font. 
 *     Since the metrics may be substantially different for different scripts, 
 *     a language tag can be provided to indicate that the metrics should be retrieved that correspond to the script(s) used by that language.
 * Params Values: font_new,pango_language_from_string("en") 
 * Expected: font metrics for script with language tag "en" 
 *   
 */
static void test_purpose_2()
{
    #define FONT font_new
    #define LANGUAGE pango_language_from_string("en")
    
    PangoFontDescription *font_desc;
    PangoContext *context_new;
    PangoFont *font_new;
    PangoFontMap* font_ft2_map;
    PangoFontMetrics *metrix = NULL;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /* To create the new context.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    
    /*Get font description of the new created context.*/
    font_desc = pango_context_get_font_description(context_new);
    font_new = pango_font_map_load_font(font_ft2_map,context_new,font_desc);
    
    /*
    * Get the overall metric information for the font used,
    *     and the reference count number is also increased by 1!
    */
    metrix = pango_font_get_metrics(FONT,LANGUAGE);
    if (metrix == NULL){
        TEST_FAIL(get_not_created_msg(), NULL);
    }
    
    /*Decrease the reference count number of matrix.*/
    pango_font_metrics_unref(metrix);
    
    
    pango_font_description_free(font_desc);
    pango_font_metrics_unref(metrix);
    g_object_unref(font_new);
    g_object_unref(font_ft2_map);
        
    #undef FONT
    #undef LANGUAGE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_font_get_metrics
 * Params: PangoFont *font, PangoLanguage *language
 * Returns: a PangoFontMetrics object. The caller must call pango_font_metrics_unref() when finished using the object.
 * Assertion: Gets overall metric information for a font. 
 *     Since the metrics may be substantially different for different scripts, 
 *     a language tag can be provided to indicate that the metrics should be retrieved that correspond to the script(s) used by that language.
 * Params Values: font_new,pango_language_from_string("chn") 
 * Expected: font metrics for script with language tag "chn" 
 *   
 */
static void test_purpose_3()
{
    #define FONT font_new
    #define LANGUAGE pango_language_from_string("chn")
    
    PangoFontDescription *font_desc;
    PangoContext *context_new;
    PangoFont *font_new;
    PangoFontMap* font_ft2_map;
    PangoFontMetrics *metrix = NULL;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /* To create the new context.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    
    /*Get font description of the new created context.*/
    font_desc = pango_context_get_font_description(context_new);
    font_new = pango_font_map_load_font(font_ft2_map,context_new,font_desc);
    
    /*
    * Get the overall metric information for the font used,
    *     and the reference count number is also increased by 1!
    */
    metrix = pango_font_get_metrics(FONT,LANGUAGE);
    if (metrix == NULL){
        TEST_FAIL(get_not_created_msg(), NULL);
    }
    
    /*Decrease the reference count number of matrix.*/
    pango_font_metrics_unref(metrix);
    
    
    pango_font_description_free(font_desc);
    pango_font_metrics_unref(metrix);
    g_object_unref(font_new);
    g_object_unref(font_ft2_map);
        
    #undef FONT
    #undef LANGUAGE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_font_find_shaper
 * Params: PangoFont *font, PangoLanguage *language,guint32 ch
 * Returns: the best matching shaper.
 * Assertion: Finds the best matching shaper for a font for a particular language tag and character point.
 * Params Values: font_new,pango_panguage_from_string("en"),"A"
 * Expected: The best matching shaper
 *   
 */
static void test_purpose_4()
{
    #define FONT font_new
    #define LANGUAGE pango_language_from_string("en")
    #define CHAR (guint32)'A'
    
    PangoItem     *item;
    PangoGlyphString * glyphs;
    
    PangoFontDescription *font_desc;
    PangoContext *context_new;
    PangoFont *font_new;
    PangoFontMap* font_ft2_map;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    glyphs = pango_glyph_string_new();
    item = pango_item_new();
    
    /*To create the new context.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    font_desc = pango_context_get_font_description(context_new);
    font_new = pango_font_map_load_font(font_ft2_map,context_new,font_desc);
    
    /*Initialize the shape engine value of PangoAnalysis.*/
    item->analysis.shape_engine = NULL;
    
    /*Find the best matching shaper of the given string.*/
    item->analysis.shape_engine = pango_font_find_shaper(FONT,LANGUAGE,CHAR);
    
    /*Verify that the shape engine is found.*/
    if (item->analysis.shape_engine == NULL)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    pango_glyph_string_free(glyphs);
    pango_item_free(item);
    pango_font_description_free(font_desc);
    g_object_unref(font_new);
    g_object_unref(font_ft2_map);
    
    #undef FONT
    #undef LANGUAGE
    #undef CHAR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_font_find_shaper
 * Params: PangoFont *font, PangoLanguage *language,guint32 ch
 * Returns: the best matching shaper.
 * Assertion: Finds the best matching shaper for a font for a particular language tag and character point.
 * Params Values: font_new,pango_panguage_from_string("en"),"A"
 * Expected: The best matching shaper
 *   
 */
static void test_purpose_5()
{
    #define FONT font_new
    #define LANGUAGE pango_language_from_string("en")
    #define CHAR (guint32)'&'
    
    PangoItem     *item;
    PangoGlyphString * glyphs;
    
    PangoFontDescription *font_desc;
    PangoContext *context_new;
    PangoFont *font_new;
    PangoFontMap* font_ft2_map;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    glyphs = pango_glyph_string_new();
    item = pango_item_new();
    
    /*To create the new context.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    font_desc = pango_context_get_font_description(context_new);
    font_new = pango_font_map_load_font(font_ft2_map,context_new,font_desc);
    
    /*Initialize the shape engine value of PangoAnalysis.*/
    item->analysis.shape_engine = NULL;
    
    /*Find the best matching shaper of the given string.*/
    item->analysis.shape_engine = pango_font_find_shaper(FONT,LANGUAGE,CHAR);
    
    /*Verify that the shape engine is found.*/
    if (item->analysis.shape_engine == NULL)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    pango_glyph_string_free(glyphs);
    pango_item_free(item);
    pango_font_description_free(font_desc);
    g_object_unref(font_new);
    g_object_unref(font_ft2_map);
    
    #undef FONT
    #undef LANGUAGE
    #undef CHAR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_font_find_shaper
 * Params: PangoFont *font, PangoLanguage *language,guint32 ch
 * Returns: the best matching shaper.
 * Assertion: Finds the best matching shaper for a font for a particular language tag and character point.
 * Params Values: font_new,pango_panguage_from_string("en"),"A"
 * Expected: The best matching shaper
 *   
 */
static void test_purpose_6()
{
    #define FONT font_new
    #define LANGUAGE pango_language_from_string("en")
    #define CHAR (guint32)'$'
    
    PangoItem     *item;
    PangoGlyphString * glyphs;
    
    PangoFontDescription *font_desc;
    PangoContext *context_new;
    PangoFont *font_new;
    PangoFontMap* font_ft2_map;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    glyphs = pango_glyph_string_new();
    item = pango_item_new();
    
    /*To create the new context.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    font_desc = pango_context_get_font_description(context_new);
    font_new = pango_font_map_load_font(font_ft2_map,context_new,font_desc);
    
    /*Initialize the shape engine value of PangoAnalysis.*/
    item->analysis.shape_engine = NULL;
    
    /*Find the best matching shaper of the given string.*/
    item->analysis.shape_engine = pango_font_find_shaper(FONT,LANGUAGE,CHAR);
    
    /*Verify that the shape engine is found.*/
    if (item->analysis.shape_engine == NULL)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    pango_glyph_string_free(glyphs);
    pango_item_free(item);
    pango_font_description_free(font_desc);
    g_object_unref(font_new);
    g_object_unref(font_ft2_map);
    
    #undef FONT
    #undef LANGUAGE
    #undef CHAR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_font_describe
 * Params: PangoFont *font
 * Returns: a newly-allocated PangoFontDescription object.
 * Assertion: Returns a description of the font.
 * Params Values: font_new,PANGO_WEIGHT_NORMAL
 * Expected: The description of the font,with weight PANGO_WEIGHT_NORMAL
 *   
 */
static void test_purpose_7()
{
    #define FONT font_new
    #define WEIGHT PANGO_WEIGHT_NORMAL
    
    PangoFontDescription *font_desc = NULL;
    PangoFontDescription *font_desc_org = NULL;
    PangoFontDescription *desc_new = NULL;
    PangoContext *context_new;
    PangoFont *font_new;
    PangoFontMap* font_ft2_map;
    PangoWeight weight;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    /*To create the new context.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    
    /*Get font description of the context.*/
    font_desc_org = pango_context_get_font_description(context_new);
    
    /*Create a new font description and copy the original font description to it.*/
    font_desc = pango_font_description_new();
    font_desc = pango_font_description_copy(font_desc_org);
    
    /*Set new attribute of the font description.*/
    pango_font_description_set_weight(font_desc,WEIGHT);
    
    /*Set font description for the context.*/
    pango_context_set_font_description(context_new,font_desc);
    
    font_new = pango_font_map_load_font(font_ft2_map,context_new,font_desc);
    
    /*Get the description of the font.*/
    desc_new = pango_font_describe(FONT);
    
    /*Get weight of the new font description.*/
    weight = pango_font_description_get_weight(desc_new);
     
    /*Weight of the font is not WEIGHT,test fail.*/
    if (weight != WEIGHT)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(font_new);
    g_object_unref(font_ft2_map);
    pango_font_description_free(font_desc);
    
    #undef WEIGHT
    #undef FONT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_font_describe
 * Params: PangoFont *font
 * Returns: a newly-allocated PangoFontDescription object.
 * Assertion: Returns a description of the font.
 * Params Values: font_new,PANGO_WEIGHT_BOLD
 * Expected: The description of the font,with weight PANGO_WEIGHT_BOLD
 *   
 */
static void test_purpose_8()
{
    #define FONT font_new
    #define WEIGHT PANGO_WEIGHT_BOLD
    
    PangoFontDescription *font_desc = NULL;
    PangoFontDescription *font_desc_org = NULL;
    PangoFontDescription *desc_new = NULL;
    PangoContext *context_new;
    PangoFont *font_new;
    PangoFontMap* font_ft2_map;
    PangoWeight weight;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    /*To create the new context.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    
    /*Get font description of the context.*/
    font_desc_org = pango_context_get_font_description(context_new);
    
    /*Create a new font description and copy the original font description to it.*/
    font_desc = pango_font_description_new();
    font_desc = pango_font_description_copy(font_desc_org);
    
    /*Set new attribute of the font description.*/
    pango_font_description_set_weight(font_desc,WEIGHT);
    
    /*Set font description for the context.*/
    pango_context_set_font_description(context_new,font_desc);
    
    font_new = pango_font_map_load_font(font_ft2_map,context_new,font_desc);
    
    /*Get the description of the font.*/
    desc_new = pango_font_describe(FONT);
    
    /*Get weight of the new font description.*/
    weight = pango_font_description_get_weight(desc_new);
     
    /*Weight of the font is not WEIGHT,test fail.*/
    if (weight != WEIGHT)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(font_new);
    g_object_unref(font_ft2_map);
    pango_font_description_free(font_desc);
    
    #undef WEIGHT
    #undef FONT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_font_map_load_font
 * Params: pango_font_map_load_font
 * Returns: the font loaded, or NULL if no font matched.
 * Assertion: Load the font in the fontmap that is the closest match for desc.
 * Params Values: font_ft2_map,context_new,font_desc
 * Expected: the font in the fontmap that is closest match for font_desc 
 *   
 */
static void test_purpose_9()
{
    #define FONT_MAP font_ft2_map
    #define CONTEXT context_new
    #define DESC font_desc
    
    PangoFontDescription *font_desc;
    PangoFontDescription *desc_new;
    PangoContext *context_new;
    PangoFont *font_new = NULL;
    PangoFontMap* font_ft2_map;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create the new context.*/ 
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    font_desc = pango_context_get_font_description(context_new);
    
    /*Load font from the font map.*/
    font_new = pango_font_map_load_font(FONT_MAP,CONTEXT,font_desc);
    
    /* Font is not loaded,test fail.*/
    if (font_new == NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    /*Change the description of the font.*/
    desc_new = pango_font_description_new();
    /*desc_new = pango_font_description_copy(font_desc);*/
    pango_font_description_set_family(desc_new,"My_font_family");
    
    /*Load font from the font map.*/
    font_new = pango_font_map_load_font(FONT_MAP,CONTEXT,desc_new);
    
    if (font_new == NULL)
        {
            TEST_FAIL("Font map load failed!\n",NULL);
            g_object_unref(font_ft2_map);
            pango_font_description_free(font_desc);
            return;
        }
    
    g_object_unref(font_new);
    g_object_unref(font_ft2_map);
    pango_font_description_free(font_desc);
    pango_font_description_free(desc_new);
    
    #undef FONT_MAP
    #undef CONTEXT
    #undef DESC
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_font_map_load_font
 * Params: pango_font_map_load_font
 * Returns: the font loaded, or NULL if no font matched.
 * Assertion: Load the font in the fontmap that is the closest match for desc.
 * Params Values: font_ft2_map,context_new,desc_new
 * Expected: the font in the fontmap that is closest match for desc_new 
 *   
 */
static void test_purpose_10()
{
    #define FONT_MAP font_ft2_map
    #define CONTEXT context_new
    #define DESC desc_new
    
    PangoFontDescription *font_desc;
    PangoFontDescription *desc_new;
    PangoContext *context_new;
    PangoFont *font_new = NULL;
    PangoFontMap* font_ft2_map;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create the new context.*/ 
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    font_desc = pango_context_get_font_description(context_new);
    
    /*Load font from the font map.*/
    font_new = pango_font_map_load_font(FONT_MAP,CONTEXT,font_desc);
    
    /* Font is not loaded,test fail.*/
    if (font_new == NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    /*Change the description of the font.*/
    desc_new = pango_font_description_new();
    /*desc_new = pango_font_description_copy(font_desc);*/
    pango_font_description_set_family(desc_new,"My_font_family");
    
    /*Load font from the font map.*/
    font_new = pango_font_map_load_font(FONT_MAP,CONTEXT,desc_new);
    
    if (font_new == NULL)
        {
            TEST_FAIL("Font map load failed!\n",NULL);
            g_object_unref(font_ft2_map);
            pango_font_description_free(font_desc);
            return;
        }
    
    g_object_unref(font_new);
    g_object_unref(font_ft2_map);
    pango_font_description_free(font_desc);
    pango_font_description_free(desc_new);
    
    #undef FONT_MAP
    #undef CONTEXT
    #undef DESC
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for pango_font ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {NULL,0}
};
