/*
 * GtkListStore methods tests
 * Testing GtkListStore methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
#include <float.h>
va_list var_args;

void global_var_args_init (int prav_param, ...)
{
    va_start (var_args, prav_param);
}

global_valist (GtkListStore* list_store, GtkTreeIter* iter, ...)
{
    va_list list;

    va_start (list, iter);
    gtk_list_store_set_valist (list_store, iter, list);
    va_end (list);
}


/*
 * Name: gtk_list_store_new
 * Params: void
 * Returns: GtkListStore*
 * Assertion: Creates a new list store as with n_columns columns each of the types passed in.
 * Params Values: 2,G_TYPE_DOUBLE,G_TYPE_CHAR
 * Expected: GtkListStore*  
 */
static void test_purpose_1()
{
    #define COLUMNS_N_AND_TYPES 2,G_TYPE_DOUBLE,G_TYPE_CHAR
    #define COLUMNS_TYPES "G_TYPE_DOUBLE,G_TYPE_CHAR"
    
    GtkListStore* store;
    gchar* tp;
    GtkWidget *tree_view;
    gint i = 0;
    gchar* columns_types = calloc (1, strlen (COLUMNS_TYPES) + 1);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    memcpy (columns_types, COLUMNS_TYPES, strlen (COLUMNS_TYPES));
    store = gtk_list_store_new (COLUMNS_N_AND_TYPES);
    
    if (!store) 
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    tp = (char*)strtok (columns_types, ",");
    
    while (tp != NULL)
    {  
        GType col_type = gtk_tree_model_get_column_type (GTK_TREE_MODEL (store), i++);
    
        if (col_type == G_TYPE_CHAR)
        {
            if (strcmp (tp, "G_TYPE_CHAR"))
            {
                TEST_FAIL ("col_type is %d, tp is %s", col_type, tp);
            }
        } else if (col_type == G_TYPE_DOUBLE) {
            if (strcmp (tp, "G_TYPE_DOUBLE"))
            {
                TEST_FAIL ("col_type is %d, tp is %s", col_type, tp);
            }
        } else if (col_type == G_TYPE_BOOLEAN) {
            if (strcmp (tp, "G_TYPE_BOOLEAN"))
            {
                TEST_FAIL ("col_type is %d, tp is %s", col_type, tp);
            }
        } else {
            TEST_FAIL ("unexpected col_type, please extend the test", NULL);
        }
    
        tp = (char*) strtok (NULL, ",");
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef COLUMNS_N_AND_TYPES
    #undef COLUMNS_TYPES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_new
 * Params: void
 * Returns: GtkListStore*
 * Assertion: Creates a new list store as with n_columns columns each of the types passed in.
 * Params Values: 8,G_TYPE_DOUBLE,G_TYPE_CHAR,G_TYPE_DOUBLE,G_TYPE_CHAR,G_TYPE_DOUBLE,G_TYPE_CHAR,G_TYPE_DOUBLE,G_TYPE_CHAR
 * Expected: GtkListStore*  
 */
static void test_purpose_2()
{
    #define COLUMNS_N_AND_TYPES 8,G_TYPE_DOUBLE,G_TYPE_CHAR,G_TYPE_DOUBLE,G_TYPE_CHAR,G_TYPE_DOUBLE,G_TYPE_CHAR,G_TYPE_DOUBLE,G_TYPE_CHAR
    #define COLUMNS_TYPES "G_TYPE_DOUBLE,G_TYPE_CHAR,G_TYPE_DOUBLE,G_TYPE_CHAR,G_TYPE_DOUBLE,G_TYPE_CHAR,G_TYPE_DOUBLE,G_TYPE_CHAR"
    
    GtkListStore* store;
    gchar* tp;
    GtkWidget *tree_view;
    gint i = 0;
    gchar* columns_types = calloc (1, strlen (COLUMNS_TYPES) + 1);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    memcpy (columns_types, COLUMNS_TYPES, strlen (COLUMNS_TYPES));
    store = gtk_list_store_new (COLUMNS_N_AND_TYPES);
    
    if (!store) 
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    tp = (char*)strtok (columns_types, ",");
    
    while (tp != NULL)
    {  
        GType col_type = gtk_tree_model_get_column_type (GTK_TREE_MODEL (store), i++);
    
        if (col_type == G_TYPE_CHAR)
        {
            if (strcmp (tp, "G_TYPE_CHAR"))
            {
                TEST_FAIL ("col_type is %d, tp is %s", col_type, tp);
            }
        } else if (col_type == G_TYPE_DOUBLE) {
            if (strcmp (tp, "G_TYPE_DOUBLE"))
            {
                TEST_FAIL ("col_type is %d, tp is %s", col_type, tp);
            }
        } else if (col_type == G_TYPE_BOOLEAN) {
            if (strcmp (tp, "G_TYPE_BOOLEAN"))
            {
                TEST_FAIL ("col_type is %d, tp is %s", col_type, tp);
            }
        } else {
            TEST_FAIL ("unexpected col_type, please extend the test", NULL);
        }
    
        tp = (char*) strtok (NULL, ",");
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef COLUMNS_N_AND_TYPES
    #undef COLUMNS_TYPES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_new
 * Params: void
 * Returns: GtkListStore*
 * Assertion: Creates a new list store as with n_columns columns each of the types passed in.
 * Params Values: 8,G_TYPE_DOUBLE,G_TYPE_CHAR,G_TYPE_DOUBLE,G_TYPE_BOOLEAN,G_TYPE_DOUBLE,G_TYPE_CHAR,G_TYPE_DOUBLE,G_TYPE_CHAR
 * Expected: GtkListStore*  
 */
static void test_purpose_3()
{
    #define COLUMNS_N_AND_TYPES 8,G_TYPE_DOUBLE,G_TYPE_CHAR,G_TYPE_DOUBLE,G_TYPE_BOOLEAN,G_TYPE_DOUBLE,G_TYPE_CHAR,G_TYPE_DOUBLE,G_TYPE_CHAR
    #define COLUMNS_TYPES "G_TYPE_DOUBLE,G_TYPE_CHAR,G_TYPE_DOUBLE,G_TYPE_BOOLEAN,G_TYPE_DOUBLE,G_TYPE_CHAR,G_TYPE_DOUBLE,G_TYPE_CHAR"
    
    GtkListStore* store;
    gchar* tp;
    GtkWidget *tree_view;
    gint i = 0;
    gchar* columns_types = calloc (1, strlen (COLUMNS_TYPES) + 1);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    memcpy (columns_types, COLUMNS_TYPES, strlen (COLUMNS_TYPES));
    store = gtk_list_store_new (COLUMNS_N_AND_TYPES);
    
    if (!store) 
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    tp = (char*)strtok (columns_types, ",");
    
    while (tp != NULL)
    {  
        GType col_type = gtk_tree_model_get_column_type (GTK_TREE_MODEL (store), i++);
    
        if (col_type == G_TYPE_CHAR)
        {
            if (strcmp (tp, "G_TYPE_CHAR"))
            {
                TEST_FAIL ("col_type is %d, tp is %s", col_type, tp);
            }
        } else if (col_type == G_TYPE_DOUBLE) {
            if (strcmp (tp, "G_TYPE_DOUBLE"))
            {
                TEST_FAIL ("col_type is %d, tp is %s", col_type, tp);
            }
        } else if (col_type == G_TYPE_BOOLEAN) {
            if (strcmp (tp, "G_TYPE_BOOLEAN"))
            {
                TEST_FAIL ("col_type is %d, tp is %s", col_type, tp);
            }
        } else {
            TEST_FAIL ("unexpected col_type, please extend the test", NULL);
        }
    
        tp = (char*) strtok (NULL, ",");
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef COLUMNS_N_AND_TYPES
    #undef COLUMNS_TYPES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_new
 * Params: void
 * Returns: GtkListStore*
 * Assertion:  As an example, gtk_tree_store_new (3, G_TYPE_INT, G_TYPE_STRING, GDK_TYPE_PIXBUF); will create a new GtkListStore with three columns, of type int, string and GdkPixbuf respectively.
 * Params Values: 3, G_TYPE_INT, G_TYPE_STRING, GDK_TYPE_PIXBUF
 * Expected: GtkListStore* with three columns, of type int, string and GDkPixbuf respectively  
 */
static void test_purpose_4()
{
    GtkListStore* store;
    GtkWidget *tree_view;
    GType col_type;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    store = gtk_list_store_new (3, G_TYPE_INT, G_TYPE_STRING, GDK_TYPE_PIXBUF);
    
    if (!store) 
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    col_type = gtk_tree_model_get_column_type (GTK_TREE_MODEL (store), 0);
    if (col_type != G_TYPE_INT)
    {
        TEST_FAIL ("col_type is %d, should be %d", col_type, G_TYPE_INT);
    }
    
    col_type = gtk_tree_model_get_column_type (GTK_TREE_MODEL (store), 1);
    if (col_type != G_TYPE_STRING)
    {
        TEST_FAIL ("col_type is %d, should be %d", col_type, G_TYPE_STRING);
    }
    
    col_type = gtk_tree_model_get_column_type (GTK_TREE_MODEL (store), 2);
    if (col_type != GDK_TYPE_PIXBUF)
    {
        TEST_FAIL ("col_type is %d, should be %d", col_type, GDK_TYPE_PIXBUF);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_set_column_types
 * Params: GtkListStore *list_store, gint n_columns, GType *types
 * Returns: void
 * Assertion: This function is meant primarily for GObjects that inherit from GtkListStore, and should only be used when constructing a new GtkListStore.
 * Params Values: a newly created GtkListStore*, 1, "gchar"
 * Expected: void  
 */
static void test_purpose_5()
{
    #define COLUMNS_N_AND_TYPES 2, G_TYPE_DOUBLE,G_TYPE_CHAR
    #define COLUMNS_TYPES "G_TYPE_DOUBLE,G_TYPE_CHAR"
    #define NEW_COLUMNS_N 1
    #define NEW_COLUMNS_TYPES "gchar"
    #define NEW_COLUMNS_TYPES_STR "G_TYPE_CHAR"
    
    GtkListStore* store;
    GtkWidget *tree_view;
    gchar* tp;
    gint i = 0;
    GType new_types[NEW_COLUMNS_N];
    gchar* columns_types = calloc (1, strlen (COLUMNS_TYPES) + 1);
    gchar* new_columns_types = calloc (1, strlen (NEW_COLUMNS_TYPES_STR) + 1);
    gchar* new_real_columns_types = calloc (1, strlen (NEW_COLUMNS_TYPES_STR) + 1);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    memcpy (new_columns_types, NEW_COLUMNS_TYPES, strlen (NEW_COLUMNS_TYPES_STR));
    memcpy (new_real_columns_types, NEW_COLUMNS_TYPES_STR, strlen (NEW_COLUMNS_TYPES_STR));
    
    store = gtk_list_store_new (COLUMNS_N_AND_TYPES);
    if (!store) 
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    tp = (char*)strtok (new_columns_types, ",");
    for (i = 0; tp != NULL && i <= NEW_COLUMNS_N; i++)
    {  
        new_types [i] = g_type_from_name (tp);
        tp = (char*) strtok (NULL, ",");
    }
    
    gtk_list_store_set_column_types (store, NEW_COLUMNS_N, &new_types[0]);
    
    tp = (char*)strtok (new_real_columns_types, ",");
    for (i = 0; tp != NULL; i++)
    {  
        GType col_type 
            = gtk_tree_model_get_column_type (GTK_TREE_MODEL (store), i);
    
        if (col_type == G_TYPE_CHAR)
        {
            if (strcmp (tp, "G_TYPE_CHAR"))
            {
                TEST_FAIL ("i = %d. col_type is %d, tp is %s", 
                           i - 1, col_type, tp);
            }
        } else if (col_type == G_TYPE_DOUBLE) {
            if (strcmp (tp, "G_TYPE_DOUBLE"))
            {
                TEST_FAIL ("i = %d, col_type is %d, tp is %s", 
                           i - 1, col_type, tp);
            }
        } else if (col_type == G_TYPE_BOOLEAN) {
            if (strcmp (tp, "G_TYPE_BOOLEAN"))
            {
                TEST_FAIL ("i = %d, col_type is %d, tp is %s", 
                           i - 1, col_type, tp);
            }
        } else {
            TEST_FAIL ("unexpected col_type, please extend the test", NULL);
        }
    
        tp = (char*) strtok (NULL, ",");
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef COLUMNS_N_AND_TYPES
    #undef COLUMNS_TYPES
    #undef NEW_COLUMNS_N
    #undef NEW_COLUMNS_TYPES
    #undef NEW_COLUMNS_TYPES_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_set_column_types
 * Params: GtkListStore *list_store, gint n_columns, GType *types
 * Returns: void
 * Assertion: This function is meant primarily for GObjects that inherit from GtkListStore, and should only be used when constructing a new GtkListStore.
 * Params Values: a newly created GtkListStore*, 2, "gchar,gdouble"
 * Expected: void  
 */
static void test_purpose_6()
{
    #define COLUMNS_N_AND_TYPES 2, G_TYPE_DOUBLE,G_TYPE_CHAR
    #define COLUMNS_TYPES "G_TYPE_DOUBLE,G_TYPE_CHAR"
    #define NEW_COLUMNS_N 2
    #define NEW_COLUMNS_TYPES "gchar,gdouble"
    #define NEW_COLUMNS_TYPES_STR "G_TYPE_CHAR,G_TYPE_DOUBLE"
    
    GtkListStore* store;
    GtkWidget *tree_view;
    gchar* tp;
    gint i = 0;
    GType new_types[NEW_COLUMNS_N];
    gchar* columns_types = calloc (1, strlen (COLUMNS_TYPES) + 1);
    gchar* new_columns_types = calloc (1, strlen (NEW_COLUMNS_TYPES_STR) + 1);
    gchar* new_real_columns_types = calloc (1, strlen (NEW_COLUMNS_TYPES_STR) + 1);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    memcpy (new_columns_types, NEW_COLUMNS_TYPES, strlen (NEW_COLUMNS_TYPES_STR));
    memcpy (new_real_columns_types, NEW_COLUMNS_TYPES_STR, strlen (NEW_COLUMNS_TYPES_STR));
    
    store = gtk_list_store_new (COLUMNS_N_AND_TYPES);
    if (!store) 
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    tp = (char*)strtok (new_columns_types, ",");
    for (i = 0; tp != NULL && i <= NEW_COLUMNS_N; i++)
    {  
        new_types [i] = g_type_from_name (tp);
        tp = (char*) strtok (NULL, ",");
    }
    
    gtk_list_store_set_column_types (store, NEW_COLUMNS_N, &new_types[0]);
    
    tp = (char*)strtok (new_real_columns_types, ",");
    for (i = 0; tp != NULL; i++)
    {  
        GType col_type 
            = gtk_tree_model_get_column_type (GTK_TREE_MODEL (store), i);
    
        if (col_type == G_TYPE_CHAR)
        {
            if (strcmp (tp, "G_TYPE_CHAR"))
            {
                TEST_FAIL ("i = %d. col_type is %d, tp is %s", 
                           i - 1, col_type, tp);
            }
        } else if (col_type == G_TYPE_DOUBLE) {
            if (strcmp (tp, "G_TYPE_DOUBLE"))
            {
                TEST_FAIL ("i = %d, col_type is %d, tp is %s", 
                           i - 1, col_type, tp);
            }
        } else if (col_type == G_TYPE_BOOLEAN) {
            if (strcmp (tp, "G_TYPE_BOOLEAN"))
            {
                TEST_FAIL ("i = %d, col_type is %d, tp is %s", 
                           i - 1, col_type, tp);
            }
        } else {
            TEST_FAIL ("unexpected col_type, please extend the test", NULL);
        }
    
        tp = (char*) strtok (NULL, ",");
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef COLUMNS_N_AND_TYPES
    #undef COLUMNS_TYPES
    #undef NEW_COLUMNS_N
    #undef NEW_COLUMNS_TYPES
    #undef NEW_COLUMNS_TYPES_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_set_column_types
 * Params: GtkListStore *list_store, gint n_columns, GType *types
 * Returns: void
 * Assertion: This function is meant primarily for GObjects that inherit from GtkListStore, and should only be used when constructing a new GtkListStore.
 * Params Values: a newly created GtkListStore*, 3, "gchar,gdouble,gboolean"
 * Expected: void  
 */
static void test_purpose_7()
{
    #define COLUMNS_N_AND_TYPES 2, G_TYPE_DOUBLE,G_TYPE_CHAR
    #define COLUMNS_TYPES "G_TYPE_DOUBLE,G_TYPE_CHAR"
    #define NEW_COLUMNS_N 3
    #define NEW_COLUMNS_TYPES "gchar,gdouble,gboolean"
    #define NEW_COLUMNS_TYPES_STR "G_TYPE_CHAR,G_TYPE_DOUBLE,G_TYPE_BOOLEAN"
    
    GtkListStore* store;
    GtkWidget *tree_view;
    gchar* tp;
    gint i = 0;
    GType new_types[NEW_COLUMNS_N];
    gchar* columns_types = calloc (1, strlen (COLUMNS_TYPES) + 1);
    gchar* new_columns_types = calloc (1, strlen (NEW_COLUMNS_TYPES_STR) + 1);
    gchar* new_real_columns_types = calloc (1, strlen (NEW_COLUMNS_TYPES_STR) + 1);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    memcpy (new_columns_types, NEW_COLUMNS_TYPES, strlen (NEW_COLUMNS_TYPES_STR));
    memcpy (new_real_columns_types, NEW_COLUMNS_TYPES_STR, strlen (NEW_COLUMNS_TYPES_STR));
    
    store = gtk_list_store_new (COLUMNS_N_AND_TYPES);
    if (!store) 
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    tp = (char*)strtok (new_columns_types, ",");
    for (i = 0; tp != NULL && i <= NEW_COLUMNS_N; i++)
    {  
        new_types [i] = g_type_from_name (tp);
        tp = (char*) strtok (NULL, ",");
    }
    
    gtk_list_store_set_column_types (store, NEW_COLUMNS_N, &new_types[0]);
    
    tp = (char*)strtok (new_real_columns_types, ",");
    for (i = 0; tp != NULL; i++)
    {  
        GType col_type 
            = gtk_tree_model_get_column_type (GTK_TREE_MODEL (store), i);
    
        if (col_type == G_TYPE_CHAR)
        {
            if (strcmp (tp, "G_TYPE_CHAR"))
            {
                TEST_FAIL ("i = %d. col_type is %d, tp is %s", 
                           i - 1, col_type, tp);
            }
        } else if (col_type == G_TYPE_DOUBLE) {
            if (strcmp (tp, "G_TYPE_DOUBLE"))
            {
                TEST_FAIL ("i = %d, col_type is %d, tp is %s", 
                           i - 1, col_type, tp);
            }
        } else if (col_type == G_TYPE_BOOLEAN) {
            if (strcmp (tp, "G_TYPE_BOOLEAN"))
            {
                TEST_FAIL ("i = %d, col_type is %d, tp is %s", 
                           i - 1, col_type, tp);
            }
        } else {
            TEST_FAIL ("unexpected col_type, please extend the test", NULL);
        }
    
        tp = (char*) strtok (NULL, ",");
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef COLUMNS_N_AND_TYPES
    #undef COLUMNS_TYPES
    #undef NEW_COLUMNS_N
    #undef NEW_COLUMNS_TYPES
    #undef NEW_COLUMNS_TYPES_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_set_column_types
 * Params: GtkListStore *list_store, gint n_columns, GType *types
 * Returns: void
 * Assertion: This function is meant primarily for GObjects that inherit from GtkListStore, and should only be used when constructing a new GtkListStore.
 * Params Values: a newly created GtkListStore*, 2, "gchar,gboolean"
 * Expected: void  
 */
static void test_purpose_8()
{
    #define COLUMNS_N_AND_TYPES 3, G_TYPE_DOUBLE,G_TYPE_CHAR, G_TYPE_INT
    #define COLUMNS_TYPES "G_TYPE_DOUBLE,G_TYPE_CHAR,G_TYPE_INT"
    #define NEW_COLUMNS_N 2
    #define NEW_COLUMNS_TYPES "gchar,gboolean"
    #define NEW_COLUMNS_TYPES_STR "G_TYPE_CHAR,G_TYPE_BOOLEAN"
    
    GtkListStore* store;
    GtkWidget *tree_view;
    gchar* tp;
    gint i = 0;
    GType new_types[NEW_COLUMNS_N];
    gchar* columns_types = calloc (1, strlen (COLUMNS_TYPES) + 1);
    gchar* new_columns_types = calloc (1, strlen (NEW_COLUMNS_TYPES_STR) + 1);
    gchar* new_real_columns_types = calloc (1, strlen (NEW_COLUMNS_TYPES_STR) + 1);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    memcpy (new_columns_types, NEW_COLUMNS_TYPES, strlen (NEW_COLUMNS_TYPES_STR));
    memcpy (new_real_columns_types, NEW_COLUMNS_TYPES_STR, strlen (NEW_COLUMNS_TYPES_STR));
    
    store = gtk_list_store_new (COLUMNS_N_AND_TYPES);
    if (!store) 
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    tp = (char*)strtok (new_columns_types, ",");
    for (i = 0; tp != NULL && i <= NEW_COLUMNS_N; i++)
    {  
        new_types [i] = g_type_from_name (tp);
        tp = (char*) strtok (NULL, ",");
    }
    
    gtk_list_store_set_column_types (store, NEW_COLUMNS_N, &new_types[0]);
    
    tp = (char*)strtok (new_real_columns_types, ",");
    for (i = 0; tp != NULL; i++)
    {  
        GType col_type 
            = gtk_tree_model_get_column_type (GTK_TREE_MODEL (store), i);
    
        if (col_type == G_TYPE_CHAR)
        {
            if (strcmp (tp, "G_TYPE_CHAR"))
            {
                TEST_FAIL ("i = %d. col_type is %d, tp is %s", 
                           i - 1, col_type, tp);
            }
        } else if (col_type == G_TYPE_DOUBLE) {
            if (strcmp (tp, "G_TYPE_DOUBLE"))
            {
                TEST_FAIL ("i = %d, col_type is %d, tp is %s", 
                           i - 1, col_type, tp);
            }
        } else if (col_type == G_TYPE_BOOLEAN) {
            if (strcmp (tp, "G_TYPE_BOOLEAN"))
            {
                TEST_FAIL ("i = %d, col_type is %d, tp is %s", 
                           i - 1, col_type, tp);
            }
        } else {
            TEST_FAIL ("unexpected col_type, please extend the test", NULL);
        }
    
        tp = (char*) strtok (NULL, ",");
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef COLUMNS_N_AND_TYPES
    #undef COLUMNS_TYPES
    #undef NEW_COLUMNS_N
    #undef NEW_COLUMNS_TYPES
    #undef NEW_COLUMNS_TYPES_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_remove
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: void
 * Assertion: Removes the given row from the list store.
 * Params Values: newly created GtkListStore*, uninitialized iter
 * Expected: void
 * 
 * Name: gtk_list_store_remove
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: void
 * Assertion: After being removed, iter is set to be the next valid row, or invalidated if it pointed to the last row in list_store.
 * Params Values: newly created GtkTreeModel*, uninitialized iter
 * Expected: void  
 */
static void test_purpose_9()
{
    #define N_ROWS 2
    #define ROW_NUM 0
    #define UINT_VALUE 53184995
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GValue next_val = {0,};
    GValue val = {0,};
    guint uint_value;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_value_init (&next_val, G_TYPE_UINT);
    g_value_set_uint (&next_val, UINT_VALUE);
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        if (i == ROW_NUM)
        {
            saved_iter = iter;
        };
        if (i == (ROW_NUM + 1))
        {
            gtk_list_store_set_value (list_store, &iter, 0, &next_val);
        };
    }
    gtk_list_store_remove (list_store, &saved_iter); 
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &saved_iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != UINT_VALUE)
    {
        TEST_FAIL ("gtk_list_store_remove () set iter in iter with value = %i, instead of %i.", uint_value, UINT_VALUE); 
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef ROW_NUM
    #undef UINT_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_remove
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: void
 * Assertion: Removes the given row from the list store.
 * Params Values: newly created GtkListStore*, uninitialized iter
 * Expected: void
 * 
 * Name: gtk_list_store_remove
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: void
 * Assertion: After being removed, iter is set to be the next valid row, or invalidated if it pointed to the last row in list_store.
 * Params Values: newly created GtkTreeModel*, uninitialized iter
 * Expected: void  
 */
static void test_purpose_10()
{
    #define N_ROWS 11
    #define ROW_NUM 7
    #define UINT_VALUE 53184995
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GValue next_val = {0,};
    GValue val = {0,};
    guint uint_value;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_value_init (&next_val, G_TYPE_UINT);
    g_value_set_uint (&next_val, UINT_VALUE);
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        if (i == ROW_NUM)
        {
            saved_iter = iter;
        };
        if (i == (ROW_NUM + 1))
        {
            gtk_list_store_set_value (list_store, &iter, 0, &next_val);
        };
    }
    gtk_list_store_remove (list_store, &saved_iter); 
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &saved_iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != UINT_VALUE)
    {
        TEST_FAIL ("gtk_list_store_remove () set iter in iter with value = %i, instead of %i.", uint_value, UINT_VALUE); 
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef ROW_NUM
    #undef UINT_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_insert
 * Params: GtkListStore *list_store, GtkTreeIter *iter, gint position
 * Returns: void
 * Assertion: Creates a new row at position.  
 * Params Values: newly created GtkListStore*, uninitialized iter, 0
 * Expected: void
 * 
 * Name: gtk_list_store_insert
 * Params: GtkListStore *list_store, GtkTreeIter *iter, gint position
 * Returns: void
 * Assertion: iter will be changed to point to this new row. 
 * Params Values: newly created GtkListStore*, uninitialized iter, 0
 * Expected: void
 * 
 * Name: gtk_list_store_insert
 * Params: GtkListStore *list_store, GtkTreeIter *iter, gint position
 * Returns: void
 * Assertion: If position is larger than the number of rows on the list, then the new row will be appended to the list.
 * Params Values: newly created GtkListStore*, uninitialized iter, 0
 * Expected: void
 * 
 * Name: gtk_list_store_insert
 * Params: GtkListStore *list_store, GtkTreeIter *iter, gint position
 * Returns: void
 * Assertion: The row will be empty before this function is called.
 * Params Values: newly created GtkListStore*, uninitialized iter, 0
 * Expected: void  
 */
static void test_purpose_11()
{
    #define N_ROWS 1
    #define ROW_NUM 0
    #define UINT_VALUE 53184995
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GValue inserted_val = {0,};
    GValue val = {0,};
    GValue rval = {0,};
    guint uint_value;
    guint i, row_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_value_init (&inserted_val, G_TYPE_UINT);
    g_value_set_uint (&inserted_val, UINT_VALUE);
    row_num = (ROW_NUM >= N_ROWS)?(N_ROWS - 1):(ROW_NUM);
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        if (i == (row_num - 1))
        {
            saved_iter = iter;
        };
    }
    gtk_list_store_insert (list_store, &iter, ROW_NUM); 
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iter, 0, &rval);
    uint_value = g_value_get_uint (&rval);
    if (uint_value != 0)
    {
        TEST_FAIL ("The row should be empty.",NULL);
    }
    
    
    gtk_list_store_set_value (list_store, &iter, 0, &inserted_val);
    if (row_num != 0)
    {
        gtk_tree_model_iter_next (GTK_TREE_MODEL (list_store), &saved_iter);
    } else {
        gtk_tree_model_get_iter (GTK_TREE_MODEL (list_store), &saved_iter, 
                                 gtk_tree_path_new_from_string ("0"));
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &saved_iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != UINT_VALUE)
    {
        TEST_FAIL ("At position %i iter value = %i, instead of %i.", row_num, uint_value, UINT_VALUE); 
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef ROW_NUM
    #undef UINT_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_insert
 * Params: GtkListStore *list_store, GtkTreeIter *iter, gint position
 * Returns: void
 * Assertion: Creates a new row at position.  
 * Params Values: newly created GtkListStore*, uninitialized iter, 7
 * Expected: void
 * 
 * Name: gtk_list_store_insert
 * Params: GtkListStore *list_store, GtkTreeIter *iter, gint position
 * Returns: void
 * Assertion: iter will be changed to point to this new row. 
 * Params Values: newly created GtkListStore*, uninitialized iter, 7
 * Expected: void
 * 
 * Name: gtk_list_store_insert
 * Params: GtkListStore *list_store, GtkTreeIter *iter, gint position
 * Returns: void
 * Assertion: If position is larger than the number of rows on the list, then the new row will be appended to the list.
 * Params Values: newly created GtkListStore*, uninitialized iter, 7
 * Expected: void
 * 
 * Name: gtk_list_store_insert
 * Params: GtkListStore *list_store, GtkTreeIter *iter, gint position
 * Returns: void
 * Assertion: The row will be empty before this function is called.
 * Params Values: newly created GtkListStore*, uninitialized iter, 7
 * Expected: void  
 */
static void test_purpose_12()
{
    #define N_ROWS 11
    #define ROW_NUM 7
    #define UINT_VALUE 53184995
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GValue inserted_val = {0,};
    GValue val = {0,};
    GValue rval = {0,};
    guint uint_value;
    guint i, row_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_value_init (&inserted_val, G_TYPE_UINT);
    g_value_set_uint (&inserted_val, UINT_VALUE);
    row_num = (ROW_NUM >= N_ROWS)?(N_ROWS - 1):(ROW_NUM);
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        if (i == (row_num - 1))
        {
            saved_iter = iter;
        };
    }
    gtk_list_store_insert (list_store, &iter, ROW_NUM); 
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iter, 0, &rval);
    uint_value = g_value_get_uint (&rval);
    if (uint_value != 0)
    {
        TEST_FAIL ("The row should be empty.",NULL);
    }
    
    
    gtk_list_store_set_value (list_store, &iter, 0, &inserted_val);
    if (row_num != 0)
    {
        gtk_tree_model_iter_next (GTK_TREE_MODEL (list_store), &saved_iter);
    } else {
        gtk_tree_model_get_iter (GTK_TREE_MODEL (list_store), &saved_iter, 
                                 gtk_tree_path_new_from_string ("0"));
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &saved_iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != UINT_VALUE)
    {
        TEST_FAIL ("At position %i iter value = %i, instead of %i.", row_num, uint_value, UINT_VALUE); 
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef ROW_NUM
    #undef UINT_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_insert
 * Params: GtkListStore *list_store, GtkTreeIter *iter, gint position
 * Returns: void
 * Assertion: Creates a new row at position.  
 * Params Values: newly created GtkListStore*, uninitialized iter, 6
 * Expected: void
 * 
 * Name: gtk_list_store_insert
 * Params: GtkListStore *list_store, GtkTreeIter *iter, gint position
 * Returns: void
 * Assertion: iter will be changed to point to this new row. 
 * Params Values: newly created GtkListStore*, uninitialized iter, 6
 * Expected: void
 * 
 * Name: gtk_list_store_insert
 * Params: GtkListStore *list_store, GtkTreeIter *iter, gint position
 * Returns: void
 * Assertion: If position is larger than the number of rows on the list, then the new row will be appended to the list.
 * Params Values: newly created GtkListStore*, uninitialized iter, 6
 * Expected: void
 * 
 * Name: gtk_list_store_insert
 * Params: GtkListStore *list_store, GtkTreeIter *iter, gint position
 * Returns: void
 * Assertion: The row will be empty before this function is called.
 * Params Values: newly created GtkListStore*, uninitialized iter, 6
 * Expected: void  
 */
static void test_purpose_13()
{
    #define N_ROWS 7
    #define ROW_NUM 6
    #define UINT_VALUE 53184995
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GValue inserted_val = {0,};
    GValue val = {0,};
    GValue rval = {0,};
    guint uint_value;
    guint i, row_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_value_init (&inserted_val, G_TYPE_UINT);
    g_value_set_uint (&inserted_val, UINT_VALUE);
    row_num = (ROW_NUM >= N_ROWS)?(N_ROWS - 1):(ROW_NUM);
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        if (i == (row_num - 1))
        {
            saved_iter = iter;
        };
    }
    gtk_list_store_insert (list_store, &iter, ROW_NUM); 
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iter, 0, &rval);
    uint_value = g_value_get_uint (&rval);
    if (uint_value != 0)
    {
        TEST_FAIL ("The row should be empty.",NULL);
    }
    
    
    gtk_list_store_set_value (list_store, &iter, 0, &inserted_val);
    if (row_num != 0)
    {
        gtk_tree_model_iter_next (GTK_TREE_MODEL (list_store), &saved_iter);
    } else {
        gtk_tree_model_get_iter (GTK_TREE_MODEL (list_store), &saved_iter, 
                                 gtk_tree_path_new_from_string ("0"));
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &saved_iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != UINT_VALUE)
    {
        TEST_FAIL ("At position %i iter value = %i, instead of %i.", row_num, uint_value, UINT_VALUE); 
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef ROW_NUM
    #undef UINT_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_insert_before
 * Params: GtkListStore *list_store, GtkTreeIter *iter, GtkTreeIter *sibling
 * Returns: void
 * Assertion: Inserts a new row before sibling.
 * Params Values: newly created GtkListStore*, uninitialized iter, initialized iter
 * Expected: void
 * 
 * Name: gtk_list_store_insert_before
 * Params: GtkListStore *list_store, GtkTreeIter *iter, GtkTreeIter *sibling
 * Returns: void
 * Assertion: The row will be empty before this function is called.
 * Params Values: newly created GtkListStore*, uninitialized iter, initialized iter
 * Expected: void
 * 
 * Name: gtk_list_store_insert_before
 * Params: GtkListStore *list_store, GtkTreeIter *iter, GtkTreeIter *sibling
 * Returns: void
 * Assertion: iter will be changed to point to this new row.
 * Params Values: newly created GtkListStore*, uninitialized iter, initialized iter
 * Expected: void  
 */
static void test_purpose_14()
{
    #define N_ROWS 1
    #define ROW_NUM 0
    #define UINT_VALUE 53184995
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GValue next_val = {0,};
    GValue val = {0,};
    guint uint_value;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_value_init (&next_val, G_TYPE_UINT);
    g_value_set_uint (&next_val, UINT_VALUE);
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        if (i == (ROW_NUM))
        {
            saved_iter = iter;
            gtk_list_store_set_value (list_store, &saved_iter, 0, &next_val);
        };
    }
    gtk_list_store_insert_before (list_store, &iter, &saved_iter); 
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != 0)
    {
        TEST_FAIL ("The row should be empty.",NULL);
    }
    g_value_unset (&val);
    
    
    gtk_tree_model_iter_next (GTK_TREE_MODEL (list_store), &iter);
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != UINT_VALUE)
    {
        TEST_FAIL ("At position %i iter value = %i, instead of %i.", ROW_NUM, uint_value, UINT_VALUE); 
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef ROW_NUM
    #undef UINT_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_insert_before
 * Params: GtkListStore *list_store, GtkTreeIter *iter, GtkTreeIter *sibling
 * Returns: void
 * Assertion: Inserts a new row before sibling.
 * Params Values: newly created GtkListStore*, uninitialized iter, initialized iter
 * Expected: void
 * 
 * Name: gtk_list_store_insert_before
 * Params: GtkListStore *list_store, GtkTreeIter *iter, GtkTreeIter *sibling
 * Returns: void
 * Assertion: The row will be empty before this function is called.
 * Params Values: newly created GtkListStore*, uninitialized iter, initialized iter
 * Expected: void
 * 
 * Name: gtk_list_store_insert_before
 * Params: GtkListStore *list_store, GtkTreeIter *iter, GtkTreeIter *sibling
 * Returns: void
 * Assertion: iter will be changed to point to this new row.
 * Params Values: newly created GtkListStore*, uninitialized iter, initialized iter
 * Expected: void  
 */
static void test_purpose_15()
{
    #define N_ROWS 11
    #define ROW_NUM 7
    #define UINT_VALUE 53184995
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GValue next_val = {0,};
    GValue val = {0,};
    guint uint_value;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_value_init (&next_val, G_TYPE_UINT);
    g_value_set_uint (&next_val, UINT_VALUE);
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        if (i == (ROW_NUM))
        {
            saved_iter = iter;
            gtk_list_store_set_value (list_store, &saved_iter, 0, &next_val);
        };
    }
    gtk_list_store_insert_before (list_store, &iter, &saved_iter); 
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != 0)
    {
        TEST_FAIL ("The row should be empty.",NULL);
    }
    g_value_unset (&val);
    
    
    gtk_tree_model_iter_next (GTK_TREE_MODEL (list_store), &iter);
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != UINT_VALUE)
    {
        TEST_FAIL ("At position %i iter value = %i, instead of %i.", ROW_NUM, uint_value, UINT_VALUE); 
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef ROW_NUM
    #undef UINT_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_insert_before
 * Params: GtkListStore *list_store, GtkTreeIter *iter, GtkTreeIter *sibling
 * Returns: void
 * Assertion: Inserts a new row before sibling.
 * Params Values: newly created GtkListStore*, uninitialized iter, initialized iter
 * Expected: void
 * 
 * Name: gtk_list_store_insert_before
 * Params: GtkListStore *list_store, GtkTreeIter *iter, GtkTreeIter *sibling
 * Returns: void
 * Assertion: The row will be empty before this function is called.
 * Params Values: newly created GtkListStore*, uninitialized iter, initialized iter
 * Expected: void
 * 
 * Name: gtk_list_store_insert_before
 * Params: GtkListStore *list_store, GtkTreeIter *iter, GtkTreeIter *sibling
 * Returns: void
 * Assertion: iter will be changed to point to this new row.
 * Params Values: newly created GtkListStore*, uninitialized iter, initialized iter
 * Expected: void  
 */
static void test_purpose_16()
{
    #define N_ROWS 7
    #define ROW_NUM 6
    #define UINT_VALUE 53184995
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GValue next_val = {0,};
    GValue val = {0,};
    guint uint_value;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_value_init (&next_val, G_TYPE_UINT);
    g_value_set_uint (&next_val, UINT_VALUE);
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        if (i == (ROW_NUM))
        {
            saved_iter = iter;
            gtk_list_store_set_value (list_store, &saved_iter, 0, &next_val);
        };
    }
    gtk_list_store_insert_before (list_store, &iter, &saved_iter); 
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != 0)
    {
        TEST_FAIL ("The row should be empty.",NULL);
    }
    g_value_unset (&val);
    
    
    gtk_tree_model_iter_next (GTK_TREE_MODEL (list_store), &iter);
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != UINT_VALUE)
    {
        TEST_FAIL ("At position %i iter value = %i, instead of %i.", ROW_NUM, uint_value, UINT_VALUE); 
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef ROW_NUM
    #undef UINT_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_insert_before
 * Params: GtkListStore *list_store, GtkTreeIter *iter, GtkTreeIter *sibling
 * Returns: void
 * Assertion: If sibling is NULL, then the row will be appended to the end of the list.
 * Params Values: newly created GtkListStore*, uninitialized iter, initialized iter
 * Expected: void  
 */
static void test_purpose_17()
{
    #define N_ROWS 1
    #define ROW_NUM 0
    #define UINT_VALUE 53184995
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GValue next_val = {0,};
    GValue val = {0,};
    guint uint_value;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_value_init (&next_val, G_TYPE_UINT);
    g_value_set_uint (&next_val, UINT_VALUE);
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        if (i == (ROW_NUM))
        {
            saved_iter = iter;
        };
    }
    gtk_list_store_insert_before (list_store, &iter, NULL); 
    gtk_list_store_set_value (list_store, &iter, 0, &next_val);
    gtk_tree_model_iter_next (GTK_TREE_MODEL (list_store), &saved_iter);
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &saved_iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != UINT_VALUE)
    {
        TEST_FAIL ("At position %i iter value = %i, instead of %i.", ROW_NUM + 1, uint_value, UINT_VALUE); 
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef ROW_NUM
    #undef UINT_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_insert_before
 * Params: GtkListStore *list_store, GtkTreeIter *iter, GtkTreeIter *sibling
 * Returns: void
 * Assertion: If sibling is NULL, then the row will be appended to the end of the list.
 * Params Values: newly created GtkListStore*, uninitialized iter, initialized iter
 * Expected: void  
 */
static void test_purpose_18()
{
    #define N_ROWS 7
    #define ROW_NUM 6
    #define UINT_VALUE 53184995
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GValue next_val = {0,};
    GValue val = {0,};
    guint uint_value;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_value_init (&next_val, G_TYPE_UINT);
    g_value_set_uint (&next_val, UINT_VALUE);
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        if (i == (ROW_NUM))
        {
            saved_iter = iter;
        };
    }
    gtk_list_store_insert_before (list_store, &iter, NULL); 
    gtk_list_store_set_value (list_store, &iter, 0, &next_val);
    gtk_tree_model_iter_next (GTK_TREE_MODEL (list_store), &saved_iter);
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &saved_iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != UINT_VALUE)
    {
        TEST_FAIL ("At position %i iter value = %i, instead of %i.", ROW_NUM + 1, uint_value, UINT_VALUE); 
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef ROW_NUM
    #undef UINT_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_insert_after
 * Params: GtkListStore *list_store, GtkTreeIter *iter, GtkTreeIter *sibling
 * Returns: void
 * Assertion: Inserts a new row after sibling. 
 * Params Values: newly created GtkListStore*, uninitialized iter, initialized iter
 * Expected: void
 * 
 * Name: gtk_list_store_insert_after
 * Params: GtkListStore *list_store, GtkTreeIter *iter, GtkTreeIter *sibling
 * Returns: void
 * Assertion: The row will be empty after this function is called.
 * Params Values: newly created GtkListStore*, uninitialized iter, initialized iter
 * Expected: void
 * 
 * Name: gtk_list_store_insert_after
 * Params: GtkListStore *list_store, GtkTreeIter *iter, GtkTreeIter *sibling
 * Returns: void
 * Assertion: iter will be changed to point to this new row.
 * Params Values: newly created GtkListStore*, uninitialized iter, initialized iter
 * Expected: void  
 */
static void test_purpose_19()
{
    #define N_ROWS 1
    #define ROW_NUM 0
    #define UINT_VALUE 53184995
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GValue next_val = {0,};
    GValue val = {0,};
    guint uint_value;
    guint i,row_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_value_init (&next_val, G_TYPE_UINT);
    g_value_set_uint (&next_val, UINT_VALUE);
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        if (i == (ROW_NUM))
        {
            saved_iter = iter;
        };
    }
    gtk_list_store_insert_after (list_store, &iter, &saved_iter); 
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != 0)
    {
        TEST_FAIL ("The row should be empty.",NULL);
    }
    
    g_value_unset (&val);
    
    gtk_list_store_set_value (list_store, &iter, 0, &next_val);
    gtk_tree_model_iter_next (GTK_TREE_MODEL (list_store), &saved_iter);
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &saved_iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != UINT_VALUE)
    {
        TEST_FAIL ("At position %i iter value = %i, instead of %i.", ROW_NUM + 1, uint_value, UINT_VALUE); 
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef ROW_NUM
    #undef UINT_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_insert_after
 * Params: GtkListStore *list_store, GtkTreeIter *iter, GtkTreeIter *sibling
 * Returns: void
 * Assertion: Inserts a new row after sibling. 
 * Params Values: newly created GtkListStore*, uninitialized iter, initialized iter
 * Expected: void
 * 
 * Name: gtk_list_store_insert_after
 * Params: GtkListStore *list_store, GtkTreeIter *iter, GtkTreeIter *sibling
 * Returns: void
 * Assertion: The row will be empty after this function is called.
 * Params Values: newly created GtkListStore*, uninitialized iter, initialized iter
 * Expected: void
 * 
 * Name: gtk_list_store_insert_after
 * Params: GtkListStore *list_store, GtkTreeIter *iter, GtkTreeIter *sibling
 * Returns: void
 * Assertion: iter will be changed to point to this new row.
 * Params Values: newly created GtkListStore*, uninitialized iter, initialized iter
 * Expected: void  
 */
static void test_purpose_20()
{
    #define N_ROWS 11
    #define ROW_NUM 7
    #define UINT_VALUE 53184995
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GValue next_val = {0,};
    GValue val = {0,};
    guint uint_value;
    guint i,row_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_value_init (&next_val, G_TYPE_UINT);
    g_value_set_uint (&next_val, UINT_VALUE);
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        if (i == (ROW_NUM))
        {
            saved_iter = iter;
        };
    }
    gtk_list_store_insert_after (list_store, &iter, &saved_iter); 
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != 0)
    {
        TEST_FAIL ("The row should be empty.",NULL);
    }
    
    g_value_unset (&val);
    
    gtk_list_store_set_value (list_store, &iter, 0, &next_val);
    gtk_tree_model_iter_next (GTK_TREE_MODEL (list_store), &saved_iter);
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &saved_iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != UINT_VALUE)
    {
        TEST_FAIL ("At position %i iter value = %i, instead of %i.", ROW_NUM + 1, uint_value, UINT_VALUE); 
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef ROW_NUM
    #undef UINT_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_insert_after
 * Params: GtkListStore *list_store, GtkTreeIter *iter, GtkTreeIter *sibling
 * Returns: void
 * Assertion: Inserts a new row after sibling. 
 * Params Values: newly created GtkListStore*, uninitialized iter, initialized iter
 * Expected: void
 * 
 * Name: gtk_list_store_insert_after
 * Params: GtkListStore *list_store, GtkTreeIter *iter, GtkTreeIter *sibling
 * Returns: void
 * Assertion: The row will be empty after this function is called.
 * Params Values: newly created GtkListStore*, uninitialized iter, initialized iter
 * Expected: void
 * 
 * Name: gtk_list_store_insert_after
 * Params: GtkListStore *list_store, GtkTreeIter *iter, GtkTreeIter *sibling
 * Returns: void
 * Assertion: iter will be changed to point to this new row.
 * Params Values: newly created GtkListStore*, uninitialized iter, initialized iter
 * Expected: void  
 */
static void test_purpose_21()
{
    #define N_ROWS 7
    #define ROW_NUM 6
    #define UINT_VALUE 53184995
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GValue next_val = {0,};
    GValue val = {0,};
    guint uint_value;
    guint i,row_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_value_init (&next_val, G_TYPE_UINT);
    g_value_set_uint (&next_val, UINT_VALUE);
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        if (i == (ROW_NUM))
        {
            saved_iter = iter;
        };
    }
    gtk_list_store_insert_after (list_store, &iter, &saved_iter); 
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != 0)
    {
        TEST_FAIL ("The row should be empty.",NULL);
    }
    
    g_value_unset (&val);
    
    gtk_list_store_set_value (list_store, &iter, 0, &next_val);
    gtk_tree_model_iter_next (GTK_TREE_MODEL (list_store), &saved_iter);
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &saved_iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != UINT_VALUE)
    {
        TEST_FAIL ("At position %i iter value = %i, instead of %i.", ROW_NUM + 1, uint_value, UINT_VALUE); 
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef ROW_NUM
    #undef UINT_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_insert_after
 * Params: GtkListStore *list_store, GtkTreeIter *iter, GtkTreeIter *sibling
 * Returns: void
 * Assertion: If sibling is NULL, then the row will be prepended to the beginning of the list. 
 * Params Values: newly created GtkListStore*, uninitialized iter, initialized iter
 * Expected: void  
 */
static void test_purpose_22()
{
    #define N_ROWS 1
    #define UINT_VALUE 53184995
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GValue inserted_val = {0,};
    GValue val = {0,};
    guint uint_value;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_value_init (&inserted_val, G_TYPE_UINT);
    g_value_set_uint (&inserted_val, UINT_VALUE);
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
    }
    gtk_list_store_insert_after (list_store, &iter, NULL); 
    gtk_list_store_set_value (list_store, &iter, 0, &inserted_val);
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_tree_model_get_iter (GTK_TREE_MODEL (list_store), &iter, 
                             gtk_tree_path_new_from_string ("0"));
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != UINT_VALUE)
    {
        TEST_FAIL ("At position %i iter value = %i, instead of %i.", 0, uint_value, UINT_VALUE); 
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef UINT_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_insert_after
 * Params: GtkListStore *list_store, GtkTreeIter *iter, GtkTreeIter *sibling
 * Returns: void
 * Assertion: If sibling is NULL, then the row will be prepended to the beginning of the list. 
 * Params Values: newly created GtkListStore*, uninitialized iter, initialized iter
 * Expected: void  
 */
static void test_purpose_23()
{
    #define N_ROWS 7
    #define UINT_VALUE 53184995
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GValue inserted_val = {0,};
    GValue val = {0,};
    guint uint_value;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_value_init (&inserted_val, G_TYPE_UINT);
    g_value_set_uint (&inserted_val, UINT_VALUE);
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
    }
    gtk_list_store_insert_after (list_store, &iter, NULL); 
    gtk_list_store_set_value (list_store, &iter, 0, &inserted_val);
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_tree_model_get_iter (GTK_TREE_MODEL (list_store), &iter, 
                             gtk_tree_path_new_from_string ("0"));
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != UINT_VALUE)
    {
        TEST_FAIL ("At position %i iter value = %i, instead of %i.", 0, uint_value, UINT_VALUE); 
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef UINT_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_prepend
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: void
 * Assertion: Prepends a new row to list_store. 
 * Params Values: newly created GtkListStore*, uninitialized iter
 * Expected: void
 * 
 * Name: gtk_list_store_prepend
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: void
 * Assertion: iter will be changed to point to this new row.
 * Params Values: newly created GtkListStore*, uninitialized iter
 * Expected: void
 * 
 * Name: gtk_list_store_prepend
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: void
 * Assertion: The row will be empty after this function is called.
 * Params Values: newly created GtkListStore*, uninitialized iter
 * Expected: void  
 */
static void test_purpose_24()
{
    #define N_ROWS 0
    #define UINT_VALUE 53184995
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GValue prepended_val = {0,};
    GValue val = {0,};
    guint uint_value;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_value_init (&prepended_val, G_TYPE_UINT);
    g_value_set_uint (&prepended_val, UINT_VALUE);
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
    }
    gtk_list_store_prepend (list_store, &iter); 
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != 0)
    {
        TEST_FAIL ("The row should be empty.",NULL);
    }
    g_value_unset (&val);
    
    
    gtk_list_store_set_value (list_store, &iter, 0, &prepended_val);
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_tree_model_get_iter (GTK_TREE_MODEL (list_store), &iter, 
                             gtk_tree_path_new_from_string ("0"));
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != UINT_VALUE)
    {
        TEST_FAIL ("At position %i iter value = %i, instead of %i.", 0, uint_value, UINT_VALUE); 
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef UINT_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_prepend
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: void
 * Assertion: Prepends a new row to list_store. 
 * Params Values: newly created GtkListStore*, uninitialized iter
 * Expected: void
 * 
 * Name: gtk_list_store_prepend
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: void
 * Assertion: iter will be changed to point to this new row.
 * Params Values: newly created GtkListStore*, uninitialized iter
 * Expected: void
 * 
 * Name: gtk_list_store_prepend
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: void
 * Assertion: The row will be empty after this function is called.
 * Params Values: newly created GtkListStore*, uninitialized iter
 * Expected: void  
 */
static void test_purpose_25()
{
    #define N_ROWS 1
    #define UINT_VALUE 53184995
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GValue prepended_val = {0,};
    GValue val = {0,};
    guint uint_value;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_value_init (&prepended_val, G_TYPE_UINT);
    g_value_set_uint (&prepended_val, UINT_VALUE);
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
    }
    gtk_list_store_prepend (list_store, &iter); 
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != 0)
    {
        TEST_FAIL ("The row should be empty.",NULL);
    }
    g_value_unset (&val);
    
    
    gtk_list_store_set_value (list_store, &iter, 0, &prepended_val);
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_tree_model_get_iter (GTK_TREE_MODEL (list_store), &iter, 
                             gtk_tree_path_new_from_string ("0"));
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != UINT_VALUE)
    {
        TEST_FAIL ("At position %i iter value = %i, instead of %i.", 0, uint_value, UINT_VALUE); 
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef UINT_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_prepend
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: void
 * Assertion: Prepends a new row to list_store. 
 * Params Values: newly created GtkListStore*, uninitialized iter
 * Expected: void
 * 
 * Name: gtk_list_store_prepend
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: void
 * Assertion: iter will be changed to point to this new row.
 * Params Values: newly created GtkListStore*, uninitialized iter
 * Expected: void
 * 
 * Name: gtk_list_store_prepend
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: void
 * Assertion: The row will be empty after this function is called.
 * Params Values: newly created GtkListStore*, uninitialized iter
 * Expected: void  
 */
static void test_purpose_26()
{
    #define N_ROWS 7
    #define UINT_VALUE 53184995
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GValue prepended_val = {0,};
    GValue val = {0,};
    guint uint_value;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_value_init (&prepended_val, G_TYPE_UINT);
    g_value_set_uint (&prepended_val, UINT_VALUE);
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
    }
    gtk_list_store_prepend (list_store, &iter); 
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != 0)
    {
        TEST_FAIL ("The row should be empty.",NULL);
    }
    g_value_unset (&val);
    
    
    gtk_list_store_set_value (list_store, &iter, 0, &prepended_val);
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_tree_model_get_iter (GTK_TREE_MODEL (list_store), &iter, 
                             gtk_tree_path_new_from_string ("0"));
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != UINT_VALUE)
    {
        TEST_FAIL ("At position %i iter value = %i, instead of %i.", 0, uint_value, UINT_VALUE); 
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef UINT_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_append
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: void
 * Assertion: Appends a new row to list_store.
 * Params Values: newly created GtkListStore*, uninitialized iter
 * Expected: void
 * 
 * Name: gtk_list_store_append
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: void
 * Assertion: iter will be changed to point to this new row.
 * Params Values: newly created GtkListStore*, uninitialized iter
 * Expected: void
 * 
 * Name: gtk_list_store_append
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: void
 * Assertion: The row will be empty after this function is called.
 * Params Values: newly created GtkListStore*, uninitialized iter
 * Expected: void  
 */
static void test_purpose_27()
{
    #define N_ROWS 0
    #define UINT_VALUE 53184995
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GValue appended_val = {0,};
    GValue val = {0,};
    guint uint_value;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_value_init (&appended_val, G_TYPE_UINT);
    g_value_set_uint (&appended_val, UINT_VALUE);
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
    }
    if (N_ROWS > 0)
    {
        saved_iter = iter;
    }
    gtk_list_store_append (list_store, &iter); 
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != 0)
    {
        TEST_FAIL ("The row should be empty.",NULL);
    }
    g_value_unset (&val);
    
    gtk_list_store_set_value (list_store, &iter, 0, &appended_val);
    if (N_ROWS > 0)
    {
        gtk_tree_model_iter_next (GTK_TREE_MODEL (list_store), &saved_iter);
        gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &saved_iter, 0, &val);
    } else {
        gtk_tree_model_get_iter (GTK_TREE_MODEL (list_store), &iter, 
                                 gtk_tree_path_new_from_string ("0"));
        gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iter, 0, &val);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    uint_value = g_value_get_uint (&val);
    if (uint_value != UINT_VALUE)
    {
        TEST_FAIL ("At position %i iter value = %i, instead of %i.", N_ROWS, uint_value, UINT_VALUE); 
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef UINT_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_append
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: void
 * Assertion: Appends a new row to list_store.
 * Params Values: newly created GtkListStore*, uninitialized iter
 * Expected: void
 * 
 * Name: gtk_list_store_append
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: void
 * Assertion: iter will be changed to point to this new row.
 * Params Values: newly created GtkListStore*, uninitialized iter
 * Expected: void
 * 
 * Name: gtk_list_store_append
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: void
 * Assertion: The row will be empty after this function is called.
 * Params Values: newly created GtkListStore*, uninitialized iter
 * Expected: void  
 */
static void test_purpose_28()
{
    #define N_ROWS 1
    #define UINT_VALUE 53184995
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GValue appended_val = {0,};
    GValue val = {0,};
    guint uint_value;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_value_init (&appended_val, G_TYPE_UINT);
    g_value_set_uint (&appended_val, UINT_VALUE);
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
    }
    if (N_ROWS > 0)
    {
        saved_iter = iter;
    }
    gtk_list_store_append (list_store, &iter); 
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != 0)
    {
        TEST_FAIL ("The row should be empty.",NULL);
    }
    g_value_unset (&val);
    
    gtk_list_store_set_value (list_store, &iter, 0, &appended_val);
    if (N_ROWS > 0)
    {
        gtk_tree_model_iter_next (GTK_TREE_MODEL (list_store), &saved_iter);
        gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &saved_iter, 0, &val);
    } else {
        gtk_tree_model_get_iter (GTK_TREE_MODEL (list_store), &iter, 
                                 gtk_tree_path_new_from_string ("0"));
        gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iter, 0, &val);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    uint_value = g_value_get_uint (&val);
    if (uint_value != UINT_VALUE)
    {
        TEST_FAIL ("At position %i iter value = %i, instead of %i.", N_ROWS, uint_value, UINT_VALUE); 
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef UINT_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_append
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: void
 * Assertion: Appends a new row to list_store.
 * Params Values: newly created GtkListStore*, uninitialized iter
 * Expected: void
 * 
 * Name: gtk_list_store_append
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: void
 * Assertion: iter will be changed to point to this new row.
 * Params Values: newly created GtkListStore*, uninitialized iter
 * Expected: void
 * 
 * Name: gtk_list_store_append
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: void
 * Assertion: The row will be empty after this function is called.
 * Params Values: newly created GtkListStore*, uninitialized iter
 * Expected: void  
 */
static void test_purpose_29()
{
    #define N_ROWS 7
    #define UINT_VALUE 53184995
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GValue appended_val = {0,};
    GValue val = {0,};
    guint uint_value;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_value_init (&appended_val, G_TYPE_UINT);
    g_value_set_uint (&appended_val, UINT_VALUE);
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
    }
    if (N_ROWS > 0)
    {
        saved_iter = iter;
    }
    gtk_list_store_append (list_store, &iter); 
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != 0)
    {
        TEST_FAIL ("The row should be empty.",NULL);
    }
    g_value_unset (&val);
    
    gtk_list_store_set_value (list_store, &iter, 0, &appended_val);
    if (N_ROWS > 0)
    {
        gtk_tree_model_iter_next (GTK_TREE_MODEL (list_store), &saved_iter);
        gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &saved_iter, 0, &val);
    } else {
        gtk_tree_model_get_iter (GTK_TREE_MODEL (list_store), &iter, 
                                 gtk_tree_path_new_from_string ("0"));
        gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iter, 0, &val);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    uint_value = g_value_get_uint (&val);
    if (uint_value != UINT_VALUE)
    {
        TEST_FAIL ("At position %i iter value = %i, instead of %i.", N_ROWS, uint_value, UINT_VALUE); 
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef UINT_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_clear
 * Params: GtkListStore *list_store
 * Returns: void
 * Assertion: Removes all rows from the list store.
 * Params Values: newly created GtkListStore*
 * Expected: void  
 */
static void test_purpose_30()
{
    #define N_ROWS 0
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    gint n_columns;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
    }
    
    gtk_list_store_clear(list_store);
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    n_columns = gtk_tree_model_get_n_columns (GTK_TREE_MODEL (list_store));
    if (n_columns != 1)
    {
        TEST_FAIL("n_columns = %d, should be 1", n_columns);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_clear
 * Params: GtkListStore *list_store
 * Returns: void
 * Assertion: Removes all rows from the list store.
 * Params Values: newly created GtkListStore*
 * Expected: void  
 */
static void test_purpose_31()
{
    #define N_ROWS 1
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    gint n_columns;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
    }
    
    gtk_list_store_clear(list_store);
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    n_columns = gtk_tree_model_get_n_columns (GTK_TREE_MODEL (list_store));
    if (n_columns != 1)
    {
        TEST_FAIL("n_columns = %d, should be 1", n_columns);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_clear
 * Params: GtkListStore *list_store
 * Returns: void
 * Assertion: Removes all rows from the list store.
 * Params Values: newly created GtkListStore*
 * Expected: void  
 */
static void test_purpose_32()
{
    #define N_ROWS 7
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    gint n_columns;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
    }
    
    gtk_list_store_clear(list_store);
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    n_columns = gtk_tree_model_get_n_columns (GTK_TREE_MODEL (list_store));
    if (n_columns != 1)
    {
        TEST_FAIL("n_columns = %d, should be 1", n_columns);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_clear
 * Params: GtkListStore *list_store
 * Returns: void
 * Assertion: Removes all rows from the list store.
 * Params Values: newly created GtkListStore*
 * Expected: void  
 */
static void test_purpose_33()
{
    #define N_ROWS 777
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    gint n_columns;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
    }
    
    gtk_list_store_clear(list_store);
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    n_columns = gtk_tree_model_get_n_columns (GTK_TREE_MODEL (list_store));
    if (n_columns != 1)
    {
        TEST_FAIL("n_columns = %d, should be 1", n_columns);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_newv
 * Params: void
 * Returns: GtkListStore*
 * Assertion: Non-vararg creation function.
 * Params Values: 2, G_TYPE_DOUBLE,G_TYPE_CHAR
 * Expected: GtkListStore*  
 */
static void test_purpose_34()
{
    #define COLUMNS_N_AND_TYPES 2, G_TYPE_DOUBLE,G_TYPE_CHAR
    #define COLUMNS_TYPES "G_TYPE_DOUBLE,G_TYPE_CHAR"
    #define NEW_COLUMNS_N 1
    #define NEW_COLUMNS_TYPES "gchar"
    #define NEW_COLUMNS_TYPES_STR "G_TYPE_CHAR"
    
    GtkListStore* store;
    GtkWidget *tree_view;
    gchar* tp;
    gint i = 0;
    GType new_types[NEW_COLUMNS_N];
    gchar* columns_types = calloc (1, strlen (COLUMNS_TYPES) + 1);
    gchar* new_columns_types = calloc (1, strlen (NEW_COLUMNS_TYPES_STR) + 1);
    gchar* new_real_columns_types = calloc (1, strlen (NEW_COLUMNS_TYPES_STR) + 1);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    memcpy (new_columns_types, NEW_COLUMNS_TYPES, strlen (NEW_COLUMNS_TYPES_STR));
    memcpy (new_real_columns_types, NEW_COLUMNS_TYPES_STR, strlen (NEW_COLUMNS_TYPES_STR));
    
    tp = (char*)strtok (new_columns_types, ",");
    for (i = 0; tp != NULL && i <= NEW_COLUMNS_N; i++)
    {  
        new_types [i] = g_type_from_name (tp);
        tp = (char*) strtok (NULL, ",");
    }
    
    store = gtk_list_store_newv (NEW_COLUMNS_N, &new_types[0]);
    if (!store) 
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    tp = (char*)strtok (new_real_columns_types, ",");
    for (i = 0; tp != NULL; i++)
    {  
        GType col_type = gtk_tree_model_get_column_type (GTK_TREE_MODEL (store), i);
    
        if (col_type == G_TYPE_CHAR)
        {
            if (strcmp (tp, "G_TYPE_CHAR"))
            {
                TEST_FAIL ("i = %d. col_type is %d, tp is %s", 
                           i - 1, col_type, tp);
            }
        } else if (col_type == G_TYPE_DOUBLE) {
            if (strcmp (tp, "G_TYPE_DOUBLE"))
            {
                TEST_FAIL ("i = %d, col_type is %d, tp is %s", 
                           i - 1, col_type, tp);
            }
        } else if (col_type == G_TYPE_BOOLEAN) {
            if (strcmp (tp, "G_TYPE_BOOLEAN"))
            {
                TEST_FAIL ("i = %d, col_type is %d, tp is %s", 
                           i - 1, col_type, tp);
            }
        } else {
            TEST_FAIL ("unexpected col_type, please extend the test", NULL);
        }
    
        tp = (char*) strtok (NULL, ",");
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef COLUMNS_N_AND_TYPES
    #undef COLUMNS_TYPES
    #undef NEW_COLUMNS_N
    #undef NEW_COLUMNS_TYPES
    #undef NEW_COLUMNS_TYPES_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_newv
 * Params: void
 * Returns: GtkListStore*
 * Assertion: Non-vararg creation function.
 * Params Values: 2, G_TYPE_DOUBLE,G_TYPE_CHAR
 * Expected: GtkListStore*  
 */
static void test_purpose_35()
{
    #define COLUMNS_N_AND_TYPES 2, G_TYPE_DOUBLE,G_TYPE_CHAR
    #define COLUMNS_TYPES "G_TYPE_DOUBLE,G_TYPE_CHAR"
    #define NEW_COLUMNS_N 2
    #define NEW_COLUMNS_TYPES "gchar,gdouble"
    #define NEW_COLUMNS_TYPES_STR "G_TYPE_CHAR,G_TYPE_DOUBLE"
    
    GtkListStore* store;
    GtkWidget *tree_view;
    gchar* tp;
    gint i = 0;
    GType new_types[NEW_COLUMNS_N];
    gchar* columns_types = calloc (1, strlen (COLUMNS_TYPES) + 1);
    gchar* new_columns_types = calloc (1, strlen (NEW_COLUMNS_TYPES_STR) + 1);
    gchar* new_real_columns_types = calloc (1, strlen (NEW_COLUMNS_TYPES_STR) + 1);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    memcpy (new_columns_types, NEW_COLUMNS_TYPES, strlen (NEW_COLUMNS_TYPES_STR));
    memcpy (new_real_columns_types, NEW_COLUMNS_TYPES_STR, strlen (NEW_COLUMNS_TYPES_STR));
    
    tp = (char*)strtok (new_columns_types, ",");
    for (i = 0; tp != NULL && i <= NEW_COLUMNS_N; i++)
    {  
        new_types [i] = g_type_from_name (tp);
        tp = (char*) strtok (NULL, ",");
    }
    
    store = gtk_list_store_newv (NEW_COLUMNS_N, &new_types[0]);
    if (!store) 
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    tp = (char*)strtok (new_real_columns_types, ",");
    for (i = 0; tp != NULL; i++)
    {  
        GType col_type = gtk_tree_model_get_column_type (GTK_TREE_MODEL (store), i);
    
        if (col_type == G_TYPE_CHAR)
        {
            if (strcmp (tp, "G_TYPE_CHAR"))
            {
                TEST_FAIL ("i = %d. col_type is %d, tp is %s", 
                           i - 1, col_type, tp);
            }
        } else if (col_type == G_TYPE_DOUBLE) {
            if (strcmp (tp, "G_TYPE_DOUBLE"))
            {
                TEST_FAIL ("i = %d, col_type is %d, tp is %s", 
                           i - 1, col_type, tp);
            }
        } else if (col_type == G_TYPE_BOOLEAN) {
            if (strcmp (tp, "G_TYPE_BOOLEAN"))
            {
                TEST_FAIL ("i = %d, col_type is %d, tp is %s", 
                           i - 1, col_type, tp);
            }
        } else {
            TEST_FAIL ("unexpected col_type, please extend the test", NULL);
        }
    
        tp = (char*) strtok (NULL, ",");
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef COLUMNS_N_AND_TYPES
    #undef COLUMNS_TYPES
    #undef NEW_COLUMNS_N
    #undef NEW_COLUMNS_TYPES
    #undef NEW_COLUMNS_TYPES_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_newv
 * Params: void
 * Returns: GtkListStore*
 * Assertion: Non-vararg creation function.
 * Params Values: 2, G_TYPE_DOUBLE,G_TYPE_CHAR
 * Expected: GtkListStore*  
 */
static void test_purpose_36()
{
    #define COLUMNS_N_AND_TYPES 2, G_TYPE_DOUBLE,G_TYPE_CHAR
    #define COLUMNS_TYPES "G_TYPE_DOUBLE,G_TYPE_CHAR"
    #define NEW_COLUMNS_N 3
    #define NEW_COLUMNS_TYPES "gchar,gdouble,gboolean"
    #define NEW_COLUMNS_TYPES_STR "G_TYPE_CHAR,G_TYPE_DOUBLE,G_TYPE_BOOLEAN"
    
    GtkListStore* store;
    GtkWidget *tree_view;
    gchar* tp;
    gint i = 0;
    GType new_types[NEW_COLUMNS_N];
    gchar* columns_types = calloc (1, strlen (COLUMNS_TYPES) + 1);
    gchar* new_columns_types = calloc (1, strlen (NEW_COLUMNS_TYPES_STR) + 1);
    gchar* new_real_columns_types = calloc (1, strlen (NEW_COLUMNS_TYPES_STR) + 1);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    memcpy (new_columns_types, NEW_COLUMNS_TYPES, strlen (NEW_COLUMNS_TYPES_STR));
    memcpy (new_real_columns_types, NEW_COLUMNS_TYPES_STR, strlen (NEW_COLUMNS_TYPES_STR));
    
    tp = (char*)strtok (new_columns_types, ",");
    for (i = 0; tp != NULL && i <= NEW_COLUMNS_N; i++)
    {  
        new_types [i] = g_type_from_name (tp);
        tp = (char*) strtok (NULL, ",");
    }
    
    store = gtk_list_store_newv (NEW_COLUMNS_N, &new_types[0]);
    if (!store) 
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    tp = (char*)strtok (new_real_columns_types, ",");
    for (i = 0; tp != NULL; i++)
    {  
        GType col_type = gtk_tree_model_get_column_type (GTK_TREE_MODEL (store), i);
    
        if (col_type == G_TYPE_CHAR)
        {
            if (strcmp (tp, "G_TYPE_CHAR"))
            {
                TEST_FAIL ("i = %d. col_type is %d, tp is %s", 
                           i - 1, col_type, tp);
            }
        } else if (col_type == G_TYPE_DOUBLE) {
            if (strcmp (tp, "G_TYPE_DOUBLE"))
            {
                TEST_FAIL ("i = %d, col_type is %d, tp is %s", 
                           i - 1, col_type, tp);
            }
        } else if (col_type == G_TYPE_BOOLEAN) {
            if (strcmp (tp, "G_TYPE_BOOLEAN"))
            {
                TEST_FAIL ("i = %d, col_type is %d, tp is %s", 
                           i - 1, col_type, tp);
            }
        } else {
            TEST_FAIL ("unexpected col_type, please extend the test", NULL);
        }
    
        tp = (char*) strtok (NULL, ",");
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef COLUMNS_N_AND_TYPES
    #undef COLUMNS_TYPES
    #undef NEW_COLUMNS_N
    #undef NEW_COLUMNS_TYPES
    #undef NEW_COLUMNS_TYPES_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_newv
 * Params: void
 * Returns: GtkListStore*
 * Assertion: Non-vararg creation function.
 * Params Values: 3, G_TYPE_DOUBLE,G_TYPE_CHAR, G_TYPE_INT
 * Expected: GtkListStore*  
 */
static void test_purpose_37()
{
    #define COLUMNS_N_AND_TYPES 3, G_TYPE_DOUBLE,G_TYPE_CHAR, G_TYPE_INT
    #define COLUMNS_TYPES "G_TYPE_DOUBLE,G_TYPE_CHAR,G_TYPE_INT"
    #define NEW_COLUMNS_N 2
    #define NEW_COLUMNS_TYPES "gchar,gboolean"
    #define NEW_COLUMNS_TYPES_STR "G_TYPE_CHAR,G_TYPE_BOOLEAN"
    
    GtkListStore* store;
    GtkWidget *tree_view;
    gchar* tp;
    gint i = 0;
    GType new_types[NEW_COLUMNS_N];
    gchar* columns_types = calloc (1, strlen (COLUMNS_TYPES) + 1);
    gchar* new_columns_types = calloc (1, strlen (NEW_COLUMNS_TYPES_STR) + 1);
    gchar* new_real_columns_types = calloc (1, strlen (NEW_COLUMNS_TYPES_STR) + 1);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    memcpy (new_columns_types, NEW_COLUMNS_TYPES, strlen (NEW_COLUMNS_TYPES_STR));
    memcpy (new_real_columns_types, NEW_COLUMNS_TYPES_STR, strlen (NEW_COLUMNS_TYPES_STR));
    
    tp = (char*)strtok (new_columns_types, ",");
    for (i = 0; tp != NULL && i <= NEW_COLUMNS_N; i++)
    {  
        new_types [i] = g_type_from_name (tp);
        tp = (char*) strtok (NULL, ",");
    }
    
    store = gtk_list_store_newv (NEW_COLUMNS_N, &new_types[0]);
    if (!store) 
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    tp = (char*)strtok (new_real_columns_types, ",");
    for (i = 0; tp != NULL; i++)
    {  
        GType col_type = gtk_tree_model_get_column_type (GTK_TREE_MODEL (store), i);
    
        if (col_type == G_TYPE_CHAR)
        {
            if (strcmp (tp, "G_TYPE_CHAR"))
            {
                TEST_FAIL ("i = %d. col_type is %d, tp is %s", 
                           i - 1, col_type, tp);
            }
        } else if (col_type == G_TYPE_DOUBLE) {
            if (strcmp (tp, "G_TYPE_DOUBLE"))
            {
                TEST_FAIL ("i = %d, col_type is %d, tp is %s", 
                           i - 1, col_type, tp);
            }
        } else if (col_type == G_TYPE_BOOLEAN) {
            if (strcmp (tp, "G_TYPE_BOOLEAN"))
            {
                TEST_FAIL ("i = %d, col_type is %d, tp is %s", 
                           i - 1, col_type, tp);
            }
        } else {
            TEST_FAIL ("unexpected col_type, please extend the test", NULL);
        }
    
        tp = (char*) strtok (NULL, ",");
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef COLUMNS_N_AND_TYPES
    #undef COLUMNS_TYPES
    #undef NEW_COLUMNS_N
    #undef NEW_COLUMNS_TYPES
    #undef NEW_COLUMNS_TYPES_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_set_value 
 * Params: GtkListStore *list_store, GtkTreeIter *iter, gint column, GValue *value
 * Returns: void
 * Assertion: Sets the data in the cell specified by iter and column. 
 * Params Values: newly created GtkListStore*, uninitialized iter, 7,GValue*
 * Expected: void  
 */
static void test_purpose_38()
{
    #define N_ROWS 11
    #define ROW_NUM 7
    #define UINT_VALUE 0
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GValue inserted_val = {0,};
    GValue val = {0,};
    guint uint_value;
    guint i, row_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_value_init (&inserted_val, G_TYPE_UINT);
    g_value_set_uint (&inserted_val, UINT_VALUE);
    
    row_num = (ROW_NUM >= N_ROWS)?(N_ROWS - 1):(ROW_NUM);
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        if (i == row_num)
        {
            saved_iter = iter;
        };
    }
    
    
    gtk_list_store_set_value (list_store, &saved_iter, 0, &inserted_val);
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &saved_iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != UINT_VALUE)
    {
        TEST_FAIL ("At position %i iter value = %i, instead of %i.", row_num, uint_value, UINT_VALUE); 
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef ROW_NUM
    #undef UINT_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_set_value 
 * Params: GtkListStore *list_store, GtkTreeIter *iter, gint column, GValue *value
 * Returns: void
 * Assertion: Sets the data in the cell specified by iter and column. 
 * Params Values: newly created GtkListStore*, uninitialized iter, 7,GValue*
 * Expected: void  
 */
static void test_purpose_39()
{
    #define N_ROWS 11
    #define ROW_NUM 7
    #define UINT_VALUE 1
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GValue inserted_val = {0,};
    GValue val = {0,};
    guint uint_value;
    guint i, row_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_value_init (&inserted_val, G_TYPE_UINT);
    g_value_set_uint (&inserted_val, UINT_VALUE);
    
    row_num = (ROW_NUM >= N_ROWS)?(N_ROWS - 1):(ROW_NUM);
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        if (i == row_num)
        {
            saved_iter = iter;
        };
    }
    
    
    gtk_list_store_set_value (list_store, &saved_iter, 0, &inserted_val);
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &saved_iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != UINT_VALUE)
    {
        TEST_FAIL ("At position %i iter value = %i, instead of %i.", row_num, uint_value, UINT_VALUE); 
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef ROW_NUM
    #undef UINT_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_set_value 
 * Params: GtkListStore *list_store, GtkTreeIter *iter, gint column, GValue *value
 * Returns: void
 * Assertion: Sets the data in the cell specified by iter and column. 
 * Params Values: newly created GtkListStore*, uninitialized iter, 7,GValue*
 * Expected: void  
 */
static void test_purpose_40()
{
    #define N_ROWS 11
    #define ROW_NUM 7
    #define UINT_VALUE 10
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GValue inserted_val = {0,};
    GValue val = {0,};
    guint uint_value;
    guint i, row_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_value_init (&inserted_val, G_TYPE_UINT);
    g_value_set_uint (&inserted_val, UINT_VALUE);
    
    row_num = (ROW_NUM >= N_ROWS)?(N_ROWS - 1):(ROW_NUM);
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        if (i == row_num)
        {
            saved_iter = iter;
        };
    }
    
    
    gtk_list_store_set_value (list_store, &saved_iter, 0, &inserted_val);
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &saved_iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != UINT_VALUE)
    {
        TEST_FAIL ("At position %i iter value = %i, instead of %i.", row_num, uint_value, UINT_VALUE); 
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef ROW_NUM
    #undef UINT_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_set_value 
 * Params: GtkListStore *list_store, GtkTreeIter *iter, gint column, GValue *value
 * Returns: void
 * Assertion: Sets the data in the cell specified by iter and column. 
 * Params Values: newly created GtkListStore*, uninitialized iter, 7,GValue*
 * Expected: void  
 */
static void test_purpose_41()
{
    #define N_ROWS 11
    #define ROW_NUM 7
    #define UINT_VALUE 100
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GValue inserted_val = {0,};
    GValue val = {0,};
    guint uint_value;
    guint i, row_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_value_init (&inserted_val, G_TYPE_UINT);
    g_value_set_uint (&inserted_val, UINT_VALUE);
    
    row_num = (ROW_NUM >= N_ROWS)?(N_ROWS - 1):(ROW_NUM);
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        if (i == row_num)
        {
            saved_iter = iter;
        };
    }
    
    
    gtk_list_store_set_value (list_store, &saved_iter, 0, &inserted_val);
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &saved_iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != UINT_VALUE)
    {
        TEST_FAIL ("At position %i iter value = %i, instead of %i.", row_num, uint_value, UINT_VALUE); 
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef ROW_NUM
    #undef UINT_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_set_value 
 * Params: GtkListStore *list_store, GtkTreeIter *iter, gint column, GValue *value
 * Returns: void
 * Assertion: Sets the data in the cell specified by iter and column. 
 * Params Values: newly created GtkListStore*, uninitialized iter, 7,GValue*
 * Expected: void  
 */
static void test_purpose_42()
{
    #define N_ROWS 11
    #define ROW_NUM 7
    #define UINT_VALUE G_MAXINT
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GValue inserted_val = {0,};
    GValue val = {0,};
    guint uint_value;
    guint i, row_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_value_init (&inserted_val, G_TYPE_UINT);
    g_value_set_uint (&inserted_val, UINT_VALUE);
    
    row_num = (ROW_NUM >= N_ROWS)?(N_ROWS - 1):(ROW_NUM);
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        if (i == row_num)
        {
            saved_iter = iter;
        };
    }
    
    
    gtk_list_store_set_value (list_store, &saved_iter, 0, &inserted_val);
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &saved_iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != UINT_VALUE)
    {
        TEST_FAIL ("At position %i iter value = %i, instead of %i.", row_num, uint_value, UINT_VALUE); 
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef ROW_NUM
    #undef UINT_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_set_value 
 * Params: GtkListStore *list_store, GtkTreeIter *iter, gint column, GValue *value
 * Returns: void
 * Assertion: Sets the data in the cell specified by iter and column. 
 * Params Values: newly created GtkListStore*, uninitialized iter, 6,GValue*
 * Expected: void  
 */
static void test_purpose_43()
{
    #define N_ROWS 7
    #define ROW_NUM 6
    #define UINT_VALUE 1000
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GValue inserted_val = {0,};
    GValue val = {0,};
    guint uint_value;
    guint i, row_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_value_init (&inserted_val, G_TYPE_UINT);
    g_value_set_uint (&inserted_val, UINT_VALUE);
    
    row_num = (ROW_NUM >= N_ROWS)?(N_ROWS - 1):(ROW_NUM);
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        if (i == row_num)
        {
            saved_iter = iter;
        };
    }
    
    
    gtk_list_store_set_value (list_store, &saved_iter, 0, &inserted_val);
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &saved_iter, 0, &val);
    uint_value = g_value_get_uint (&val);
    if (uint_value != UINT_VALUE)
    {
        TEST_FAIL ("At position %i iter value = %i, instead of %i.", row_num, uint_value, UINT_VALUE); 
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef ROW_NUM
    #undef UINT_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_set
 * Params: GtkListStore *list_store, GtkTreeIter *iter, ...
 * Returns: void
 * Assertion: Sets the value of one or more cells in the row referenced by iter. 
 * Params Values: newly created GtkListStore*, uninitialized iter, "G_TYPE_UINT",GValue*
 * Expected: void  
 */
static void test_purpose_44()
{
    #define COLUMNS_N 1
    #define COLUMNS_TYPES "G_TYPE_UINT"
    #define COLUMNS_N_AND_TYPES 1,G_TYPE_UINT 
    #define DATA 0, 100, -1
    #define COLUMNS_VALUES "100"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GValue val = {0,};
    GValue nval = {0,};
    guint i;
    gchar* tp;
    gchar* columns_types = calloc (1, strlen (COLUMNS_TYPES) + 1);
    gchar* columns_values = calloc (1, strlen (COLUMNS_VALUES) + 1);
    GType types[COLUMNS_N];
    GValue values[COLUMNS_N];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    memcpy (columns_types, COLUMNS_TYPES, strlen (COLUMNS_TYPES));
    memcpy (columns_values, COLUMNS_VALUES, strlen (COLUMNS_VALUES));
    
    
    list_store = gtk_list_store_new (COLUMNS_N_AND_TYPES);
    if (!list_store) 
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_list_store_append (list_store, &iter); 
    
    
    tp = (char*)strtok (columns_types, ",");
    for (i = 0; tp != NULL && i < COLUMNS_N; i++)
    {  
        types [i] = g_type_from_name (tp);
        tp = (char*) strtok (NULL, ",");
    }
    
    tp = (char*)strtok (columns_values, ",");
    for (i = 0; tp != NULL && i < COLUMNS_N; i++)
    {  
        if (types [i] == G_TYPE_INT)
        {
            g_value_init(&val, G_TYPE_INT);
            g_value_set_int (&values[i],atoi(tp));
    
        } else if (types [i] == G_TYPE_DOUBLE)
        {
            g_value_init(&val, G_TYPE_DOUBLE);
            g_value_set_double (&values[i],atof(tp));
           
        } else if (types [i] == G_TYPE_LONG)
        {
            g_value_init(&val, G_TYPE_LONG);
            g_value_set_long (&values[i],atol(tp));
            
        } else if (types [i] == G_TYPE_STRING)
        {
            g_value_init(&val, G_TYPE_STRING);
            g_value_set_string (&values[i],tp);
            
        } else if (types [i] == G_TYPE_UINT)
        {
            g_value_init(&val, G_TYPE_UINT);
            g_value_set_uint (&values[i],(u_int)atoi(tp));
            
        } else if (types [i] == G_TYPE_CHAR)
        {
            g_value_init(&val, G_TYPE_CHAR);
            g_value_set_char (&values[i],atoi(tp));
        } 
        tp = (char*) strtok (NULL, ",");
    }
    
    
    gtk_list_store_set (list_store, &iter, DATA);
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    tp = (char*)strtok (columns_types, ",");
    for (i = 0; tp != NULL && i < COLUMNS_N; i++)
    {  
        if (types [i] == G_TYPE_INT)
        {
            g_value_init(&val, G_TYPE_INT);
            gtk_tree_model_get_value (GTK_TREE_MODEL (list_store),&iter,i,&val);
    
            if (g_value_get_int (&val) != g_value_get_int (&values[i]))
            {
                TEST_FAIL ("Int Value is '%d',should be '%d'",g_value_get_int (&val),g_value_get_int (&values[i]));
               
            }
            g_value_unset (&val);
    
        } else if (types [i] == G_TYPE_DOUBLE)
        {
            g_value_init(&val, G_TYPE_DOUBLE);
            gtk_tree_model_get_value (GTK_TREE_MODEL (list_store),&iter,i,&val);
            if (g_value_get_long (&val) != g_value_get_long (&values[i]))
            {
                TEST_FAIL ("long Value is '%d',should be '%d'",g_value_get_long (&val),g_value_get_long (&values[i]));
               
            }
            g_value_unset (&val);
        } else if (types [i] == G_TYPE_LONG)
        {
            g_value_init(&val, G_TYPE_LONG);
            gtk_tree_model_get_value (GTK_TREE_MODEL (list_store),&iter,i,&val);
            if (g_value_get_long (&val) != g_value_get_long (&values[i]))
            {
                TEST_FAIL ("Long Value is '%d',should be '%d'",g_value_get_double (&val),g_value_get_double (&values[i]));
               
            }
            g_value_unset (&val);
            
        } else if (types [i] == G_TYPE_STRING)
        {
            g_value_init(&val, G_TYPE_STRING);
            gtk_tree_model_get_value (GTK_TREE_MODEL (list_store),&iter,i,&val);
            if (g_value_get_string (&val) != g_value_get_string (&values[i]))
            {
                TEST_FAIL ("String Value is '%d',should be '%d'",g_value_get_string (&val),g_value_get_string (&values[i]));
               
            }
            g_value_unset (&val);
            
        } else if (types [i] == G_TYPE_UINT)
        {
            g_value_init(&val, G_TYPE_UINT);
            gtk_tree_model_get_value (GTK_TREE_MODEL (list_store),&iter,i,&val);
            if (g_value_get_uint (&val) != g_value_get_uint (&values[i]))
            {
                TEST_FAIL ("Uint Value is '%d',should be '%d'",g_value_get_uint (&val),g_value_get_uint (&values[i]));
               
            }
            g_value_unset (&val);
            
        } else if (types [i] == G_TYPE_CHAR)
        {
            g_value_init(&val, G_TYPE_CHAR);
            gtk_tree_model_get_value (GTK_TREE_MODEL (list_store),&iter,i,&val);
            if (g_value_get_char (&val) != g_value_get_char (&values[i]))
            {
                TEST_FAIL ("Char Value is '%d',should be '%d'",g_value_get_char (&val),g_value_get_char (&values[i]));
               
            }
            g_value_unset (&val);
            
        } 
        
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef COLUMNS_N
    #undef COLUMNS_TYPES 
    #undef COLUMNS_N_AND_TYPES
    #undef DATA 
    #undef COLUMNS_VALUES 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_set
 * Params: GtkListStore *list_store, GtkTreeIter *iter, ...
 * Returns: void
 * Assertion: Sets the value of one or more cells in the row referenced by iter. 
 * Params Values: newly created GtkListStore*, uninitialized iter, "G_TYPE_INT, G_TYPE_CHAR, G_TYPE_BOOLEAN, G_TYPE_FLOAT, G_TYPE_DOUBLE, G_TYPE_STRING",GValue*
 * Expected: void  
 */
static void test_purpose_45()
{
    #define COLUMNS_N 6
    #define COLUMNS_TYPES "G_TYPE_INT, G_TYPE_CHAR, G_TYPE_BOOLEAN, G_TYPE_FLOAT, G_TYPE_DOUBLE, G_TYPE_STRING"
    #define COLUMNS_N_AND_TYPES 6,G_TYPE_INT, G_TYPE_CHAR, G_TYPE_BOOLEAN, G_TYPE_FLOAT, G_TYPE_DOUBLE, G_TYPE_STRING
    #define DATA 0, G_MAXINT, 1, '\0', 2, TRUE, 3, G_MINFLOAT, 4, G_MAXDOUBLE, 5, "\n\t_b", -1
    #define COLUMNS_VALUES "G_MAXINT,'\0',TRUE,G_MINFLOAT,G_MAXDOUBLE,\"\n\t_b\""
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GValue val = {0,};
    GValue nval = {0,};
    guint i;
    gchar* tp;
    gchar* columns_types = calloc (1, strlen (COLUMNS_TYPES) + 1);
    gchar* columns_values = calloc (1, strlen (COLUMNS_VALUES) + 1);
    GType types[COLUMNS_N];
    GValue values[COLUMNS_N];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    memcpy (columns_types, COLUMNS_TYPES, strlen (COLUMNS_TYPES));
    memcpy (columns_values, COLUMNS_VALUES, strlen (COLUMNS_VALUES));
    
    
    list_store = gtk_list_store_new (COLUMNS_N_AND_TYPES);
    if (!list_store) 
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_list_store_append (list_store, &iter); 
    
    
    tp = (char*)strtok (columns_types, ",");
    for (i = 0; tp != NULL && i < COLUMNS_N; i++)
    {  
        types [i] = g_type_from_name (tp);
        tp = (char*) strtok (NULL, ",");
    }
    
    tp = (char*)strtok (columns_values, ",");
    for (i = 0; tp != NULL && i < COLUMNS_N; i++)
    {  
        if (types [i] == G_TYPE_INT)
        {
            g_value_init(&val, G_TYPE_INT);
            g_value_set_int (&values[i],atoi(tp));
    
        } else if (types [i] == G_TYPE_DOUBLE)
        {
            g_value_init(&val, G_TYPE_DOUBLE);
            g_value_set_double (&values[i],atof(tp));
           
        } else if (types [i] == G_TYPE_LONG)
        {
            g_value_init(&val, G_TYPE_LONG);
            g_value_set_long (&values[i],atol(tp));
            
        } else if (types [i] == G_TYPE_STRING)
        {
            g_value_init(&val, G_TYPE_STRING);
            g_value_set_string (&values[i],tp);
            
        } else if (types [i] == G_TYPE_UINT)
        {
            g_value_init(&val, G_TYPE_UINT);
            g_value_set_uint (&values[i],(u_int)atoi(tp));
            
        } else if (types [i] == G_TYPE_CHAR)
        {
            g_value_init(&val, G_TYPE_CHAR);
            g_value_set_char (&values[i],atoi(tp));
        } 
        tp = (char*) strtok (NULL, ",");
    }
    
    
    gtk_list_store_set (list_store, &iter, DATA);
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    tp = (char*)strtok (columns_types, ",");
    for (i = 0; tp != NULL && i < COLUMNS_N; i++)
    {  
        if (types [i] == G_TYPE_INT)
        {
            g_value_init(&val, G_TYPE_INT);
            gtk_tree_model_get_value (GTK_TREE_MODEL (list_store),&iter,i,&val);
    
            if (g_value_get_int (&val) != g_value_get_int (&values[i]))
            {
                TEST_FAIL ("Int Value is '%d',should be '%d'",g_value_get_int (&val),g_value_get_int (&values[i]));
               
            }
            g_value_unset (&val);
    
        } else if (types [i] == G_TYPE_DOUBLE)
        {
            g_value_init(&val, G_TYPE_DOUBLE);
            gtk_tree_model_get_value (GTK_TREE_MODEL (list_store),&iter,i,&val);
            if (g_value_get_long (&val) != g_value_get_long (&values[i]))
            {
                TEST_FAIL ("long Value is '%d',should be '%d'",g_value_get_long (&val),g_value_get_long (&values[i]));
               
            }
            g_value_unset (&val);
        } else if (types [i] == G_TYPE_LONG)
        {
            g_value_init(&val, G_TYPE_LONG);
            gtk_tree_model_get_value (GTK_TREE_MODEL (list_store),&iter,i,&val);
            if (g_value_get_long (&val) != g_value_get_long (&values[i]))
            {
                TEST_FAIL ("Long Value is '%d',should be '%d'",g_value_get_double (&val),g_value_get_double (&values[i]));
               
            }
            g_value_unset (&val);
            
        } else if (types [i] == G_TYPE_STRING)
        {
            g_value_init(&val, G_TYPE_STRING);
            gtk_tree_model_get_value (GTK_TREE_MODEL (list_store),&iter,i,&val);
            if (g_value_get_string (&val) != g_value_get_string (&values[i]))
            {
                TEST_FAIL ("String Value is '%d',should be '%d'",g_value_get_string (&val),g_value_get_string (&values[i]));
               
            }
            g_value_unset (&val);
            
        } else if (types [i] == G_TYPE_UINT)
        {
            g_value_init(&val, G_TYPE_UINT);
            gtk_tree_model_get_value (GTK_TREE_MODEL (list_store),&iter,i,&val);
            if (g_value_get_uint (&val) != g_value_get_uint (&values[i]))
            {
                TEST_FAIL ("Uint Value is '%d',should be '%d'",g_value_get_uint (&val),g_value_get_uint (&values[i]));
               
            }
            g_value_unset (&val);
            
        } else if (types [i] == G_TYPE_CHAR)
        {
            g_value_init(&val, G_TYPE_CHAR);
            gtk_tree_model_get_value (GTK_TREE_MODEL (list_store),&iter,i,&val);
            if (g_value_get_char (&val) != g_value_get_char (&values[i]))
            {
                TEST_FAIL ("Char Value is '%d',should be '%d'",g_value_get_char (&val),g_value_get_char (&values[i]));
               
            }
            g_value_unset (&val);
            
        } 
        
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef COLUMNS_N
    #undef COLUMNS_TYPES 
    #undef COLUMNS_N_AND_TYPES
    #undef DATA 
    #undef COLUMNS_VALUES 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_set_valist
 * Params: GtkTreeStore* list_store, GtkTreeIter *iter, va_list var_args
 * Returns: void
 * Assertion: See gtk_list_store_set(); this version takes a va_list for use by language bindings.
 * Params Values: newly created GtkTreeStore*, initialized GtkTreeIter *iter, 1,G_TYPE_UINT 
 * Expected: void  
 */
static void test_purpose_46()
{
    #define COLUMNS_N 1
    #define COLUMNS_TYPES "G_TYPE_UINT"
    #define COLUMNS_N_AND_TYPES 1,G_TYPE_UINT 
    #define DATA 0, 100, -1
    #define COLUMNS_VALUES "100"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GValue val = {0,};
    GValue nval = {0,};
    guint i;
    gchar* tp;
    gchar* columns_types = calloc (1, strlen (COLUMNS_TYPES) + 1);
    gchar* columns_values = calloc (1, strlen (COLUMNS_VALUES) + 1);
    GType types[COLUMNS_N];
    GValue values[COLUMNS_N];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    memcpy (columns_types, COLUMNS_TYPES, strlen (COLUMNS_TYPES));
    memcpy (columns_values, COLUMNS_VALUES, strlen (COLUMNS_VALUES));
    
    
    list_store = gtk_list_store_new (COLUMNS_N_AND_TYPES);
    if (!list_store) 
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_list_store_append (list_store, &iter); 
    
    
    tp = (char*)strtok (columns_types, ",");
    for (i = 0; tp != NULL && i < COLUMNS_N; i++)
    {  
        types [i] = g_type_from_name (tp);
        tp = (char*) strtok (NULL, ",");
    }
    
    tp = (char*)strtok (columns_values, ",");
    for (i = 0; tp != NULL && i < COLUMNS_N; i++)
    {  
        if (types [i] == G_TYPE_INT)
        {
            g_value_init(&val, G_TYPE_INT);
            g_value_set_int (&values[i],atoi(tp));
    
        } else if (types [i] == G_TYPE_DOUBLE)
        {
            g_value_init(&val, G_TYPE_DOUBLE);
            g_value_set_double (&values[i],atof(tp));
           
        } else if (types [i] == G_TYPE_LONG)
        {
            g_value_init(&val, G_TYPE_LONG);
            g_value_set_long (&values[i],atol(tp));
            
        } else if (types [i] == G_TYPE_STRING)
        {
            g_value_init(&val, G_TYPE_STRING);
            g_value_set_string (&values[i],tp);
            
        } else if (types [i] == G_TYPE_UINT)
        {
            g_value_init(&val, G_TYPE_UINT);
            g_value_set_uint (&values[i],(u_int)atoi(tp));
            
        } else if (types [i] == G_TYPE_CHAR)
        {
            g_value_init(&val, G_TYPE_CHAR);
            g_value_set_char (&values[i],atoi(tp));
        } 
        tp = (char*) strtok (NULL, ",");
    }
    
    
    global_valist (list_store, &iter, DATA);
    
    tp = (char*)strtok (columns_types, ",");
    for (i = 0; tp != NULL && i < COLUMNS_N; i++)
    {  
        if (types [i] == G_TYPE_INT)
        {
            g_value_init(&val, G_TYPE_INT);
            gtk_tree_model_get_value (GTK_TREE_MODEL (list_store),&iter,i,&val);
    
            if (g_value_get_int (&val) != g_value_get_int (&values[i]))
            {
                TEST_FAIL ("Int Value is '%d',should be '%d'",g_value_get_int (&val),g_value_get_int (&values[i]));
               
            }
            g_value_unset (&val);
    
        } else if (types [i] == G_TYPE_DOUBLE)
        {
            g_value_init(&val, G_TYPE_DOUBLE);
            gtk_tree_model_get_value (GTK_TREE_MODEL (list_store),&iter,i,&val);
            if (g_value_get_long (&val) != g_value_get_long (&values[i]))
            {
                TEST_FAIL ("long Value is '%d',should be '%d'",g_value_get_long (&val),g_value_get_long (&values[i]));
               
            }
            g_value_unset (&val);
        } else if (types [i] == G_TYPE_LONG)
        {
            g_value_init(&val, G_TYPE_LONG);
            gtk_tree_model_get_value (GTK_TREE_MODEL (list_store),&iter,i,&val);
            if (g_value_get_long (&val) != g_value_get_long (&values[i]))
            {
                TEST_FAIL ("Long Value is '%d',should be '%d'",g_value_get_double (&val),g_value_get_double (&values[i]));
               
            }
            g_value_unset (&val);
            
        } else if (types [i] == G_TYPE_STRING)
        {
            g_value_init(&val, G_TYPE_STRING);
            gtk_tree_model_get_value (GTK_TREE_MODEL (list_store),&iter,i,&val);
            if (g_value_get_string (&val) != g_value_get_string (&values[i]))
            {
                TEST_FAIL ("String Value is '%d',should be '%d'",g_value_get_string (&val),g_value_get_string (&values[i]));
               
            }
            g_value_unset (&val);
            
        } else if (types [i] == G_TYPE_UINT)
        {
            g_value_init(&val, G_TYPE_UINT);
            gtk_tree_model_get_value (GTK_TREE_MODEL (list_store),&iter,i,&val);
            if (g_value_get_uint (&val) != g_value_get_uint (&values[i]))
            {
                TEST_FAIL ("Uint Value is '%d',should be '%d'",g_value_get_uint (&val),g_value_get_uint (&values[i]));
               
            }
            g_value_unset (&val);
            
        } else if (types [i] == G_TYPE_CHAR)
        {
            g_value_init(&val, G_TYPE_CHAR);
            gtk_tree_model_get_value (GTK_TREE_MODEL (list_store),&iter,i,&val);
            if (g_value_get_char (&val) != g_value_get_char (&values[i]))
            {
                TEST_FAIL ("Char Value is '%d',should be '%d'",g_value_get_char (&val),g_value_get_char (&values[i]));
               
            }
            g_value_unset (&val);
            
        } 
        
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef COLUMNS_N
    #undef COLUMNS_TYPES 
    #undef COLUMNS_N_AND_TYPES
    #undef DATA 
    #undef COLUMNS_VALUES 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_set_valist
 * Params: GtkTreeStore* list_store, GtkTreeIter *iter, va_list var_args
 * Returns: void
 * Assertion: See gtk_list_store_set(); this version takes a va_list for use by language bindings.
 * Params Values: newly created GtkTreeStore*, initialized GtkTreeIter *iter, 6,G_TYPE_INT, G_TYPE_CHAR, G_TYPE_BOOLEAN, G_TYPE_FLOAT, G_TYPE_DOUBLE, G_TYPE_STRING
 * Expected: void  
 */
static void test_purpose_47()
{
    #define COLUMNS_N 6
    #define COLUMNS_TYPES "G_TYPE_INT, G_TYPE_CHAR, G_TYPE_BOOLEAN, G_TYPE_FLOAT, G_TYPE_DOUBLE, G_TYPE_STRING"
    #define COLUMNS_N_AND_TYPES 6,G_TYPE_INT, G_TYPE_CHAR, G_TYPE_BOOLEAN, G_TYPE_FLOAT, G_TYPE_DOUBLE, G_TYPE_STRING
    #define DATA 0, G_MAXINT, 1, '\0', 2, TRUE, 3, G_MINFLOAT, 4, G_MAXDOUBLE, 5, "\n\t_b", -1
    #define COLUMNS_VALUES "G_MAXINT,'\0',TRUE,G_MINFLOAT,G_MAXDOUBLE,\"\n\t_b\""
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GValue val = {0,};
    GValue nval = {0,};
    guint i;
    gchar* tp;
    gchar* columns_types = calloc (1, strlen (COLUMNS_TYPES) + 1);
    gchar* columns_values = calloc (1, strlen (COLUMNS_VALUES) + 1);
    GType types[COLUMNS_N];
    GValue values[COLUMNS_N];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    memcpy (columns_types, COLUMNS_TYPES, strlen (COLUMNS_TYPES));
    memcpy (columns_values, COLUMNS_VALUES, strlen (COLUMNS_VALUES));
    
    
    list_store = gtk_list_store_new (COLUMNS_N_AND_TYPES);
    if (!list_store) 
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_list_store_append (list_store, &iter); 
    
    
    tp = (char*)strtok (columns_types, ",");
    for (i = 0; tp != NULL && i < COLUMNS_N; i++)
    {  
        types [i] = g_type_from_name (tp);
        tp = (char*) strtok (NULL, ",");
    }
    
    tp = (char*)strtok (columns_values, ",");
    for (i = 0; tp != NULL && i < COLUMNS_N; i++)
    {  
        if (types [i] == G_TYPE_INT)
        {
            g_value_init(&val, G_TYPE_INT);
            g_value_set_int (&values[i],atoi(tp));
    
        } else if (types [i] == G_TYPE_DOUBLE)
        {
            g_value_init(&val, G_TYPE_DOUBLE);
            g_value_set_double (&values[i],atof(tp));
           
        } else if (types [i] == G_TYPE_LONG)
        {
            g_value_init(&val, G_TYPE_LONG);
            g_value_set_long (&values[i],atol(tp));
            
        } else if (types [i] == G_TYPE_STRING)
        {
            g_value_init(&val, G_TYPE_STRING);
            g_value_set_string (&values[i],tp);
            
        } else if (types [i] == G_TYPE_UINT)
        {
            g_value_init(&val, G_TYPE_UINT);
            g_value_set_uint (&values[i],(u_int)atoi(tp));
            
        } else if (types [i] == G_TYPE_CHAR)
        {
            g_value_init(&val, G_TYPE_CHAR);
            g_value_set_char (&values[i],atoi(tp));
        } 
        tp = (char*) strtok (NULL, ",");
    }
    
    
    global_valist (list_store, &iter, DATA);
    
    tp = (char*)strtok (columns_types, ",");
    for (i = 0; tp != NULL && i < COLUMNS_N; i++)
    {  
        if (types [i] == G_TYPE_INT)
        {
            g_value_init(&val, G_TYPE_INT);
            gtk_tree_model_get_value (GTK_TREE_MODEL (list_store),&iter,i,&val);
    
            if (g_value_get_int (&val) != g_value_get_int (&values[i]))
            {
                TEST_FAIL ("Int Value is '%d',should be '%d'",g_value_get_int (&val),g_value_get_int (&values[i]));
               
            }
            g_value_unset (&val);
    
        } else if (types [i] == G_TYPE_DOUBLE)
        {
            g_value_init(&val, G_TYPE_DOUBLE);
            gtk_tree_model_get_value (GTK_TREE_MODEL (list_store),&iter,i,&val);
            if (g_value_get_long (&val) != g_value_get_long (&values[i]))
            {
                TEST_FAIL ("long Value is '%d',should be '%d'",g_value_get_long (&val),g_value_get_long (&values[i]));
               
            }
            g_value_unset (&val);
        } else if (types [i] == G_TYPE_LONG)
        {
            g_value_init(&val, G_TYPE_LONG);
            gtk_tree_model_get_value (GTK_TREE_MODEL (list_store),&iter,i,&val);
            if (g_value_get_long (&val) != g_value_get_long (&values[i]))
            {
                TEST_FAIL ("Long Value is '%d',should be '%d'",g_value_get_double (&val),g_value_get_double (&values[i]));
               
            }
            g_value_unset (&val);
            
        } else if (types [i] == G_TYPE_STRING)
        {
            g_value_init(&val, G_TYPE_STRING);
            gtk_tree_model_get_value (GTK_TREE_MODEL (list_store),&iter,i,&val);
            if (g_value_get_string (&val) != g_value_get_string (&values[i]))
            {
                TEST_FAIL ("String Value is '%d',should be '%d'",g_value_get_string (&val),g_value_get_string (&values[i]));
               
            }
            g_value_unset (&val);
            
        } else if (types [i] == G_TYPE_UINT)
        {
            g_value_init(&val, G_TYPE_UINT);
            gtk_tree_model_get_value (GTK_TREE_MODEL (list_store),&iter,i,&val);
            if (g_value_get_uint (&val) != g_value_get_uint (&values[i]))
            {
                TEST_FAIL ("Uint Value is '%d',should be '%d'",g_value_get_uint (&val),g_value_get_uint (&values[i]));
               
            }
            g_value_unset (&val);
            
        } else if (types [i] == G_TYPE_CHAR)
        {
            g_value_init(&val, G_TYPE_CHAR);
            gtk_tree_model_get_value (GTK_TREE_MODEL (list_store),&iter,i,&val);
            if (g_value_get_char (&val) != g_value_get_char (&values[i]))
            {
                TEST_FAIL ("Char Value is '%d',should be '%d'",g_value_get_char (&val),g_value_get_char (&values[i]));
               
            }
            g_value_unset (&val);
            
        } 
        
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef COLUMNS_N
    #undef COLUMNS_TYPES 
    #undef COLUMNS_N_AND_TYPES
    #undef DATA 
    #undef COLUMNS_VALUES 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_iter_is_valid
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Checks if the given iter is a valid iter for this GtkListStore.
 * Params Values: newly created GtkListStore* containing 0 rows, GtkTreeIter* pointing to "0"
 * Expected: FALSE  
 */
static void test_purpose_48()
{
    #define N_ROWS 0
    #define ITER_PATH "0"
    #define CORRECT_RES FALSE
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter test_iter;
    gboolean res;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_tree_model_get_iter (GTK_TREE_MODEL (list_store), &test_iter, 
                             gtk_tree_path_new_from_string (ITER_PATH));
    res = gtk_list_store_iter_is_valid (list_store, &test_iter);
    if (res != CORRECT_RES)
    {
        TEST_FAIL ("res = %d, should be %d", res, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef ITER_PATH
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_iter_is_valid
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Checks if the given iter is a valid iter for this GtkListStore.
 * Params Values: newly created GtkListStore* containing 0 rows, GtkTreeIter* pointing to "5"
 * Expected: FALSE  
 */
static void test_purpose_49()
{
    #define N_ROWS 0
    #define ITER_PATH "5"
    #define CORRECT_RES FALSE
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter test_iter;
    gboolean res;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_tree_model_get_iter (GTK_TREE_MODEL (list_store), &test_iter, 
                             gtk_tree_path_new_from_string (ITER_PATH));
    res = gtk_list_store_iter_is_valid (list_store, &test_iter);
    if (res != CORRECT_RES)
    {
        TEST_FAIL ("res = %d, should be %d", res, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef ITER_PATH
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_iter_is_valid
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Checks if the given iter is a valid iter for this GtkListStore.
 * Params Values: newly created GtkListStore* containing 1 rows, GtkTreeIter* pointing to "0"
 * Expected: TRUE  
 */
static void test_purpose_50()
{
    #define N_ROWS 1
    #define ITER_PATH "0"
    #define CORRECT_RES TRUE
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter test_iter;
    gboolean res;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_tree_model_get_iter (GTK_TREE_MODEL (list_store), &test_iter, 
                             gtk_tree_path_new_from_string (ITER_PATH));
    res = gtk_list_store_iter_is_valid (list_store, &test_iter);
    if (res != CORRECT_RES)
    {
        TEST_FAIL ("res = %d, should be %d", res, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef ITER_PATH
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_iter_is_valid
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Checks if the given iter is a valid iter for this GtkListStore.
 * Params Values: newly created GtkListStore* containing 1 rows, GtkTreeIter* pointing to "1"
 * Expected: FALSE  
 */
static void test_purpose_51()
{
    #define N_ROWS 1
    #define ITER_PATH "1"
    #define CORRECT_RES FALSE
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter test_iter;
    gboolean res;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_tree_model_get_iter (GTK_TREE_MODEL (list_store), &test_iter, 
                             gtk_tree_path_new_from_string (ITER_PATH));
    res = gtk_list_store_iter_is_valid (list_store, &test_iter);
    if (res != CORRECT_RES)
    {
        TEST_FAIL ("res = %d, should be %d", res, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef ITER_PATH
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_iter_is_valid
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Checks if the given iter is a valid iter for this GtkListStore.
 * Params Values: newly created GtkListStore* containing 1 rows, GtkTreeIter* pointing to "2"
 * Expected: FALSE  
 */
static void test_purpose_52()
{
    #define N_ROWS 1
    #define ITER_PATH "2"
    #define CORRECT_RES FALSE
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter test_iter;
    gboolean res;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_tree_model_get_iter (GTK_TREE_MODEL (list_store), &test_iter, 
                             gtk_tree_path_new_from_string (ITER_PATH));
    res = gtk_list_store_iter_is_valid (list_store, &test_iter);
    if (res != CORRECT_RES)
    {
        TEST_FAIL ("res = %d, should be %d", res, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef ITER_PATH
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_iter_is_valid
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Checks if the given iter is a valid iter for this GtkListStore.
 * Params Values: newly created GtkListStore* containing 1 rows, GtkTreeIter* pointing to "5"
 * Expected: FALSE  
 */
static void test_purpose_53()
{
    #define N_ROWS 1
    #define ITER_PATH "5"
    #define CORRECT_RES FALSE
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter test_iter;
    gboolean res;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_tree_model_get_iter (GTK_TREE_MODEL (list_store), &test_iter, 
                             gtk_tree_path_new_from_string (ITER_PATH));
    res = gtk_list_store_iter_is_valid (list_store, &test_iter);
    if (res != CORRECT_RES)
    {
        TEST_FAIL ("res = %d, should be %d", res, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef ITER_PATH
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_iter_is_valid
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Checks if the given iter is a valid iter for this GtkListStore.
 * Params Values: newly created GtkListStore* containing 49 rows, GtkTreeIter* pointing to "0"
 * Expected: TRUE  
 */
static void test_purpose_54()
{
    #define N_ROWS 49
    #define ITER_PATH "0"
    #define CORRECT_RES TRUE
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter test_iter;
    gboolean res;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_tree_model_get_iter (GTK_TREE_MODEL (list_store), &test_iter, 
                             gtk_tree_path_new_from_string (ITER_PATH));
    res = gtk_list_store_iter_is_valid (list_store, &test_iter);
    if (res != CORRECT_RES)
    {
        TEST_FAIL ("res = %d, should be %d", res, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef ITER_PATH
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_iter_is_valid
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Checks if the given iter is a valid iter for this GtkListStore.
 * Params Values: newly created GtkListStore* containing 49 rows, GtkTreeIter* pointing to "25"
 * Expected: TRUE  
 */
static void test_purpose_55()
{
    #define N_ROWS 49
    #define ITER_PATH "25"
    #define CORRECT_RES TRUE
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter test_iter;
    gboolean res;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_tree_model_get_iter (GTK_TREE_MODEL (list_store), &test_iter, 
                             gtk_tree_path_new_from_string (ITER_PATH));
    res = gtk_list_store_iter_is_valid (list_store, &test_iter);
    if (res != CORRECT_RES)
    {
        TEST_FAIL ("res = %d, should be %d", res, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef ITER_PATH
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_iter_is_valid
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Checks if the given iter is a valid iter for this GtkListStore.
 * Params Values: newly created GtkListStore* containing 49 rows, GtkTreeIter* pointing to "48"
 * Expected: TRUE  
 */
static void test_purpose_56()
{
    #define N_ROWS 49
    #define ITER_PATH "48"
    #define CORRECT_RES TRUE
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter test_iter;
    gboolean res;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_tree_model_get_iter (GTK_TREE_MODEL (list_store), &test_iter, 
                             gtk_tree_path_new_from_string (ITER_PATH));
    res = gtk_list_store_iter_is_valid (list_store, &test_iter);
    if (res != CORRECT_RES)
    {
        TEST_FAIL ("res = %d, should be %d", res, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef ITER_PATH
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_iter_is_valid
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Checks if the given iter is a valid iter for this GtkListStore.
 * Params Values: newly created GtkListStore* containing 49 rows, GtkTreeIter* pointing to "49"
 * Expected: FALSE  
 */
static void test_purpose_57()
{
    #define N_ROWS 49
    #define ITER_PATH "49"
    #define CORRECT_RES FALSE
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter test_iter;
    gboolean res;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_tree_model_get_iter (GTK_TREE_MODEL (list_store), &test_iter, 
                             gtk_tree_path_new_from_string (ITER_PATH));
    res = gtk_list_store_iter_is_valid (list_store, &test_iter);
    if (res != CORRECT_RES)
    {
        TEST_FAIL ("res = %d, should be %d", res, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef ITER_PATH
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_iter_is_valid
 * Params: GtkListStore *list_store, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Checks if the given iter is a valid iter for this GtkListStore.
 * Params Values: newly created GtkListStore* containing 49 rows, GtkTreeIter* pointing to "149"
 * Expected: FALSE  
 */
static void test_purpose_58()
{
    #define N_ROWS 49
    #define ITER_PATH "149"
    #define CORRECT_RES FALSE
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter test_iter;
    gboolean res;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    gtk_tree_model_get_iter (GTK_TREE_MODEL (list_store), &test_iter, 
                             gtk_tree_path_new_from_string (ITER_PATH));
    res = gtk_list_store_iter_is_valid (list_store, &test_iter);
    if (res != CORRECT_RES)
    {
        TEST_FAIL ("res = %d, should be %d", res, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef ITER_PATH
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_move_before
 * Params: GtkListStore *store, GtkTreeIter *iter, GtkTreePath *position
 * Returns: void
 * Assertion: Moves iter in store to the position before position.
 * Params Values: newly created GtkListStore* containing 1 rows, GtkTreeIter* pointing to "0", GtkTreePath* pointing to "0"
 * Expected: void  
 */
static void test_purpose_59()
{
    #define N_ROWS 1
    #define SRC_PATH_STR "0"
    #define DEST_PATH_STR "0"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter;
    GtkTreeIter target_iter;
    GtkTreeIter dest_iter;
    guint i;
    gboolean iter_valid;
    guint src_uint_value;
    guint dest_uint_value;
    GValue src_val = {0,};
    GValue dest_val = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = DEST_PATH_STR ? strdup (DEST_PATH_STR) : NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", src_path_str);
        return;
    }
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter, 0, &src_val);
    src_uint_value = g_value_get_uint (&src_val);
    
    if (dest_path_str) {
        iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store),
                                                          &target_iter, dest_path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
            return;
        }
    }
    
    gtk_list_store_move_before (list_store, &src_iter, dest_path_str ? &target_iter : NULL);
    
    if (dest_path_str) {
        /* we expect correct parameters passed to the function */
        int isrc;
        int idest;
    
        isrc = atoi (src_path_str);
        idest = atoi (dest_path_str);
        
        if (idest > isrc)
        {
            sprintf (dest_path_str, "%d", idest - 1);
        }
    } else {
        dest_path_str = strdup (src_path_str);
        sprintf (dest_path_str, "%d", N_ROWS - 1);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter, dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter, 0, &dest_val);
    dest_uint_value = g_value_get_uint (&dest_val);
    
    if (src_uint_value != dest_uint_value)
    {
        TEST_FAIL ("value of iter pointing to '%s' is %d, should be %d", 
                   dest_path_str, src_uint_value, dest_uint_value);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_move_before
 * Params: GtkListStore *store, GtkTreeIter *iter, GtkTreePath *position
 * Returns: void
 * Assertion: Moves iter in store to the position before position.
 * Params Values: newly created GtkListStore* containing 4 rows, GtkTreeIter* pointing to "3", GtkTreePath* pointing to "3"
 * Expected: void  
 */
static void test_purpose_60()
{
    #define N_ROWS 4
    #define SRC_PATH_STR "3"
    #define DEST_PATH_STR "3"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter;
    GtkTreeIter target_iter;
    GtkTreeIter dest_iter;
    guint i;
    gboolean iter_valid;
    guint src_uint_value;
    guint dest_uint_value;
    GValue src_val = {0,};
    GValue dest_val = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = DEST_PATH_STR ? strdup (DEST_PATH_STR) : NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", src_path_str);
        return;
    }
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter, 0, &src_val);
    src_uint_value = g_value_get_uint (&src_val);
    
    if (dest_path_str) {
        iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store),
                                                          &target_iter, dest_path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
            return;
        }
    }
    
    gtk_list_store_move_before (list_store, &src_iter, dest_path_str ? &target_iter : NULL);
    
    if (dest_path_str) {
        /* we expect correct parameters passed to the function */
        int isrc;
        int idest;
    
        isrc = atoi (src_path_str);
        idest = atoi (dest_path_str);
        
        if (idest > isrc)
        {
            sprintf (dest_path_str, "%d", idest - 1);
        }
    } else {
        dest_path_str = strdup (src_path_str);
        sprintf (dest_path_str, "%d", N_ROWS - 1);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter, dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter, 0, &dest_val);
    dest_uint_value = g_value_get_uint (&dest_val);
    
    if (src_uint_value != dest_uint_value)
    {
        TEST_FAIL ("value of iter pointing to '%s' is %d, should be %d", 
                   dest_path_str, src_uint_value, dest_uint_value);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_move_before
 * Params: GtkListStore *store, GtkTreeIter *iter, GtkTreePath *position
 * Returns: void
 * Assertion: Moves iter in store to the position before position.
 * Params Values: newly created GtkListStore* containing 7 rows, GtkTreeIter* pointing to "3", GtkTreePath* pointing to "0"
 * Expected: void  
 */
static void test_purpose_61()
{
    #define N_ROWS 7
    #define SRC_PATH_STR "3"
    #define DEST_PATH_STR "0"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter;
    GtkTreeIter target_iter;
    GtkTreeIter dest_iter;
    guint i;
    gboolean iter_valid;
    guint src_uint_value;
    guint dest_uint_value;
    GValue src_val = {0,};
    GValue dest_val = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = DEST_PATH_STR ? strdup (DEST_PATH_STR) : NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", src_path_str);
        return;
    }
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter, 0, &src_val);
    src_uint_value = g_value_get_uint (&src_val);
    
    if (dest_path_str) {
        iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store),
                                                          &target_iter, dest_path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
            return;
        }
    }
    
    gtk_list_store_move_before (list_store, &src_iter, dest_path_str ? &target_iter : NULL);
    
    if (dest_path_str) {
        /* we expect correct parameters passed to the function */
        int isrc;
        int idest;
    
        isrc = atoi (src_path_str);
        idest = atoi (dest_path_str);
        
        if (idest > isrc)
        {
            sprintf (dest_path_str, "%d", idest - 1);
        }
    } else {
        dest_path_str = strdup (src_path_str);
        sprintf (dest_path_str, "%d", N_ROWS - 1);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter, dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter, 0, &dest_val);
    dest_uint_value = g_value_get_uint (&dest_val);
    
    if (src_uint_value != dest_uint_value)
    {
        TEST_FAIL ("value of iter pointing to '%s' is %d, should be %d", 
                   dest_path_str, src_uint_value, dest_uint_value);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_move_before
 * Params: GtkListStore *store, GtkTreeIter *iter, GtkTreePath *position
 * Returns: void
 * Assertion: Moves iter in store to the position before position.
 * Params Values: newly created GtkListStore* containing 7 rows, GtkTreeIter* pointing to "0", GtkTreePath* pointing to "3"
 * Expected: void  
 */
static void test_purpose_62()
{
    #define N_ROWS 7
    #define SRC_PATH_STR "0"
    #define DEST_PATH_STR "3"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter;
    GtkTreeIter target_iter;
    GtkTreeIter dest_iter;
    guint i;
    gboolean iter_valid;
    guint src_uint_value;
    guint dest_uint_value;
    GValue src_val = {0,};
    GValue dest_val = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = DEST_PATH_STR ? strdup (DEST_PATH_STR) : NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", src_path_str);
        return;
    }
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter, 0, &src_val);
    src_uint_value = g_value_get_uint (&src_val);
    
    if (dest_path_str) {
        iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store),
                                                          &target_iter, dest_path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
            return;
        }
    }
    
    gtk_list_store_move_before (list_store, &src_iter, dest_path_str ? &target_iter : NULL);
    
    if (dest_path_str) {
        /* we expect correct parameters passed to the function */
        int isrc;
        int idest;
    
        isrc = atoi (src_path_str);
        idest = atoi (dest_path_str);
        
        if (idest > isrc)
        {
            sprintf (dest_path_str, "%d", idest - 1);
        }
    } else {
        dest_path_str = strdup (src_path_str);
        sprintf (dest_path_str, "%d", N_ROWS - 1);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter, dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter, 0, &dest_val);
    dest_uint_value = g_value_get_uint (&dest_val);
    
    if (src_uint_value != dest_uint_value)
    {
        TEST_FAIL ("value of iter pointing to '%s' is %d, should be %d", 
                   dest_path_str, src_uint_value, dest_uint_value);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_move_before
 * Params: GtkListStore *store, GtkTreeIter *iter, GtkTreePath *position
 * Returns: void
 * Assertion: Moves iter in store to the position before position.
 * Params Values: newly created GtkListStore* containing 7 rows, GtkTreeIter* pointing to "0", GtkTreePath* pointing to "1"
 * Expected: void  
 */
static void test_purpose_63()
{
    #define N_ROWS 7
    #define SRC_PATH_STR "0"
    #define DEST_PATH_STR "1"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter;
    GtkTreeIter target_iter;
    GtkTreeIter dest_iter;
    guint i;
    gboolean iter_valid;
    guint src_uint_value;
    guint dest_uint_value;
    GValue src_val = {0,};
    GValue dest_val = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = DEST_PATH_STR ? strdup (DEST_PATH_STR) : NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", src_path_str);
        return;
    }
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter, 0, &src_val);
    src_uint_value = g_value_get_uint (&src_val);
    
    if (dest_path_str) {
        iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store),
                                                          &target_iter, dest_path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
            return;
        }
    }
    
    gtk_list_store_move_before (list_store, &src_iter, dest_path_str ? &target_iter : NULL);
    
    if (dest_path_str) {
        /* we expect correct parameters passed to the function */
        int isrc;
        int idest;
    
        isrc = atoi (src_path_str);
        idest = atoi (dest_path_str);
        
        if (idest > isrc)
        {
            sprintf (dest_path_str, "%d", idest - 1);
        }
    } else {
        dest_path_str = strdup (src_path_str);
        sprintf (dest_path_str, "%d", N_ROWS - 1);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter, dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter, 0, &dest_val);
    dest_uint_value = g_value_get_uint (&dest_val);
    
    if (src_uint_value != dest_uint_value)
    {
        TEST_FAIL ("value of iter pointing to '%s' is %d, should be %d", 
                   dest_path_str, src_uint_value, dest_uint_value);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_move_before
 * Params: GtkListStore *store, GtkTreeIter *iter, GtkTreePath *position
 * Returns: void
 * Assertion: Moves iter in store to the position before position.
 * Params Values: newly created GtkListStore* containing 7 rows, GtkTreeIter* pointing to "1", GtkTreePath* pointing to "0"
 * Expected: void  
 */
static void test_purpose_64()
{
    #define N_ROWS 7
    #define SRC_PATH_STR "1"
    #define DEST_PATH_STR "0"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter;
    GtkTreeIter target_iter;
    GtkTreeIter dest_iter;
    guint i;
    gboolean iter_valid;
    guint src_uint_value;
    guint dest_uint_value;
    GValue src_val = {0,};
    GValue dest_val = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = DEST_PATH_STR ? strdup (DEST_PATH_STR) : NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", src_path_str);
        return;
    }
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter, 0, &src_val);
    src_uint_value = g_value_get_uint (&src_val);
    
    if (dest_path_str) {
        iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store),
                                                          &target_iter, dest_path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
            return;
        }
    }
    
    gtk_list_store_move_before (list_store, &src_iter, dest_path_str ? &target_iter : NULL);
    
    if (dest_path_str) {
        /* we expect correct parameters passed to the function */
        int isrc;
        int idest;
    
        isrc = atoi (src_path_str);
        idest = atoi (dest_path_str);
        
        if (idest > isrc)
        {
            sprintf (dest_path_str, "%d", idest - 1);
        }
    } else {
        dest_path_str = strdup (src_path_str);
        sprintf (dest_path_str, "%d", N_ROWS - 1);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter, dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter, 0, &dest_val);
    dest_uint_value = g_value_get_uint (&dest_val);
    
    if (src_uint_value != dest_uint_value)
    {
        TEST_FAIL ("value of iter pointing to '%s' is %d, should be %d", 
                   dest_path_str, src_uint_value, dest_uint_value);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_move_before
 * Params: GtkListStore *store, GtkTreeIter *iter, GtkTreePath *position
 * Returns: void
 * Assertion: Moves iter in store to the position before position.
 * Params Values: newly created GtkListStore* containing 7 rows, GtkTreeIter* pointing to "0", GtkTreePath* pointing to "6"
 * Expected: void  
 */
static void test_purpose_65()
{
    #define N_ROWS 7
    #define SRC_PATH_STR "0"
    #define DEST_PATH_STR "6"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter;
    GtkTreeIter target_iter;
    GtkTreeIter dest_iter;
    guint i;
    gboolean iter_valid;
    guint src_uint_value;
    guint dest_uint_value;
    GValue src_val = {0,};
    GValue dest_val = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = DEST_PATH_STR ? strdup (DEST_PATH_STR) : NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", src_path_str);
        return;
    }
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter, 0, &src_val);
    src_uint_value = g_value_get_uint (&src_val);
    
    if (dest_path_str) {
        iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store),
                                                          &target_iter, dest_path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
            return;
        }
    }
    
    gtk_list_store_move_before (list_store, &src_iter, dest_path_str ? &target_iter : NULL);
    
    if (dest_path_str) {
        /* we expect correct parameters passed to the function */
        int isrc;
        int idest;
    
        isrc = atoi (src_path_str);
        idest = atoi (dest_path_str);
        
        if (idest > isrc)
        {
            sprintf (dest_path_str, "%d", idest - 1);
        }
    } else {
        dest_path_str = strdup (src_path_str);
        sprintf (dest_path_str, "%d", N_ROWS - 1);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter, dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter, 0, &dest_val);
    dest_uint_value = g_value_get_uint (&dest_val);
    
    if (src_uint_value != dest_uint_value)
    {
        TEST_FAIL ("value of iter pointing to '%s' is %d, should be %d", 
                   dest_path_str, src_uint_value, dest_uint_value);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_move_before
 * Params: GtkListStore *store, GtkTreeIter *iter, GtkTreePath *position
 * Returns: void
 * Assertion: Moves iter in store to the position before position.
 * Params Values: newly created GtkListStore* containing 7 rows, GtkTreeIter* pointing to "6", GtkTreePath* pointing to "0"
 * Expected: void  
 */
static void test_purpose_66()
{
    #define N_ROWS 7
    #define SRC_PATH_STR "6"
    #define DEST_PATH_STR "0"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter;
    GtkTreeIter target_iter;
    GtkTreeIter dest_iter;
    guint i;
    gboolean iter_valid;
    guint src_uint_value;
    guint dest_uint_value;
    GValue src_val = {0,};
    GValue dest_val = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = DEST_PATH_STR ? strdup (DEST_PATH_STR) : NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", src_path_str);
        return;
    }
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter, 0, &src_val);
    src_uint_value = g_value_get_uint (&src_val);
    
    if (dest_path_str) {
        iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store),
                                                          &target_iter, dest_path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
            return;
        }
    }
    
    gtk_list_store_move_before (list_store, &src_iter, dest_path_str ? &target_iter : NULL);
    
    if (dest_path_str) {
        /* we expect correct parameters passed to the function */
        int isrc;
        int idest;
    
        isrc = atoi (src_path_str);
        idest = atoi (dest_path_str);
        
        if (idest > isrc)
        {
            sprintf (dest_path_str, "%d", idest - 1);
        }
    } else {
        dest_path_str = strdup (src_path_str);
        sprintf (dest_path_str, "%d", N_ROWS - 1);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter, dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter, 0, &dest_val);
    dest_uint_value = g_value_get_uint (&dest_val);
    
    if (src_uint_value != dest_uint_value)
    {
        TEST_FAIL ("value of iter pointing to '%s' is %d, should be %d", 
                   dest_path_str, src_uint_value, dest_uint_value);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_move_before
 * Params: GtkListStore *store, GtkTreeIter *iter, GtkTreePath *position
 * Returns: void
 * Assertion: Moves iter in store to the position before position.
 * Params Values: newly created GtkListStore* containing 7 rows, GtkTreeIter* pointing to "2", GtkTreePath* pointing to "5"
 * Expected: void  
 */
static void test_purpose_67()
{
    #define N_ROWS 7
    #define SRC_PATH_STR "2"
    #define DEST_PATH_STR "5"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter;
    GtkTreeIter target_iter;
    GtkTreeIter dest_iter;
    guint i;
    gboolean iter_valid;
    guint src_uint_value;
    guint dest_uint_value;
    GValue src_val = {0,};
    GValue dest_val = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = DEST_PATH_STR ? strdup (DEST_PATH_STR) : NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", src_path_str);
        return;
    }
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter, 0, &src_val);
    src_uint_value = g_value_get_uint (&src_val);
    
    if (dest_path_str) {
        iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store),
                                                          &target_iter, dest_path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
            return;
        }
    }
    
    gtk_list_store_move_before (list_store, &src_iter, dest_path_str ? &target_iter : NULL);
    
    if (dest_path_str) {
        /* we expect correct parameters passed to the function */
        int isrc;
        int idest;
    
        isrc = atoi (src_path_str);
        idest = atoi (dest_path_str);
        
        if (idest > isrc)
        {
            sprintf (dest_path_str, "%d", idest - 1);
        }
    } else {
        dest_path_str = strdup (src_path_str);
        sprintf (dest_path_str, "%d", N_ROWS - 1);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter, dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter, 0, &dest_val);
    dest_uint_value = g_value_get_uint (&dest_val);
    
    if (src_uint_value != dest_uint_value)
    {
        TEST_FAIL ("value of iter pointing to '%s' is %d, should be %d", 
                   dest_path_str, src_uint_value, dest_uint_value);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_move_before
 * Params: GtkListStore *store, GtkTreeIter *iter, GtkTreePath *position
 * Returns: void
 * Assertion: Moves iter in store to the position before position.
 * Params Values: newly created GtkListStore* containing 7 rows, GtkTreeIter* pointing to "5", GtkTreePath* pointing to "2"
 * Expected: void  
 */
static void test_purpose_68()
{
    #define N_ROWS 7
    #define SRC_PATH_STR "5"
    #define DEST_PATH_STR "2"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter;
    GtkTreeIter target_iter;
    GtkTreeIter dest_iter;
    guint i;
    gboolean iter_valid;
    guint src_uint_value;
    guint dest_uint_value;
    GValue src_val = {0,};
    GValue dest_val = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = DEST_PATH_STR ? strdup (DEST_PATH_STR) : NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", src_path_str);
        return;
    }
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter, 0, &src_val);
    src_uint_value = g_value_get_uint (&src_val);
    
    if (dest_path_str) {
        iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store),
                                                          &target_iter, dest_path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
            return;
        }
    }
    
    gtk_list_store_move_before (list_store, &src_iter, dest_path_str ? &target_iter : NULL);
    
    if (dest_path_str) {
        /* we expect correct parameters passed to the function */
        int isrc;
        int idest;
    
        isrc = atoi (src_path_str);
        idest = atoi (dest_path_str);
        
        if (idest > isrc)
        {
            sprintf (dest_path_str, "%d", idest - 1);
        }
    } else {
        dest_path_str = strdup (src_path_str);
        sprintf (dest_path_str, "%d", N_ROWS - 1);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter, dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter, 0, &dest_val);
    dest_uint_value = g_value_get_uint (&dest_val);
    
    if (src_uint_value != dest_uint_value)
    {
        TEST_FAIL ("value of iter pointing to '%s' is %d, should be %d", 
                   dest_path_str, src_uint_value, dest_uint_value);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_move_before
 * Params: GtkListStore *store, GtkTreeIter *iter, GtkTreePath *position
 * Returns: void
 * Assertion: Moves iter in store to the position before position.
 * Params Values: newly created GtkListStore* containing 5 rows, GtkTreeIter* pointing to "0", GtkTreePath* pointing to NULL
 * Expected: void  
 */
static void test_purpose_69()
{
    #define N_ROWS 5
    #define SRC_PATH_STR "0"
    #define DEST_PATH_STR NULL
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter;
    GtkTreeIter target_iter;
    GtkTreeIter dest_iter;
    guint i;
    gboolean iter_valid;
    guint src_uint_value;
    guint dest_uint_value;
    GValue src_val = {0,};
    GValue dest_val = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = DEST_PATH_STR ? strdup (DEST_PATH_STR) : NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", src_path_str);
        return;
    }
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter, 0, &src_val);
    src_uint_value = g_value_get_uint (&src_val);
    
    if (dest_path_str) {
        iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store),
                                                          &target_iter, dest_path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
            return;
        }
    }
    
    gtk_list_store_move_before (list_store, &src_iter, dest_path_str ? &target_iter : NULL);
    
    if (dest_path_str) {
        /* we expect correct parameters passed to the function */
        int isrc;
        int idest;
    
        isrc = atoi (src_path_str);
        idest = atoi (dest_path_str);
        
        if (idest > isrc)
        {
            sprintf (dest_path_str, "%d", idest - 1);
        }
    } else {
        dest_path_str = strdup (src_path_str);
        sprintf (dest_path_str, "%d", N_ROWS - 1);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter, dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter, 0, &dest_val);
    dest_uint_value = g_value_get_uint (&dest_val);
    
    if (src_uint_value != dest_uint_value)
    {
        TEST_FAIL ("value of iter pointing to '%s' is %d, should be %d", 
                   dest_path_str, src_uint_value, dest_uint_value);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_move_before
 * Params: GtkListStore *store, GtkTreeIter *iter, GtkTreePath *position
 * Returns: void
 * Assertion: Moves iter in store to the position before position.
 * Params Values: newly created GtkListStore* containing 5 rows, GtkTreeIter* pointing to "1", GtkTreePath* pointing to NULL
 * Expected: void  
 */
static void test_purpose_70()
{
    #define N_ROWS 5
    #define SRC_PATH_STR "1"
    #define DEST_PATH_STR NULL
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter;
    GtkTreeIter target_iter;
    GtkTreeIter dest_iter;
    guint i;
    gboolean iter_valid;
    guint src_uint_value;
    guint dest_uint_value;
    GValue src_val = {0,};
    GValue dest_val = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = DEST_PATH_STR ? strdup (DEST_PATH_STR) : NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", src_path_str);
        return;
    }
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter, 0, &src_val);
    src_uint_value = g_value_get_uint (&src_val);
    
    if (dest_path_str) {
        iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store),
                                                          &target_iter, dest_path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
            return;
        }
    }
    
    gtk_list_store_move_before (list_store, &src_iter, dest_path_str ? &target_iter : NULL);
    
    if (dest_path_str) {
        /* we expect correct parameters passed to the function */
        int isrc;
        int idest;
    
        isrc = atoi (src_path_str);
        idest = atoi (dest_path_str);
        
        if (idest > isrc)
        {
            sprintf (dest_path_str, "%d", idest - 1);
        }
    } else {
        dest_path_str = strdup (src_path_str);
        sprintf (dest_path_str, "%d", N_ROWS - 1);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter, dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter, 0, &dest_val);
    dest_uint_value = g_value_get_uint (&dest_val);
    
    if (src_uint_value != dest_uint_value)
    {
        TEST_FAIL ("value of iter pointing to '%s' is %d, should be %d", 
                   dest_path_str, src_uint_value, dest_uint_value);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_move_before
 * Params: GtkListStore *store, GtkTreeIter *iter, GtkTreePath *position
 * Returns: void
 * Assertion: Moves iter in store to the position before position.
 * Params Values: newly created GtkListStore* containing 5 rows, GtkTreeIter* pointing to "2", GtkTreePath* pointing to NULL
 * Expected: void  
 */
static void test_purpose_71()
{
    #define N_ROWS 5
    #define SRC_PATH_STR "2"
    #define DEST_PATH_STR NULL
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter;
    GtkTreeIter target_iter;
    GtkTreeIter dest_iter;
    guint i;
    gboolean iter_valid;
    guint src_uint_value;
    guint dest_uint_value;
    GValue src_val = {0,};
    GValue dest_val = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = DEST_PATH_STR ? strdup (DEST_PATH_STR) : NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", src_path_str);
        return;
    }
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter, 0, &src_val);
    src_uint_value = g_value_get_uint (&src_val);
    
    if (dest_path_str) {
        iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store),
                                                          &target_iter, dest_path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
            return;
        }
    }
    
    gtk_list_store_move_before (list_store, &src_iter, dest_path_str ? &target_iter : NULL);
    
    if (dest_path_str) {
        /* we expect correct parameters passed to the function */
        int isrc;
        int idest;
    
        isrc = atoi (src_path_str);
        idest = atoi (dest_path_str);
        
        if (idest > isrc)
        {
            sprintf (dest_path_str, "%d", idest - 1);
        }
    } else {
        dest_path_str = strdup (src_path_str);
        sprintf (dest_path_str, "%d", N_ROWS - 1);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter, dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter, 0, &dest_val);
    dest_uint_value = g_value_get_uint (&dest_val);
    
    if (src_uint_value != dest_uint_value)
    {
        TEST_FAIL ("value of iter pointing to '%s' is %d, should be %d", 
                   dest_path_str, src_uint_value, dest_uint_value);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_move_before
 * Params: GtkListStore *store, GtkTreeIter *iter, GtkTreePath *position
 * Returns: void
 * Assertion: Moves iter in store to the position before position.
 * Params Values: newly created GtkListStore* containing 5 rows, GtkTreeIter* pointing to "3", GtkTreePath* pointing to NULL
 * Expected: void  
 */
static void test_purpose_72()
{
    #define N_ROWS 5
    #define SRC_PATH_STR "3"
    #define DEST_PATH_STR NULL
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter;
    GtkTreeIter target_iter;
    GtkTreeIter dest_iter;
    guint i;
    gboolean iter_valid;
    guint src_uint_value;
    guint dest_uint_value;
    GValue src_val = {0,};
    GValue dest_val = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = DEST_PATH_STR ? strdup (DEST_PATH_STR) : NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", src_path_str);
        return;
    }
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter, 0, &src_val);
    src_uint_value = g_value_get_uint (&src_val);
    
    if (dest_path_str) {
        iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store),
                                                          &target_iter, dest_path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
            return;
        }
    }
    
    gtk_list_store_move_before (list_store, &src_iter, dest_path_str ? &target_iter : NULL);
    
    if (dest_path_str) {
        /* we expect correct parameters passed to the function */
        int isrc;
        int idest;
    
        isrc = atoi (src_path_str);
        idest = atoi (dest_path_str);
        
        if (idest > isrc)
        {
            sprintf (dest_path_str, "%d", idest - 1);
        }
    } else {
        dest_path_str = strdup (src_path_str);
        sprintf (dest_path_str, "%d", N_ROWS - 1);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter, dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter, 0, &dest_val);
    dest_uint_value = g_value_get_uint (&dest_val);
    
    if (src_uint_value != dest_uint_value)
    {
        TEST_FAIL ("value of iter pointing to '%s' is %d, should be %d", 
                   dest_path_str, src_uint_value, dest_uint_value);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_move_before
 * Params: GtkListStore *store, GtkTreeIter *iter, GtkTreePath *position
 * Returns: void
 * Assertion: Moves iter in store to the position before position.
 * Params Values: newly created GtkListStore* containing 5 rows, GtkTreeIter* pointing to "4", GtkTreePath* pointing to NULL
 * Expected: void  
 */
static void test_purpose_73()
{
    #define N_ROWS 5
    #define SRC_PATH_STR "4"
    #define DEST_PATH_STR NULL
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter;
    GtkTreeIter target_iter;
    GtkTreeIter dest_iter;
    guint i;
    gboolean iter_valid;
    guint src_uint_value;
    guint dest_uint_value;
    GValue src_val = {0,};
    GValue dest_val = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = DEST_PATH_STR ? strdup (DEST_PATH_STR) : NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", src_path_str);
        return;
    }
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter, 0, &src_val);
    src_uint_value = g_value_get_uint (&src_val);
    
    if (dest_path_str) {
        iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store),
                                                          &target_iter, dest_path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
            return;
        }
    }
    
    gtk_list_store_move_before (list_store, &src_iter, dest_path_str ? &target_iter : NULL);
    
    if (dest_path_str) {
        /* we expect correct parameters passed to the function */
        int isrc;
        int idest;
    
        isrc = atoi (src_path_str);
        idest = atoi (dest_path_str);
        
        if (idest > isrc)
        {
            sprintf (dest_path_str, "%d", idest - 1);
        }
    } else {
        dest_path_str = strdup (src_path_str);
        sprintf (dest_path_str, "%d", N_ROWS - 1);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter, dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter, 0, &dest_val);
    dest_uint_value = g_value_get_uint (&dest_val);
    
    if (src_uint_value != dest_uint_value)
    {
        TEST_FAIL ("value of iter pointing to '%s' is %d, should be %d", 
                   dest_path_str, src_uint_value, dest_uint_value);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_move_after
 * Params: GtkListStore *store, GtkTreeIter *iter, GtkTreePath *position
 * Returns: void
 * Assertion: Moves iter in store to the position before position.
 * Params Values: newly created GtkListStore* containing 1 rows, GtkTreeIter* pointing to "0", GtkTreePath* pointing to "0"
 * Expected: void  
 */
static void test_purpose_74()
{
    #define N_ROWS 1
    #define SRC_PATH_STR "0"
    #define DEST_PATH_STR "0"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter;
    GtkTreeIter target_iter;
    GtkTreeIter dest_iter;
    guint i;
    gboolean iter_valid;
    guint src_uint_value;
    guint dest_uint_value;
    GValue src_val = {0,};
    GValue dest_val = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = DEST_PATH_STR ? strdup (DEST_PATH_STR) : NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", src_path_str);
        return;
    }
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter, 0, &src_val);
    src_uint_value = g_value_get_uint (&src_val);
    
    if (dest_path_str) {
        iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store),
                                                          &target_iter, dest_path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
            return;
        }
    }
    
    gtk_list_store_move_after (list_store, &src_iter, dest_path_str ? &target_iter : NULL);
    
    if (dest_path_str) {
        /* we expect correct parameters passed to the function */
        int isrc;
        int idest;
    
        isrc = atoi (src_path_str);
        idest = atoi (dest_path_str);
        
        if (idest < isrc)
        {
            sprintf (dest_path_str, "%d", idest + 1);
        }
    } else {
        dest_path_str = strdup (src_path_str);
        sprintf (dest_path_str, "%d", 0);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter, dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter, 0, &dest_val);
    dest_uint_value = g_value_get_uint (&dest_val);
    
    if (src_uint_value != dest_uint_value)
    {
        TEST_FAIL ("value of iter pointing to '%s' is %d, should be %d", 
                   dest_path_str, src_uint_value, dest_uint_value);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_move_after
 * Params: GtkListStore *store, GtkTreeIter *iter, GtkTreePath *position
 * Returns: void
 * Assertion: Moves iter in store to the position before position.
 * Params Values: newly created GtkListStore* containing 4 rows, GtkTreeIter* pointing to "3", GtkTreePath* pointing to "3"
 * Expected: void  
 */
static void test_purpose_75()
{
    #define N_ROWS 4
    #define SRC_PATH_STR "3"
    #define DEST_PATH_STR "3"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter;
    GtkTreeIter target_iter;
    GtkTreeIter dest_iter;
    guint i;
    gboolean iter_valid;
    guint src_uint_value;
    guint dest_uint_value;
    GValue src_val = {0,};
    GValue dest_val = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = DEST_PATH_STR ? strdup (DEST_PATH_STR) : NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", src_path_str);
        return;
    }
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter, 0, &src_val);
    src_uint_value = g_value_get_uint (&src_val);
    
    if (dest_path_str) {
        iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store),
                                                          &target_iter, dest_path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
            return;
        }
    }
    
    gtk_list_store_move_after (list_store, &src_iter, dest_path_str ? &target_iter : NULL);
    
    if (dest_path_str) {
        /* we expect correct parameters passed to the function */
        int isrc;
        int idest;
    
        isrc = atoi (src_path_str);
        idest = atoi (dest_path_str);
        
        if (idest < isrc)
        {
            sprintf (dest_path_str, "%d", idest + 1);
        }
    } else {
        dest_path_str = strdup (src_path_str);
        sprintf (dest_path_str, "%d", 0);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter, dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter, 0, &dest_val);
    dest_uint_value = g_value_get_uint (&dest_val);
    
    if (src_uint_value != dest_uint_value)
    {
        TEST_FAIL ("value of iter pointing to '%s' is %d, should be %d", 
                   dest_path_str, src_uint_value, dest_uint_value);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_move_after
 * Params: GtkListStore *store, GtkTreeIter *iter, GtkTreePath *position
 * Returns: void
 * Assertion: Moves iter in store to the position before position.
 * Params Values: newly created GtkListStore* containing 7 rows, GtkTreeIter* pointing to "3", GtkTreePath* pointing to "0"
 * Expected: void  
 */
static void test_purpose_76()
{
    #define N_ROWS 7
    #define SRC_PATH_STR "3"
    #define DEST_PATH_STR "0"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter;
    GtkTreeIter target_iter;
    GtkTreeIter dest_iter;
    guint i;
    gboolean iter_valid;
    guint src_uint_value;
    guint dest_uint_value;
    GValue src_val = {0,};
    GValue dest_val = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = DEST_PATH_STR ? strdup (DEST_PATH_STR) : NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", src_path_str);
        return;
    }
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter, 0, &src_val);
    src_uint_value = g_value_get_uint (&src_val);
    
    if (dest_path_str) {
        iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store),
                                                          &target_iter, dest_path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
            return;
        }
    }
    
    gtk_list_store_move_after (list_store, &src_iter, dest_path_str ? &target_iter : NULL);
    
    if (dest_path_str) {
        /* we expect correct parameters passed to the function */
        int isrc;
        int idest;
    
        isrc = atoi (src_path_str);
        idest = atoi (dest_path_str);
        
        if (idest < isrc)
        {
            sprintf (dest_path_str, "%d", idest + 1);
        }
    } else {
        dest_path_str = strdup (src_path_str);
        sprintf (dest_path_str, "%d", 0);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter, dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter, 0, &dest_val);
    dest_uint_value = g_value_get_uint (&dest_val);
    
    if (src_uint_value != dest_uint_value)
    {
        TEST_FAIL ("value of iter pointing to '%s' is %d, should be %d", 
                   dest_path_str, src_uint_value, dest_uint_value);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_move_after
 * Params: GtkListStore *store, GtkTreeIter *iter, GtkTreePath *position
 * Returns: void
 * Assertion: Moves iter in store to the position before position.
 * Params Values: newly created GtkListStore* containing 7 rows, GtkTreeIter* pointing to "0", GtkTreePath* pointing to "3"
 * Expected: void  
 */
static void test_purpose_77()
{
    #define N_ROWS 7
    #define SRC_PATH_STR "0"
    #define DEST_PATH_STR "3"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter;
    GtkTreeIter target_iter;
    GtkTreeIter dest_iter;
    guint i;
    gboolean iter_valid;
    guint src_uint_value;
    guint dest_uint_value;
    GValue src_val = {0,};
    GValue dest_val = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = DEST_PATH_STR ? strdup (DEST_PATH_STR) : NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", src_path_str);
        return;
    }
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter, 0, &src_val);
    src_uint_value = g_value_get_uint (&src_val);
    
    if (dest_path_str) {
        iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store),
                                                          &target_iter, dest_path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
            return;
        }
    }
    
    gtk_list_store_move_after (list_store, &src_iter, dest_path_str ? &target_iter : NULL);
    
    if (dest_path_str) {
        /* we expect correct parameters passed to the function */
        int isrc;
        int idest;
    
        isrc = atoi (src_path_str);
        idest = atoi (dest_path_str);
        
        if (idest < isrc)
        {
            sprintf (dest_path_str, "%d", idest + 1);
        }
    } else {
        dest_path_str = strdup (src_path_str);
        sprintf (dest_path_str, "%d", 0);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter, dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter, 0, &dest_val);
    dest_uint_value = g_value_get_uint (&dest_val);
    
    if (src_uint_value != dest_uint_value)
    {
        TEST_FAIL ("value of iter pointing to '%s' is %d, should be %d", 
                   dest_path_str, src_uint_value, dest_uint_value);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_move_after
 * Params: GtkListStore *store, GtkTreeIter *iter, GtkTreePath *position
 * Returns: void
 * Assertion: Moves iter in store to the position before position.
 * Params Values: newly created GtkListStore* containing 7 rows, GtkTreeIter* pointing to "0", GtkTreePath* pointing to "1"
 * Expected: void  
 */
static void test_purpose_78()
{
    #define N_ROWS 7
    #define SRC_PATH_STR "0"
    #define DEST_PATH_STR "1"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter;
    GtkTreeIter target_iter;
    GtkTreeIter dest_iter;
    guint i;
    gboolean iter_valid;
    guint src_uint_value;
    guint dest_uint_value;
    GValue src_val = {0,};
    GValue dest_val = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = DEST_PATH_STR ? strdup (DEST_PATH_STR) : NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", src_path_str);
        return;
    }
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter, 0, &src_val);
    src_uint_value = g_value_get_uint (&src_val);
    
    if (dest_path_str) {
        iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store),
                                                          &target_iter, dest_path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
            return;
        }
    }
    
    gtk_list_store_move_after (list_store, &src_iter, dest_path_str ? &target_iter : NULL);
    
    if (dest_path_str) {
        /* we expect correct parameters passed to the function */
        int isrc;
        int idest;
    
        isrc = atoi (src_path_str);
        idest = atoi (dest_path_str);
        
        if (idest < isrc)
        {
            sprintf (dest_path_str, "%d", idest + 1);
        }
    } else {
        dest_path_str = strdup (src_path_str);
        sprintf (dest_path_str, "%d", 0);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter, dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter, 0, &dest_val);
    dest_uint_value = g_value_get_uint (&dest_val);
    
    if (src_uint_value != dest_uint_value)
    {
        TEST_FAIL ("value of iter pointing to '%s' is %d, should be %d", 
                   dest_path_str, src_uint_value, dest_uint_value);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_move_after
 * Params: GtkListStore *store, GtkTreeIter *iter, GtkTreePath *position
 * Returns: void
 * Assertion: Moves iter in store to the position before position.
 * Params Values: newly created GtkListStore* containing 7 rows, GtkTreeIter* pointing to "1", GtkTreePath* pointing to "0"
 * Expected: void  
 */
static void test_purpose_79()
{
    #define N_ROWS 7
    #define SRC_PATH_STR "1"
    #define DEST_PATH_STR "0"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter;
    GtkTreeIter target_iter;
    GtkTreeIter dest_iter;
    guint i;
    gboolean iter_valid;
    guint src_uint_value;
    guint dest_uint_value;
    GValue src_val = {0,};
    GValue dest_val = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = DEST_PATH_STR ? strdup (DEST_PATH_STR) : NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", src_path_str);
        return;
    }
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter, 0, &src_val);
    src_uint_value = g_value_get_uint (&src_val);
    
    if (dest_path_str) {
        iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store),
                                                          &target_iter, dest_path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
            return;
        }
    }
    
    gtk_list_store_move_after (list_store, &src_iter, dest_path_str ? &target_iter : NULL);
    
    if (dest_path_str) {
        /* we expect correct parameters passed to the function */
        int isrc;
        int idest;
    
        isrc = atoi (src_path_str);
        idest = atoi (dest_path_str);
        
        if (idest < isrc)
        {
            sprintf (dest_path_str, "%d", idest + 1);
        }
    } else {
        dest_path_str = strdup (src_path_str);
        sprintf (dest_path_str, "%d", 0);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter, dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter, 0, &dest_val);
    dest_uint_value = g_value_get_uint (&dest_val);
    
    if (src_uint_value != dest_uint_value)
    {
        TEST_FAIL ("value of iter pointing to '%s' is %d, should be %d", 
                   dest_path_str, src_uint_value, dest_uint_value);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_move_after
 * Params: GtkListStore *store, GtkTreeIter *iter, GtkTreePath *position
 * Returns: void
 * Assertion: Moves iter in store to the position before position.
 * Params Values: newly created GtkListStore* containing 7 rows, GtkTreeIter* pointing to "0", GtkTreePath* pointing to "6"
 * Expected: void  
 */
static void test_purpose_80()
{
    #define N_ROWS 7
    #define SRC_PATH_STR "0"
    #define DEST_PATH_STR "6"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter;
    GtkTreeIter target_iter;
    GtkTreeIter dest_iter;
    guint i;
    gboolean iter_valid;
    guint src_uint_value;
    guint dest_uint_value;
    GValue src_val = {0,};
    GValue dest_val = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = DEST_PATH_STR ? strdup (DEST_PATH_STR) : NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", src_path_str);
        return;
    }
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter, 0, &src_val);
    src_uint_value = g_value_get_uint (&src_val);
    
    if (dest_path_str) {
        iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store),
                                                          &target_iter, dest_path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
            return;
        }
    }
    
    gtk_list_store_move_after (list_store, &src_iter, dest_path_str ? &target_iter : NULL);
    
    if (dest_path_str) {
        /* we expect correct parameters passed to the function */
        int isrc;
        int idest;
    
        isrc = atoi (src_path_str);
        idest = atoi (dest_path_str);
        
        if (idest < isrc)
        {
            sprintf (dest_path_str, "%d", idest + 1);
        }
    } else {
        dest_path_str = strdup (src_path_str);
        sprintf (dest_path_str, "%d", 0);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter, dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter, 0, &dest_val);
    dest_uint_value = g_value_get_uint (&dest_val);
    
    if (src_uint_value != dest_uint_value)
    {
        TEST_FAIL ("value of iter pointing to '%s' is %d, should be %d", 
                   dest_path_str, src_uint_value, dest_uint_value);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_move_after
 * Params: GtkListStore *store, GtkTreeIter *iter, GtkTreePath *position
 * Returns: void
 * Assertion: Moves iter in store to the position before position.
 * Params Values: newly created GtkListStore* containing 7 rows, GtkTreeIter* pointing to "6", GtkTreePath* pointing to "0"
 * Expected: void  
 */
static void test_purpose_81()
{
    #define N_ROWS 7
    #define SRC_PATH_STR "6"
    #define DEST_PATH_STR "0"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter;
    GtkTreeIter target_iter;
    GtkTreeIter dest_iter;
    guint i;
    gboolean iter_valid;
    guint src_uint_value;
    guint dest_uint_value;
    GValue src_val = {0,};
    GValue dest_val = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = DEST_PATH_STR ? strdup (DEST_PATH_STR) : NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", src_path_str);
        return;
    }
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter, 0, &src_val);
    src_uint_value = g_value_get_uint (&src_val);
    
    if (dest_path_str) {
        iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store),
                                                          &target_iter, dest_path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
            return;
        }
    }
    
    gtk_list_store_move_after (list_store, &src_iter, dest_path_str ? &target_iter : NULL);
    
    if (dest_path_str) {
        /* we expect correct parameters passed to the function */
        int isrc;
        int idest;
    
        isrc = atoi (src_path_str);
        idest = atoi (dest_path_str);
        
        if (idest < isrc)
        {
            sprintf (dest_path_str, "%d", idest + 1);
        }
    } else {
        dest_path_str = strdup (src_path_str);
        sprintf (dest_path_str, "%d", 0);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter, dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter, 0, &dest_val);
    dest_uint_value = g_value_get_uint (&dest_val);
    
    if (src_uint_value != dest_uint_value)
    {
        TEST_FAIL ("value of iter pointing to '%s' is %d, should be %d", 
                   dest_path_str, src_uint_value, dest_uint_value);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_move_after
 * Params: GtkListStore *store, GtkTreeIter *iter, GtkTreePath *position
 * Returns: void
 * Assertion: Moves iter in store to the position before position.
 * Params Values: newly created GtkListStore* containing 7 rows, GtkTreeIter* pointing to "2", GtkTreePath* pointing to "5"
 * Expected: void  
 */
static void test_purpose_82()
{
    #define N_ROWS 7
    #define SRC_PATH_STR "2"
    #define DEST_PATH_STR "5"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter;
    GtkTreeIter target_iter;
    GtkTreeIter dest_iter;
    guint i;
    gboolean iter_valid;
    guint src_uint_value;
    guint dest_uint_value;
    GValue src_val = {0,};
    GValue dest_val = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = DEST_PATH_STR ? strdup (DEST_PATH_STR) : NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", src_path_str);
        return;
    }
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter, 0, &src_val);
    src_uint_value = g_value_get_uint (&src_val);
    
    if (dest_path_str) {
        iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store),
                                                          &target_iter, dest_path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
            return;
        }
    }
    
    gtk_list_store_move_after (list_store, &src_iter, dest_path_str ? &target_iter : NULL);
    
    if (dest_path_str) {
        /* we expect correct parameters passed to the function */
        int isrc;
        int idest;
    
        isrc = atoi (src_path_str);
        idest = atoi (dest_path_str);
        
        if (idest < isrc)
        {
            sprintf (dest_path_str, "%d", idest + 1);
        }
    } else {
        dest_path_str = strdup (src_path_str);
        sprintf (dest_path_str, "%d", 0);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter, dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter, 0, &dest_val);
    dest_uint_value = g_value_get_uint (&dest_val);
    
    if (src_uint_value != dest_uint_value)
    {
        TEST_FAIL ("value of iter pointing to '%s' is %d, should be %d", 
                   dest_path_str, src_uint_value, dest_uint_value);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_move_after
 * Params: GtkListStore *store, GtkTreeIter *iter, GtkTreePath *position
 * Returns: void
 * Assertion: Moves iter in store to the position before position.
 * Params Values: newly created GtkListStore* containing 7 rows, GtkTreeIter* pointing to "5", GtkTreePath* pointing to "2"
 * Expected: void  
 */
static void test_purpose_83()
{
    #define N_ROWS 7
    #define SRC_PATH_STR "5"
    #define DEST_PATH_STR "2"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter;
    GtkTreeIter target_iter;
    GtkTreeIter dest_iter;
    guint i;
    gboolean iter_valid;
    guint src_uint_value;
    guint dest_uint_value;
    GValue src_val = {0,};
    GValue dest_val = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = DEST_PATH_STR ? strdup (DEST_PATH_STR) : NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", src_path_str);
        return;
    }
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter, 0, &src_val);
    src_uint_value = g_value_get_uint (&src_val);
    
    if (dest_path_str) {
        iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store),
                                                          &target_iter, dest_path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
            return;
        }
    }
    
    gtk_list_store_move_after (list_store, &src_iter, dest_path_str ? &target_iter : NULL);
    
    if (dest_path_str) {
        /* we expect correct parameters passed to the function */
        int isrc;
        int idest;
    
        isrc = atoi (src_path_str);
        idest = atoi (dest_path_str);
        
        if (idest < isrc)
        {
            sprintf (dest_path_str, "%d", idest + 1);
        }
    } else {
        dest_path_str = strdup (src_path_str);
        sprintf (dest_path_str, "%d", 0);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter, dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter, 0, &dest_val);
    dest_uint_value = g_value_get_uint (&dest_val);
    
    if (src_uint_value != dest_uint_value)
    {
        TEST_FAIL ("value of iter pointing to '%s' is %d, should be %d", 
                   dest_path_str, src_uint_value, dest_uint_value);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_move_after
 * Params: GtkListStore *store, GtkTreeIter *iter, GtkTreePath *position
 * Returns: void
 * Assertion: Moves iter in store to the position before position.
 * Params Values: newly created GtkListStore* containing 5 rows, GtkTreeIter* pointing to "0", GtkTreePath* pointing to NULL
 * Expected: void  
 */
static void test_purpose_84()
{
    #define N_ROWS 5
    #define SRC_PATH_STR "0"
    #define DEST_PATH_STR NULL
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter;
    GtkTreeIter target_iter;
    GtkTreeIter dest_iter;
    guint i;
    gboolean iter_valid;
    guint src_uint_value;
    guint dest_uint_value;
    GValue src_val = {0,};
    GValue dest_val = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = DEST_PATH_STR ? strdup (DEST_PATH_STR) : NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", src_path_str);
        return;
    }
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter, 0, &src_val);
    src_uint_value = g_value_get_uint (&src_val);
    
    if (dest_path_str) {
        iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store),
                                                          &target_iter, dest_path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
            return;
        }
    }
    
    gtk_list_store_move_after (list_store, &src_iter, dest_path_str ? &target_iter : NULL);
    
    if (dest_path_str) {
        /* we expect correct parameters passed to the function */
        int isrc;
        int idest;
    
        isrc = atoi (src_path_str);
        idest = atoi (dest_path_str);
        
        if (idest < isrc)
        {
            sprintf (dest_path_str, "%d", idest + 1);
        }
    } else {
        dest_path_str = strdup (src_path_str);
        sprintf (dest_path_str, "%d", 0);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter, dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter, 0, &dest_val);
    dest_uint_value = g_value_get_uint (&dest_val);
    
    if (src_uint_value != dest_uint_value)
    {
        TEST_FAIL ("value of iter pointing to '%s' is %d, should be %d", 
                   dest_path_str, src_uint_value, dest_uint_value);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_move_after
 * Params: GtkListStore *store, GtkTreeIter *iter, GtkTreePath *position
 * Returns: void
 * Assertion: Moves iter in store to the position before position.
 * Params Values: newly created GtkListStore* containing 5 rows, GtkTreeIter* pointing to "1", GtkTreePath* pointing to NULL
 * Expected: void  
 */
static void test_purpose_85()
{
    #define N_ROWS 5
    #define SRC_PATH_STR "1"
    #define DEST_PATH_STR NULL
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter;
    GtkTreeIter target_iter;
    GtkTreeIter dest_iter;
    guint i;
    gboolean iter_valid;
    guint src_uint_value;
    guint dest_uint_value;
    GValue src_val = {0,};
    GValue dest_val = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = DEST_PATH_STR ? strdup (DEST_PATH_STR) : NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", src_path_str);
        return;
    }
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter, 0, &src_val);
    src_uint_value = g_value_get_uint (&src_val);
    
    if (dest_path_str) {
        iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store),
                                                          &target_iter, dest_path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
            return;
        }
    }
    
    gtk_list_store_move_after (list_store, &src_iter, dest_path_str ? &target_iter : NULL);
    
    if (dest_path_str) {
        /* we expect correct parameters passed to the function */
        int isrc;
        int idest;
    
        isrc = atoi (src_path_str);
        idest = atoi (dest_path_str);
        
        if (idest < isrc)
        {
            sprintf (dest_path_str, "%d", idest + 1);
        }
    } else {
        dest_path_str = strdup (src_path_str);
        sprintf (dest_path_str, "%d", 0);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter, dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter, 0, &dest_val);
    dest_uint_value = g_value_get_uint (&dest_val);
    
    if (src_uint_value != dest_uint_value)
    {
        TEST_FAIL ("value of iter pointing to '%s' is %d, should be %d", 
                   dest_path_str, src_uint_value, dest_uint_value);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_move_after
 * Params: GtkListStore *store, GtkTreeIter *iter, GtkTreePath *position
 * Returns: void
 * Assertion: Moves iter in store to the position before position.
 * Params Values: newly created GtkListStore* containing 5 rows, GtkTreeIter* pointing to "2", GtkTreePath* pointing to NULL
 * Expected: void  
 */
static void test_purpose_86()
{
    #define N_ROWS 5
    #define SRC_PATH_STR "2"
    #define DEST_PATH_STR NULL
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter;
    GtkTreeIter target_iter;
    GtkTreeIter dest_iter;
    guint i;
    gboolean iter_valid;
    guint src_uint_value;
    guint dest_uint_value;
    GValue src_val = {0,};
    GValue dest_val = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = DEST_PATH_STR ? strdup (DEST_PATH_STR) : NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", src_path_str);
        return;
    }
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter, 0, &src_val);
    src_uint_value = g_value_get_uint (&src_val);
    
    if (dest_path_str) {
        iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store),
                                                          &target_iter, dest_path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
            return;
        }
    }
    
    gtk_list_store_move_after (list_store, &src_iter, dest_path_str ? &target_iter : NULL);
    
    if (dest_path_str) {
        /* we expect correct parameters passed to the function */
        int isrc;
        int idest;
    
        isrc = atoi (src_path_str);
        idest = atoi (dest_path_str);
        
        if (idest < isrc)
        {
            sprintf (dest_path_str, "%d", idest + 1);
        }
    } else {
        dest_path_str = strdup (src_path_str);
        sprintf (dest_path_str, "%d", 0);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter, dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter, 0, &dest_val);
    dest_uint_value = g_value_get_uint (&dest_val);
    
    if (src_uint_value != dest_uint_value)
    {
        TEST_FAIL ("value of iter pointing to '%s' is %d, should be %d", 
                   dest_path_str, src_uint_value, dest_uint_value);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_move_after
 * Params: GtkListStore *store, GtkTreeIter *iter, GtkTreePath *position
 * Returns: void
 * Assertion: Moves iter in store to the position before position.
 * Params Values: newly created GtkListStore* containing 5 rows, GtkTreeIter* pointing to "3", GtkTreePath* pointing to NULL
 * Expected: void  
 */
static void test_purpose_87()
{
    #define N_ROWS 5
    #define SRC_PATH_STR "3"
    #define DEST_PATH_STR NULL
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter;
    GtkTreeIter target_iter;
    GtkTreeIter dest_iter;
    guint i;
    gboolean iter_valid;
    guint src_uint_value;
    guint dest_uint_value;
    GValue src_val = {0,};
    GValue dest_val = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = DEST_PATH_STR ? strdup (DEST_PATH_STR) : NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", src_path_str);
        return;
    }
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter, 0, &src_val);
    src_uint_value = g_value_get_uint (&src_val);
    
    if (dest_path_str) {
        iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store),
                                                          &target_iter, dest_path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
            return;
        }
    }
    
    gtk_list_store_move_after (list_store, &src_iter, dest_path_str ? &target_iter : NULL);
    
    if (dest_path_str) {
        /* we expect correct parameters passed to the function */
        int isrc;
        int idest;
    
        isrc = atoi (src_path_str);
        idest = atoi (dest_path_str);
        
        if (idest < isrc)
        {
            sprintf (dest_path_str, "%d", idest + 1);
        }
    } else {
        dest_path_str = strdup (src_path_str);
        sprintf (dest_path_str, "%d", 0);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter, dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter, 0, &dest_val);
    dest_uint_value = g_value_get_uint (&dest_val);
    
    if (src_uint_value != dest_uint_value)
    {
        TEST_FAIL ("value of iter pointing to '%s' is %d, should be %d", 
                   dest_path_str, src_uint_value, dest_uint_value);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_move_after
 * Params: GtkListStore *store, GtkTreeIter *iter, GtkTreePath *position
 * Returns: void
 * Assertion: Moves iter in store to the position before position.
 * Params Values: newly created GtkListStore* containing 5 rows, GtkTreeIter* pointing to "4", GtkTreePath* pointing to NULL
 * Expected: void  
 */
static void test_purpose_88()
{
    #define N_ROWS 5
    #define SRC_PATH_STR "4"
    #define DEST_PATH_STR NULL
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter;
    GtkTreeIter target_iter;
    GtkTreeIter dest_iter;
    guint i;
    gboolean iter_valid;
    guint src_uint_value;
    guint dest_uint_value;
    GValue src_val = {0,};
    GValue dest_val = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = DEST_PATH_STR ? strdup (DEST_PATH_STR) : NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", src_path_str);
        return;
    }
    
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter, 0, &src_val);
    src_uint_value = g_value_get_uint (&src_val);
    
    if (dest_path_str) {
        iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store),
                                                          &target_iter, dest_path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
            return;
        }
    }
    
    gtk_list_store_move_after (list_store, &src_iter, dest_path_str ? &target_iter : NULL);
    
    if (dest_path_str) {
        /* we expect correct parameters passed to the function */
        int isrc;
        int idest;
    
        isrc = atoi (src_path_str);
        idest = atoi (dest_path_str);
        
        if (idest < isrc)
        {
            sprintf (dest_path_str, "%d", idest + 1);
        }
    } else {
        dest_path_str = strdup (src_path_str);
        sprintf (dest_path_str, "%d", 0);
    }
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter, dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter, 0, &dest_val);
    dest_uint_value = g_value_get_uint (&dest_val);
    
    if (src_uint_value != dest_uint_value)
    {
        TEST_FAIL ("value of iter pointing to '%s' is %d, should be %d", 
                   dest_path_str, src_uint_value, dest_uint_value);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_swap
 * Params: GtkListStore *store, GtkTreeIter *a, GtkTreeIter *b
 * Returns: void
 * Assertion: Swaps a and b in store.
 * Params Values: newly created GtkListStore* containing 1 rows, GtkTreeIter* pointing to "0", GtkTreeIter* pointing to "0"
 * Expected: void  
 */
static void test_purpose_89()
{
    #define N_ROWS 1
    #define SRC_PATH_STR "0"
    #define DEST_PATH_STR "0"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter_before;
    GtkTreeIter dest_iter_before;
    GtkTreeIter src_iter_after;
    GtkTreeIter dest_iter_after;
    guint i;
    gboolean iter_valid;
    guint src_uint_value_before;
    guint dest_uint_value_before;
    guint src_uint_value_after;
    guint dest_uint_value_after;
    GValue src_val_before = {0,};
    GValue dest_val_before = {0,};
    GValue src_val_after = {0,};
    GValue dest_val_after = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = strdup (DEST_PATH_STR);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter_before, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("1: can't get iter pointing to '%s'", src_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter_before, 
                              0, &src_val_before);
    src_uint_value_before = g_value_get_uint (&src_val_before);
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter_before, 
                                                      dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("1: can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter_before, 
                              0, &dest_val_before);
    dest_uint_value_before = g_value_get_uint (&dest_val_before);
    
    
    gtk_list_store_swap (list_store, &src_iter_before, &dest_iter_before);
    
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter_after, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("2: can't get iter pointing to '%s'", src_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter_after, 
                              0, &src_val_after);
    src_uint_value_after = g_value_get_uint (&src_val_after);
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter_after, 
                                                      dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("2: can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter_after, 
                              0, &dest_val_after);
    dest_uint_value_after = g_value_get_uint (&dest_val_after);
    
    if (src_uint_value_before != dest_uint_value_after)
    {
        TEST_FAIL ("src_uint_value_before = %d, dest_uint_value_after = %d, they should be the same", 
                   src_uint_value_before, dest_uint_value_after);
    }
    
    if (src_uint_value_after != dest_uint_value_before)
    {
        TEST_FAIL ("src_uint_value_after = %d, dest_uint_value_before = %d, they should be the same", 
                   src_uint_value_after, dest_uint_value_before);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_swap
 * Params: GtkListStore *store, GtkTreeIter *a, GtkTreeIter *b
 * Returns: void
 * Assertion: Swaps a and b in store.
 * Params Values: newly created GtkListStore* containing 4 rows, GtkTreeIter* pointing to "3", GtkTreeIter* pointing to "3"
 * Expected: void  
 */
static void test_purpose_90()
{
    #define N_ROWS 4
    #define SRC_PATH_STR "3"
    #define DEST_PATH_STR "3"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter_before;
    GtkTreeIter dest_iter_before;
    GtkTreeIter src_iter_after;
    GtkTreeIter dest_iter_after;
    guint i;
    gboolean iter_valid;
    guint src_uint_value_before;
    guint dest_uint_value_before;
    guint src_uint_value_after;
    guint dest_uint_value_after;
    GValue src_val_before = {0,};
    GValue dest_val_before = {0,};
    GValue src_val_after = {0,};
    GValue dest_val_after = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = strdup (DEST_PATH_STR);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter_before, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("1: can't get iter pointing to '%s'", src_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter_before, 
                              0, &src_val_before);
    src_uint_value_before = g_value_get_uint (&src_val_before);
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter_before, 
                                                      dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("1: can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter_before, 
                              0, &dest_val_before);
    dest_uint_value_before = g_value_get_uint (&dest_val_before);
    
    
    gtk_list_store_swap (list_store, &src_iter_before, &dest_iter_before);
    
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter_after, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("2: can't get iter pointing to '%s'", src_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter_after, 
                              0, &src_val_after);
    src_uint_value_after = g_value_get_uint (&src_val_after);
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter_after, 
                                                      dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("2: can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter_after, 
                              0, &dest_val_after);
    dest_uint_value_after = g_value_get_uint (&dest_val_after);
    
    if (src_uint_value_before != dest_uint_value_after)
    {
        TEST_FAIL ("src_uint_value_before = %d, dest_uint_value_after = %d, they should be the same", 
                   src_uint_value_before, dest_uint_value_after);
    }
    
    if (src_uint_value_after != dest_uint_value_before)
    {
        TEST_FAIL ("src_uint_value_after = %d, dest_uint_value_before = %d, they should be the same", 
                   src_uint_value_after, dest_uint_value_before);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_swap
 * Params: GtkListStore *store, GtkTreeIter *a, GtkTreeIter *b
 * Returns: void
 * Assertion: Swaps a and b in store.
 * Params Values: newly created GtkListStore* containing 7 rows, GtkTreeIter* pointing to "3", GtkTreeIter* pointing to "0"
 * Expected: void  
 */
static void test_purpose_91()
{
    #define N_ROWS 7
    #define SRC_PATH_STR "3"
    #define DEST_PATH_STR "0"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter_before;
    GtkTreeIter dest_iter_before;
    GtkTreeIter src_iter_after;
    GtkTreeIter dest_iter_after;
    guint i;
    gboolean iter_valid;
    guint src_uint_value_before;
    guint dest_uint_value_before;
    guint src_uint_value_after;
    guint dest_uint_value_after;
    GValue src_val_before = {0,};
    GValue dest_val_before = {0,};
    GValue src_val_after = {0,};
    GValue dest_val_after = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = strdup (DEST_PATH_STR);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter_before, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("1: can't get iter pointing to '%s'", src_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter_before, 
                              0, &src_val_before);
    src_uint_value_before = g_value_get_uint (&src_val_before);
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter_before, 
                                                      dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("1: can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter_before, 
                              0, &dest_val_before);
    dest_uint_value_before = g_value_get_uint (&dest_val_before);
    
    
    gtk_list_store_swap (list_store, &src_iter_before, &dest_iter_before);
    
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter_after, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("2: can't get iter pointing to '%s'", src_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter_after, 
                              0, &src_val_after);
    src_uint_value_after = g_value_get_uint (&src_val_after);
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter_after, 
                                                      dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("2: can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter_after, 
                              0, &dest_val_after);
    dest_uint_value_after = g_value_get_uint (&dest_val_after);
    
    if (src_uint_value_before != dest_uint_value_after)
    {
        TEST_FAIL ("src_uint_value_before = %d, dest_uint_value_after = %d, they should be the same", 
                   src_uint_value_before, dest_uint_value_after);
    }
    
    if (src_uint_value_after != dest_uint_value_before)
    {
        TEST_FAIL ("src_uint_value_after = %d, dest_uint_value_before = %d, they should be the same", 
                   src_uint_value_after, dest_uint_value_before);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_swap
 * Params: GtkListStore *store, GtkTreeIter *a, GtkTreeIter *b
 * Returns: void
 * Assertion: Swaps a and b in store.
 * Params Values: newly created GtkListStore* containing 7 rows, GtkTreeIter* pointing to "0", GtkTreeIter* pointing to "3"
 * Expected: void  
 */
static void test_purpose_92()
{
    #define N_ROWS 7
    #define SRC_PATH_STR "0"
    #define DEST_PATH_STR "3"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter_before;
    GtkTreeIter dest_iter_before;
    GtkTreeIter src_iter_after;
    GtkTreeIter dest_iter_after;
    guint i;
    gboolean iter_valid;
    guint src_uint_value_before;
    guint dest_uint_value_before;
    guint src_uint_value_after;
    guint dest_uint_value_after;
    GValue src_val_before = {0,};
    GValue dest_val_before = {0,};
    GValue src_val_after = {0,};
    GValue dest_val_after = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = strdup (DEST_PATH_STR);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter_before, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("1: can't get iter pointing to '%s'", src_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter_before, 
                              0, &src_val_before);
    src_uint_value_before = g_value_get_uint (&src_val_before);
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter_before, 
                                                      dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("1: can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter_before, 
                              0, &dest_val_before);
    dest_uint_value_before = g_value_get_uint (&dest_val_before);
    
    
    gtk_list_store_swap (list_store, &src_iter_before, &dest_iter_before);
    
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter_after, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("2: can't get iter pointing to '%s'", src_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter_after, 
                              0, &src_val_after);
    src_uint_value_after = g_value_get_uint (&src_val_after);
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter_after, 
                                                      dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("2: can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter_after, 
                              0, &dest_val_after);
    dest_uint_value_after = g_value_get_uint (&dest_val_after);
    
    if (src_uint_value_before != dest_uint_value_after)
    {
        TEST_FAIL ("src_uint_value_before = %d, dest_uint_value_after = %d, they should be the same", 
                   src_uint_value_before, dest_uint_value_after);
    }
    
    if (src_uint_value_after != dest_uint_value_before)
    {
        TEST_FAIL ("src_uint_value_after = %d, dest_uint_value_before = %d, they should be the same", 
                   src_uint_value_after, dest_uint_value_before);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_swap
 * Params: GtkListStore *store, GtkTreeIter *a, GtkTreeIter *b
 * Returns: void
 * Assertion: Swaps a and b in store.
 * Params Values: newly created GtkListStore* containing 7 rows, GtkTreeIter* pointing to "0", GtkTreeIter* pointing to "1"
 * Expected: void  
 */
static void test_purpose_93()
{
    #define N_ROWS 7
    #define SRC_PATH_STR "0"
    #define DEST_PATH_STR "1"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter_before;
    GtkTreeIter dest_iter_before;
    GtkTreeIter src_iter_after;
    GtkTreeIter dest_iter_after;
    guint i;
    gboolean iter_valid;
    guint src_uint_value_before;
    guint dest_uint_value_before;
    guint src_uint_value_after;
    guint dest_uint_value_after;
    GValue src_val_before = {0,};
    GValue dest_val_before = {0,};
    GValue src_val_after = {0,};
    GValue dest_val_after = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = strdup (DEST_PATH_STR);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter_before, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("1: can't get iter pointing to '%s'", src_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter_before, 
                              0, &src_val_before);
    src_uint_value_before = g_value_get_uint (&src_val_before);
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter_before, 
                                                      dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("1: can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter_before, 
                              0, &dest_val_before);
    dest_uint_value_before = g_value_get_uint (&dest_val_before);
    
    
    gtk_list_store_swap (list_store, &src_iter_before, &dest_iter_before);
    
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter_after, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("2: can't get iter pointing to '%s'", src_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter_after, 
                              0, &src_val_after);
    src_uint_value_after = g_value_get_uint (&src_val_after);
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter_after, 
                                                      dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("2: can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter_after, 
                              0, &dest_val_after);
    dest_uint_value_after = g_value_get_uint (&dest_val_after);
    
    if (src_uint_value_before != dest_uint_value_after)
    {
        TEST_FAIL ("src_uint_value_before = %d, dest_uint_value_after = %d, they should be the same", 
                   src_uint_value_before, dest_uint_value_after);
    }
    
    if (src_uint_value_after != dest_uint_value_before)
    {
        TEST_FAIL ("src_uint_value_after = %d, dest_uint_value_before = %d, they should be the same", 
                   src_uint_value_after, dest_uint_value_before);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_swap
 * Params: GtkListStore *store, GtkTreeIter *a, GtkTreeIter *b
 * Returns: void
 * Assertion: Swaps a and b in store.
 * Params Values: newly created GtkListStore* containing 7 rows, GtkTreeIter* pointing to "1", GtkTreeIter* pointing to "0"
 * Expected: void  
 */
static void test_purpose_94()
{
    #define N_ROWS 7
    #define SRC_PATH_STR "1"
    #define DEST_PATH_STR "0"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter_before;
    GtkTreeIter dest_iter_before;
    GtkTreeIter src_iter_after;
    GtkTreeIter dest_iter_after;
    guint i;
    gboolean iter_valid;
    guint src_uint_value_before;
    guint dest_uint_value_before;
    guint src_uint_value_after;
    guint dest_uint_value_after;
    GValue src_val_before = {0,};
    GValue dest_val_before = {0,};
    GValue src_val_after = {0,};
    GValue dest_val_after = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = strdup (DEST_PATH_STR);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter_before, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("1: can't get iter pointing to '%s'", src_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter_before, 
                              0, &src_val_before);
    src_uint_value_before = g_value_get_uint (&src_val_before);
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter_before, 
                                                      dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("1: can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter_before, 
                              0, &dest_val_before);
    dest_uint_value_before = g_value_get_uint (&dest_val_before);
    
    
    gtk_list_store_swap (list_store, &src_iter_before, &dest_iter_before);
    
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter_after, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("2: can't get iter pointing to '%s'", src_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter_after, 
                              0, &src_val_after);
    src_uint_value_after = g_value_get_uint (&src_val_after);
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter_after, 
                                                      dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("2: can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter_after, 
                              0, &dest_val_after);
    dest_uint_value_after = g_value_get_uint (&dest_val_after);
    
    if (src_uint_value_before != dest_uint_value_after)
    {
        TEST_FAIL ("src_uint_value_before = %d, dest_uint_value_after = %d, they should be the same", 
                   src_uint_value_before, dest_uint_value_after);
    }
    
    if (src_uint_value_after != dest_uint_value_before)
    {
        TEST_FAIL ("src_uint_value_after = %d, dest_uint_value_before = %d, they should be the same", 
                   src_uint_value_after, dest_uint_value_before);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_swap
 * Params: GtkListStore *store, GtkTreeIter *a, GtkTreeIter *b
 * Returns: void
 * Assertion: Swaps a and b in store.
 * Params Values: newly created GtkListStore* containing 7 rows, GtkTreeIter* pointing to "6", GtkTreeIter* pointing to "0"
 * Expected: void  
 */
static void test_purpose_95()
{
    #define N_ROWS 7
    #define SRC_PATH_STR "6"
    #define DEST_PATH_STR "0"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter_before;
    GtkTreeIter dest_iter_before;
    GtkTreeIter src_iter_after;
    GtkTreeIter dest_iter_after;
    guint i;
    gboolean iter_valid;
    guint src_uint_value_before;
    guint dest_uint_value_before;
    guint src_uint_value_after;
    guint dest_uint_value_after;
    GValue src_val_before = {0,};
    GValue dest_val_before = {0,};
    GValue src_val_after = {0,};
    GValue dest_val_after = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = strdup (DEST_PATH_STR);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter_before, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("1: can't get iter pointing to '%s'", src_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter_before, 
                              0, &src_val_before);
    src_uint_value_before = g_value_get_uint (&src_val_before);
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter_before, 
                                                      dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("1: can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter_before, 
                              0, &dest_val_before);
    dest_uint_value_before = g_value_get_uint (&dest_val_before);
    
    
    gtk_list_store_swap (list_store, &src_iter_before, &dest_iter_before);
    
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter_after, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("2: can't get iter pointing to '%s'", src_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter_after, 
                              0, &src_val_after);
    src_uint_value_after = g_value_get_uint (&src_val_after);
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter_after, 
                                                      dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("2: can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter_after, 
                              0, &dest_val_after);
    dest_uint_value_after = g_value_get_uint (&dest_val_after);
    
    if (src_uint_value_before != dest_uint_value_after)
    {
        TEST_FAIL ("src_uint_value_before = %d, dest_uint_value_after = %d, they should be the same", 
                   src_uint_value_before, dest_uint_value_after);
    }
    
    if (src_uint_value_after != dest_uint_value_before)
    {
        TEST_FAIL ("src_uint_value_after = %d, dest_uint_value_before = %d, they should be the same", 
                   src_uint_value_after, dest_uint_value_before);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_swap
 * Params: GtkListStore *store, GtkTreeIter *a, GtkTreeIter *b
 * Returns: void
 * Assertion: Swaps a and b in store.
 * Params Values: newly created GtkListStore* containing 7 rows, GtkTreeIter* pointing to "2", GtkTreeIter* pointing to "5"
 * Expected: void  
 */
static void test_purpose_96()
{
    #define N_ROWS 7
    #define SRC_PATH_STR "2"
    #define DEST_PATH_STR "5"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter_before;
    GtkTreeIter dest_iter_before;
    GtkTreeIter src_iter_after;
    GtkTreeIter dest_iter_after;
    guint i;
    gboolean iter_valid;
    guint src_uint_value_before;
    guint dest_uint_value_before;
    guint src_uint_value_after;
    guint dest_uint_value_after;
    GValue src_val_before = {0,};
    GValue dest_val_before = {0,};
    GValue src_val_after = {0,};
    GValue dest_val_after = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = strdup (DEST_PATH_STR);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter_before, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("1: can't get iter pointing to '%s'", src_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter_before, 
                              0, &src_val_before);
    src_uint_value_before = g_value_get_uint (&src_val_before);
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter_before, 
                                                      dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("1: can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter_before, 
                              0, &dest_val_before);
    dest_uint_value_before = g_value_get_uint (&dest_val_before);
    
    
    gtk_list_store_swap (list_store, &src_iter_before, &dest_iter_before);
    
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter_after, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("2: can't get iter pointing to '%s'", src_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter_after, 
                              0, &src_val_after);
    src_uint_value_after = g_value_get_uint (&src_val_after);
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter_after, 
                                                      dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("2: can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter_after, 
                              0, &dest_val_after);
    dest_uint_value_after = g_value_get_uint (&dest_val_after);
    
    if (src_uint_value_before != dest_uint_value_after)
    {
        TEST_FAIL ("src_uint_value_before = %d, dest_uint_value_after = %d, they should be the same", 
                   src_uint_value_before, dest_uint_value_after);
    }
    
    if (src_uint_value_after != dest_uint_value_before)
    {
        TEST_FAIL ("src_uint_value_after = %d, dest_uint_value_before = %d, they should be the same", 
                   src_uint_value_after, dest_uint_value_before);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_swap
 * Params: GtkListStore *store, GtkTreeIter *a, GtkTreeIter *b
 * Returns: void
 * Assertion: Swaps a and b in store.
 * Params Values: newly created GtkListStore* containing 7 rows, GtkTreeIter* pointing to "5", GtkTreeIter* pointing to "2"
 * Expected: void  
 */
static void test_purpose_97()
{
    #define N_ROWS 7
    #define SRC_PATH_STR "5"
    #define DEST_PATH_STR "2"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter_before;
    GtkTreeIter dest_iter_before;
    GtkTreeIter src_iter_after;
    GtkTreeIter dest_iter_after;
    guint i;
    gboolean iter_valid;
    guint src_uint_value_before;
    guint dest_uint_value_before;
    guint src_uint_value_after;
    guint dest_uint_value_after;
    GValue src_val_before = {0,};
    GValue dest_val_before = {0,};
    GValue src_val_after = {0,};
    GValue dest_val_after = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = strdup (DEST_PATH_STR);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter_before, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("1: can't get iter pointing to '%s'", src_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter_before, 
                              0, &src_val_before);
    src_uint_value_before = g_value_get_uint (&src_val_before);
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter_before, 
                                                      dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("1: can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter_before, 
                              0, &dest_val_before);
    dest_uint_value_before = g_value_get_uint (&dest_val_before);
    
    
    gtk_list_store_swap (list_store, &src_iter_before, &dest_iter_before);
    
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter_after, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("2: can't get iter pointing to '%s'", src_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter_after, 
                              0, &src_val_after);
    src_uint_value_after = g_value_get_uint (&src_val_after);
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter_after, 
                                                      dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("2: can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter_after, 
                              0, &dest_val_after);
    dest_uint_value_after = g_value_get_uint (&dest_val_after);
    
    if (src_uint_value_before != dest_uint_value_after)
    {
        TEST_FAIL ("src_uint_value_before = %d, dest_uint_value_after = %d, they should be the same", 
                   src_uint_value_before, dest_uint_value_after);
    }
    
    if (src_uint_value_after != dest_uint_value_before)
    {
        TEST_FAIL ("src_uint_value_after = %d, dest_uint_value_before = %d, they should be the same", 
                   src_uint_value_after, dest_uint_value_before);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_swap
 * Params: GtkListStore *store, GtkTreeIter *a, GtkTreeIter *b
 * Returns: void
 * Assertion: Swaps a and b in store.
 * Params Values: newly created GtkListStore* containing 7 rows, GtkTreeIter* pointing to "0", GtkTreeIter* pointing to "6"
 * Expected: void  
 */
static void test_purpose_98()
{
    #define N_ROWS 7
    #define SRC_PATH_STR "0"
    #define DEST_PATH_STR "6"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter_before;
    GtkTreeIter dest_iter_before;
    GtkTreeIter src_iter_after;
    GtkTreeIter dest_iter_after;
    guint i;
    gboolean iter_valid;
    guint src_uint_value_before;
    guint dest_uint_value_before;
    guint src_uint_value_after;
    guint dest_uint_value_after;
    GValue src_val_before = {0,};
    GValue dest_val_before = {0,};
    GValue src_val_after = {0,};
    GValue dest_val_after = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = strdup (DEST_PATH_STR);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter_before, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("1: can't get iter pointing to '%s'", src_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter_before, 
                              0, &src_val_before);
    src_uint_value_before = g_value_get_uint (&src_val_before);
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter_before, 
                                                      dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("1: can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter_before, 
                              0, &dest_val_before);
    dest_uint_value_before = g_value_get_uint (&dest_val_before);
    
    
    gtk_list_store_swap (list_store, &src_iter_before, &dest_iter_before);
    
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter_after, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("2: can't get iter pointing to '%s'", src_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter_after, 
                              0, &src_val_after);
    src_uint_value_after = g_value_get_uint (&src_val_after);
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter_after, 
                                                      dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("2: can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter_after, 
                              0, &dest_val_after);
    dest_uint_value_after = g_value_get_uint (&dest_val_after);
    
    if (src_uint_value_before != dest_uint_value_after)
    {
        TEST_FAIL ("src_uint_value_before = %d, dest_uint_value_after = %d, they should be the same", 
                   src_uint_value_before, dest_uint_value_after);
    }
    
    if (src_uint_value_after != dest_uint_value_before)
    {
        TEST_FAIL ("src_uint_value_after = %d, dest_uint_value_before = %d, they should be the same", 
                   src_uint_value_after, dest_uint_value_before);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_swap
 * Params: GtkListStore *store, GtkTreeIter *a, GtkTreeIter *b
 * Returns: void
 * Assertion: Swaps a and b in store.
 * Params Values: newly created GtkListStore* containing 2 rows, GtkTreeIter* pointing to "1", GtkTreeIter* pointing to "0"
 * Expected: void  
 */
static void test_purpose_99()
{
    #define N_ROWS 2
    #define SRC_PATH_STR "1"
    #define DEST_PATH_STR "0"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter_before;
    GtkTreeIter dest_iter_before;
    GtkTreeIter src_iter_after;
    GtkTreeIter dest_iter_after;
    guint i;
    gboolean iter_valid;
    guint src_uint_value_before;
    guint dest_uint_value_before;
    guint src_uint_value_after;
    guint dest_uint_value_after;
    GValue src_val_before = {0,};
    GValue dest_val_before = {0,};
    GValue src_val_after = {0,};
    GValue dest_val_after = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = strdup (DEST_PATH_STR);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter_before, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("1: can't get iter pointing to '%s'", src_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter_before, 
                              0, &src_val_before);
    src_uint_value_before = g_value_get_uint (&src_val_before);
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter_before, 
                                                      dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("1: can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter_before, 
                              0, &dest_val_before);
    dest_uint_value_before = g_value_get_uint (&dest_val_before);
    
    
    gtk_list_store_swap (list_store, &src_iter_before, &dest_iter_before);
    
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter_after, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("2: can't get iter pointing to '%s'", src_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter_after, 
                              0, &src_val_after);
    src_uint_value_after = g_value_get_uint (&src_val_after);
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter_after, 
                                                      dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("2: can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter_after, 
                              0, &dest_val_after);
    dest_uint_value_after = g_value_get_uint (&dest_val_after);
    
    if (src_uint_value_before != dest_uint_value_after)
    {
        TEST_FAIL ("src_uint_value_before = %d, dest_uint_value_after = %d, they should be the same", 
                   src_uint_value_before, dest_uint_value_after);
    }
    
    if (src_uint_value_after != dest_uint_value_before)
    {
        TEST_FAIL ("src_uint_value_after = %d, dest_uint_value_before = %d, they should be the same", 
                   src_uint_value_after, dest_uint_value_before);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_swap
 * Params: GtkListStore *store, GtkTreeIter *a, GtkTreeIter *b
 * Returns: void
 * Assertion: Swaps a and b in store.
 * Params Values: newly created GtkListStore* containing 2 rows, GtkTreeIter* pointing to "0", GtkTreeIter* pointing to "1"
 * Expected: void  
 */
static void test_purpose_100()
{
    #define N_ROWS 2
    #define SRC_PATH_STR "0"
    #define DEST_PATH_STR "1"
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter src_iter_before;
    GtkTreeIter dest_iter_before;
    GtkTreeIter src_iter_after;
    GtkTreeIter dest_iter_after;
    guint i;
    gboolean iter_valid;
    guint src_uint_value_before;
    guint dest_uint_value_before;
    guint src_uint_value_after;
    guint dest_uint_value_after;
    GValue src_val_before = {0,};
    GValue dest_val_before = {0,};
    GValue src_val_after = {0,};
    GValue dest_val_after = {0,};
    gchar* src_path_str = strdup (SRC_PATH_STR);
    gchar* dest_path_str = strdup (DEST_PATH_STR);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter_before, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("1: can't get iter pointing to '%s'", src_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter_before, 
                              0, &src_val_before);
    src_uint_value_before = g_value_get_uint (&src_val_before);
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter_before, 
                                                      dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("1: can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter_before, 
                              0, &dest_val_before);
    dest_uint_value_before = g_value_get_uint (&dest_val_before);
    
    
    gtk_list_store_swap (list_store, &src_iter_before, &dest_iter_before);
    
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &src_iter_after, src_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("2: can't get iter pointing to '%s'", src_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &src_iter_after, 
                              0, &src_val_after);
    src_uint_value_after = g_value_get_uint (&src_val_after);
    
    iter_valid = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), 
                                                      &dest_iter_after, 
                                                      dest_path_str);
    if (!iter_valid)
    {
        TEST_FAIL ("2: can't get iter pointing to '%s'", dest_path_str);
        return;
    }
    gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &dest_iter_after, 
                              0, &dest_val_after);
    dest_uint_value_after = g_value_get_uint (&dest_val_after);
    
    if (src_uint_value_before != dest_uint_value_after)
    {
        TEST_FAIL ("src_uint_value_before = %d, dest_uint_value_after = %d, they should be the same", 
                   src_uint_value_before, dest_uint_value_after);
    }
    
    if (src_uint_value_after != dest_uint_value_before)
    {
        TEST_FAIL ("src_uint_value_after = %d, dest_uint_value_before = %d, they should be the same", 
                   src_uint_value_after, dest_uint_value_before);
    }
    
    free (src_path_str);
    free (dest_path_str);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef N_ROWS
    #undef SRC_PATH_STR
    #undef DEST_PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_reorder
 * Params: GtkListStore *store, gint *new_order
 * Returns: void
 * Assertion: Reorders store to follow the order indicated by new_order.
 * Params Values: newly created GtkListStore* containing {0, 1, 2, 3, 4} rows, gint*
 * Expected: void  
 */
static void test_purpose_101()
{
    #define NEW_ORDER_ARRAY {0, 1, 2, 3, 4}
    #define N_ROWS 5
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter iters_before[5];
    GtkTreeIter iters_after[5];
    guint i;
    guint j;
    gboolean iter_valid;
    guint iters_uint_values_before[5];
    guint iters_uint_values_after[5];
    GValue iters_val_before[] = {{0,}, {0,}, {0,}, {0,}, {0,}};
    GValue iters_val_after[] = {{0,}, {0,}, {0,}, {0,}, {0,}};
    gint new_order_array[] = NEW_ORDER_ARRAY;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (sizeof (new_order_array) / sizeof (new_order_array[0]) != 5)
    {
        TEST_FAIL ("new_order_array should contain 5 elements", NULL);
        return;
    }
    
    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    for (i = 0; i < N_ROWS; i++)
    {
        char* path_str = (char*) calloc (sizeof (char), 2);
        
        sprintf (path_str, "%d", i);
        iter_valid = gtk_tree_model_get_iter_from_string 
            (GTK_TREE_MODEL (list_store), &iters_before[i], path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("1: can't get iter pointing to '%s', i = %d", 
                       path_str, i);
            return;
        }
        gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iters_before[i], 0, 
                                  &iters_val_before[i]);
        iters_uint_values_before[i] = g_value_get_uint (&iters_val_before[i]);
    }
    
    gtk_list_store_reorder (list_store, new_order_array);
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    for (i = 0; i < N_ROWS; i++)
    {
        char* path_str = (char*) calloc (sizeof (char), 2);
        
        sprintf (path_str, "%d", i);
        iter_valid = gtk_tree_model_get_iter_from_string 
            (GTK_TREE_MODEL (list_store), &iters_after[i], path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("2: can't get iter pointing to '%s', i = %d", 
                       path_str, i);
            return;
        }
        gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iters_after[i], 0, 
                                  &iters_val_after[i]);
        iters_uint_values_after[i] = g_value_get_uint (&iters_val_after[i]);
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        for (j = 0; j < N_ROWS && new_order_array[j] != i; j++)
            ;
    
        if (iters_uint_values_before[i] != iters_uint_values_after[j])
        {
            TEST_FAIL ("iters_uint_values_before[%d] = %d, iters_uint_values_after[%d] = %d, they should be equal", i, iters_uint_values_before[i], j, iters_uint_values_after[j]);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef NEW_ORDER_ARRAY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_reorder
 * Params: GtkListStore *store, gint *new_order
 * Returns: void
 * Assertion: Reorders store to follow the order indicated by new_order.
 * Params Values: newly created GtkListStore* containing {1, 0, 2, 3, 4} rows, gint*
 * Expected: void  
 */
static void test_purpose_102()
{
    #define NEW_ORDER_ARRAY {1, 0, 2, 3, 4}
    #define N_ROWS 5
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter iters_before[5];
    GtkTreeIter iters_after[5];
    guint i;
    guint j;
    gboolean iter_valid;
    guint iters_uint_values_before[5];
    guint iters_uint_values_after[5];
    GValue iters_val_before[] = {{0,}, {0,}, {0,}, {0,}, {0,}};
    GValue iters_val_after[] = {{0,}, {0,}, {0,}, {0,}, {0,}};
    gint new_order_array[] = NEW_ORDER_ARRAY;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (sizeof (new_order_array) / sizeof (new_order_array[0]) != 5)
    {
        TEST_FAIL ("new_order_array should contain 5 elements", NULL);
        return;
    }
    
    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    for (i = 0; i < N_ROWS; i++)
    {
        char* path_str = (char*) calloc (sizeof (char), 2);
        
        sprintf (path_str, "%d", i);
        iter_valid = gtk_tree_model_get_iter_from_string 
            (GTK_TREE_MODEL (list_store), &iters_before[i], path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("1: can't get iter pointing to '%s', i = %d", 
                       path_str, i);
            return;
        }
        gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iters_before[i], 0, 
                                  &iters_val_before[i]);
        iters_uint_values_before[i] = g_value_get_uint (&iters_val_before[i]);
    }
    
    gtk_list_store_reorder (list_store, new_order_array);
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    for (i = 0; i < N_ROWS; i++)
    {
        char* path_str = (char*) calloc (sizeof (char), 2);
        
        sprintf (path_str, "%d", i);
        iter_valid = gtk_tree_model_get_iter_from_string 
            (GTK_TREE_MODEL (list_store), &iters_after[i], path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("2: can't get iter pointing to '%s', i = %d", 
                       path_str, i);
            return;
        }
        gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iters_after[i], 0, 
                                  &iters_val_after[i]);
        iters_uint_values_after[i] = g_value_get_uint (&iters_val_after[i]);
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        for (j = 0; j < N_ROWS && new_order_array[j] != i; j++)
            ;
    
        if (iters_uint_values_before[i] != iters_uint_values_after[j])
        {
            TEST_FAIL ("iters_uint_values_before[%d] = %d, iters_uint_values_after[%d] = %d, they should be equal", i, iters_uint_values_before[i], j, iters_uint_values_after[j]);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef NEW_ORDER_ARRAY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_reorder
 * Params: GtkListStore *store, gint *new_order
 * Returns: void
 * Assertion: Reorders store to follow the order indicated by new_order.
 * Params Values: newly created GtkListStore* containing {0, 1, 2, 4, 3} rows, gint*
 * Expected: void  
 */
static void test_purpose_103()
{
    #define NEW_ORDER_ARRAY {0, 1, 2, 4, 3}
    #define N_ROWS 5
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter iters_before[5];
    GtkTreeIter iters_after[5];
    guint i;
    guint j;
    gboolean iter_valid;
    guint iters_uint_values_before[5];
    guint iters_uint_values_after[5];
    GValue iters_val_before[] = {{0,}, {0,}, {0,}, {0,}, {0,}};
    GValue iters_val_after[] = {{0,}, {0,}, {0,}, {0,}, {0,}};
    gint new_order_array[] = NEW_ORDER_ARRAY;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (sizeof (new_order_array) / sizeof (new_order_array[0]) != 5)
    {
        TEST_FAIL ("new_order_array should contain 5 elements", NULL);
        return;
    }
    
    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    for (i = 0; i < N_ROWS; i++)
    {
        char* path_str = (char*) calloc (sizeof (char), 2);
        
        sprintf (path_str, "%d", i);
        iter_valid = gtk_tree_model_get_iter_from_string 
            (GTK_TREE_MODEL (list_store), &iters_before[i], path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("1: can't get iter pointing to '%s', i = %d", 
                       path_str, i);
            return;
        }
        gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iters_before[i], 0, 
                                  &iters_val_before[i]);
        iters_uint_values_before[i] = g_value_get_uint (&iters_val_before[i]);
    }
    
    gtk_list_store_reorder (list_store, new_order_array);
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    for (i = 0; i < N_ROWS; i++)
    {
        char* path_str = (char*) calloc (sizeof (char), 2);
        
        sprintf (path_str, "%d", i);
        iter_valid = gtk_tree_model_get_iter_from_string 
            (GTK_TREE_MODEL (list_store), &iters_after[i], path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("2: can't get iter pointing to '%s', i = %d", 
                       path_str, i);
            return;
        }
        gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iters_after[i], 0, 
                                  &iters_val_after[i]);
        iters_uint_values_after[i] = g_value_get_uint (&iters_val_after[i]);
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        for (j = 0; j < N_ROWS && new_order_array[j] != i; j++)
            ;
    
        if (iters_uint_values_before[i] != iters_uint_values_after[j])
        {
            TEST_FAIL ("iters_uint_values_before[%d] = %d, iters_uint_values_after[%d] = %d, they should be equal", i, iters_uint_values_before[i], j, iters_uint_values_after[j]);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef NEW_ORDER_ARRAY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_reorder
 * Params: GtkListStore *store, gint *new_order
 * Returns: void
 * Assertion: Reorders store to follow the order indicated by new_order.
 * Params Values: newly created GtkListStore* containing {4, 0, 1, 2, 3} rows, gint*
 * Expected: void  
 */
static void test_purpose_104()
{
    #define NEW_ORDER_ARRAY {4, 0, 1, 2, 3}
    #define N_ROWS 5
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter iters_before[5];
    GtkTreeIter iters_after[5];
    guint i;
    guint j;
    gboolean iter_valid;
    guint iters_uint_values_before[5];
    guint iters_uint_values_after[5];
    GValue iters_val_before[] = {{0,}, {0,}, {0,}, {0,}, {0,}};
    GValue iters_val_after[] = {{0,}, {0,}, {0,}, {0,}, {0,}};
    gint new_order_array[] = NEW_ORDER_ARRAY;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (sizeof (new_order_array) / sizeof (new_order_array[0]) != 5)
    {
        TEST_FAIL ("new_order_array should contain 5 elements", NULL);
        return;
    }
    
    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    for (i = 0; i < N_ROWS; i++)
    {
        char* path_str = (char*) calloc (sizeof (char), 2);
        
        sprintf (path_str, "%d", i);
        iter_valid = gtk_tree_model_get_iter_from_string 
            (GTK_TREE_MODEL (list_store), &iters_before[i], path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("1: can't get iter pointing to '%s', i = %d", 
                       path_str, i);
            return;
        }
        gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iters_before[i], 0, 
                                  &iters_val_before[i]);
        iters_uint_values_before[i] = g_value_get_uint (&iters_val_before[i]);
    }
    
    gtk_list_store_reorder (list_store, new_order_array);
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    for (i = 0; i < N_ROWS; i++)
    {
        char* path_str = (char*) calloc (sizeof (char), 2);
        
        sprintf (path_str, "%d", i);
        iter_valid = gtk_tree_model_get_iter_from_string 
            (GTK_TREE_MODEL (list_store), &iters_after[i], path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("2: can't get iter pointing to '%s', i = %d", 
                       path_str, i);
            return;
        }
        gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iters_after[i], 0, 
                                  &iters_val_after[i]);
        iters_uint_values_after[i] = g_value_get_uint (&iters_val_after[i]);
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        for (j = 0; j < N_ROWS && new_order_array[j] != i; j++)
            ;
    
        if (iters_uint_values_before[i] != iters_uint_values_after[j])
        {
            TEST_FAIL ("iters_uint_values_before[%d] = %d, iters_uint_values_after[%d] = %d, they should be equal", i, iters_uint_values_before[i], j, iters_uint_values_after[j]);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef NEW_ORDER_ARRAY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_reorder
 * Params: GtkListStore *store, gint *new_order
 * Returns: void
 * Assertion: Reorders store to follow the order indicated by new_order.
 * Params Values: newly created GtkListStore* containing {4, 2, 0, 1, 3} rows, gint*
 * Expected: void  
 */
static void test_purpose_105()
{
    #define NEW_ORDER_ARRAY {4, 2, 0, 1, 3}
    #define N_ROWS 5
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter iters_before[5];
    GtkTreeIter iters_after[5];
    guint i;
    guint j;
    gboolean iter_valid;
    guint iters_uint_values_before[5];
    guint iters_uint_values_after[5];
    GValue iters_val_before[] = {{0,}, {0,}, {0,}, {0,}, {0,}};
    GValue iters_val_after[] = {{0,}, {0,}, {0,}, {0,}, {0,}};
    gint new_order_array[] = NEW_ORDER_ARRAY;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (sizeof (new_order_array) / sizeof (new_order_array[0]) != 5)
    {
        TEST_FAIL ("new_order_array should contain 5 elements", NULL);
        return;
    }
    
    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    for (i = 0; i < N_ROWS; i++)
    {
        char* path_str = (char*) calloc (sizeof (char), 2);
        
        sprintf (path_str, "%d", i);
        iter_valid = gtk_tree_model_get_iter_from_string 
            (GTK_TREE_MODEL (list_store), &iters_before[i], path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("1: can't get iter pointing to '%s', i = %d", 
                       path_str, i);
            return;
        }
        gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iters_before[i], 0, 
                                  &iters_val_before[i]);
        iters_uint_values_before[i] = g_value_get_uint (&iters_val_before[i]);
    }
    
    gtk_list_store_reorder (list_store, new_order_array);
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    for (i = 0; i < N_ROWS; i++)
    {
        char* path_str = (char*) calloc (sizeof (char), 2);
        
        sprintf (path_str, "%d", i);
        iter_valid = gtk_tree_model_get_iter_from_string 
            (GTK_TREE_MODEL (list_store), &iters_after[i], path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("2: can't get iter pointing to '%s', i = %d", 
                       path_str, i);
            return;
        }
        gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iters_after[i], 0, 
                                  &iters_val_after[i]);
        iters_uint_values_after[i] = g_value_get_uint (&iters_val_after[i]);
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        for (j = 0; j < N_ROWS && new_order_array[j] != i; j++)
            ;
    
        if (iters_uint_values_before[i] != iters_uint_values_after[j])
        {
            TEST_FAIL ("iters_uint_values_before[%d] = %d, iters_uint_values_after[%d] = %d, they should be equal", i, iters_uint_values_before[i], j, iters_uint_values_after[j]);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef NEW_ORDER_ARRAY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_reorder
 * Params: GtkListStore *store, gint *new_order
 * Returns: void
 * Assertion: Reorders store to follow the order indicated by new_order.
 * Params Values: newly created GtkListStore* containing {2, 4, 1, 3, 0} rows, gint*
 * Expected: void  
 */
static void test_purpose_106()
{
    #define NEW_ORDER_ARRAY {2, 4, 1, 3, 0}
    #define N_ROWS 5
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter iters_before[5];
    GtkTreeIter iters_after[5];
    guint i;
    guint j;
    gboolean iter_valid;
    guint iters_uint_values_before[5];
    guint iters_uint_values_after[5];
    GValue iters_val_before[] = {{0,}, {0,}, {0,}, {0,}, {0,}};
    GValue iters_val_after[] = {{0,}, {0,}, {0,}, {0,}, {0,}};
    gint new_order_array[] = NEW_ORDER_ARRAY;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (sizeof (new_order_array) / sizeof (new_order_array[0]) != 5)
    {
        TEST_FAIL ("new_order_array should contain 5 elements", NULL);
        return;
    }
    
    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    for (i = 0; i < N_ROWS; i++)
    {
        char* path_str = (char*) calloc (sizeof (char), 2);
        
        sprintf (path_str, "%d", i);
        iter_valid = gtk_tree_model_get_iter_from_string 
            (GTK_TREE_MODEL (list_store), &iters_before[i], path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("1: can't get iter pointing to '%s', i = %d", 
                       path_str, i);
            return;
        }
        gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iters_before[i], 0, 
                                  &iters_val_before[i]);
        iters_uint_values_before[i] = g_value_get_uint (&iters_val_before[i]);
    }
    
    gtk_list_store_reorder (list_store, new_order_array);
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    for (i = 0; i < N_ROWS; i++)
    {
        char* path_str = (char*) calloc (sizeof (char), 2);
        
        sprintf (path_str, "%d", i);
        iter_valid = gtk_tree_model_get_iter_from_string 
            (GTK_TREE_MODEL (list_store), &iters_after[i], path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("2: can't get iter pointing to '%s', i = %d", 
                       path_str, i);
            return;
        }
        gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iters_after[i], 0, 
                                  &iters_val_after[i]);
        iters_uint_values_after[i] = g_value_get_uint (&iters_val_after[i]);
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        for (j = 0; j < N_ROWS && new_order_array[j] != i; j++)
            ;
    
        if (iters_uint_values_before[i] != iters_uint_values_after[j])
        {
            TEST_FAIL ("iters_uint_values_before[%d] = %d, iters_uint_values_after[%d] = %d, they should be equal", i, iters_uint_values_before[i], j, iters_uint_values_after[j]);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef NEW_ORDER_ARRAY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_reorder
 * Params: GtkListStore *store, gint *new_order
 * Returns: void
 * Assertion: Reorders store to follow the order indicated by new_order.
 * Params Values: newly created GtkListStore* containing {0, 4, 3, 1, 2} rows, gint*
 * Expected: void  
 */
static void test_purpose_107()
{
    #define NEW_ORDER_ARRAY {0, 4, 3, 1, 2}
    #define N_ROWS 5
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter iters_before[5];
    GtkTreeIter iters_after[5];
    guint i;
    guint j;
    gboolean iter_valid;
    guint iters_uint_values_before[5];
    guint iters_uint_values_after[5];
    GValue iters_val_before[] = {{0,}, {0,}, {0,}, {0,}, {0,}};
    GValue iters_val_after[] = {{0,}, {0,}, {0,}, {0,}, {0,}};
    gint new_order_array[] = NEW_ORDER_ARRAY;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (sizeof (new_order_array) / sizeof (new_order_array[0]) != 5)
    {
        TEST_FAIL ("new_order_array should contain 5 elements", NULL);
        return;
    }
    
    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    for (i = 0; i < N_ROWS; i++)
    {
        char* path_str = (char*) calloc (sizeof (char), 2);
        
        sprintf (path_str, "%d", i);
        iter_valid = gtk_tree_model_get_iter_from_string 
            (GTK_TREE_MODEL (list_store), &iters_before[i], path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("1: can't get iter pointing to '%s', i = %d", 
                       path_str, i);
            return;
        }
        gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iters_before[i], 0, 
                                  &iters_val_before[i]);
        iters_uint_values_before[i] = g_value_get_uint (&iters_val_before[i]);
    }
    
    gtk_list_store_reorder (list_store, new_order_array);
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    for (i = 0; i < N_ROWS; i++)
    {
        char* path_str = (char*) calloc (sizeof (char), 2);
        
        sprintf (path_str, "%d", i);
        iter_valid = gtk_tree_model_get_iter_from_string 
            (GTK_TREE_MODEL (list_store), &iters_after[i], path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("2: can't get iter pointing to '%s', i = %d", 
                       path_str, i);
            return;
        }
        gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iters_after[i], 0, 
                                  &iters_val_after[i]);
        iters_uint_values_after[i] = g_value_get_uint (&iters_val_after[i]);
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        for (j = 0; j < N_ROWS && new_order_array[j] != i; j++)
            ;
    
        if (iters_uint_values_before[i] != iters_uint_values_after[j])
        {
            TEST_FAIL ("iters_uint_values_before[%d] = %d, iters_uint_values_after[%d] = %d, they should be equal", i, iters_uint_values_before[i], j, iters_uint_values_after[j]);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef NEW_ORDER_ARRAY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_reorder
 * Params: GtkListStore *store, gint *new_order
 * Returns: void
 * Assertion: Reorders store to follow the order indicated by new_order.
 * Params Values: newly created GtkListStore* containing {1, 4, 2, 0, 3} rows, gint*
 * Expected: void  
 */
static void test_purpose_108()
{
    #define NEW_ORDER_ARRAY {1, 4, 2, 0, 3}
    #define N_ROWS 5
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter iters_before[5];
    GtkTreeIter iters_after[5];
    guint i;
    guint j;
    gboolean iter_valid;
    guint iters_uint_values_before[5];
    guint iters_uint_values_after[5];
    GValue iters_val_before[] = {{0,}, {0,}, {0,}, {0,}, {0,}};
    GValue iters_val_after[] = {{0,}, {0,}, {0,}, {0,}, {0,}};
    gint new_order_array[] = NEW_ORDER_ARRAY;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (sizeof (new_order_array) / sizeof (new_order_array[0]) != 5)
    {
        TEST_FAIL ("new_order_array should contain 5 elements", NULL);
        return;
    }
    
    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    for (i = 0; i < N_ROWS; i++)
    {
        char* path_str = (char*) calloc (sizeof (char), 2);
        
        sprintf (path_str, "%d", i);
        iter_valid = gtk_tree_model_get_iter_from_string 
            (GTK_TREE_MODEL (list_store), &iters_before[i], path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("1: can't get iter pointing to '%s', i = %d", 
                       path_str, i);
            return;
        }
        gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iters_before[i], 0, 
                                  &iters_val_before[i]);
        iters_uint_values_before[i] = g_value_get_uint (&iters_val_before[i]);
    }
    
    gtk_list_store_reorder (list_store, new_order_array);
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    for (i = 0; i < N_ROWS; i++)
    {
        char* path_str = (char*) calloc (sizeof (char), 2);
        
        sprintf (path_str, "%d", i);
        iter_valid = gtk_tree_model_get_iter_from_string 
            (GTK_TREE_MODEL (list_store), &iters_after[i], path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("2: can't get iter pointing to '%s', i = %d", 
                       path_str, i);
            return;
        }
        gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iters_after[i], 0, 
                                  &iters_val_after[i]);
        iters_uint_values_after[i] = g_value_get_uint (&iters_val_after[i]);
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        for (j = 0; j < N_ROWS && new_order_array[j] != i; j++)
            ;
    
        if (iters_uint_values_before[i] != iters_uint_values_after[j])
        {
            TEST_FAIL ("iters_uint_values_before[%d] = %d, iters_uint_values_after[%d] = %d, they should be equal", i, iters_uint_values_before[i], j, iters_uint_values_after[j]);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef NEW_ORDER_ARRAY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_list_store_reorder
 * Params: GtkListStore *store, gint *new_order
 * Returns: void
 * Assertion: Reorders store to follow the order indicated by new_order.
 * Params Values: newly created GtkListStore* containing {4, 1, 2, 3, 0} rows, gint*
 * Expected: void  
 */
static void test_purpose_109()
{
    #define NEW_ORDER_ARRAY {4, 1, 2, 3, 0}
    #define N_ROWS 5
    
    GtkListStore *list_store;
    GtkWidget *tree_view;
    GtkTreeIter iter;
    GtkTreeIter iters_before[5];
    GtkTreeIter iters_after[5];
    guint i;
    guint j;
    gboolean iter_valid;
    guint iters_uint_values_before[5];
    guint iters_uint_values_after[5];
    GValue iters_val_before[] = {{0,}, {0,}, {0,}, {0,}, {0,}};
    GValue iters_val_after[] = {{0,}, {0,}, {0,}, {0,}, {0,}};
    gint new_order_array[] = NEW_ORDER_ARRAY;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (sizeof (new_order_array) / sizeof (new_order_array[0]) != 5)
    {
        TEST_FAIL ("new_order_array should contain 5 elements", NULL);
        return;
    }
    
    list_store = gtk_list_store_new (1, G_TYPE_UINT);
    if (!list_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_LIST_STORE (list_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        gtk_list_store_append (list_store, &iter); 
        gtk_list_store_set (list_store, &iter, 0, i, -1);
    }
    
    
    for (i = 0; i < N_ROWS; i++)
    {
        char* path_str = (char*) calloc (sizeof (char), 2);
        
        sprintf (path_str, "%d", i);
        iter_valid = gtk_tree_model_get_iter_from_string 
            (GTK_TREE_MODEL (list_store), &iters_before[i], path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("1: can't get iter pointing to '%s', i = %d", 
                       path_str, i);
            return;
        }
        gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iters_before[i], 0, 
                                  &iters_val_before[i]);
        iters_uint_values_before[i] = g_value_get_uint (&iters_val_before[i]);
    }
    
    gtk_list_store_reorder (list_store, new_order_array);
    
    /******* VISUALISATION *******/
    {
    
        GtkCellRenderer* renderer;
        GtkTreeViewColumn* column0;
        tree_view = gtk_tree_view_new_with_model 
            (GTK_TREE_MODEL (list_store));
        
        renderer = gtk_cell_renderer_text_new ();
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1",
                                                            renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        TEST_VISUALIZE (tree_view);
    }
    /******* -------------  *******/  
    
    for (i = 0; i < N_ROWS; i++)
    {
        char* path_str = (char*) calloc (sizeof (char), 2);
        
        sprintf (path_str, "%d", i);
        iter_valid = gtk_tree_model_get_iter_from_string 
            (GTK_TREE_MODEL (list_store), &iters_after[i], path_str);
        if (!iter_valid)
        {
            TEST_FAIL ("2: can't get iter pointing to '%s', i = %d", 
                       path_str, i);
            return;
        }
        gtk_tree_model_get_value (GTK_TREE_MODEL (list_store), &iters_after[i], 0, 
                                  &iters_val_after[i]);
        iters_uint_values_after[i] = g_value_get_uint (&iters_val_after[i]);
    }
    
    for (i = 0; i < N_ROWS; i++)
    {
        for (j = 0; j < N_ROWS && new_order_array[j] != i; j++)
            ;
    
        if (iters_uint_values_before[i] != iters_uint_values_after[j])
        {
            TEST_FAIL ("iters_uint_values_before[%d] = %d, iters_uint_values_after[%d] = %d, they should be equal", i, iters_uint_values_before[i], j, iters_uint_values_after[j]);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef NEW_ORDER_ARRAY
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkListStore ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {test_purpose_52, 1},
    {test_purpose_53, 1},
    {test_purpose_54, 1},
    {test_purpose_55, 1},
    {test_purpose_56, 1},
    {test_purpose_57, 1},
    {test_purpose_58, 1},
    {test_purpose_59, 1},
    {test_purpose_60, 1},
    {test_purpose_61, 1},
    {test_purpose_62, 1},
    {test_purpose_63, 1},
    {test_purpose_64, 1},
    {test_purpose_65, 1},
    {test_purpose_66, 1},
    {test_purpose_67, 1},
    {test_purpose_68, 1},
    {test_purpose_69, 1},
    {test_purpose_70, 1},
    {test_purpose_71, 1},
    {test_purpose_72, 1},
    {test_purpose_73, 1},
    {test_purpose_74, 1},
    {test_purpose_75, 1},
    {test_purpose_76, 1},
    {test_purpose_77, 1},
    {test_purpose_78, 1},
    {test_purpose_79, 1},
    {test_purpose_80, 1},
    {test_purpose_81, 1},
    {test_purpose_82, 1},
    {test_purpose_83, 1},
    {test_purpose_84, 1},
    {test_purpose_85, 1},
    {test_purpose_86, 1},
    {test_purpose_87, 1},
    {test_purpose_88, 1},
    {test_purpose_89, 1},
    {test_purpose_90, 1},
    {test_purpose_91, 1},
    {test_purpose_92, 1},
    {test_purpose_93, 1},
    {test_purpose_94, 1},
    {test_purpose_95, 1},
    {test_purpose_96, 1},
    {test_purpose_97, 1},
    {test_purpose_98, 1},
    {test_purpose_99, 1},
    {test_purpose_100, 1},
    {test_purpose_101, 1},
    {test_purpose_102, 1},
    {test_purpose_103, 1},
    {test_purpose_104, 1},
    {test_purpose_105, 1},
    {test_purpose_106, 1},
    {test_purpose_107, 1},
    {test_purpose_108, 1},
    {test_purpose_109, 1},
    {NULL,0}
};
