/*
 * GtkTextBuffer methods tests
 * Testing GtkTextBuffer methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

static gint modified_catched;

typedef struct
{
  GtkClipboard *clipboard;
  guint ref_count;
} SelectionClipboard;


void  
global_mark (GtkTextBuffer *textbuffer,
             GtkTextIter arg1,
             GtkTextMark *arg2,
             gpointer user_data)
{
    modified_catched++;
}


void   
global_tag (GtkTextBuffer *textbuffer,
                  GtkTextTag *arg1,
                  GtkTextIter arg2,
                  GtkTextIter arg3,
                  gpointer user_data)
{
    modified_catched++;
}


void   
global_user_action (GtkTextBuffer *textbuffer,
                    gpointer user_data)
{
    modified_catched++;
}


void 
global_modified (GtkTextBuffer *textbuffer, gpointer user_data)
{
    modified_catched ++;
}


void 
global_insert_text (GtkTextBuffer *textbuffer,
                    GtkTextIter arg1,
                    gchar *arg2,
                    gint arg3,
                    gpointer user_data)
{
    modified_catched++;
}


void 
global_delete_range (GtkTextBuffer *textbuffer,
              GtkTextIter arg1,
              GtkTextIter arg2,
              gpointer user_data)
{
    modified_catched++;
}

SelectionClipboard*
global_find_selection_clipboard (GtkTextBuffer *buffer,
			  GtkClipboard  *clipboard)
{
    GSList *tmp_list = buffer->selection_clipboards;
    while (tmp_list)
    {
        SelectionClipboard *selection_clipboard = tmp_list->data;
        if (selection_clipboard->clipboard == clipboard)
            return selection_clipboard;
        
        tmp_list = tmp_list->next;
    }
   
    return NULL;
}



/*
 * Name: gtk_text_buffer_new
 * Params: GtkTextTagTable *table
 * Returns:  GtkTextBuffer* 
 * Assertion: Creates a new text buffer.
 * Params Values: NULL
 * Expected:  GtkTextBuffer*  
 */
static void test_purpose_1()
{
    #define TABLE NULL
    
    GtkTextBuffer* buffer;
    GtkTextTagTable* table;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    table = TABLE;
    buffer =  gtk_text_buffer_new(table);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    #undef TABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_new
 * Params: GtkTextTagTable *table
 * Returns:  GtkTextBuffer* 
 * Assertion: Creates a new text buffer.
 * Params Values: gtk_text_tag_table_new()
 * Expected:  GtkTextBuffer*  
 */
static void test_purpose_2()
{
    #define TABLE gtk_text_tag_table_new()
    
    GtkTextBuffer* buffer;
    GtkTextTagTable* table;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    table = TABLE;
    buffer =  gtk_text_buffer_new(table);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    #undef TABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_line_count
 * Params: GtkTextBuffer *buffer
 * Returns:  gint
 * Assertion: Obtains the number of lines in the buffer.
 * Params Values: ""
 * Expected:  1  
 */
static void test_purpose_3()
{
    #define TEXT ""
    #define TEXT_LENGTH 0
    #define CORRECT_LINE_COUNT 1
    
    GtkTextBuffer* buffer;
    int line_count;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    line_count = gtk_text_buffer_get_line_count (buffer);
    if (line_count != CORRECT_LINE_COUNT)
    {
        TEST_FAIL ("line_count = %d, should be %d\n", line_count, 
                   (gint) CORRECT_LINE_COUNT);
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef CORRECT_LINE_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_line_count
 * Params: GtkTextBuffer *buffer
 * Returns:  gint
 * Assertion: Obtains the number of lines in the buffer.
 * Params Values: " "
 * Expected:  1  
 */
static void test_purpose_4()
{
    #define TEXT " "
    #define TEXT_LENGTH 1
    #define CORRECT_LINE_COUNT 1
    
    GtkTextBuffer* buffer;
    int line_count;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    line_count = gtk_text_buffer_get_line_count (buffer);
    if (line_count != CORRECT_LINE_COUNT)
    {
        TEST_FAIL ("line_count = %d, should be %d\n", line_count, 
                   (gint) CORRECT_LINE_COUNT);
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef CORRECT_LINE_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_line_count
 * Params: GtkTextBuffer *buffer
 * Returns:  gint
 * Assertion: Obtains the number of lines in the buffer.
 * Params Values: "Text\n"
 * Expected:  2  
 */
static void test_purpose_5()
{
    #define TEXT "Text\n"
    #define TEXT_LENGTH strlen ("Text\n")
    #define CORRECT_LINE_COUNT 2
    
    GtkTextBuffer* buffer;
    int line_count;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    line_count = gtk_text_buffer_get_line_count (buffer);
    if (line_count != CORRECT_LINE_COUNT)
    {
        TEST_FAIL ("line_count = %d, should be %d\n", line_count, 
                   (gint) CORRECT_LINE_COUNT);
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef CORRECT_LINE_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_line_count
 * Params: GtkTextBuffer *buffer
 * Returns:  gint
 * Assertion: Obtains the number of lines in the buffer.
 * Params Values: "Text\nText\n"
 * Expected:  3  
 */
static void test_purpose_6()
{
    #define TEXT "Text\nText\n"
    #define TEXT_LENGTH strlen ("Text\nText\n")
    #define CORRECT_LINE_COUNT 3
    
    GtkTextBuffer* buffer;
    int line_count;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    line_count = gtk_text_buffer_get_line_count (buffer);
    if (line_count != CORRECT_LINE_COUNT)
    {
        TEST_FAIL ("line_count = %d, should be %d\n", line_count, 
                   (gint) CORRECT_LINE_COUNT);
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef CORRECT_LINE_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_line_count
 * Params: GtkTextBuffer *buffer
 * Returns:  gint
 * Assertion: Obtains the number of lines in the buffer.
 * Params Values: "Text\n\bText\n"
 * Expected:  3  
 */
static void test_purpose_7()
{
    #define TEXT "Text\n\bText\n"
    #define TEXT_LENGTH strlen ("Text\n\bText\n")
    #define CORRECT_LINE_COUNT 3
    
    GtkTextBuffer* buffer;
    int line_count;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    line_count = gtk_text_buffer_get_line_count (buffer);
    if (line_count != CORRECT_LINE_COUNT)
    {
        TEST_FAIL ("line_count = %d, should be %d\n", line_count, 
                   (gint) CORRECT_LINE_COUNT);
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef CORRECT_LINE_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_line_count
 * Params: GtkTextBuffer *buffer
 * Returns:  gint
 * Assertion: Obtains the number of lines in the buffer.
 * Params Values: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
 * Expected:  2  
 */
static void test_purpose_8()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    #define TEXT_LENGTH strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n")
    #define CORRECT_LINE_COUNT 2
    
    GtkTextBuffer* buffer;
    int line_count;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    line_count = gtk_text_buffer_get_line_count (buffer);
    if (line_count != CORRECT_LINE_COUNT)
    {
        TEST_FAIL ("line_count = %d, should be %d\n", line_count, 
                   (gint) CORRECT_LINE_COUNT);
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef CORRECT_LINE_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_line_count
 * Params: GtkTextBuffer *buffer
 * Returns:  gint
 * Assertion: Obtains the number of lines in the buffer.
 * Params Values: "!@#$%^&*()_+|~=\";:'?<>`/" 
 * Expected:  1  
 */
static void test_purpose_9()
{
    #define TEXT "!@#$%^&*()_+|~=\";:'?<>`/" 
    #define TEXT_LENGTH strlen ("!@#$%^&*()_+|~=\";:'?<>`/")
    #define CORRECT_LINE_COUNT 1
    
    GtkTextBuffer* buffer;
    int line_count;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    line_count = gtk_text_buffer_get_line_count (buffer);
    if (line_count != CORRECT_LINE_COUNT)
    {
        TEST_FAIL ("line_count = %d, should be %d\n", line_count, 
                   (gint) CORRECT_LINE_COUNT);
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef CORRECT_LINE_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_line_count
 * Params: GtkTextBuffer *buffer
 * Returns:  gint
 * Assertion: Obtains the number of lines in the buffer.
 * Params Values: "\b\n\t\n" 
 * Expected:  3  
 */
static void test_purpose_10()
{
    #define TEXT "\b\n\t\n" 
    #define TEXT_LENGTH strlen ("\b\n\t\n")
    #define CORRECT_LINE_COUNT 3
    
    GtkTextBuffer* buffer;
    int line_count;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    line_count = gtk_text_buffer_get_line_count (buffer);
    if (line_count != CORRECT_LINE_COUNT)
    {
        TEST_FAIL ("line_count = %d, should be %d\n", line_count, 
                   (gint) CORRECT_LINE_COUNT);
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef CORRECT_LINE_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_char_count
 * Params: GtkTextBuffer *buffer
 * Returns:  gint
 * Assertion: Gets the number of characters in the buffer; note that characters and bytes are not the same, you can't e.g. expect the contents of the buffer in string form to be this many bytes long.'
 * Params Values: ""
 * Expected:  0  
 */
static void test_purpose_11()
{
    #define TEXT ""
    #define TEXT_LENGTH strlen ("")
    #define CORRECT_CHAR_COUNT 0
    
    GtkTextBuffer* buffer;
    int char_count;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    char_count = gtk_text_buffer_get_char_count (buffer);
    if (char_count != CORRECT_CHAR_COUNT)
    {
        TEST_FAIL ("char_count = %d, should be %d\n", char_count, 
                   (gint) CORRECT_CHAR_COUNT);
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef CORRECT_CHAR_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_char_count
 * Params: GtkTextBuffer *buffer
 * Returns:  gint
 * Assertion: Gets the number of characters in the buffer; note that characters and bytes are not the same, you can't e.g. expect the contents of the buffer in string form to be this many bytes long.'
 * Params Values: " "
 * Expected:  1  
 */
static void test_purpose_12()
{
    #define TEXT " "
    #define TEXT_LENGTH strlen (" ")
    #define CORRECT_CHAR_COUNT 1
    
    GtkTextBuffer* buffer;
    int char_count;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    char_count = gtk_text_buffer_get_char_count (buffer);
    if (char_count != CORRECT_CHAR_COUNT)
    {
        TEST_FAIL ("char_count = %d, should be %d\n", char_count, 
                   (gint) CORRECT_CHAR_COUNT);
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef CORRECT_CHAR_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_char_count
 * Params: GtkTextBuffer *buffer
 * Returns:  gint
 * Assertion: Gets the number of characters in the buffer; note that characters and bytes are not the same, you can't e.g. expect the contents of the buffer in string form to be this many bytes long.'
 * Params Values: "Text\n"
 * Expected:  strlen ("Text\n")  
 */
static void test_purpose_13()
{
    #define TEXT "Text\n"
    #define TEXT_LENGTH strlen ("Text\n")
    #define CORRECT_CHAR_COUNT strlen ("Text\n")
    
    GtkTextBuffer* buffer;
    int char_count;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    char_count = gtk_text_buffer_get_char_count (buffer);
    if (char_count != CORRECT_CHAR_COUNT)
    {
        TEST_FAIL ("char_count = %d, should be %d\n", char_count, 
                   (gint) CORRECT_CHAR_COUNT);
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef CORRECT_CHAR_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_char_count
 * Params: GtkTextBuffer *buffer
 * Returns:  gint
 * Assertion: Gets the number of characters in the buffer; note that characters and bytes are not the same, you can't e.g. expect the contents of the buffer in string form to be this many bytes long.'
 * Params Values: "Text\nText\n"
 * Expected:  strlen ("Text\nText\n")  
 */
static void test_purpose_14()
{
    #define TEXT "Text\nText\n"
    #define TEXT_LENGTH strlen ("Text\nText\n")
    #define CORRECT_CHAR_COUNT strlen ("Text\nText\n")
    
    GtkTextBuffer* buffer;
    int char_count;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    char_count = gtk_text_buffer_get_char_count (buffer);
    if (char_count != CORRECT_CHAR_COUNT)
    {
        TEST_FAIL ("char_count = %d, should be %d\n", char_count, 
                   (gint) CORRECT_CHAR_COUNT);
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef CORRECT_CHAR_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_char_count
 * Params: GtkTextBuffer *buffer
 * Returns:  gint
 * Assertion: Gets the number of characters in the buffer; note that characters and bytes are not the same, you can't e.g. expect the contents of the buffer in string form to be this many bytes long.'
 * Params Values: "Text\n\bText\n"
 * Expected:  strlen ("Text\n\bText\n")  
 */
static void test_purpose_15()
{
    #define TEXT "Text\n\bText\n"
    #define TEXT_LENGTH strlen ("Text\n\bText\n")
    #define CORRECT_CHAR_COUNT strlen ("Text\n\bText\n")
    
    GtkTextBuffer* buffer;
    int char_count;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    char_count = gtk_text_buffer_get_char_count (buffer);
    if (char_count != CORRECT_CHAR_COUNT)
    {
        TEST_FAIL ("char_count = %d, should be %d\n", char_count, 
                   (gint) CORRECT_CHAR_COUNT);
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef CORRECT_CHAR_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_char_count
 * Params: GtkTextBuffer *buffer
 * Returns:  gint
 * Assertion: Gets the number of characters in the buffer; note that characters and bytes are not the same, you can't e.g. expect the contents of the buffer in string form to be this many bytes long.'
 * Params Values: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
 * Expected:  strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n")  
 */
static void test_purpose_16()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    #define TEXT_LENGTH strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n")
    #define CORRECT_CHAR_COUNT strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n")
    
    GtkTextBuffer* buffer;
    int char_count;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    char_count = gtk_text_buffer_get_char_count (buffer);
    if (char_count != CORRECT_CHAR_COUNT)
    {
        TEST_FAIL ("char_count = %d, should be %d\n", char_count, 
                   (gint) CORRECT_CHAR_COUNT);
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef CORRECT_CHAR_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_char_count
 * Params: GtkTextBuffer *buffer
 * Returns:  gint
 * Assertion: Gets the number of characters in the buffer; note that characters and bytes are not the same, you can't e.g. expect the contents of the buffer in string form to be this many bytes long.'
 * Params Values: "!@#$%^&*()_+|~=\";:'?<>`/" 
 * Expected:  strlen ("!@#$%^&*()_+|~=\";:'?<>`/")   
 */
static void test_purpose_17()
{
    #define TEXT "!@#$%^&*()_+|~=\";:'?<>`/" 
    #define TEXT_LENGTH strlen ("!@#$%^&*()_+|~=\";:'?<>`/")
    #define CORRECT_CHAR_COUNT strlen ("!@#$%^&*()_+|~=\";:'?<>`/") 
    
    GtkTextBuffer* buffer;
    int char_count;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    char_count = gtk_text_buffer_get_char_count (buffer);
    if (char_count != CORRECT_CHAR_COUNT)
    {
        TEST_FAIL ("char_count = %d, should be %d\n", char_count, 
                   (gint) CORRECT_CHAR_COUNT);
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef CORRECT_CHAR_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_char_count
 * Params: GtkTextBuffer *buffer
 * Returns:  gint
 * Assertion: Gets the number of characters in the buffer; note that characters and bytes are not the same, you can't e.g. expect the contents of the buffer in string form to be this many bytes long.'
 * Params Values: "\b\n\t\n" 
 * Expected:  strlen ("\b\n\t\n")  
 */
static void test_purpose_18()
{
    #define TEXT "\b\n\t\n" 
    #define TEXT_LENGTH strlen ("\b\n\t\n")
    #define CORRECT_CHAR_COUNT strlen ("\b\n\t\n")
    
    GtkTextBuffer* buffer;
    int char_count;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    char_count = gtk_text_buffer_get_char_count (buffer);
    if (char_count != CORRECT_CHAR_COUNT)
    {
        TEST_FAIL ("char_count = %d, should be %d\n", char_count, 
                   (gint) CORRECT_CHAR_COUNT);
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef CORRECT_CHAR_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_tag_table
 * Params: GtkTextBuffer *buffer
 * Returns:  GtkTextTagTable*
 * Assertion: Get the GtkTextTagTable associated with this buffer.
 * Params Values: a newly created GtkTextBuffer with NULL as the GtkTagTable 
 * Expected:  NULL  
 */
static void test_purpose_19()
{
    #define TABLE NULL
    
    GtkTextBuffer* buffer;
    GtkTextTagTable* table;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    table = TABLE;
    buffer =  gtk_text_buffer_new(table);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    if (table)
    {
        if (gtk_text_buffer_get_tag_table (buffer) != table)
        {
            TEST_FAIL ("tag_table is not correct", NULL);
        }
    } else {
        if (!gtk_text_buffer_get_tag_table (buffer))
        {
            TEST_FAIL ("tag_table is not created", NULL);
        }
    }
    
    #undef TABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_tag_table
 * Params: GtkTextBuffer *buffer
 * Returns:  GtkTextTagTable*
 * Assertion: Get the GtkTextTagTable associated with this buffer.
 * Params Values: a newly created GtkTextBuffer with gtk_text_tag_table_new() as the GtkTagTable 
 * Expected:  gtk_text_tag_table_new()  
 */
static void test_purpose_20()
{
    #define TABLE gtk_text_tag_table_new()
    
    GtkTextBuffer* buffer;
    GtkTextTagTable* table;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    table = TABLE;
    buffer =  gtk_text_buffer_new(table);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    if (table)
    {
        if (gtk_text_buffer_get_tag_table (buffer) != table)
        {
            TEST_FAIL ("tag_table is not correct", NULL);
        }
    } else {
        if (!gtk_text_buffer_get_tag_table (buffer))
        {
            TEST_FAIL ("tag_table is not created", NULL);
        }
    }
    
    #undef TABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_set_text
 * Params: GtkTextBuffer *buffer, const gchar *text, gint len
 * Returns:  void
 * Assertion: Deletes current contents of buffer, and inserts text instead.
 * Params Values: newly created GtkTextBuffer*, "", 0
 * Expected:  void
 * 
 * Name: gtk_text_buffer_get_text
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end, gboolean include_hidden_chars
 * Returns:  gchar*
 * Assertion: Returns the text in the range [start,end).
 * Params Values: newly created GtkTextBuffer*, GtkTextIter with line = 0 and line offset = 0, GtkTextIter with line = 0 and line offset = 0, FALSE
 * Expected:  ""  
 */
static void test_purpose_21()
{
    #define TEXT ""
    #define TEXT_LENGTH 0
    #define START_LINE_NUM 0
    #define START_LINE_OFFSET 0
    #define END_LINE_NUM 0
    #define END_LINE_OFFSET 0
    #define INCLUDE_HIDDEN_CHARS FALSE
    #define CORRECT_TEXT ""
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    gtk_text_iter_set_line (&start, START_LINE_NUM);
    gtk_text_iter_set_line_offset (&start, START_LINE_OFFSET);
    gtk_text_iter_set_line (&end, END_LINE_NUM);
    gtk_text_iter_set_line_offset (&end, END_LINE_OFFSET);
    
    text = (gchar*) calloc (1, TEXT_LENGTH);
    text = gtk_text_buffer_get_text (buffer, &start, &end, INCLUDE_HIDDEN_CHARS);
    text = g_locale_from_utf8 (text, strlen (text), NULL, NULL, NULL);
    
    if (!text)
    {
        TEST_FAIL ("g_locale_from_utf8() returned NULL", NULL);
    } else {
        if (strcmp (text, (gchar*) CORRECT_TEXT))
        {
            TEST_FAIL ("text = '%s', should be '%s'", text, (gchar*) CORRECT_TEXT);
        }
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef START_LINE_NUM
    #undef START_LINE_OFFSET
    #undef END_LINE_NUM
    #undef END_LINE_OFFSET
    #undef INCLUDE_HIDDEN_CHARS
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_set_text
 * Params: GtkTextBuffer *buffer, const gchar *text, gint len
 * Returns:  void
 * Assertion: Deletes current contents of buffer, and inserts text instead.
 * Params Values: newly created GtkTextBuffer*, " ", 1
 * Expected:  void
 * 
 * Name: gtk_text_buffer_get_text
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end, gboolean include_hidden_chars
 * Returns:  gchar*
 * Assertion: Returns the text in the range [start,end).
 * Params Values: newly created GtkTextBuffer*, GtkTextIter with line = 0 and line offset = 0, GtkTextIter with line = 0 and line offset = 1, TRUE
 * Expected:  " "  
 */
static void test_purpose_22()
{
    #define TEXT " "
    #define TEXT_LENGTH 1
    #define START_LINE_NUM 0
    #define START_LINE_OFFSET 0
    #define END_LINE_NUM 0
    #define END_LINE_OFFSET 1
    #define INCLUDE_HIDDEN_CHARS TRUE
    #define CORRECT_TEXT " "
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    gtk_text_iter_set_line (&start, START_LINE_NUM);
    gtk_text_iter_set_line_offset (&start, START_LINE_OFFSET);
    gtk_text_iter_set_line (&end, END_LINE_NUM);
    gtk_text_iter_set_line_offset (&end, END_LINE_OFFSET);
    
    text = (gchar*) calloc (1, TEXT_LENGTH);
    text = gtk_text_buffer_get_text (buffer, &start, &end, INCLUDE_HIDDEN_CHARS);
    text = g_locale_from_utf8 (text, strlen (text), NULL, NULL, NULL);
    
    if (!text)
    {
        TEST_FAIL ("g_locale_from_utf8() returned NULL", NULL);
    } else {
        if (strcmp (text, (gchar*) CORRECT_TEXT))
        {
            TEST_FAIL ("text = '%s', should be '%s'", text, (gchar*) CORRECT_TEXT);
        }
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef START_LINE_NUM
    #undef START_LINE_OFFSET
    #undef END_LINE_NUM
    #undef END_LINE_OFFSET
    #undef INCLUDE_HIDDEN_CHARS
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_set_text
 * Params: GtkTextBuffer *buffer, const gchar *text, gint len
 * Returns:  void
 * Assertion: Deletes current contents of buffer, and inserts text instead.
 * Params Values: newly created GtkTextBuffer*, " ", 1
 * Expected:  void
 * 
 * Name: gtk_text_buffer_get_text
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end, gboolean include_hidden_chars
 * Returns:  gchar*
 * Assertion: Returns the text in the range [start,end).
 * Params Values: newly created GtkTextBuffer*, GtkTextIter with line = 0 and line offset = 0, GtkTextIter with line = 0 and line offset = 0, TRUE
 * Expected:  ""  
 */
static void test_purpose_23()
{
    #define TEXT " "
    #define TEXT_LENGTH 1
    #define START_LINE_NUM 0
    #define START_LINE_OFFSET 0
    #define END_LINE_NUM 0
    #define END_LINE_OFFSET 0
    #define INCLUDE_HIDDEN_CHARS TRUE
    #define CORRECT_TEXT ""
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    gtk_text_iter_set_line (&start, START_LINE_NUM);
    gtk_text_iter_set_line_offset (&start, START_LINE_OFFSET);
    gtk_text_iter_set_line (&end, END_LINE_NUM);
    gtk_text_iter_set_line_offset (&end, END_LINE_OFFSET);
    
    text = (gchar*) calloc (1, TEXT_LENGTH);
    text = gtk_text_buffer_get_text (buffer, &start, &end, INCLUDE_HIDDEN_CHARS);
    text = g_locale_from_utf8 (text, strlen (text), NULL, NULL, NULL);
    
    if (!text)
    {
        TEST_FAIL ("g_locale_from_utf8() returned NULL", NULL);
    } else {
        if (strcmp (text, (gchar*) CORRECT_TEXT))
        {
            TEST_FAIL ("text = '%s', should be '%s'", text, (gchar*) CORRECT_TEXT);
        }
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef START_LINE_NUM
    #undef START_LINE_OFFSET
    #undef END_LINE_NUM
    #undef END_LINE_OFFSET
    #undef INCLUDE_HIDDEN_CHARS
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_set_text
 * Params: GtkTextBuffer *buffer, const gchar *text, gint len
 * Returns:  void
 * Assertion: Deletes current contents of buffer, and inserts text instead.
 * Params Values: newly created GtkTextBuffer*, "Text\n", strlen ("Text\n")
 * Expected:  void
 * 
 * Name: gtk_text_buffer_get_text
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end, gboolean include_hidden_chars
 * Returns:  gchar*
 * Assertion: Returns the text in the range [start,end).
 * Params Values: newly created GtkTextBuffer*, GtkTextIter with line = 0 and line offset = 0, GtkTextIter with line = 0 and line offset = 2, FALSE
 * Expected:  "Te"  
 */
static void test_purpose_24()
{
    #define TEXT "Text\n"
    #define TEXT_LENGTH strlen ("Text\n")
    #define START_LINE_NUM 0
    #define START_LINE_OFFSET 0
    #define END_LINE_NUM 0
    #define END_LINE_OFFSET 2
    #define INCLUDE_HIDDEN_CHARS FALSE
    #define CORRECT_TEXT "Te"
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    gtk_text_iter_set_line (&start, START_LINE_NUM);
    gtk_text_iter_set_line_offset (&start, START_LINE_OFFSET);
    gtk_text_iter_set_line (&end, END_LINE_NUM);
    gtk_text_iter_set_line_offset (&end, END_LINE_OFFSET);
    
    text = (gchar*) calloc (1, TEXT_LENGTH);
    text = gtk_text_buffer_get_text (buffer, &start, &end, INCLUDE_HIDDEN_CHARS);
    text = g_locale_from_utf8 (text, strlen (text), NULL, NULL, NULL);
    
    if (!text)
    {
        TEST_FAIL ("g_locale_from_utf8() returned NULL", NULL);
    } else {
        if (strcmp (text, (gchar*) CORRECT_TEXT))
        {
            TEST_FAIL ("text = '%s', should be '%s'", text, (gchar*) CORRECT_TEXT);
        }
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef START_LINE_NUM
    #undef START_LINE_OFFSET
    #undef END_LINE_NUM
    #undef END_LINE_OFFSET
    #undef INCLUDE_HIDDEN_CHARS
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_set_text
 * Params: GtkTextBuffer *buffer, const gchar *text, gint len
 * Returns:  void
 * Assertion: Deletes current contents of buffer, and inserts text instead.
 * Params Values: newly created GtkTextBuffer*, "Text\nText\n", strlen ("Text\nText\n")
 * Expected:  void
 * 
 * Name: gtk_text_buffer_get_text
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end, gboolean include_hidden_chars
 * Returns:  gchar*
 * Assertion: Returns the text in the range [start,end).
 * Params Values: newly created GtkTextBuffer*, GtkTextIter with line = 0 and line offset = 2, GtkTextIter with line = 1 and line offset = 4, TRUE
 * Expected:  "xt\nText"  
 */
static void test_purpose_25()
{
    #define TEXT "Text\nText\n"
    #define TEXT_LENGTH strlen ("Text\nText\n")
    #define START_LINE_NUM 0
    #define START_LINE_OFFSET 2
    #define END_LINE_NUM 1
    #define END_LINE_OFFSET 4
    #define INCLUDE_HIDDEN_CHARS TRUE
    #define CORRECT_TEXT "xt\nText"
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    gtk_text_iter_set_line (&start, START_LINE_NUM);
    gtk_text_iter_set_line_offset (&start, START_LINE_OFFSET);
    gtk_text_iter_set_line (&end, END_LINE_NUM);
    gtk_text_iter_set_line_offset (&end, END_LINE_OFFSET);
    
    text = (gchar*) calloc (1, TEXT_LENGTH);
    text = gtk_text_buffer_get_text (buffer, &start, &end, INCLUDE_HIDDEN_CHARS);
    text = g_locale_from_utf8 (text, strlen (text), NULL, NULL, NULL);
    
    if (!text)
    {
        TEST_FAIL ("g_locale_from_utf8() returned NULL", NULL);
    } else {
        if (strcmp (text, (gchar*) CORRECT_TEXT))
        {
            TEST_FAIL ("text = '%s', should be '%s'", text, (gchar*) CORRECT_TEXT);
        }
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef START_LINE_NUM
    #undef START_LINE_OFFSET
    #undef END_LINE_NUM
    #undef END_LINE_OFFSET
    #undef INCLUDE_HIDDEN_CHARS
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_set_text
 * Params: GtkTextBuffer *buffer, const gchar *text, gint len
 * Returns:  void
 * Assertion: Deletes current contents of buffer, and inserts text instead.
 * Params Values: newly created GtkTextBuffer*, "Text\n\bText\n", strlen ("Text\n\bText\n")
 * Expected:  void
 * 
 * Name: gtk_text_buffer_get_text
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end, gboolean include_hidden_chars
 * Returns:  gchar*
 * Assertion: Returns the text in the range [start,end).
 * Params Values: newly created GtkTextBuffer*, GtkTextIter with line = 0 and line offset = 4, GtkTextIter with line = 1 and line offset = 2, TRUE
 * Expected:  "\n\bT"  
 */
static void test_purpose_26()
{
    #define TEXT "Text\n\bText\n"
    #define TEXT_LENGTH strlen ("Text\n\bText\n")
    #define START_LINE_NUM 0
    #define START_LINE_OFFSET 4
    #define END_LINE_NUM 1
    #define END_LINE_OFFSET 2
    #define INCLUDE_HIDDEN_CHARS TRUE
    #define CORRECT_TEXT "\n\bT"
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    gtk_text_iter_set_line (&start, START_LINE_NUM);
    gtk_text_iter_set_line_offset (&start, START_LINE_OFFSET);
    gtk_text_iter_set_line (&end, END_LINE_NUM);
    gtk_text_iter_set_line_offset (&end, END_LINE_OFFSET);
    
    text = (gchar*) calloc (1, TEXT_LENGTH);
    text = gtk_text_buffer_get_text (buffer, &start, &end, INCLUDE_HIDDEN_CHARS);
    text = g_locale_from_utf8 (text, strlen (text), NULL, NULL, NULL);
    
    if (!text)
    {
        TEST_FAIL ("g_locale_from_utf8() returned NULL", NULL);
    } else {
        if (strcmp (text, (gchar*) CORRECT_TEXT))
        {
            TEST_FAIL ("text = '%s', should be '%s'", text, (gchar*) CORRECT_TEXT);
        }
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef START_LINE_NUM
    #undef START_LINE_OFFSET
    #undef END_LINE_NUM
    #undef END_LINE_OFFSET
    #undef INCLUDE_HIDDEN_CHARS
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_set_text
 * Params: GtkTextBuffer *buffer, const gchar *text, gint len
 * Returns:  void
 * Assertion: Deletes current contents of buffer, and inserts text instead.
 * Params Values: newly created GtkTextBuffer*, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" , strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n")
 * Expected:  void
 * 
 * Name: gtk_text_buffer_get_text
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end, gboolean include_hidden_chars
 * Returns:  gchar*
 * Assertion: Returns the text in the range [start,end).
 * Params Values: newly created GtkTextBuffer*, GtkTextIter with line = 0 and line offset = 5, GtkTextIter with line = 0 and line offset = 57, FALSE
 * Expected:  "fghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ12345"   
 */
static void test_purpose_27()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    #define TEXT_LENGTH strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n")
    #define START_LINE_NUM 0
    #define START_LINE_OFFSET 5
    #define END_LINE_NUM 0
    #define END_LINE_OFFSET 57
    #define INCLUDE_HIDDEN_CHARS FALSE
    #define CORRECT_TEXT "fghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ12345" 
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    gtk_text_iter_set_line (&start, START_LINE_NUM);
    gtk_text_iter_set_line_offset (&start, START_LINE_OFFSET);
    gtk_text_iter_set_line (&end, END_LINE_NUM);
    gtk_text_iter_set_line_offset (&end, END_LINE_OFFSET);
    
    text = (gchar*) calloc (1, TEXT_LENGTH);
    text = gtk_text_buffer_get_text (buffer, &start, &end, INCLUDE_HIDDEN_CHARS);
    text = g_locale_from_utf8 (text, strlen (text), NULL, NULL, NULL);
    
    if (!text)
    {
        TEST_FAIL ("g_locale_from_utf8() returned NULL", NULL);
    } else {
        if (strcmp (text, (gchar*) CORRECT_TEXT))
        {
            TEST_FAIL ("text = '%s', should be '%s'", text, (gchar*) CORRECT_TEXT);
        }
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef START_LINE_NUM
    #undef START_LINE_OFFSET
    #undef END_LINE_NUM
    #undef END_LINE_OFFSET
    #undef INCLUDE_HIDDEN_CHARS
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_set_text
 * Params: GtkTextBuffer *buffer, const gchar *text, gint len
 * Returns:  void
 * Assertion: Deletes current contents of buffer, and inserts text instead.
 * Params Values: newly created GtkTextBuffer*, "!@#$%^&*()_+|~=\";:'?<>`/" , strlen ("!@#$%^&*()_+|~=\";:'?<>`/")
 * Expected:  void
 * 
 * Name: gtk_text_buffer_get_text
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end, gboolean include_hidden_chars
 * Returns:  gchar*
 * Assertion: Returns the text in the range [start,end).
 * Params Values: newly created GtkTextBuffer*, GtkTextIter with line = 0 and line offset = 2, GtkTextIter with line = 0 and line offset = 23, TRUE
 * Expected:  "#$%^&*()_+|~=\";:'?<>`"  
 */
static void test_purpose_28()
{
    #define TEXT "!@#$%^&*()_+|~=\";:'?<>`/" 
    #define TEXT_LENGTH strlen ("!@#$%^&*()_+|~=\";:'?<>`/")
    #define START_LINE_NUM 0
    #define START_LINE_OFFSET 2
    #define END_LINE_NUM 0
    #define END_LINE_OFFSET 23
    #define INCLUDE_HIDDEN_CHARS TRUE
    #define CORRECT_TEXT "#$%^&*()_+|~=\";:'?<>`"
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    gtk_text_iter_set_line (&start, START_LINE_NUM);
    gtk_text_iter_set_line_offset (&start, START_LINE_OFFSET);
    gtk_text_iter_set_line (&end, END_LINE_NUM);
    gtk_text_iter_set_line_offset (&end, END_LINE_OFFSET);
    
    text = (gchar*) calloc (1, TEXT_LENGTH);
    text = gtk_text_buffer_get_text (buffer, &start, &end, INCLUDE_HIDDEN_CHARS);
    text = g_locale_from_utf8 (text, strlen (text), NULL, NULL, NULL);
    
    if (!text)
    {
        TEST_FAIL ("g_locale_from_utf8() returned NULL", NULL);
    } else {
        if (strcmp (text, (gchar*) CORRECT_TEXT))
        {
            TEST_FAIL ("text = '%s', should be '%s'", text, (gchar*) CORRECT_TEXT);
        }
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef START_LINE_NUM
    #undef START_LINE_OFFSET
    #undef END_LINE_NUM
    #undef END_LINE_OFFSET
    #undef INCLUDE_HIDDEN_CHARS
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_set_text
 * Params: GtkTextBuffer *buffer, const gchar *text, gint len
 * Returns:  void
 * Assertion: Deletes current contents of buffer, and inserts text instead.
 * Params Values: newly created GtkTextBuffer*, "\b\n\t\n" , strlen ("\b\n\t\n")
 * Expected:  void
 * 
 * Name: gtk_text_buffer_get_text
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end, gboolean include_hidden_chars
 * Returns:  gchar*
 * Assertion: Returns the text in the range [start,end).
 * Params Values: newly created GtkTextBuffer*, GtkTextIter with line = 0 and line offset = 1, GtkTextIter with line = 0 and line offset = 2, TRUE
 * Expected:  "\n"  
 */
static void test_purpose_29()
{
    #define TEXT "\b\n\t\n" 
    #define TEXT_LENGTH strlen ("\b\n\t\n")
    #define START_LINE_NUM 0
    #define START_LINE_OFFSET 1
    #define END_LINE_NUM 0
    #define END_LINE_OFFSET 2
    #define INCLUDE_HIDDEN_CHARS TRUE
    #define CORRECT_TEXT "\n"
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    gtk_text_iter_set_line (&start, START_LINE_NUM);
    gtk_text_iter_set_line_offset (&start, START_LINE_OFFSET);
    gtk_text_iter_set_line (&end, END_LINE_NUM);
    gtk_text_iter_set_line_offset (&end, END_LINE_OFFSET);
    
    text = (gchar*) calloc (1, TEXT_LENGTH);
    text = gtk_text_buffer_get_text (buffer, &start, &end, INCLUDE_HIDDEN_CHARS);
    text = g_locale_from_utf8 (text, strlen (text), NULL, NULL, NULL);
    
    if (!text)
    {
        TEST_FAIL ("g_locale_from_utf8() returned NULL", NULL);
    } else {
        if (strcmp (text, (gchar*) CORRECT_TEXT))
        {
            TEST_FAIL ("text = '%s', should be '%s'", text, (gchar*) CORRECT_TEXT);
        }
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef START_LINE_NUM
    #undef START_LINE_OFFSET
    #undef END_LINE_NUM
    #undef END_LINE_OFFSET
    #undef INCLUDE_HIDDEN_CHARS
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_text
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end, gboolean include_hidden_chars
 * Returns:  gchar*
 * Assertion: Excludes undisplayed text (text marked with tags that set the invisibility attribute) if include_hidden_chars is FALSE.
 * Params Values: newly created GtkTextBuffer*, GtkTextIter with line = 0 and line offset = 1, GtkTextIter with line = 0 and line offset = 4
 * Expected:  ""  
 */
static void test_purpose_30()
{
    #define TEXT "abcde"
    #define TEXT_LENGTH strlen ("abcde")
    #define START_LINE_NUM 0
    #define START_LINE_OFFSET 1
    #define END_LINE_NUM 0
    #define END_LINE_OFFSET 4
    #define INCLUDE_HIDDEN_CHARS TRUE
    #define CORRECT_TEXT "abcde"
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter invisible_start;
    GtkTextIter invisible_end;
    GtkTextTag* invisible_tag;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    gtk_text_buffer_get_bounds (buffer, &invisible_start, &invisible_end);
    
    gtk_text_iter_set_line (&invisible_start, START_LINE_NUM);
    gtk_text_iter_set_line_offset (&invisible_start, START_LINE_OFFSET);
    gtk_text_iter_set_line (&invisible_end, END_LINE_NUM);
    gtk_text_iter_set_line_offset (&invisible_end, END_LINE_OFFSET);
    
    invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag",
    					    "invisible", TRUE, NULL);
    gtk_text_buffer_apply_tag (buffer, invisible_tag,
    			   &invisible_start, &invisible_end);
    
    text = (gchar*) calloc (1, TEXT_LENGTH);
    text = gtk_text_buffer_get_text (buffer, &start, &end, INCLUDE_HIDDEN_CHARS);
    text = g_locale_from_utf8 (text, strlen (text), NULL, NULL, NULL);
    
    if (!text)
    {
        TEST_FAIL ("g_locale_from_utf8() returned NULL", NULL);
    } else {
        if (strcmp (text, CORRECT_TEXT))
        {
            TEST_FAIL ("text = '%s', should be '%s'", text, (gchar*) CORRECT_TEXT);
        }
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef START_LINE_NUM
    #undef START_LINE_OFFSET
    #undef END_LINE_NUM
    #undef END_LINE_OFFSET
    #undef INCLUDE_HIDDEN_CHARS
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_text
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end, gboolean include_hidden_chars
 * Returns:  gchar*
 * Assertion: Excludes undisplayed text (text marked with tags that set the invisibility attribute) if include_hidden_chars is FALSE.
 * Params Values: newly created GtkTextBuffer*, GtkTextIter with line = 0 and line offset = 1, GtkTextIter with line = 0 and line offset = 4
 * Expected:  ""  
 */
static void test_purpose_31()
{
    #define TEXT "abcde"
    #define TEXT_LENGTH strlen ("abcde")
    #define START_LINE_NUM 0
    #define START_LINE_OFFSET 1
    #define END_LINE_NUM 0
    #define END_LINE_OFFSET 4
    #define INCLUDE_HIDDEN_CHARS FALSE
    #define CORRECT_TEXT "ae"
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter invisible_start;
    GtkTextIter invisible_end;
    GtkTextTag* invisible_tag;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    gtk_text_buffer_get_bounds (buffer, &invisible_start, &invisible_end);
    
    gtk_text_iter_set_line (&invisible_start, START_LINE_NUM);
    gtk_text_iter_set_line_offset (&invisible_start, START_LINE_OFFSET);
    gtk_text_iter_set_line (&invisible_end, END_LINE_NUM);
    gtk_text_iter_set_line_offset (&invisible_end, END_LINE_OFFSET);
    
    invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag",
    					    "invisible", TRUE, NULL);
    gtk_text_buffer_apply_tag (buffer, invisible_tag,
    			   &invisible_start, &invisible_end);
    
    text = (gchar*) calloc (1, TEXT_LENGTH);
    text = gtk_text_buffer_get_text (buffer, &start, &end, INCLUDE_HIDDEN_CHARS);
    text = g_locale_from_utf8 (text, strlen (text), NULL, NULL, NULL);
    
    if (!text)
    {
        TEST_FAIL ("g_locale_from_utf8() returned NULL", NULL);
    } else {
        if (strcmp (text, CORRECT_TEXT))
        {
            TEST_FAIL ("text = '%s', should be '%s'", text, (gchar*) CORRECT_TEXT);
        }
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef START_LINE_NUM
    #undef START_LINE_OFFSET
    #undef END_LINE_NUM
    #undef END_LINE_OFFSET
    #undef INCLUDE_HIDDEN_CHARS
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_slice
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end, gboolean include_hidden_chars
 * Returns:  gchar*
 * Assertion: Returns the text in the range [start,end).
 * Params Values: newly created GtkTextBuffer* with invisible text started at (0, 0) and ended at (0, 0), GtkTextIter with line = 0 and line offset = 0, GtkTextIter with line = 0 and line offset = 0
 * Expected:  ""  
 */
static void test_purpose_32()
{
    #define TEXT ""
    #define TEXT_LENGTH 0
    #define START_LINE_NUM 0
    #define START_LINE_OFFSET 0
    #define END_LINE_NUM 0
    #define END_LINE_OFFSET 0
    #define INVISIBLE_START_LINE_NUM 0
    #define INVISIBLE_START_LINE_OFFSET 0
    #define INVISIBLE_END_LINE_NUM 0
    #define INVISIBLE_END_LINE_OFFSET 0
    #define INCLUDE_HIDDEN_CHARS FALSE
    #define CORRECT_TEXT ""
    
    GtkTextBuffer* buffer;
    GtkTextTag *invisible_tag;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter invisible_start;
    GtkTextIter invisible_end;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    gtk_text_buffer_get_bounds (buffer, &invisible_start, &invisible_end);
    
    gtk_text_iter_set_line (&start, START_LINE_NUM);
    gtk_text_iter_set_line_offset (&start, START_LINE_OFFSET);
    gtk_text_iter_set_line (&end, END_LINE_NUM);
    gtk_text_iter_set_line_offset (&end, END_LINE_OFFSET);
    
    gtk_text_iter_set_line (&invisible_start, INVISIBLE_START_LINE_NUM);
    gtk_text_iter_set_line_offset (&invisible_start, INVISIBLE_START_LINE_OFFSET);
    gtk_text_iter_set_line (&invisible_end, INVISIBLE_END_LINE_NUM);
    gtk_text_iter_set_line_offset (&invisible_end, INVISIBLE_END_LINE_OFFSET);
    
    invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", 
                                                "invisible", TRUE, NULL);
    gtk_text_buffer_apply_tag (buffer, invisible_tag, 
                               &invisible_start, &invisible_end);
    
    text = (gchar*) calloc (1, TEXT_LENGTH);
    text = gtk_text_buffer_get_slice (buffer, &start, &end, INCLUDE_HIDDEN_CHARS);
    text = g_locale_from_utf8 (text, strlen (text), NULL, NULL, NULL);
    
    if (!text)
    {
        TEST_FAIL ("g_locale_from_utf8() returned NULL", NULL);
    } else {
        if (strcmp (text, (gchar*) CORRECT_TEXT))
        {
            TEST_FAIL ("text = '%s', should be '%s'", text, (gchar*) CORRECT_TEXT);
        }
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef START_LINE_NUM
    #undef START_LINE_OFFSET
    #undef END_LINE_NUM
    #undef END_LINE_OFFSET
    #undef INVISIBLE_START_LINE_NUM
    #undef INVISIBLE_START_LINE_OFFSET
    #undef INVISIBLE_END_LINE_NUM
    #undef INVISIBLE_END_LINE_OFFSET
    #undef INCLUDE_HIDDEN_CHARS
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_slice
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end, gboolean include_hidden_chars
 * Returns:  gchar*
 * Assertion: Returns the text in the range [start,end).
 * Params Values: newly created GtkTextBuffer* with invisible text started at (0, 0) and ended at (0, 1), GtkTextIter with line = 1 and line offset = 0, GtkTextIter with line = 0 and line offset = 1
 * Expected:  " "  
 */
static void test_purpose_33()
{
    #define TEXT " "
    #define TEXT_LENGTH 1
    #define START_LINE_NUM 0
    #define START_LINE_OFFSET 0
    #define END_LINE_NUM 0
    #define END_LINE_OFFSET 1
    #define INVISIBLE_START_LINE_NUM 1
    #define INVISIBLE_START_LINE_OFFSET 0
    #define INVISIBLE_END_LINE_NUM 0
    #define INVISIBLE_END_LINE_OFFSET 1
    #define INCLUDE_HIDDEN_CHARS TRUE
    #define CORRECT_TEXT " "
    
    GtkTextBuffer* buffer;
    GtkTextTag *invisible_tag;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter invisible_start;
    GtkTextIter invisible_end;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    gtk_text_buffer_get_bounds (buffer, &invisible_start, &invisible_end);
    
    gtk_text_iter_set_line (&start, START_LINE_NUM);
    gtk_text_iter_set_line_offset (&start, START_LINE_OFFSET);
    gtk_text_iter_set_line (&end, END_LINE_NUM);
    gtk_text_iter_set_line_offset (&end, END_LINE_OFFSET);
    
    gtk_text_iter_set_line (&invisible_start, INVISIBLE_START_LINE_NUM);
    gtk_text_iter_set_line_offset (&invisible_start, INVISIBLE_START_LINE_OFFSET);
    gtk_text_iter_set_line (&invisible_end, INVISIBLE_END_LINE_NUM);
    gtk_text_iter_set_line_offset (&invisible_end, INVISIBLE_END_LINE_OFFSET);
    
    invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", 
                                                "invisible", TRUE, NULL);
    gtk_text_buffer_apply_tag (buffer, invisible_tag, 
                               &invisible_start, &invisible_end);
    
    text = (gchar*) calloc (1, TEXT_LENGTH);
    text = gtk_text_buffer_get_slice (buffer, &start, &end, INCLUDE_HIDDEN_CHARS);
    text = g_locale_from_utf8 (text, strlen (text), NULL, NULL, NULL);
    
    if (!text)
    {
        TEST_FAIL ("g_locale_from_utf8() returned NULL", NULL);
    } else {
        if (strcmp (text, (gchar*) CORRECT_TEXT))
        {
            TEST_FAIL ("text = '%s', should be '%s'", text, (gchar*) CORRECT_TEXT);
        }
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef START_LINE_NUM
    #undef START_LINE_OFFSET
    #undef END_LINE_NUM
    #undef END_LINE_OFFSET
    #undef INVISIBLE_START_LINE_NUM
    #undef INVISIBLE_START_LINE_OFFSET
    #undef INVISIBLE_END_LINE_NUM
    #undef INVISIBLE_END_LINE_OFFSET
    #undef INCLUDE_HIDDEN_CHARS
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_slice
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end, gboolean include_hidden_chars
 * Returns:  gchar*
 * Assertion: Returns the text in the range [start,end).
 * Params Values: newly created GtkTextBuffer* with invisible text started at (0, 0) and ended at (0, 1), GtkTextIter with line = 0 and line offset = 0, GtkTextIter with line = 0 and line offset = 1
 * Expected:  ""  
 */
static void test_purpose_34()
{
    #define TEXT " "
    #define TEXT_LENGTH 1
    #define START_LINE_NUM 0
    #define START_LINE_OFFSET 0
    #define END_LINE_NUM 0
    #define END_LINE_OFFSET 1
    #define INVISIBLE_START_LINE_NUM 0
    #define INVISIBLE_START_LINE_OFFSET 0
    #define INVISIBLE_END_LINE_NUM 0
    #define INVISIBLE_END_LINE_OFFSET 1
    #define INCLUDE_HIDDEN_CHARS FALSE
    #define CORRECT_TEXT ""
    
    GtkTextBuffer* buffer;
    GtkTextTag *invisible_tag;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter invisible_start;
    GtkTextIter invisible_end;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    gtk_text_buffer_get_bounds (buffer, &invisible_start, &invisible_end);
    
    gtk_text_iter_set_line (&start, START_LINE_NUM);
    gtk_text_iter_set_line_offset (&start, START_LINE_OFFSET);
    gtk_text_iter_set_line (&end, END_LINE_NUM);
    gtk_text_iter_set_line_offset (&end, END_LINE_OFFSET);
    
    gtk_text_iter_set_line (&invisible_start, INVISIBLE_START_LINE_NUM);
    gtk_text_iter_set_line_offset (&invisible_start, INVISIBLE_START_LINE_OFFSET);
    gtk_text_iter_set_line (&invisible_end, INVISIBLE_END_LINE_NUM);
    gtk_text_iter_set_line_offset (&invisible_end, INVISIBLE_END_LINE_OFFSET);
    
    invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", 
                                                "invisible", TRUE, NULL);
    gtk_text_buffer_apply_tag (buffer, invisible_tag, 
                               &invisible_start, &invisible_end);
    
    text = (gchar*) calloc (1, TEXT_LENGTH);
    text = gtk_text_buffer_get_slice (buffer, &start, &end, INCLUDE_HIDDEN_CHARS);
    text = g_locale_from_utf8 (text, strlen (text), NULL, NULL, NULL);
    
    if (!text)
    {
        TEST_FAIL ("g_locale_from_utf8() returned NULL", NULL);
    } else {
        if (strcmp (text, (gchar*) CORRECT_TEXT))
        {
            TEST_FAIL ("text = '%s', should be '%s'", text, (gchar*) CORRECT_TEXT);
        }
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef START_LINE_NUM
    #undef START_LINE_OFFSET
    #undef END_LINE_NUM
    #undef END_LINE_OFFSET
    #undef INVISIBLE_START_LINE_NUM
    #undef INVISIBLE_START_LINE_OFFSET
    #undef INVISIBLE_END_LINE_NUM
    #undef INVISIBLE_END_LINE_OFFSET
    #undef INCLUDE_HIDDEN_CHARS
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_slice
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end, gboolean include_hidden_chars
 * Returns:  gchar*
 * Assertion: Returns the text in the range [start,end).
 * Params Values: newly created GtkTextBuffer* with invisible text started at (0, 0) and ended at (0, 3), GtkTextIter with line = 0 and line offset = 3, GtkTextIter with line = 0 and line offset = 3
 * Expected:  "Tex"  
 */
static void test_purpose_35()
{
    #define TEXT "Text\n"
    #define TEXT_LENGTH strlen ("Text\n")
    #define START_LINE_NUM 0
    #define START_LINE_OFFSET 0
    #define END_LINE_NUM 0
    #define END_LINE_OFFSET 3
    #define INVISIBLE_START_LINE_NUM 0
    #define INVISIBLE_START_LINE_OFFSET 3
    #define INVISIBLE_END_LINE_NUM 0
    #define INVISIBLE_END_LINE_OFFSET 3
    #define INCLUDE_HIDDEN_CHARS FALSE
    #define CORRECT_TEXT "Tex"
    
    GtkTextBuffer* buffer;
    GtkTextTag *invisible_tag;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter invisible_start;
    GtkTextIter invisible_end;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    gtk_text_buffer_get_bounds (buffer, &invisible_start, &invisible_end);
    
    gtk_text_iter_set_line (&start, START_LINE_NUM);
    gtk_text_iter_set_line_offset (&start, START_LINE_OFFSET);
    gtk_text_iter_set_line (&end, END_LINE_NUM);
    gtk_text_iter_set_line_offset (&end, END_LINE_OFFSET);
    
    gtk_text_iter_set_line (&invisible_start, INVISIBLE_START_LINE_NUM);
    gtk_text_iter_set_line_offset (&invisible_start, INVISIBLE_START_LINE_OFFSET);
    gtk_text_iter_set_line (&invisible_end, INVISIBLE_END_LINE_NUM);
    gtk_text_iter_set_line_offset (&invisible_end, INVISIBLE_END_LINE_OFFSET);
    
    invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", 
                                                "invisible", TRUE, NULL);
    gtk_text_buffer_apply_tag (buffer, invisible_tag, 
                               &invisible_start, &invisible_end);
    
    text = (gchar*) calloc (1, TEXT_LENGTH);
    text = gtk_text_buffer_get_slice (buffer, &start, &end, INCLUDE_HIDDEN_CHARS);
    text = g_locale_from_utf8 (text, strlen (text), NULL, NULL, NULL);
    
    if (!text)
    {
        TEST_FAIL ("g_locale_from_utf8() returned NULL", NULL);
    } else {
        if (strcmp (text, (gchar*) CORRECT_TEXT))
        {
            TEST_FAIL ("text = '%s', should be '%s'", text, (gchar*) CORRECT_TEXT);
        }
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef START_LINE_NUM
    #undef START_LINE_OFFSET
    #undef END_LINE_NUM
    #undef END_LINE_OFFSET
    #undef INVISIBLE_START_LINE_NUM
    #undef INVISIBLE_START_LINE_OFFSET
    #undef INVISIBLE_END_LINE_NUM
    #undef INVISIBLE_END_LINE_OFFSET
    #undef INCLUDE_HIDDEN_CHARS
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_slice
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end, gboolean include_hidden_chars
 * Returns:  gchar*
 * Assertion: Returns the text in the range [start,end).
 * Params Values: newly created GtkTextBuffer* with invisible text started at (0, 2) and ended at (1, 4), GtkTextIter with line = 0 and line offset = 2, GtkTextIter with line = 1 and line offset = 4
 * Expected:  "xt\nText"  
 */
static void test_purpose_36()
{
    #define TEXT "Text\nText\n"
    #define TEXT_LENGTH strlen ("Text\nText\n")
    #define START_LINE_NUM 0
    #define START_LINE_OFFSET 2
    #define END_LINE_NUM 1
    #define END_LINE_OFFSET 4
    #define INVISIBLE_START_LINE_NUM 0
    #define INVISIBLE_START_LINE_OFFSET 2
    #define INVISIBLE_END_LINE_NUM 1
    #define INVISIBLE_END_LINE_OFFSET 4
    #define INCLUDE_HIDDEN_CHARS TRUE
    #define CORRECT_TEXT "xt\nText"
    
    GtkTextBuffer* buffer;
    GtkTextTag *invisible_tag;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter invisible_start;
    GtkTextIter invisible_end;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    gtk_text_buffer_get_bounds (buffer, &invisible_start, &invisible_end);
    
    gtk_text_iter_set_line (&start, START_LINE_NUM);
    gtk_text_iter_set_line_offset (&start, START_LINE_OFFSET);
    gtk_text_iter_set_line (&end, END_LINE_NUM);
    gtk_text_iter_set_line_offset (&end, END_LINE_OFFSET);
    
    gtk_text_iter_set_line (&invisible_start, INVISIBLE_START_LINE_NUM);
    gtk_text_iter_set_line_offset (&invisible_start, INVISIBLE_START_LINE_OFFSET);
    gtk_text_iter_set_line (&invisible_end, INVISIBLE_END_LINE_NUM);
    gtk_text_iter_set_line_offset (&invisible_end, INVISIBLE_END_LINE_OFFSET);
    
    invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", 
                                                "invisible", TRUE, NULL);
    gtk_text_buffer_apply_tag (buffer, invisible_tag, 
                               &invisible_start, &invisible_end);
    
    text = (gchar*) calloc (1, TEXT_LENGTH);
    text = gtk_text_buffer_get_slice (buffer, &start, &end, INCLUDE_HIDDEN_CHARS);
    text = g_locale_from_utf8 (text, strlen (text), NULL, NULL, NULL);
    
    if (!text)
    {
        TEST_FAIL ("g_locale_from_utf8() returned NULL", NULL);
    } else {
        if (strcmp (text, (gchar*) CORRECT_TEXT))
        {
            TEST_FAIL ("text = '%s', should be '%s'", text, (gchar*) CORRECT_TEXT);
        }
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef START_LINE_NUM
    #undef START_LINE_OFFSET
    #undef END_LINE_NUM
    #undef END_LINE_OFFSET
    #undef INVISIBLE_START_LINE_NUM
    #undef INVISIBLE_START_LINE_OFFSET
    #undef INVISIBLE_END_LINE_NUM
    #undef INVISIBLE_END_LINE_OFFSET
    #undef INCLUDE_HIDDEN_CHARS
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_slice
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end, gboolean include_hidden_chars
 * Returns:  gchar*
 * Assertion: Returns the text in the range [start,end).
 * Params Values: newly created GtkTextBuffer* with invisible text started at (0, 4) and ended at (1, 2), GtkTextIter with line = 0 and line offset = 4, GtkTextIter with line = 1 and line offset = 2
 * Expected:  "\n\bT"  
 */
static void test_purpose_37()
{
    #define TEXT "Text\n\bText\n"
    #define TEXT_LENGTH strlen ("Text\n\bText\n")
    #define START_LINE_NUM 0
    #define START_LINE_OFFSET 4
    #define END_LINE_NUM 1
    #define END_LINE_OFFSET 2
    #define INVISIBLE_START_LINE_NUM 0
    #define INVISIBLE_START_LINE_OFFSET 4
    #define INVISIBLE_END_LINE_NUM 1
    #define INVISIBLE_END_LINE_OFFSET 2
    #define INCLUDE_HIDDEN_CHARS TRUE
    #define CORRECT_TEXT "\n\bT"
    
    GtkTextBuffer* buffer;
    GtkTextTag *invisible_tag;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter invisible_start;
    GtkTextIter invisible_end;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    gtk_text_buffer_get_bounds (buffer, &invisible_start, &invisible_end);
    
    gtk_text_iter_set_line (&start, START_LINE_NUM);
    gtk_text_iter_set_line_offset (&start, START_LINE_OFFSET);
    gtk_text_iter_set_line (&end, END_LINE_NUM);
    gtk_text_iter_set_line_offset (&end, END_LINE_OFFSET);
    
    gtk_text_iter_set_line (&invisible_start, INVISIBLE_START_LINE_NUM);
    gtk_text_iter_set_line_offset (&invisible_start, INVISIBLE_START_LINE_OFFSET);
    gtk_text_iter_set_line (&invisible_end, INVISIBLE_END_LINE_NUM);
    gtk_text_iter_set_line_offset (&invisible_end, INVISIBLE_END_LINE_OFFSET);
    
    invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", 
                                                "invisible", TRUE, NULL);
    gtk_text_buffer_apply_tag (buffer, invisible_tag, 
                               &invisible_start, &invisible_end);
    
    text = (gchar*) calloc (1, TEXT_LENGTH);
    text = gtk_text_buffer_get_slice (buffer, &start, &end, INCLUDE_HIDDEN_CHARS);
    text = g_locale_from_utf8 (text, strlen (text), NULL, NULL, NULL);
    
    if (!text)
    {
        TEST_FAIL ("g_locale_from_utf8() returned NULL", NULL);
    } else {
        if (strcmp (text, (gchar*) CORRECT_TEXT))
        {
            TEST_FAIL ("text = '%s', should be '%s'", text, (gchar*) CORRECT_TEXT);
        }
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef START_LINE_NUM
    #undef START_LINE_OFFSET
    #undef END_LINE_NUM
    #undef END_LINE_OFFSET
    #undef INVISIBLE_START_LINE_NUM
    #undef INVISIBLE_START_LINE_OFFSET
    #undef INVISIBLE_END_LINE_NUM
    #undef INVISIBLE_END_LINE_OFFSET
    #undef INCLUDE_HIDDEN_CHARS
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_slice
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end, gboolean include_hidden_chars
 * Returns:  gchar*
 * Assertion: Returns the text in the range [start,end).
 * Params Values: newly created GtkTextBuffer* with invisible text started at (0, 5) and ended at (0, 57), GtkTextIter with line = 0 and line offset = 6, GtkTextIter with line = 0 and line offset = 56
 * Expected:  "fghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ12345"   
 */
static void test_purpose_38()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    #define TEXT_LENGTH strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n")
    #define START_LINE_NUM 0
    #define START_LINE_OFFSET 5
    #define END_LINE_NUM 0
    #define END_LINE_OFFSET 57
    #define INVISIBLE_START_LINE_NUM 0
    #define INVISIBLE_START_LINE_OFFSET 6
    #define INVISIBLE_END_LINE_NUM 0
    #define INVISIBLE_END_LINE_OFFSET 56
    #define INCLUDE_HIDDEN_CHARS TRUE
    #define CORRECT_TEXT "fghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ12345" 
    
    GtkTextBuffer* buffer;
    GtkTextTag *invisible_tag;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter invisible_start;
    GtkTextIter invisible_end;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    gtk_text_buffer_get_bounds (buffer, &invisible_start, &invisible_end);
    
    gtk_text_iter_set_line (&start, START_LINE_NUM);
    gtk_text_iter_set_line_offset (&start, START_LINE_OFFSET);
    gtk_text_iter_set_line (&end, END_LINE_NUM);
    gtk_text_iter_set_line_offset (&end, END_LINE_OFFSET);
    
    gtk_text_iter_set_line (&invisible_start, INVISIBLE_START_LINE_NUM);
    gtk_text_iter_set_line_offset (&invisible_start, INVISIBLE_START_LINE_OFFSET);
    gtk_text_iter_set_line (&invisible_end, INVISIBLE_END_LINE_NUM);
    gtk_text_iter_set_line_offset (&invisible_end, INVISIBLE_END_LINE_OFFSET);
    
    invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", 
                                                "invisible", TRUE, NULL);
    gtk_text_buffer_apply_tag (buffer, invisible_tag, 
                               &invisible_start, &invisible_end);
    
    text = (gchar*) calloc (1, TEXT_LENGTH);
    text = gtk_text_buffer_get_slice (buffer, &start, &end, INCLUDE_HIDDEN_CHARS);
    text = g_locale_from_utf8 (text, strlen (text), NULL, NULL, NULL);
    
    if (!text)
    {
        TEST_FAIL ("g_locale_from_utf8() returned NULL", NULL);
    } else {
        if (strcmp (text, (gchar*) CORRECT_TEXT))
        {
            TEST_FAIL ("text = '%s', should be '%s'", text, (gchar*) CORRECT_TEXT);
        }
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef START_LINE_NUM
    #undef START_LINE_OFFSET
    #undef END_LINE_NUM
    #undef END_LINE_OFFSET
    #undef INVISIBLE_START_LINE_NUM
    #undef INVISIBLE_START_LINE_OFFSET
    #undef INVISIBLE_END_LINE_NUM
    #undef INVISIBLE_END_LINE_OFFSET
    #undef INCLUDE_HIDDEN_CHARS
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_slice
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end, gboolean include_hidden_chars
 * Returns:  gchar*
 * Assertion: Returns the text in the range [start,end).
 * Params Values: newly created GtkTextBuffer* with invisible text started at (0, 5) and ended at (0, 57), GtkTextIter with line = 0 and line offset = 6, GtkTextIter with line = 0 and line offset = 56
 * Expected:  "f5"   
 */
static void test_purpose_39()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    #define TEXT_LENGTH strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n")
    #define START_LINE_NUM 0
    #define START_LINE_OFFSET 5
    #define END_LINE_NUM 0
    #define END_LINE_OFFSET 57
    #define INVISIBLE_START_LINE_NUM 0
    #define INVISIBLE_START_LINE_OFFSET 6
    #define INVISIBLE_END_LINE_NUM 0
    #define INVISIBLE_END_LINE_OFFSET 56
    #define INCLUDE_HIDDEN_CHARS FALSE
    #define CORRECT_TEXT "f5" 
    
    GtkTextBuffer* buffer;
    GtkTextTag *invisible_tag;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter invisible_start;
    GtkTextIter invisible_end;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    gtk_text_buffer_get_bounds (buffer, &invisible_start, &invisible_end);
    
    gtk_text_iter_set_line (&start, START_LINE_NUM);
    gtk_text_iter_set_line_offset (&start, START_LINE_OFFSET);
    gtk_text_iter_set_line (&end, END_LINE_NUM);
    gtk_text_iter_set_line_offset (&end, END_LINE_OFFSET);
    
    gtk_text_iter_set_line (&invisible_start, INVISIBLE_START_LINE_NUM);
    gtk_text_iter_set_line_offset (&invisible_start, INVISIBLE_START_LINE_OFFSET);
    gtk_text_iter_set_line (&invisible_end, INVISIBLE_END_LINE_NUM);
    gtk_text_iter_set_line_offset (&invisible_end, INVISIBLE_END_LINE_OFFSET);
    
    invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", 
                                                "invisible", TRUE, NULL);
    gtk_text_buffer_apply_tag (buffer, invisible_tag, 
                               &invisible_start, &invisible_end);
    
    text = (gchar*) calloc (1, TEXT_LENGTH);
    text = gtk_text_buffer_get_slice (buffer, &start, &end, INCLUDE_HIDDEN_CHARS);
    text = g_locale_from_utf8 (text, strlen (text), NULL, NULL, NULL);
    
    if (!text)
    {
        TEST_FAIL ("g_locale_from_utf8() returned NULL", NULL);
    } else {
        if (strcmp (text, (gchar*) CORRECT_TEXT))
        {
            TEST_FAIL ("text = '%s', should be '%s'", text, (gchar*) CORRECT_TEXT);
        }
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef START_LINE_NUM
    #undef START_LINE_OFFSET
    #undef END_LINE_NUM
    #undef END_LINE_OFFSET
    #undef INVISIBLE_START_LINE_NUM
    #undef INVISIBLE_START_LINE_OFFSET
    #undef INVISIBLE_END_LINE_NUM
    #undef INVISIBLE_END_LINE_OFFSET
    #undef INCLUDE_HIDDEN_CHARS
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_slice
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end, gboolean include_hidden_chars
 * Returns:  gchar*
 * Assertion: Returns the text in the range [start,end).
 * Params Values: newly created GtkTextBuffer* with invisible text started at (0, 2) and ended at (0, 23), GtkTextIter with line = 0 and line offset = 5, GtkTextIter with line = 0 and line offset = 10
 * Expected:  "#$%^&*()_+|~=\";:'?<>`"  
 */
static void test_purpose_40()
{
    #define TEXT "!@#$%^&*()_+|~=\";:'?<>`/" 
    #define TEXT_LENGTH strlen ("!@#$%^&*()_+|~=\";:'?<>`/")
    #define START_LINE_NUM 0
    #define START_LINE_OFFSET 2
    #define END_LINE_NUM 0
    #define END_LINE_OFFSET 23
    #define INVISIBLE_START_LINE_NUM 0
    #define INVISIBLE_START_LINE_OFFSET 5
    #define INVISIBLE_END_LINE_NUM 0
    #define INVISIBLE_END_LINE_OFFSET 10
    #define INCLUDE_HIDDEN_CHARS TRUE
    #define CORRECT_TEXT "#$%^&*()_+|~=\";:'?<>`"
    
    GtkTextBuffer* buffer;
    GtkTextTag *invisible_tag;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter invisible_start;
    GtkTextIter invisible_end;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    gtk_text_buffer_get_bounds (buffer, &invisible_start, &invisible_end);
    
    gtk_text_iter_set_line (&start, START_LINE_NUM);
    gtk_text_iter_set_line_offset (&start, START_LINE_OFFSET);
    gtk_text_iter_set_line (&end, END_LINE_NUM);
    gtk_text_iter_set_line_offset (&end, END_LINE_OFFSET);
    
    gtk_text_iter_set_line (&invisible_start, INVISIBLE_START_LINE_NUM);
    gtk_text_iter_set_line_offset (&invisible_start, INVISIBLE_START_LINE_OFFSET);
    gtk_text_iter_set_line (&invisible_end, INVISIBLE_END_LINE_NUM);
    gtk_text_iter_set_line_offset (&invisible_end, INVISIBLE_END_LINE_OFFSET);
    
    invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", 
                                                "invisible", TRUE, NULL);
    gtk_text_buffer_apply_tag (buffer, invisible_tag, 
                               &invisible_start, &invisible_end);
    
    text = (gchar*) calloc (1, TEXT_LENGTH);
    text = gtk_text_buffer_get_slice (buffer, &start, &end, INCLUDE_HIDDEN_CHARS);
    text = g_locale_from_utf8 (text, strlen (text), NULL, NULL, NULL);
    
    if (!text)
    {
        TEST_FAIL ("g_locale_from_utf8() returned NULL", NULL);
    } else {
        if (strcmp (text, (gchar*) CORRECT_TEXT))
        {
            TEST_FAIL ("text = '%s', should be '%s'", text, (gchar*) CORRECT_TEXT);
        }
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef START_LINE_NUM
    #undef START_LINE_OFFSET
    #undef END_LINE_NUM
    #undef END_LINE_OFFSET
    #undef INVISIBLE_START_LINE_NUM
    #undef INVISIBLE_START_LINE_OFFSET
    #undef INVISIBLE_END_LINE_NUM
    #undef INVISIBLE_END_LINE_OFFSET
    #undef INCLUDE_HIDDEN_CHARS
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_slice
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end, gboolean include_hidden_chars
 * Returns:  gchar*
 * Assertion: Returns the text in the range [start,end).
 * Params Values: newly created GtkTextBuffer* with invisible text started at (0, 2) and ended at (0, 23), GtkTextIter with line = 0 and line offset = 5, GtkTextIter with line = 0 and line offset = 10
 * Expected:  "#$%_+|~=\";:'?<>`"  
 */
static void test_purpose_41()
{
    #define TEXT "!@#$%^&*()_+|~=\";:'?<>`/" 
    #define TEXT_LENGTH strlen ("!@#$%^&*()_+|~=\";:'?<>`/")
    #define START_LINE_NUM 0
    #define START_LINE_OFFSET 2
    #define END_LINE_NUM 0
    #define END_LINE_OFFSET 23
    #define INVISIBLE_START_LINE_NUM 0
    #define INVISIBLE_START_LINE_OFFSET 5
    #define INVISIBLE_END_LINE_NUM 0
    #define INVISIBLE_END_LINE_OFFSET 10
    #define INCLUDE_HIDDEN_CHARS FALSE
    #define CORRECT_TEXT "#$%_+|~=\";:'?<>`"
    
    GtkTextBuffer* buffer;
    GtkTextTag *invisible_tag;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter invisible_start;
    GtkTextIter invisible_end;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    gtk_text_buffer_get_bounds (buffer, &invisible_start, &invisible_end);
    
    gtk_text_iter_set_line (&start, START_LINE_NUM);
    gtk_text_iter_set_line_offset (&start, START_LINE_OFFSET);
    gtk_text_iter_set_line (&end, END_LINE_NUM);
    gtk_text_iter_set_line_offset (&end, END_LINE_OFFSET);
    
    gtk_text_iter_set_line (&invisible_start, INVISIBLE_START_LINE_NUM);
    gtk_text_iter_set_line_offset (&invisible_start, INVISIBLE_START_LINE_OFFSET);
    gtk_text_iter_set_line (&invisible_end, INVISIBLE_END_LINE_NUM);
    gtk_text_iter_set_line_offset (&invisible_end, INVISIBLE_END_LINE_OFFSET);
    
    invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", 
                                                "invisible", TRUE, NULL);
    gtk_text_buffer_apply_tag (buffer, invisible_tag, 
                               &invisible_start, &invisible_end);
    
    text = (gchar*) calloc (1, TEXT_LENGTH);
    text = gtk_text_buffer_get_slice (buffer, &start, &end, INCLUDE_HIDDEN_CHARS);
    text = g_locale_from_utf8 (text, strlen (text), NULL, NULL, NULL);
    
    if (!text)
    {
        TEST_FAIL ("g_locale_from_utf8() returned NULL", NULL);
    } else {
        if (strcmp (text, (gchar*) CORRECT_TEXT))
        {
            TEST_FAIL ("text = '%s', should be '%s'", text, (gchar*) CORRECT_TEXT);
        }
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef START_LINE_NUM
    #undef START_LINE_OFFSET
    #undef END_LINE_NUM
    #undef END_LINE_OFFSET
    #undef INVISIBLE_START_LINE_NUM
    #undef INVISIBLE_START_LINE_OFFSET
    #undef INVISIBLE_END_LINE_NUM
    #undef INVISIBLE_END_LINE_OFFSET
    #undef INCLUDE_HIDDEN_CHARS
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_slice
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end, gboolean include_hidden_chars
 * Returns:  gchar*
 * Assertion: Returns the text in the range [start,end).
 * Params Values: newly created GtkTextBuffer* with invisible text started at (0, 1) and ended at (0, 2), GtkTextIter with line = 0 and line offset = 1, GtkTextIter with line = 0 and line offset = 2
 * Expected:  "\n"  
 */
static void test_purpose_42()
{
    #define TEXT "\b\n\t\n" 
    #define TEXT_LENGTH strlen ("\b\n\t\n")
    #define START_LINE_NUM 0
    #define START_LINE_OFFSET 1
    #define END_LINE_NUM 0
    #define END_LINE_OFFSET 2
    #define INVISIBLE_START_LINE_NUM 0
    #define INVISIBLE_START_LINE_OFFSET 1
    #define INVISIBLE_END_LINE_NUM 0
    #define INVISIBLE_END_LINE_OFFSET 2
    #define INCLUDE_HIDDEN_CHARS TRUE
    #define CORRECT_TEXT "\n"
    
    GtkTextBuffer* buffer;
    GtkTextTag *invisible_tag;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter invisible_start;
    GtkTextIter invisible_end;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    gtk_text_buffer_get_bounds (buffer, &invisible_start, &invisible_end);
    
    gtk_text_iter_set_line (&start, START_LINE_NUM);
    gtk_text_iter_set_line_offset (&start, START_LINE_OFFSET);
    gtk_text_iter_set_line (&end, END_LINE_NUM);
    gtk_text_iter_set_line_offset (&end, END_LINE_OFFSET);
    
    gtk_text_iter_set_line (&invisible_start, INVISIBLE_START_LINE_NUM);
    gtk_text_iter_set_line_offset (&invisible_start, INVISIBLE_START_LINE_OFFSET);
    gtk_text_iter_set_line (&invisible_end, INVISIBLE_END_LINE_NUM);
    gtk_text_iter_set_line_offset (&invisible_end, INVISIBLE_END_LINE_OFFSET);
    
    invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", 
                                                "invisible", TRUE, NULL);
    gtk_text_buffer_apply_tag (buffer, invisible_tag, 
                               &invisible_start, &invisible_end);
    
    text = (gchar*) calloc (1, TEXT_LENGTH);
    text = gtk_text_buffer_get_slice (buffer, &start, &end, INCLUDE_HIDDEN_CHARS);
    text = g_locale_from_utf8 (text, strlen (text), NULL, NULL, NULL);
    
    if (!text)
    {
        TEST_FAIL ("g_locale_from_utf8() returned NULL", NULL);
    } else {
        if (strcmp (text, (gchar*) CORRECT_TEXT))
        {
            TEST_FAIL ("text = '%s', should be '%s'", text, (gchar*) CORRECT_TEXT);
        }
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef START_LINE_NUM
    #undef START_LINE_OFFSET
    #undef END_LINE_NUM
    #undef END_LINE_OFFSET
    #undef INVISIBLE_START_LINE_NUM
    #undef INVISIBLE_START_LINE_OFFSET
    #undef INVISIBLE_END_LINE_NUM
    #undef INVISIBLE_END_LINE_OFFSET
    #undef INCLUDE_HIDDEN_CHARS
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_slice
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end, gboolean include_hidden_chars
 * Returns:  gchar*
 * Assertion: Excludes undisplayed text (text marked with tags that set the invisibility attribute) if include_hidden_chars is FALSE.
 * Params Values: newly created GtkTextBuffer*, GtkTextIter with line = 0 and line offset = 0, GtkTextIter with line = 0 and line offset = 4
 * Expected:  ""  
 */
static void test_purpose_43()
{
    #define TEXT "abcde"
    #define TEXT_LENGTH strlen ("abcde")
    #define START_LINE_NUM 0
    #define START_LINE_OFFSET 0
    #define END_LINE_NUM 0
    #define END_LINE_OFFSET 4
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* invisible_tag;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    invisible_tag = gtk_text_tag_new ("Invisible_tag");
    g_object_set (invisible_tag, "invisible", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), invisible_tag);
    gtk_text_buffer_apply_tag (buffer, invisible_tag, &start, &end);
    
    gtk_text_iter_set_line (&start, START_LINE_NUM);
    gtk_text_iter_set_line_offset (&start, START_LINE_OFFSET);
    gtk_text_iter_set_line (&end, END_LINE_NUM);
    gtk_text_iter_set_line_offset (&end, END_LINE_OFFSET);
    
    text = (gchar*) calloc (1, TEXT_LENGTH);
    text = gtk_text_buffer_get_slice (buffer, &start, &end, FALSE);
    text = g_locale_from_utf8 (text, strlen (text), NULL, NULL, NULL);
    
    if (!text)
    {
        TEST_FAIL ("g_locale_from_utf8() returned NULL", NULL);
    } else {
        if (strcmp (text, ""))
        {
            TEST_FAIL ("text = '%s', should be empty", text);
        }
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef START_LINE_NUM
    #undef START_LINE_OFFSET
    #undef END_LINE_NUM
    #undef END_LINE_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_slice
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end, gboolean include_hidden_chars
 * Returns:  gchar*
 * Assertion: The returned string includes a 0xFFFC character whenever the buffer contains embedded images, so byte and character indexes into the returned string do correspond to byte and character indexes into the buffer.
 * Params Values: newly created GtkTextBuffer*, GtkTextIter with line = 0 and line offset = 0, GtkTextIter with line = <%4%> and line offset = <%5%>
 * Expected:  gchar*  
 */
static void test_purpose_44()
{
    #define TEXT "abcde\n"
    #define TEXT_LENGTH strlen ("abcde\n")
    #define LINE 0
    #define OFFSET 0
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GdkPixbuf* pixbuf;
    gchar* text;
    gunichar* buff;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFSET);
    
    pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 10, 10);
    gtk_text_buffer_insert_pixbuf (buffer, &start, pixbuf);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text = (gchar*) calloc (1, TEXT_LENGTH);
    text = gtk_text_buffer_get_slice (buffer, &start, &end, TRUE);
    
    if (((int8_t)text[OFFSET] != -17) || ((int8_t)text[OFFSET+1] != -65) || ((int8_t)text[OFFSET+2] != -68))
    {
        TEST_FAIL ("FFFC symbol not found", NULL);
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef LINE
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_slice
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end, gboolean include_hidden_chars
 * Returns:  gchar*
 * Assertion: The returned string includes a 0xFFFC character whenever the buffer contains embedded images, so byte and character indexes into the returned string do correspond to byte and character indexes into the buffer.
 * Params Values: newly created GtkTextBuffer*, GtkTextIter with line = 0 and line offset = 2, GtkTextIter with line = <%4%> and line offset = <%5%>
 * Expected:  gchar*  
 */
static void test_purpose_45()
{
    #define TEXT "abcde\n"
    #define TEXT_LENGTH strlen ("abcde\n")
    #define LINE 0
    #define OFFSET 2
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GdkPixbuf* pixbuf;
    gchar* text;
    gunichar* buff;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFSET);
    
    pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 10, 10);
    gtk_text_buffer_insert_pixbuf (buffer, &start, pixbuf);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text = (gchar*) calloc (1, TEXT_LENGTH);
    text = gtk_text_buffer_get_slice (buffer, &start, &end, TRUE);
    
    if (((int8_t)text[OFFSET] != -17) || ((int8_t)text[OFFSET+1] != -65) || ((int8_t)text[OFFSET+2] != -68))
    {
        TEST_FAIL ("FFFC symbol not found", NULL);
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef LINE
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_slice
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end, gboolean include_hidden_chars
 * Returns:  gchar*
 * Assertion: The returned string includes a 0xFFFC character whenever the buffer contains embedded images, so byte and character indexes into the returned string do correspond to byte and character indexes into the buffer.
 * Params Values: newly created GtkTextBuffer*, GtkTextIter with line = 0 and line offset = 4, GtkTextIter with line = <%4%> and line offset = <%5%>
 * Expected:  gchar*  
 */
static void test_purpose_46()
{
    #define TEXT "abcde\n"
    #define TEXT_LENGTH strlen ("abcde\n")
    #define LINE 0
    #define OFFSET 4
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GdkPixbuf* pixbuf;
    gchar* text;
    gunichar* buff;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, TEXT_LENGTH);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFSET);
    
    pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 10, 10);
    gtk_text_buffer_insert_pixbuf (buffer, &start, pixbuf);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text = (gchar*) calloc (1, TEXT_LENGTH);
    text = gtk_text_buffer_get_slice (buffer, &start, &end, TRUE);
    
    if (((int8_t)text[OFFSET] != -17) || ((int8_t)text[OFFSET+1] != -65) || ((int8_t)text[OFFSET+2] != -68))
    {
        TEST_FAIL ("FFFC symbol not found", NULL);
    }
    
    #undef TEXT
    #undef TEXT_LENGTH
    #undef LINE
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_mark
 * Params: GtkTextBuffer *buffer, const gchar *name
 * Returns:  GtkTextMark*, or NULL
 * Assertion: Returns the mark named name in buffer buffer, or NULL if no such mark exists in the buffer.
 * Params Values: a newly created GtkTextBuffer with mark named "mark1", "mark2"
 * Expected: NULL  
 */
static void test_purpose_47()
{
    #define MARK_NAME "mark2"
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark *mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    gtk_text_buffer_create_mark (buffer, "mark1", &start, FALSE);
    mark = gtk_text_buffer_get_mark (buffer, MARK_NAME);
    
    if (MARK_NAME && !strcmp ("mark1", (gchar*)MARK_NAME))
    {
        if (!mark)
        {
            TEST_FAIL ("mark is NULL, should be not", NULL);
        } else if (!GTK_IS_TEXT_MARK (mark)) {
            TEST_FAIL ("gtk_text_buffer_get_mark() returned not GtkTextMark*", NULL);
        }
    } else {
        if (mark)
        {
            TEST_FAIL ("mark is not NULL, should be NULL", NULL);
        }
    }
    
    #undef MARK_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_mark
 * Params: GtkTextBuffer *buffer, const gchar *name
 * Returns:  GtkTextMark*, or NULL
 * Assertion: Returns the mark named name in buffer buffer, or NULL if no such mark exists in the buffer.
 * Params Values: a newly created GtkTextBuffer with mark named "mark1", "mark1"
 * Expected: GtkTextMark*  
 */
static void test_purpose_48()
{
    #define MARK_NAME "mark1"
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark *mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    gtk_text_buffer_create_mark (buffer, "mark1", &start, FALSE);
    mark = gtk_text_buffer_get_mark (buffer, MARK_NAME);
    
    if (MARK_NAME && !strcmp ("mark1", (gchar*)MARK_NAME))
    {
        if (!mark)
        {
            TEST_FAIL ("mark is NULL, should be not", NULL);
        } else if (!GTK_IS_TEXT_MARK (mark)) {
            TEST_FAIL ("gtk_text_buffer_get_mark() returned not GtkTextMark*", NULL);
        }
    } else {
        if (mark)
        {
            TEST_FAIL ("mark is not NULL, should be NULL", NULL);
        }
    }
    
    #undef MARK_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_insert
 * Params: GtkTextBuffer *buffer
 * Returns:  GtkTextMark*
 * Assertion: Returns the mark that represents the cursor (insertion point).
 * Params Values: a newly created GtkTextBuffer*
 * Expected: GtkTextMark*  
 */
static void test_purpose_49()
{
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark *mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    mark = gtk_text_buffer_get_insert (buffer);
    
    if (!mark)
    {
        TEST_FAIL ("mark is NULL, should be not", NULL);
    } else if (!GTK_IS_TEXT_MARK (mark)) {
        TEST_FAIL ("gtk_text_buffer_get_insert() returned not GtkTextMark*", NULL);
    }
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_insert
 * Params: GtkTextBuffer *buffer
 * Returns:  GtkTextMark*
 * Assertion: Equivalent to calling gtk_text_buffer_get_mark() to get the mark named "insert", but very slightly more efficient, and involves less typing.
 * Params Values: a newly created GtkTextBuffer*
 * Expected: GtkTextMark*  
 */
static void test_purpose_50()
{
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark *mark;
    GtkTextMark *mark1;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    mark = gtk_text_buffer_get_insert (buffer);
    if (!mark)
    {
        TEST_FAIL ("mark is NULL, should be not", NULL);
    } else if (!GTK_IS_TEXT_MARK (mark)) {
        TEST_FAIL ("gtk_text_buffer_get_insert() returned not GtkTextMark*", NULL);
    }
    
    mark1 = gtk_text_buffer_get_mark (buffer, "insert");
    if (!mark1)
    {
        TEST_FAIL ("mark1 is NULL, should be not", NULL);
    } else if (!GTK_IS_TEXT_MARK (mark)) {
        TEST_FAIL ("gtk_text_buffer_get_mark() returned not GtkTextMark*", NULL);
    }
    
    if (mark != mark1)
    {
        TEST_FAIL ("mark1 should be equal to mark but it is not", NULL);
    }
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_selection_bound
 * Params: GtkTextBuffer *buffer
 * Returns:  GtkTextMark*
 * Assertion: Returns the mark that represents the selection bound.
 * Params Values: a newly created GtkTextBuffer*
 * Expected: GtkTextMark*  
 */
static void test_purpose_51()
{
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark *mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    mark = gtk_text_buffer_get_selection_bound (buffer);
    
    if (!mark)
    {
        TEST_FAIL ("mark is NULL, should be not", NULL);
    } else if (!GTK_IS_TEXT_MARK (mark)) {
        TEST_FAIL ("gtk_text_buffer_get_selection_bound () returned not GtkTextMark*", NULL);
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_selection_bound
 * Params: GtkTextBuffer *buffer
 * Returns:  GtkTextMark*
 * Assertion: Equivalent to calling gtk_text_buffer_get_mark() to get the mark named "selection_bound", but very slightly more efficient, and involves less typing.
 * Params Values: a newly created GtkTextBuffer*
 * Expected: GtkTextMark*  
 */
static void test_purpose_52()
{
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark *mark;
    GtkTextMark *mark1;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    mark = gtk_text_buffer_get_selection_bound (buffer);
    
    if (!mark)
    {
        TEST_FAIL ("mark is NULL, should be not", NULL);
    } else if (!GTK_IS_TEXT_MARK (mark)) {
        TEST_FAIL ("gtk_text_buffer_get_selection_bound () returned not GtkTextMark*", NULL);
    }
    
    mark1 = gtk_text_buffer_get_mark (buffer, "selection_bound");
    if (!mark1)
    {
        TEST_FAIL ("mark1 is NULL, should be not", NULL);
    } else if (!GTK_IS_TEXT_MARK (mark)) {
        TEST_FAIL ("gtk_text_buffer_get_mark() returned not GtkTextMark*", NULL);
    }
    if (mark != mark1)
    {
        TEST_FAIL ("mark1 should be equal to mark but it is not", NULL);
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_iter_at_line_offset
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, gint line_number, gint char_offset
 * Returns:  void
 * Assertion: Obtains an iterator pointing to char_offset within the given line.
 * Params Values: a newly created GtkTextBuffer with text '"Text\n"', a GtkTextIter to initialize, 0, 1
 * Expected: void  
 */
static void test_purpose_53()
{
    #define TEXT "Text\n"
    #define LINE_NUMBER 0
    #define CHAR_OFFSET 1
    
    GtkTextBuffer* buffer;
    GtkTextIter iter;
    gint line_number;
    gint line_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &iter, 
                                             LINE_NUMBER, CHAR_OFFSET);
    
    if (&iter == NULL)
    {
        TEST_FAIL ("iter is not initialized", NULL);
        return;
    } 
    
    line_number = gtk_text_iter_get_line (&iter);
    if (line_number != LINE_NUMBER)
    {
        TEST_FAIL ("line_number = %d, should be %d", 
                   line_number, (gint) LINE_NUMBER);
    }
    
    line_offset = gtk_text_iter_get_line_offset (&iter);
    if (line_offset != CHAR_OFFSET)
    {
        TEST_FAIL ("line_offset = %d, should be %d", 
                   line_offset, (gint) CHAR_OFFSET);
    }
    
    #undef TEXT
    #undef LINE_NUMBER
    #undef CHAR_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_iter_at_line_offset
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, gint line_number, gint char_offset
 * Returns:  void
 * Assertion: Obtains an iterator pointing to char_offset within the given line.
 * Params Values: a newly created GtkTextBuffer with text '"Text\nText\n"', a GtkTextIter to initialize, 0, 2
 * Expected: void  
 */
static void test_purpose_54()
{
    #define TEXT "Text\nText\n"
    #define LINE_NUMBER 0
    #define CHAR_OFFSET 2
    
    GtkTextBuffer* buffer;
    GtkTextIter iter;
    gint line_number;
    gint line_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &iter, 
                                             LINE_NUMBER, CHAR_OFFSET);
    
    if (&iter == NULL)
    {
        TEST_FAIL ("iter is not initialized", NULL);
        return;
    } 
    
    line_number = gtk_text_iter_get_line (&iter);
    if (line_number != LINE_NUMBER)
    {
        TEST_FAIL ("line_number = %d, should be %d", 
                   line_number, (gint) LINE_NUMBER);
    }
    
    line_offset = gtk_text_iter_get_line_offset (&iter);
    if (line_offset != CHAR_OFFSET)
    {
        TEST_FAIL ("line_offset = %d, should be %d", 
                   line_offset, (gint) CHAR_OFFSET);
    }
    
    #undef TEXT
    #undef LINE_NUMBER
    #undef CHAR_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_iter_at_line_offset
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, gint line_number, gint char_offset
 * Returns:  void
 * Assertion: Obtains an iterator pointing to char_offset within the given line.
 * Params Values: a newly created GtkTextBuffer with text '"Text\nText\n"', a GtkTextIter to initialize, 1, 3
 * Expected: void  
 */
static void test_purpose_55()
{
    #define TEXT "Text\nText\n"
    #define LINE_NUMBER 1
    #define CHAR_OFFSET 3
    
    GtkTextBuffer* buffer;
    GtkTextIter iter;
    gint line_number;
    gint line_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &iter, 
                                             LINE_NUMBER, CHAR_OFFSET);
    
    if (&iter == NULL)
    {
        TEST_FAIL ("iter is not initialized", NULL);
        return;
    } 
    
    line_number = gtk_text_iter_get_line (&iter);
    if (line_number != LINE_NUMBER)
    {
        TEST_FAIL ("line_number = %d, should be %d", 
                   line_number, (gint) LINE_NUMBER);
    }
    
    line_offset = gtk_text_iter_get_line_offset (&iter);
    if (line_offset != CHAR_OFFSET)
    {
        TEST_FAIL ("line_offset = %d, should be %d", 
                   line_offset, (gint) CHAR_OFFSET);
    }
    
    #undef TEXT
    #undef LINE_NUMBER
    #undef CHAR_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_iter_at_line_offset
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, gint line_number, gint char_offset
 * Returns:  void
 * Assertion: Obtains an iterator pointing to char_offset within the given line.
 * Params Values: a newly created GtkTextBuffer with text '"\b\n\t\n" ', a GtkTextIter to initialize, 0, 1
 * Expected: void  
 */
static void test_purpose_56()
{
    #define TEXT "\b\n\t\n" 
    #define LINE_NUMBER 0
    #define CHAR_OFFSET 1
    
    GtkTextBuffer* buffer;
    GtkTextIter iter;
    gint line_number;
    gint line_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &iter, 
                                             LINE_NUMBER, CHAR_OFFSET);
    
    if (&iter == NULL)
    {
        TEST_FAIL ("iter is not initialized", NULL);
        return;
    } 
    
    line_number = gtk_text_iter_get_line (&iter);
    if (line_number != LINE_NUMBER)
    {
        TEST_FAIL ("line_number = %d, should be %d", 
                   line_number, (gint) LINE_NUMBER);
    }
    
    line_offset = gtk_text_iter_get_line_offset (&iter);
    if (line_offset != CHAR_OFFSET)
    {
        TEST_FAIL ("line_offset = %d, should be %d", 
                   line_offset, (gint) CHAR_OFFSET);
    }
    
    #undef TEXT
    #undef LINE_NUMBER
    #undef CHAR_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_iter_at_offset
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, gint char_offset
 * Returns:  void
 * Assertion: Initializes iter to a position char_offset chars from the start of the entire buffer.
 * Params Values: a newly created GtkTextBuffer with text '"Text\n"', a GtkTextIter to initialize, 1
 * Expected: void  
 */
static void test_purpose_57()
{
    #define TEXT "Text\n"
    #define OFFSET 1
    
    GtkTextBuffer* buffer;
    GtkTextIter iter;
    gint offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    if (&iter == NULL)
    {
        TEST_FAIL ("iter is not initialized", NULL);
        return;
    } 
    
    offset = gtk_text_iter_get_offset (&iter);
    if (offset != OFFSET)
    {
        TEST_FAIL ("offset = %d, should be %d", offset, (gint) OFFSET);
    }
    
    #undef TEXT
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_iter_at_offset
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, gint char_offset
 * Returns:  void
 * Assertion: Initializes iter to a position char_offset chars from the start of the entire buffer.
 * Params Values: a newly created GtkTextBuffer with text '"Text\nText\n"', a GtkTextIter to initialize, 2
 * Expected: void  
 */
static void test_purpose_58()
{
    #define TEXT "Text\nText\n"
    #define OFFSET 2
    
    GtkTextBuffer* buffer;
    GtkTextIter iter;
    gint offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    if (&iter == NULL)
    {
        TEST_FAIL ("iter is not initialized", NULL);
        return;
    } 
    
    offset = gtk_text_iter_get_offset (&iter);
    if (offset != OFFSET)
    {
        TEST_FAIL ("offset = %d, should be %d", offset, (gint) OFFSET);
    }
    
    #undef TEXT
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_iter_at_offset
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, gint char_offset
 * Returns:  void
 * Assertion: Initializes iter to a position char_offset chars from the start of the entire buffer.
 * Params Values: a newly created GtkTextBuffer with text '"Text\nText\n"', a GtkTextIter to initialize, 6
 * Expected: void  
 */
static void test_purpose_59()
{
    #define TEXT "Text\nText\n"
    #define OFFSET 6
    
    GtkTextBuffer* buffer;
    GtkTextIter iter;
    gint offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    if (&iter == NULL)
    {
        TEST_FAIL ("iter is not initialized", NULL);
        return;
    } 
    
    offset = gtk_text_iter_get_offset (&iter);
    if (offset != OFFSET)
    {
        TEST_FAIL ("offset = %d, should be %d", offset, (gint) OFFSET);
    }
    
    #undef TEXT
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_iter_at_offset
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, gint char_offset
 * Returns:  void
 * Assertion: Initializes iter to a position char_offset chars from the start of the entire buffer.
 * Params Values: a newly created GtkTextBuffer with text '"\b\n\t\n" ', a GtkTextIter to initialize, 2
 * Expected: void  
 */
static void test_purpose_60()
{
    #define TEXT "\b\n\t\n" 
    #define OFFSET 2
    
    GtkTextBuffer* buffer;
    GtkTextIter iter;
    gint offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    if (&iter == NULL)
    {
        TEST_FAIL ("iter is not initialized", NULL);
        return;
    } 
    
    offset = gtk_text_iter_get_offset (&iter);
    if (offset != OFFSET)
    {
        TEST_FAIL ("offset = %d, should be %d", offset, (gint) OFFSET);
    }
    
    #undef TEXT
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_iter_at_offset
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, gint char_offset
 * Returns:  void
 * Assertion: If char_offset is -1 or greater than the number of characters in the buffer, iter is initialized to the end iterator, the iterator one past the last valid character in the buffer.
 * Params Values: a newly created GtkTextBuffer with text '"Text\n"', a GtkTextIter to initialize, 10
 * Expected: void  
 */
static void test_purpose_61()
{
    #define TEXT "Text\n"
    #define OFFSET 10
    
    GtkTextBuffer* buffer;
    GtkTextIter iter;
    gint offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    if (&iter == NULL)
    {
        TEST_FAIL ("iter is not initialized", NULL);
        return;
    } 
    
    offset = gtk_text_iter_get_offset (&iter);
    if (offset != strlen (TEXT))
    {
        TEST_FAIL ("offset = %d, should be %d (i.e. point to the end iterator", offset, strlen (TEXT));
    }
    
    #undef TEXT
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_iter_at_offset
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, gint char_offset
 * Returns:  void
 * Assertion: If char_offset is -1 or greater than the number of characters in the buffer, iter is initialized to the end iterator, the iterator one past the last valid character in the buffer.
 * Params Values: a newly created GtkTextBuffer with text '"Text\n"', a GtkTextIter to initialize, -1
 * Expected: void  
 */
static void test_purpose_62()
{
    #define TEXT "Text\n"
    #define OFFSET -1
    
    GtkTextBuffer* buffer;
    GtkTextIter iter;
    gint offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    if (&iter == NULL)
    {
        TEST_FAIL ("iter is not initialized", NULL);
        return;
    } 
    
    offset = gtk_text_iter_get_offset (&iter);
    if (offset != strlen (TEXT))
    {
        TEST_FAIL ("offset = %d, should be %d (i.e. point to the end iterator", offset, strlen (TEXT));
    }
    
    #undef TEXT
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_iter_at_offset
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, gint char_offset
 * Returns:  void
 * Assertion: If char_offset is -1 or greater than the number of characters in the buffer, iter is initialized to the end iterator, the iterator one past the last valid character in the buffer.
 * Params Values: a newly created GtkTextBuffer with text '"Text\nText\n"', a GtkTextIter to initialize, 20
 * Expected: void  
 */
static void test_purpose_63()
{
    #define TEXT "Text\nText\n"
    #define OFFSET 20
    
    GtkTextBuffer* buffer;
    GtkTextIter iter;
    gint offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    if (&iter == NULL)
    {
        TEST_FAIL ("iter is not initialized", NULL);
        return;
    } 
    
    offset = gtk_text_iter_get_offset (&iter);
    if (offset != strlen (TEXT))
    {
        TEST_FAIL ("offset = %d, should be %d (i.e. point to the end iterator", offset, strlen (TEXT));
    }
    
    #undef TEXT
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_iter_at_offset
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, gint char_offset
 * Returns:  void
 * Assertion: If char_offset is -1 or greater than the number of characters in the buffer, iter is initialized to the end iterator, the iterator one past the last valid character in the buffer.
 * Params Values: a newly created GtkTextBuffer with text '"Text\nText\n"', a GtkTextIter to initialize, -1
 * Expected: void  
 */
static void test_purpose_64()
{
    #define TEXT "Text\nText\n"
    #define OFFSET -1
    
    GtkTextBuffer* buffer;
    GtkTextIter iter;
    gint offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    if (&iter == NULL)
    {
        TEST_FAIL ("iter is not initialized", NULL);
        return;
    } 
    
    offset = gtk_text_iter_get_offset (&iter);
    if (offset != strlen (TEXT))
    {
        TEST_FAIL ("offset = %d, should be %d (i.e. point to the end iterator", offset, strlen (TEXT));
    }
    
    #undef TEXT
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_iter_at_offset
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, gint char_offset
 * Returns:  void
 * Assertion: If char_offset is -1 or greater than the number of characters in the buffer, iter is initialized to the end iterator, the iterator one past the last valid character in the buffer.
 * Params Values: a newly created GtkTextBuffer with text '"\b\n\t\n" ', a GtkTextIter to initialize, 10
 * Expected: void  
 */
static void test_purpose_65()
{
    #define TEXT "\b\n\t\n" 
    #define OFFSET 10
    
    GtkTextBuffer* buffer;
    GtkTextIter iter;
    gint offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    if (&iter == NULL)
    {
        TEST_FAIL ("iter is not initialized", NULL);
        return;
    } 
    
    offset = gtk_text_iter_get_offset (&iter);
    if (offset != strlen (TEXT))
    {
        TEST_FAIL ("offset = %d, should be %d (i.e. point to the end iterator", offset, strlen (TEXT));
    }
    
    #undef TEXT
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_iter_at_offset
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, gint char_offset
 * Returns:  void
 * Assertion: If char_offset is -1 or greater than the number of characters in the buffer, iter is initialized to the end iterator, the iterator one past the last valid character in the buffer.
 * Params Values: a newly created GtkTextBuffer with text '"\b\n\t\n" ', a GtkTextIter to initialize, -1
 * Expected: void  
 */
static void test_purpose_66()
{
    #define TEXT "\b\n\t\n" 
    #define OFFSET -1
    
    GtkTextBuffer* buffer;
    GtkTextIter iter;
    gint offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    if (&iter == NULL)
    {
        TEST_FAIL ("iter is not initialized", NULL);
        return;
    } 
    
    offset = gtk_text_iter_get_offset (&iter);
    if (offset != strlen (TEXT))
    {
        TEST_FAIL ("offset = %d, should be %d (i.e. point to the end iterator", offset, strlen (TEXT));
    }
    
    #undef TEXT
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_iter_at_line
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, gint line_number
 * Returns:  void
 * Assertion: Initializes iter to the start of the given line.
 * Params Values: a newly created GtkTextBuffer with text '"Text\n"', a GtkTextIter to initialize, 0
 * Expected: void  
 */
static void test_purpose_67()
{
    #define TEXT "Text\n"
    #define LINE_NUMBER 0
    
    GtkTextBuffer* buffer;
    GtkTextIter iter;
    gint line_number;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    
    gtk_text_buffer_get_iter_at_line (buffer, &iter, LINE_NUMBER);
    if (&iter == NULL)
    {
        TEST_FAIL ("iter is not initialized", NULL);
        return;
    } 
    
    line_number = gtk_text_iter_get_line (&iter);
    if (line_number != LINE_NUMBER)
    {
        TEST_FAIL ("line_number = %d, should be %d", 
                   line_number, (gint) LINE_NUMBER);
    }
    
    #undef TEXT
    #undef LINE_NUMBER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_iter_at_line
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, gint line_number
 * Returns:  void
 * Assertion: Initializes iter to the start of the given line.
 * Params Values: a newly created GtkTextBuffer with text '"Text\nText\n"', a GtkTextIter to initialize, 0
 * Expected: void  
 */
static void test_purpose_68()
{
    #define TEXT "Text\nText\n"
    #define LINE_NUMBER 0
    
    GtkTextBuffer* buffer;
    GtkTextIter iter;
    gint line_number;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    
    gtk_text_buffer_get_iter_at_line (buffer, &iter, LINE_NUMBER);
    if (&iter == NULL)
    {
        TEST_FAIL ("iter is not initialized", NULL);
        return;
    } 
    
    line_number = gtk_text_iter_get_line (&iter);
    if (line_number != LINE_NUMBER)
    {
        TEST_FAIL ("line_number = %d, should be %d", 
                   line_number, (gint) LINE_NUMBER);
    }
    
    #undef TEXT
    #undef LINE_NUMBER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_iter_at_line
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, gint line_number
 * Returns:  void
 * Assertion: Initializes iter to the start of the given line.
 * Params Values: a newly created GtkTextBuffer with text '"Text\nText\n"', a GtkTextIter to initialize, 1
 * Expected: void  
 */
static void test_purpose_69()
{
    #define TEXT "Text\nText\n"
    #define LINE_NUMBER 1
    
    GtkTextBuffer* buffer;
    GtkTextIter iter;
    gint line_number;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    
    gtk_text_buffer_get_iter_at_line (buffer, &iter, LINE_NUMBER);
    if (&iter == NULL)
    {
        TEST_FAIL ("iter is not initialized", NULL);
        return;
    } 
    
    line_number = gtk_text_iter_get_line (&iter);
    if (line_number != LINE_NUMBER)
    {
        TEST_FAIL ("line_number = %d, should be %d", 
                   line_number, (gint) LINE_NUMBER);
    }
    
    #undef TEXT
    #undef LINE_NUMBER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_iter_at_line
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, gint line_number
 * Returns:  void
 * Assertion: Initializes iter to the start of the given line.
 * Params Values: a newly created GtkTextBuffer with text '"\b\n\t\n" ', a GtkTextIter to initialize, 0
 * Expected: void  
 */
static void test_purpose_70()
{
    #define TEXT "\b\n\t\n" 
    #define LINE_NUMBER 0
    
    GtkTextBuffer* buffer;
    GtkTextIter iter;
    gint line_number;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    
    gtk_text_buffer_get_iter_at_line (buffer, &iter, LINE_NUMBER);
    if (&iter == NULL)
    {
        TEST_FAIL ("iter is not initialized", NULL);
        return;
    } 
    
    line_number = gtk_text_iter_get_line (&iter);
    if (line_number != LINE_NUMBER)
    {
        TEST_FAIL ("line_number = %d, should be %d", 
                   line_number, (gint) LINE_NUMBER);
    }
    
    #undef TEXT
    #undef LINE_NUMBER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_iter_at_line
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, gint line_number
 * Returns:  void
 * Assertion: Initializes iter to the start of the given line.
 * Params Values: a newly created GtkTextBuffer with text '"\b\n\t\n" ', a GtkTextIter to initialize, 1
 * Expected: void  
 */
static void test_purpose_71()
{
    #define TEXT "\b\n\t\n" 
    #define LINE_NUMBER 1
    
    GtkTextBuffer* buffer;
    GtkTextIter iter;
    gint line_number;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    
    gtk_text_buffer_get_iter_at_line (buffer, &iter, LINE_NUMBER);
    if (&iter == NULL)
    {
        TEST_FAIL ("iter is not initialized", NULL);
        return;
    } 
    
    line_number = gtk_text_iter_get_line (&iter);
    if (line_number != LINE_NUMBER)
    {
        TEST_FAIL ("line_number = %d, should be %d", 
                   line_number, (gint) LINE_NUMBER);
    }
    
    #undef TEXT
    #undef LINE_NUMBER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_iter_at_line_index
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, gint line_number, gint byte_index
 * Returns:  void
 * Assertion: Obtains an iterator pointing to byte_index within the given line.
 * Params Values: a newly created GtkTextBuffer with text '"Text\n"', a GtkTextIter to initialize, 0, 1
 * Expected: void  
 */
static void test_purpose_72()
{
    #define TEXT "Text\n"
    #define LINE_NUMBER 0
    #define BYTE_INDEX 1
    
    GtkTextBuffer* buffer;
    GtkTextIter iter;
    gint line_number;
    gint byte_index;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_index (buffer, &iter, 
                                            LINE_NUMBER, BYTE_INDEX);
    
    if (&iter == NULL)
    {
        TEST_FAIL ("iter is not initialized", NULL);
        return;
    } 
    
    line_number = gtk_text_iter_get_line (&iter);
    if (line_number != LINE_NUMBER)
    {
        TEST_FAIL ("line_number = %d, should be %d", 
                   line_number, (gint) LINE_NUMBER);
    }
    
    byte_index = gtk_text_iter_get_line_index (&iter);
    if (byte_index != BYTE_INDEX)
    {
        TEST_FAIL ("byte_index = %d, should be %d", 
                   byte_index, (gint) BYTE_INDEX);
    }
    
    #undef TEXT
    #undef LINE_NUMBER
    #undef BYTE_INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_iter_at_line_index
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, gint line_number, gint byte_index
 * Returns:  void
 * Assertion: Obtains an iterator pointing to byte_index within the given line.
 * Params Values: a newly created GtkTextBuffer with text '"Text\nText\n"', a GtkTextIter to initialize, 0, 2
 * Expected: void  
 */
static void test_purpose_73()
{
    #define TEXT "Text\nText\n"
    #define LINE_NUMBER 0
    #define BYTE_INDEX 2
    
    GtkTextBuffer* buffer;
    GtkTextIter iter;
    gint line_number;
    gint byte_index;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_index (buffer, &iter, 
                                            LINE_NUMBER, BYTE_INDEX);
    
    if (&iter == NULL)
    {
        TEST_FAIL ("iter is not initialized", NULL);
        return;
    } 
    
    line_number = gtk_text_iter_get_line (&iter);
    if (line_number != LINE_NUMBER)
    {
        TEST_FAIL ("line_number = %d, should be %d", 
                   line_number, (gint) LINE_NUMBER);
    }
    
    byte_index = gtk_text_iter_get_line_index (&iter);
    if (byte_index != BYTE_INDEX)
    {
        TEST_FAIL ("byte_index = %d, should be %d", 
                   byte_index, (gint) BYTE_INDEX);
    }
    
    #undef TEXT
    #undef LINE_NUMBER
    #undef BYTE_INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_iter_at_line_index
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, gint line_number, gint byte_index
 * Returns:  void
 * Assertion: Obtains an iterator pointing to byte_index within the given line.
 * Params Values: a newly created GtkTextBuffer with text '"Text\nText\n"', a GtkTextIter to initialize, 1, 3
 * Expected: void  
 */
static void test_purpose_74()
{
    #define TEXT "Text\nText\n"
    #define LINE_NUMBER 1
    #define BYTE_INDEX 3
    
    GtkTextBuffer* buffer;
    GtkTextIter iter;
    gint line_number;
    gint byte_index;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_index (buffer, &iter, 
                                            LINE_NUMBER, BYTE_INDEX);
    
    if (&iter == NULL)
    {
        TEST_FAIL ("iter is not initialized", NULL);
        return;
    } 
    
    line_number = gtk_text_iter_get_line (&iter);
    if (line_number != LINE_NUMBER)
    {
        TEST_FAIL ("line_number = %d, should be %d", 
                   line_number, (gint) LINE_NUMBER);
    }
    
    byte_index = gtk_text_iter_get_line_index (&iter);
    if (byte_index != BYTE_INDEX)
    {
        TEST_FAIL ("byte_index = %d, should be %d", 
                   byte_index, (gint) BYTE_INDEX);
    }
    
    #undef TEXT
    #undef LINE_NUMBER
    #undef BYTE_INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_iter_at_line_index
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, gint line_number, gint byte_index
 * Returns:  void
 * Assertion: Obtains an iterator pointing to byte_index within the given line.
 * Params Values: a newly created GtkTextBuffer with text '"\b\n\t\n" ', a GtkTextIter to initialize, 0, 1
 * Expected: void  
 */
static void test_purpose_75()
{
    #define TEXT "\b\n\t\n" 
    #define LINE_NUMBER 0
    #define BYTE_INDEX 1
    
    GtkTextBuffer* buffer;
    GtkTextIter iter;
    gint line_number;
    gint byte_index;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_index (buffer, &iter, 
                                            LINE_NUMBER, BYTE_INDEX);
    
    if (&iter == NULL)
    {
        TEST_FAIL ("iter is not initialized", NULL);
        return;
    } 
    
    line_number = gtk_text_iter_get_line (&iter);
    if (line_number != LINE_NUMBER)
    {
        TEST_FAIL ("line_number = %d, should be %d", 
                   line_number, (gint) LINE_NUMBER);
    }
    
    byte_index = gtk_text_iter_get_line_index (&iter);
    if (byte_index != BYTE_INDEX)
    {
        TEST_FAIL ("byte_index = %d, should be %d", 
                   byte_index, (gint) BYTE_INDEX);
    }
    
    #undef TEXT
    #undef LINE_NUMBER
    #undef BYTE_INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_iter_at_mark
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, GtkTextMark *mark
 * Returns:  void
 * Assertion: Initializes iter with the current position of mark.
 * Params Values: a newly created GtkTextBuffer with text '"Text\n"', a GtkTextIter to initialize, a new GtkTextMark named "mark1"
 * Expected: void  
 */
static void test_purpose_76()
{
    #define TEXT "Text\n"
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextMark *mark;
    GSList *marks;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    gtk_text_buffer_create_mark (buffer, "mark1", &start, FALSE);
    mark = gtk_text_buffer_get_mark (buffer, "mark1");
    gtk_text_buffer_get_iter_at_mark (buffer, &iter, mark);
    
    if (!mark)
    {
        TEST_FAIL ("mark is NULL, should be not", NULL);
    } else if (!GTK_IS_TEXT_MARK (mark)) {
        TEST_FAIL ("gtk_text_buffer_get_mark() returned not GtkTextMark*", NULL);
    }
    
    marks = gtk_text_iter_get_marks (&iter);
    if (!marks)
    {
        TEST_FAIL ("text iter doesn't have marks but it should have", NULL);
    }
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_iter_at_mark
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, GtkTextMark *mark
 * Returns:  void
 * Assertion: Initializes iter with the current position of mark.
 * Params Values: a newly created GtkTextBuffer with text '"Text\nText\n"', a GtkTextIter to initialize, a new GtkTextMark named "mark1"
 * Expected: void  
 */
static void test_purpose_77()
{
    #define TEXT "Text\nText\n"
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextMark *mark;
    GSList *marks;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    gtk_text_buffer_create_mark (buffer, "mark1", &start, FALSE);
    mark = gtk_text_buffer_get_mark (buffer, "mark1");
    gtk_text_buffer_get_iter_at_mark (buffer, &iter, mark);
    
    if (!mark)
    {
        TEST_FAIL ("mark is NULL, should be not", NULL);
    } else if (!GTK_IS_TEXT_MARK (mark)) {
        TEST_FAIL ("gtk_text_buffer_get_mark() returned not GtkTextMark*", NULL);
    }
    
    marks = gtk_text_iter_get_marks (&iter);
    if (!marks)
    {
        TEST_FAIL ("text iter doesn't have marks but it should have", NULL);
    }
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_iter_at_mark
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, GtkTextMark *mark
 * Returns:  void
 * Assertion: Initializes iter with the current position of mark.
 * Params Values: a newly created GtkTextBuffer with text '"\b\n\t\n" ', a GtkTextIter to initialize, a new GtkTextMark named "mark1"
 * Expected: void  
 */
static void test_purpose_78()
{
    #define TEXT "\b\n\t\n" 
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextMark *mark;
    GSList *marks;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    gtk_text_buffer_create_mark (buffer, "mark1", &start, FALSE);
    mark = gtk_text_buffer_get_mark (buffer, "mark1");
    gtk_text_buffer_get_iter_at_mark (buffer, &iter, mark);
    
    if (!mark)
    {
        TEST_FAIL ("mark is NULL, should be not", NULL);
    } else if (!GTK_IS_TEXT_MARK (mark)) {
        TEST_FAIL ("gtk_text_buffer_get_mark() returned not GtkTextMark*", NULL);
    }
    
    marks = gtk_text_iter_get_marks (&iter);
    if (!marks)
    {
        TEST_FAIL ("text iter doesn't have marks but it should have", NULL);
    }
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_start_iter
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter
 * Returns:  void
 * Assertion: Initialized iter with the first position in the text buffer.
 * Params Values: a newly created GtkTextBuffer with text '"Text\n"', a GtkTextIter to initialize
 * Expected: void
 * 
 * Name: gtk_text_buffer_get_start_iter
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter
 * Returns:  void
 * Assertion: This is the same as using gtk_text_buffer_get_iter_at_offset() to get the iter at character offset 0.
 * Params Values: a newly created GtkTextBuffer with text '"Text\n"', a GtkTextIter to initialize
 * Expected: void  
 */
static void test_purpose_79()
{
    #define TEXT "Text\n"
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter iter;
    gunichar last_char;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &start, 0);
    gtk_text_buffer_get_start_iter (buffer, &iter);
    
    if (!gtk_text_iter_equal (&iter, &start))
    {
        TEST_FAIL ("iters are not equal", NULL);
    } 
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_start_iter
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter
 * Returns:  void
 * Assertion: Initialized iter with the first position in the text buffer.
 * Params Values: a newly created GtkTextBuffer with text '"Text\nText\n"', a GtkTextIter to initialize
 * Expected: void
 * 
 * Name: gtk_text_buffer_get_start_iter
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter
 * Returns:  void
 * Assertion: This is the same as using gtk_text_buffer_get_iter_at_offset() to get the iter at character offset 0.
 * Params Values: a newly created GtkTextBuffer with text '"Text\nText\n"', a GtkTextIter to initialize
 * Expected: void  
 */
static void test_purpose_80()
{
    #define TEXT "Text\nText\n"
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter iter;
    gunichar last_char;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &start, 0);
    gtk_text_buffer_get_start_iter (buffer, &iter);
    
    if (!gtk_text_iter_equal (&iter, &start))
    {
        TEST_FAIL ("iters are not equal", NULL);
    } 
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_start_iter
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter
 * Returns:  void
 * Assertion: Initialized iter with the first position in the text buffer.
 * Params Values: a newly created GtkTextBuffer with text '"\b\n\t\n" ', a GtkTextIter to initialize
 * Expected: void
 * 
 * Name: gtk_text_buffer_get_start_iter
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter
 * Returns:  void
 * Assertion: This is the same as using gtk_text_buffer_get_iter_at_offset() to get the iter at character offset 0.
 * Params Values: a newly created GtkTextBuffer with text '"\b\n\t\n" ', a GtkTextIter to initialize
 * Expected: void  
 */
static void test_purpose_81()
{
    #define TEXT "\b\n\t\n" 
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter iter;
    gunichar last_char;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &start, 0);
    gtk_text_buffer_get_start_iter (buffer, &iter);
    
    if (!gtk_text_iter_equal (&iter, &start))
    {
        TEST_FAIL ("iters are not equal", NULL);
    } 
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_end_iter
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter
 * Returns:  void
 * Assertion: Initializes iter with the "end iterator," one past the last valid character in the text buffer.
 * Params Values: a newly created GtkTextBuffer with text '"Text\n"', a GtkTextIter to initialize
 * Expected: void  
 */
static void test_purpose_82()
{
    #define TEXT "Text\n"
    
    GtkTextBuffer* buffer;
    GtkTextIter end;
    GtkTextIter iter;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    
    gtk_text_buffer_get_end_iter (buffer, &iter);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, 0);
    gtk_text_iter_forward_to_end (&end);
    
    if (!gtk_text_iter_equal (&iter, &end))
    {
        TEST_FAIL ("iters are not equal", NULL);
    } 
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_end_iter
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter
 * Returns:  void
 * Assertion: Initializes iter with the "end iterator," one past the last valid character in the text buffer.
 * Params Values: a newly created GtkTextBuffer with text '"Text\nText\n"', a GtkTextIter to initialize
 * Expected: void  
 */
static void test_purpose_83()
{
    #define TEXT "Text\nText\n"
    
    GtkTextBuffer* buffer;
    GtkTextIter end;
    GtkTextIter iter;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    
    gtk_text_buffer_get_end_iter (buffer, &iter);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, 0);
    gtk_text_iter_forward_to_end (&end);
    
    if (!gtk_text_iter_equal (&iter, &end))
    {
        TEST_FAIL ("iters are not equal", NULL);
    } 
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_end_iter
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter
 * Returns:  void
 * Assertion: Initializes iter with the "end iterator," one past the last valid character in the text buffer.
 * Params Values: a newly created GtkTextBuffer with text '"\b\n\t\n" ', a GtkTextIter to initialize
 * Expected: void  
 */
static void test_purpose_84()
{
    #define TEXT "\b\n\t\n" 
    
    GtkTextBuffer* buffer;
    GtkTextIter end;
    GtkTextIter iter;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    
    gtk_text_buffer_get_end_iter (buffer, &iter);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, 0);
    gtk_text_iter_forward_to_end (&end);
    
    if (!gtk_text_iter_equal (&iter, &end))
    {
        TEST_FAIL ("iters are not equal", NULL);
    } 
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_end_iter
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter
 * Returns:  void
 * Assertion: If dereferenced with gtk_text_iter_get_char(), the end iterator has a character value of 0.
 * Params Values: a newly created GtkTextBuffer with text '"Text\n"', a GtkTextIter to initialize
 * Expected: void  
 */
static void test_purpose_85()
{
    #define TEXT "Text\n"
    
    GtkTextBuffer* buffer;
    GtkTextIter iter;
    gunichar last_char;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    
    gtk_text_buffer_get_end_iter (buffer, &iter);
    if (&iter == NULL)
    {
        TEST_FAIL ("iter is not initialized", NULL);
        return;
    } 
    
    last_char = gtk_text_iter_get_char (&iter);
    if (last_char != 0)
    {
        TEST_FAIL ("end iterator should have a character value of 0", NULL);
    }
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_bounds
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end
 * Returns:  void
 * Assertion: Retrieves the first and last iterators in the buffer, i.e. the entire buffer lies within the range [start,end).
 * Params Values: a newly created GtkTextBuffer with text '"Text\n"', a GtkTextIter to initialize, a GtkTextIter to initialize
 * Expected: void  
 */
static void test_purpose_86()
{
    #define TEXT "Text\n"
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    gunichar first_char;
    gunichar last_char;
    char *text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    text = calloc (1, strlen ((char*) TEXT) + 1);
    strcpy (text, (char*) TEXT);
    
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, text, strlen ((char*) TEXT));
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    if (&start == NULL)
    {
        TEST_FAIL ("start iter is not initialized", NULL);
        return;
    } 
    
    if (&end == NULL)
    {
        TEST_FAIL ("end iter is not initialized", NULL);
        return;
    } 
    
    first_char = gtk_text_iter_get_char (&start);
    if (first_char != *text)
    {
        TEST_FAIL ("first iterator character value = %s, should be %s", 
                   first_char, *text);
    }
    
    last_char = gtk_text_iter_get_char (&end);
    if (last_char != 0)
    {
        TEST_FAIL ("end iterator should have a character value of 0", NULL);
    }
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_bounds
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end
 * Returns:  void
 * Assertion: Retrieves the first and last iterators in the buffer, i.e. the entire buffer lies within the range [start,end).
 * Params Values: a newly created GtkTextBuffer with text '"Text\nText\n"', a GtkTextIter to initialize, a GtkTextIter to initialize
 * Expected: void  
 */
static void test_purpose_87()
{
    #define TEXT "Text\nText\n"
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    gunichar first_char;
    gunichar last_char;
    char *text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    text = calloc (1, strlen ((char*) TEXT) + 1);
    strcpy (text, (char*) TEXT);
    
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, text, strlen ((char*) TEXT));
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    if (&start == NULL)
    {
        TEST_FAIL ("start iter is not initialized", NULL);
        return;
    } 
    
    if (&end == NULL)
    {
        TEST_FAIL ("end iter is not initialized", NULL);
        return;
    } 
    
    first_char = gtk_text_iter_get_char (&start);
    if (first_char != *text)
    {
        TEST_FAIL ("first iterator character value = %s, should be %s", 
                   first_char, *text);
    }
    
    last_char = gtk_text_iter_get_char (&end);
    if (last_char != 0)
    {
        TEST_FAIL ("end iterator should have a character value of 0", NULL);
    }
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_bounds
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end
 * Returns:  void
 * Assertion: Retrieves the first and last iterators in the buffer, i.e. the entire buffer lies within the range [start,end).
 * Params Values: a newly created GtkTextBuffer with text '"\b\n\t\n" ', a GtkTextIter to initialize, a GtkTextIter to initialize
 * Expected: void  
 */
static void test_purpose_88()
{
    #define TEXT "\b\n\t\n" 
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    gunichar first_char;
    gunichar last_char;
    char *text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    text = calloc (1, strlen ((char*) TEXT) + 1);
    strcpy (text, (char*) TEXT);
    
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, text, strlen ((char*) TEXT));
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    if (&start == NULL)
    {
        TEST_FAIL ("start iter is not initialized", NULL);
        return;
    } 
    
    if (&end == NULL)
    {
        TEST_FAIL ("end iter is not initialized", NULL);
        return;
    } 
    
    first_char = gtk_text_iter_get_char (&start);
    if (first_char != *text)
    {
        TEST_FAIL ("first iterator character value = %s, should be %s", 
                   first_char, *text);
    }
    
    last_char = gtk_text_iter_get_char (&end);
    if (last_char != 0)
    {
        TEST_FAIL ("end iterator should have a character value of 0", NULL);
    }
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_modified
 * Params: GtkTextBuffer *buffer
 * Returns:  gboolean
 * Assertion: Indicates whether the buffer has been modified since the last call to gtk_text_buffer_set_modified() set the modification flag to FALSE.
 * Params Values: a newly created GtkTextBuffer
 * Expected:  TRUE
 * 
 * Name: gtk_text_buffer_set_modified
 * Params: GtkTextBuffer *buffer, gboolean setting
 * Returns:  void
 * Assertion: Used to keep track of whether the buffer has been modified since the last time it was saved.
 * Params Values: a newly created GtkTextBuffer, TRUE
 * Expected:  void  
 */
static void test_purpose_89()
{
    #define MODIFIED TRUE
    
    GtkTextBuffer* buffer;
    gboolean modified;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_modified (buffer, (gboolean) MODIFIED);
    modified = gtk_text_buffer_get_modified (buffer);
    
    if (modified != MODIFIED)
    {
        TEST_FAIL ("modified = %d, should be %d", modified, (gboolean) MODIFIED);
    }
    
    #undef MODIFIED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_modified
 * Params: GtkTextBuffer *buffer
 * Returns:  gboolean
 * Assertion: Indicates whether the buffer has been modified since the last call to gtk_text_buffer_set_modified() set the modification flag to FALSE.
 * Params Values: a newly created GtkTextBuffer
 * Expected:  FALSE
 * 
 * Name: gtk_text_buffer_set_modified
 * Params: GtkTextBuffer *buffer, gboolean setting
 * Returns:  void
 * Assertion: Used to keep track of whether the buffer has been modified since the last time it was saved.
 * Params Values: a newly created GtkTextBuffer, FALSE
 * Expected:  void  
 */
static void test_purpose_90()
{
    #define MODIFIED FALSE
    
    GtkTextBuffer* buffer;
    gboolean modified;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_modified (buffer, (gboolean) MODIFIED);
    modified = gtk_text_buffer_get_modified (buffer);
    
    if (modified != MODIFIED)
    {
        TEST_FAIL ("modified = %d, should be %d", modified, (gboolean) MODIFIED);
    }
    
    #undef MODIFIED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_set_modified
 * Params: GtkTextBuffer *buffer, gboolean setting
 * Returns:  void
 * Assertion: When the modified bit flips, the buffer emits a "modified_changed" signal.
 * Params Values: a newly created GtkTextBuffer, TRUE
 * Expected:  void  
 */
static void test_purpose_91()
{
    #define MODIFIED TRUE
    
    GtkTextBuffer* buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (buffer), "modified_changed",  GTK_SIGNAL_FUNC (global_modified), NULL);
    
    gtk_text_buffer_set_modified (buffer, (gboolean) MODIFIED);
    gtk_text_buffer_set_text (buffer, "Text", 4);
    
    
    if (modified_catched == 0)
    {
        TEST_FAIL ("buffer should emit 'modified_changed' signal", NULL);
    }
    
    #undef MODIFIED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_set_modified
 * Params: GtkTextBuffer *buffer, gboolean setting
 * Returns:  void
 * Assertion: When the modified bit flips, the buffer emits a "modified_changed" signal.
 * Params Values: a newly created GtkTextBuffer, FALSE
 * Expected:  void  
 */
static void test_purpose_92()
{
    #define MODIFIED FALSE
    
    GtkTextBuffer* buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (buffer), "modified_changed",  GTK_SIGNAL_FUNC (global_modified), NULL);
    
    gtk_text_buffer_set_modified (buffer, (gboolean) MODIFIED);
    gtk_text_buffer_set_text (buffer, "Text", 4);
    
    
    if (modified_catched == 0)
    {
        TEST_FAIL ("buffer should emit 'modified_changed' signal", NULL);
    }
    
    #undef MODIFIED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_set_modified
 * Params: GtkTextBuffer *buffer, gboolean setting
 * Returns:  void
 * Assertion: When the buffer is modified, it will automatically toggled on the modified bit again.
 * Params Values: a newly created GtkTextBuffer, <%0%>
 * Expected:  void  
 */
static void test_purpose_93()
{
    GtkTextBuffer* buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_modified (buffer, (gboolean) FALSE);
    gtk_text_buffer_set_text (buffer, "Text", 4);
    
    if (!gtk_text_buffer_get_modified (buffer))
    {
        TEST_FAIL ("'modified' bit should be 0", NULL);
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_selection_bounds
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end
 * Returns: gboolean
 * Assertion: Returns TRUE if some text is selected; places the bounds of the selection in start and end (if the selection has length 0, then start and end are filled in with the same value). 
 * Params Values: a newly created GtkTextBuffer with text '"abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" ', a GtkTextIter to initialize, a GtkTextIter to initialize
 * Expected: gboolean
 * 
 * Name: gtk_text_buffer_get_selection_bounds
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end
 * Returns: gboolean
 * Assertion: If start and end are NULL, then they are not filled in, but the return value still indicates whether text is selected
 * Params Values: a newly created GtkTextBuffer with text '"abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" ', a GtkTextIter to initialize, a GtkTextIter to initialize
 * Expected: gboolean
 * 
 * Name: gtk_text_buffer_get_selection_bounds
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end
 * Returns: gboolean
 * Assertion: start and end will be in ascending order
 * Params Values: a newly created GtkTextBuffer with text '"abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" ', a GtkTextIter to initialize, a GtkTextIter to initialize
 * Expected: gboolean  
 */
static void test_purpose_94()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    #define LINE 0
    #define OFFS 0
    #define LINE1 0
    #define OFFS1 20
    #define RESULT TRUE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    gboolean length;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    
    gtk_text_buffer_move_mark_by_name (buffer, "insert", &start);
    gtk_text_buffer_move_mark_by_name (buffer, "selection_bound", &end);
    
    length = gtk_text_buffer_get_selection_bounds (buffer, &start, &end);
    if (length != RESULT)
    {
        TEST_FAIL ("length = %d, should be %d", length, RESULT);
    }  
    
    if (gtk_text_iter_get_offset (&start) > gtk_text_iter_get_offset (&end))
    {
        TEST_FAIL ("'star't and 'end' will be in ascending order", NULL);
    }
    
    length = gtk_text_buffer_get_selection_bounds (buffer, NULL, NULL);
    if (length != RESULT)
    {
        TEST_FAIL ("length = %d, should be %d", length, RESULT);
    }  
    
    #undef TEXT
    #undef LINE 
    #undef OFFS 
    #undef LINE1 
    #undef OFFS1 
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_selection_bounds
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end
 * Returns: gboolean
 * Assertion: Returns TRUE if some text is selected; places the bounds of the selection in start and end (if the selection has length 0, then start and end are filled in with the same value). 
 * Params Values: a newly created GtkTextBuffer with text '"abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" ', a GtkTextIter to initialize, a GtkTextIter to initialize
 * Expected: gboolean
 * 
 * Name: gtk_text_buffer_get_selection_bounds
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end
 * Returns: gboolean
 * Assertion: If start and end are NULL, then they are not filled in, but the return value still indicates whether text is selected
 * Params Values: a newly created GtkTextBuffer with text '"abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" ', a GtkTextIter to initialize, a GtkTextIter to initialize
 * Expected: gboolean
 * 
 * Name: gtk_text_buffer_get_selection_bounds
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end
 * Returns: gboolean
 * Assertion: start and end will be in ascending order
 * Params Values: a newly created GtkTextBuffer with text '"abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" ', a GtkTextIter to initialize, a GtkTextIter to initialize
 * Expected: gboolean  
 */
static void test_purpose_95()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    #define LINE 0
    #define OFFS 1
    #define LINE1 0
    #define OFFS1 1
    #define RESULT FALSE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    gboolean length;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    
    gtk_text_buffer_move_mark_by_name (buffer, "insert", &start);
    gtk_text_buffer_move_mark_by_name (buffer, "selection_bound", &end);
    
    length = gtk_text_buffer_get_selection_bounds (buffer, &start, &end);
    if (length != RESULT)
    {
        TEST_FAIL ("length = %d, should be %d", length, RESULT);
    }  
    
    if (gtk_text_iter_get_offset (&start) > gtk_text_iter_get_offset (&end))
    {
        TEST_FAIL ("'star't and 'end' will be in ascending order", NULL);
    }
    
    length = gtk_text_buffer_get_selection_bounds (buffer, NULL, NULL);
    if (length != RESULT)
    {
        TEST_FAIL ("length = %d, should be %d", length, RESULT);
    }  
    
    #undef TEXT
    #undef LINE 
    #undef OFFS 
    #undef LINE1 
    #undef OFFS1 
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_selection_bounds
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end
 * Returns: gboolean
 * Assertion: Returns TRUE if some text is selected; places the bounds of the selection in start and end (if the selection has length 0, then start and end are filled in with the same value). 
 * Params Values: a newly created GtkTextBuffer with text '"abcdefghijklmnopqrstuvwxyz\nABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" ', a GtkTextIter to initialize, a GtkTextIter to initialize
 * Expected: gboolean
 * 
 * Name: gtk_text_buffer_get_selection_bounds
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end
 * Returns: gboolean
 * Assertion: If start and end are NULL, then they are not filled in, but the return value still indicates whether text is selected
 * Params Values: a newly created GtkTextBuffer with text '"abcdefghijklmnopqrstuvwxyz\nABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" ', a GtkTextIter to initialize, a GtkTextIter to initialize
 * Expected: gboolean
 * 
 * Name: gtk_text_buffer_get_selection_bounds
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end
 * Returns: gboolean
 * Assertion: start and end will be in ascending order
 * Params Values: a newly created GtkTextBuffer with text '"abcdefghijklmnopqrstuvwxyz\nABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" ', a GtkTextIter to initialize, a GtkTextIter to initialize
 * Expected: gboolean  
 */
static void test_purpose_96()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyz\nABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    #define LINE 0
    #define OFFS 1
    #define LINE1 1
    #define OFFS1 5
    #define RESULT TRUE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    gboolean length;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    
    gtk_text_buffer_move_mark_by_name (buffer, "insert", &start);
    gtk_text_buffer_move_mark_by_name (buffer, "selection_bound", &end);
    
    length = gtk_text_buffer_get_selection_bounds (buffer, &start, &end);
    if (length != RESULT)
    {
        TEST_FAIL ("length = %d, should be %d", length, RESULT);
    }  
    
    if (gtk_text_iter_get_offset (&start) > gtk_text_iter_get_offset (&end))
    {
        TEST_FAIL ("'star't and 'end' will be in ascending order", NULL);
    }
    
    length = gtk_text_buffer_get_selection_bounds (buffer, NULL, NULL);
    if (length != RESULT)
    {
        TEST_FAIL ("length = %d, should be %d", length, RESULT);
    }  
    
    #undef TEXT
    #undef LINE 
    #undef OFFS 
    #undef LINE1 
    #undef OFFS1 
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_selection_bounds
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end
 * Returns: gboolean
 * Assertion: Returns TRUE if some text is selected; places the bounds of the selection in start and end (if the selection has length 0, then start and end are filled in with the same value). 
 * Params Values: a newly created GtkTextBuffer with text '"\b\n\t\n" ', a GtkTextIter to initialize, a GtkTextIter to initialize
 * Expected: gboolean
 * 
 * Name: gtk_text_buffer_get_selection_bounds
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end
 * Returns: gboolean
 * Assertion: If start and end are NULL, then they are not filled in, but the return value still indicates whether text is selected
 * Params Values: a newly created GtkTextBuffer with text '"\b\n\t\n" ', a GtkTextIter to initialize, a GtkTextIter to initialize
 * Expected: gboolean
 * 
 * Name: gtk_text_buffer_get_selection_bounds
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end
 * Returns: gboolean
 * Assertion: start and end will be in ascending order
 * Params Values: a newly created GtkTextBuffer with text '"\b\n\t\n" ', a GtkTextIter to initialize, a GtkTextIter to initialize
 * Expected: gboolean  
 */
static void test_purpose_97()
{
    #define TEXT "\b\n\t\n" 
    #define LINE 0
    #define OFFS 0
    #define LINE1 0
    #define OFFS1 1
    #define RESULT TRUE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    gboolean length;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    
    gtk_text_buffer_move_mark_by_name (buffer, "insert", &start);
    gtk_text_buffer_move_mark_by_name (buffer, "selection_bound", &end);
    
    length = gtk_text_buffer_get_selection_bounds (buffer, &start, &end);
    if (length != RESULT)
    {
        TEST_FAIL ("length = %d, should be %d", length, RESULT);
    }  
    
    if (gtk_text_iter_get_offset (&start) > gtk_text_iter_get_offset (&end))
    {
        TEST_FAIL ("'star't and 'end' will be in ascending order", NULL);
    }
    
    length = gtk_text_buffer_get_selection_bounds (buffer, NULL, NULL);
    if (length != RESULT)
    {
        TEST_FAIL ("length = %d, should be %d", length, RESULT);
    }  
    
    #undef TEXT
    #undef LINE 
    #undef OFFS 
    #undef LINE1 
    #undef OFFS1 
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len
 * Returns:  void
 * Assertion: Inserts len bytes of text at position iter.
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len
 * Expected: void  
 */
static void test_purpose_98()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define INSERT "insert"
    #define LENGTH -1
    #define LINE 0
    #define OFFS 5
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    gtk_text_buffer_insert (buffer, &start, INSERT, LENGTH);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE, OFFS + strlen (INSERT));
    
    if (strcmp (INSERT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
    {
        TEST_FAIL ("Text isn't correct", NULL);
    }
    
    #undef TEXT
    #undef INSERT
    #undef LENGTH 
    #undef LINE 
    #undef OFFS 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len
 * Returns:  void
 * Assertion: Inserts len bytes of text at position iter.
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len
 * Expected: void  
 */
static void test_purpose_99()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define INSERT "insert"
    #define LENGTH -1
    #define LINE 0
    #define OFFS 3
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    gtk_text_buffer_insert (buffer, &start, INSERT, LENGTH);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE, OFFS + strlen (INSERT));
    
    if (strcmp (INSERT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
    {
        TEST_FAIL ("Text isn't correct", NULL);
    }
    
    #undef TEXT
    #undef INSERT
    #undef LENGTH 
    #undef LINE 
    #undef OFFS 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len
 * Returns:  void
 * Assertion: Inserts len bytes of text at position iter.
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len
 * Expected: void  
 */
static void test_purpose_100()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define INSERT "insert"
    #define LENGTH -1
    #define LINE 1
    #define OFFS 0
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    gtk_text_buffer_insert (buffer, &start, INSERT, LENGTH);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE, OFFS + strlen (INSERT));
    
    if (strcmp (INSERT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
    {
        TEST_FAIL ("Text isn't correct", NULL);
    }
    
    #undef TEXT
    #undef INSERT
    #undef LENGTH 
    #undef LINE 
    #undef OFFS 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len
 * Returns:  void
 * Assertion: Emits the "insert_text" signal; insertion actually occurs in the default handler for the signal.
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len
 * Expected: void  
 */
static void test_purpose_101()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define INSERT "insert"
    #define LENGTH -1
    #define LINE 0
    #define OFFS 5
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    g_signal_connect (G_OBJECT (buffer), "insert-text", GTK_SIGNAL_FUNC (global_insert_text), NULL);
    gtk_text_buffer_insert (buffer, &start, INSERT, LENGTH);
    
    if (modified_catched == 0)
    {
        TEST_FAIL ("buffer should emit 'insert-text' signal", NULL);
    }
    
    #undef TEXT
    #undef INSERT
    #undef LENGTH 
    #undef LINE 
    #undef OFFS 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len
 * Returns:  void
 * Assertion: Emits the "insert_text" signal; insertion actually occurs in the default handler for the signal.
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len
 * Expected: void  
 */
static void test_purpose_102()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define INSERT "insert text"
    #define LENGTH -1
    #define LINE 0
    #define OFFS 3
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    g_signal_connect (G_OBJECT (buffer), "insert-text", GTK_SIGNAL_FUNC (global_insert_text), NULL);
    gtk_text_buffer_insert (buffer, &start, INSERT, LENGTH);
    
    if (modified_catched == 0)
    {
        TEST_FAIL ("buffer should emit 'insert-text' signal", NULL);
    }
    
    #undef TEXT
    #undef INSERT
    #undef LENGTH 
    #undef LINE 
    #undef OFFS 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len
 * Returns:  void
 * Assertion: Emits the "insert_text" signal; insertion actually occurs in the default handler for the signal.
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len
 * Expected: void  
 */
static void test_purpose_103()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define INSERT "text"
    #define LENGTH -1
    #define LINE 1
    #define OFFS 0
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    g_signal_connect (G_OBJECT (buffer), "insert-text", GTK_SIGNAL_FUNC (global_insert_text), NULL);
    gtk_text_buffer_insert (buffer, &start, INSERT, LENGTH);
    
    if (modified_catched == 0)
    {
        TEST_FAIL ("buffer should emit 'insert-text' signal", NULL);
    }
    
    #undef TEXT
    #undef INSERT
    #undef LENGTH 
    #undef LINE 
    #undef OFFS 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len
 * Returns:  void
 * Assertion: iter is invalidated when insertion occurs (because the buffer contents change), but the default signal handler revalidates it to point to the end of the inserted text
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len
 * Expected: void  
 */
static void test_purpose_104()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define INSERT "insert"
    #define LENGTH -1
    #define LINE 0
    #define OFFS 5
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    gtk_text_buffer_insert (buffer, &start, INSERT, LENGTH);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE, OFFS + strlen (INSERT));
    
    if (gtk_text_iter_compare(&start, &end))
    {
        TEST_FAIL ("start and end iters not equal", NULL);
    }
    
    #undef TEXT
    #undef INSERT
    #undef LENGTH 
    #undef LINE 
    #undef OFFS 
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len
 * Returns:  void
 * Assertion: iter is invalidated when insertion occurs (because the buffer contents change), but the default signal handler revalidates it to point to the end of the inserted text
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len
 * Expected: void  
 */
static void test_purpose_105()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define INSERT "insert"
    #define LENGTH -1
    #define LINE 0
    #define OFFS 1
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    gtk_text_buffer_insert (buffer, &start, INSERT, LENGTH);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE, OFFS + strlen (INSERT));
    
    if (gtk_text_iter_compare(&start, &end))
    {
        TEST_FAIL ("start and end iters not equal", NULL);
    }
    
    #undef TEXT
    #undef INSERT
    #undef LENGTH 
    #undef LINE 
    #undef OFFS 
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len
 * Returns:  void
 * Assertion: iter is invalidated when insertion occurs (because the buffer contents change), but the default signal handler revalidates it to point to the end of the inserted text
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len
 * Expected: void  
 */
static void test_purpose_106()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define INSERT "insert"
    #define LENGTH -1
    #define LINE 1
    #define OFFS 3
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    gtk_text_buffer_insert (buffer, &start, INSERT, LENGTH);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE, OFFS + strlen (INSERT));
    
    if (gtk_text_iter_compare(&start, &end))
    {
        TEST_FAIL ("start and end iters not equal", NULL);
    }
    
    #undef TEXT
    #undef INSERT
    #undef LENGTH 
    #undef LINE 
    #undef OFFS 
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_at_cursor
 * Params: GtkTextBuffer *buffer, const gchar *text, gint len
 * Returns:  void
 * Assertion: Simply calls gtk_text_buffer_insert(), using the current cursor position as the insertion point.
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len
 * Expected: void  
 */
static void test_purpose_107()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define INSERT "insert"
    #define LENGTH -1
    #define LINE 0
    #define OFFS 5
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_place_cursor (buffer, &start);
    
    gtk_text_buffer_insert_at_cursor (buffer, INSERT, LENGTH);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE, OFFS + strlen (INSERT));
    
    if (strcmp (INSERT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
    {
        TEST_FAIL ("Text isn't correct", NULL);
    }
    
    #undef TEXT
    #undef INSERT
    #undef LENGTH 
    #undef LINE 
    #undef OFFS 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_at_cursor
 * Params: GtkTextBuffer *buffer, const gchar *text, gint len
 * Returns:  void
 * Assertion: Simply calls gtk_text_buffer_insert(), using the current cursor position as the insertion point.
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len
 * Expected: void  
 */
static void test_purpose_108()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define INSERT "insert"
    #define LENGTH -1
    #define LINE 0
    #define OFFS 3
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_place_cursor (buffer, &start);
    
    gtk_text_buffer_insert_at_cursor (buffer, INSERT, LENGTH);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE, OFFS + strlen (INSERT));
    
    if (strcmp (INSERT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
    {
        TEST_FAIL ("Text isn't correct", NULL);
    }
    
    #undef TEXT
    #undef INSERT
    #undef LENGTH 
    #undef LINE 
    #undef OFFS 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_at_cursor
 * Params: GtkTextBuffer *buffer, const gchar *text, gint len
 * Returns:  void
 * Assertion: Simply calls gtk_text_buffer_insert(), using the current cursor position as the insertion point.
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len
 * Expected: void  
 */
static void test_purpose_109()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define INSERT "insert"
    #define LENGTH -1
    #define LINE 1
    #define OFFS 0
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_place_cursor (buffer, &start);
    
    gtk_text_buffer_insert_at_cursor (buffer, INSERT, LENGTH);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE, OFFS + strlen (INSERT));
    
    if (strcmp (INSERT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
    {
        TEST_FAIL ("Text isn't correct", NULL);
    }
    
    #undef TEXT
    #undef INSERT
    #undef LENGTH 
    #undef LINE 
    #undef OFFS 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_interactive
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len, gboolean default_editable
 * Returns:  gboolean
 * Assertion: Like gtk_text_buffer_insert(), but the insertion will not occur if iter is at a non-editable location in the buffer.
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len, gboolean default_editable
 * Expected: gboolean  
 */
static void test_purpose_110()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define INSERT "insert"
    #define LENGTH -1
    #define LINE 0
    #define OFFS 5
    #define EDITABLE TRUE
    #define TAG TRUE
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    if (TAG)
    {
        tag = gtk_text_tag_new ("Tag");
        g_object_set (tag, "editable", (gboolean) EDITABLE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    result = gtk_text_buffer_insert_interactive (buffer, &start, INSERT, LENGTH, EDITABLE);
    
    if (EDITABLE) 
    {
        gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
        gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE, OFFS + strlen (INSERT));
        if (strcmp (INSERT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
        {
            TEST_FAIL ("Text isn't correct \n%s\n%s", INSERT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE));
        }
    
    } else {
    
        gtk_text_buffer_get_bounds (buffer, &start, &end);
        if (strcmp (TEXT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
        {
            TEST_FAIL ("Text isn't correct \n%s\n%s", TEXT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE));
        }
        if (result)
        {
            TEST_FAIL ("gtk_text_buffer_insert_interactive() returns TRUE although TextBuffer is not editable", NULL);
        }
    }
    
    #undef TEXT
    #undef INSERT
    #undef LENGTH 
    #undef LINE 
    #undef OFFS 
    #undef TAG
    #undef EDITABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_interactive
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len, gboolean default_editable
 * Returns:  gboolean
 * Assertion: Like gtk_text_buffer_insert(), but the insertion will not occur if iter is at a non-editable location in the buffer.
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len, gboolean default_editable
 * Expected: gboolean  
 */
static void test_purpose_111()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define INSERT "insert"
    #define LENGTH -1
    #define LINE 0
    #define OFFS 3
    #define EDITABLE TRUE
    #define TAG FALSE
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    if (TAG)
    {
        tag = gtk_text_tag_new ("Tag");
        g_object_set (tag, "editable", (gboolean) EDITABLE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    result = gtk_text_buffer_insert_interactive (buffer, &start, INSERT, LENGTH, EDITABLE);
    
    if (EDITABLE) 
    {
        gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
        gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE, OFFS + strlen (INSERT));
        if (strcmp (INSERT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
        {
            TEST_FAIL ("Text isn't correct \n%s\n%s", INSERT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE));
        }
    
    } else {
    
        gtk_text_buffer_get_bounds (buffer, &start, &end);
        if (strcmp (TEXT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
        {
            TEST_FAIL ("Text isn't correct \n%s\n%s", TEXT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE));
        }
        if (result)
        {
            TEST_FAIL ("gtk_text_buffer_insert_interactive() returns TRUE although TextBuffer is not editable", NULL);
        }
    }
    
    #undef TEXT
    #undef INSERT
    #undef LENGTH 
    #undef LINE 
    #undef OFFS 
    #undef TAG
    #undef EDITABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_interactive
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len, gboolean default_editable
 * Returns:  gboolean
 * Assertion: Like gtk_text_buffer_insert(), but the insertion will not occur if iter is at a non-editable location in the buffer.
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len, gboolean default_editable
 * Expected: gboolean  
 */
static void test_purpose_112()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define INSERT "insert"
    #define LENGTH -1
    #define LINE 1
    #define OFFS 0
    #define EDITABLE FALSE
    #define TAG TRUE
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    if (TAG)
    {
        tag = gtk_text_tag_new ("Tag");
        g_object_set (tag, "editable", (gboolean) EDITABLE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    result = gtk_text_buffer_insert_interactive (buffer, &start, INSERT, LENGTH, EDITABLE);
    
    if (EDITABLE) 
    {
        gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
        gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE, OFFS + strlen (INSERT));
        if (strcmp (INSERT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
        {
            TEST_FAIL ("Text isn't correct \n%s\n%s", INSERT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE));
        }
    
    } else {
    
        gtk_text_buffer_get_bounds (buffer, &start, &end);
        if (strcmp (TEXT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
        {
            TEST_FAIL ("Text isn't correct \n%s\n%s", TEXT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE));
        }
        if (result)
        {
            TEST_FAIL ("gtk_text_buffer_insert_interactive() returns TRUE although TextBuffer is not editable", NULL);
        }
    }
    
    #undef TEXT
    #undef INSERT
    #undef LENGTH 
    #undef LINE 
    #undef OFFS 
    #undef TAG
    #undef EDITABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_interactive
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len, gboolean default_editable
 * Returns:  gboolean
 * Assertion: Like gtk_text_buffer_insert(), but the insertion will not occur if iter is at a non-editable location in the buffer.
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len, gboolean default_editable
 * Expected: gboolean  
 */
static void test_purpose_113()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define INSERT "insert"
    #define LENGTH -1
    #define LINE 1
    #define OFFS 4
    #define EDITABLE FALSE
    #define TAG FALSE
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    if (TAG)
    {
        tag = gtk_text_tag_new ("Tag");
        g_object_set (tag, "editable", (gboolean) EDITABLE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    result = gtk_text_buffer_insert_interactive (buffer, &start, INSERT, LENGTH, EDITABLE);
    
    if (EDITABLE) 
    {
        gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
        gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE, OFFS + strlen (INSERT));
        if (strcmp (INSERT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
        {
            TEST_FAIL ("Text isn't correct \n%s\n%s", INSERT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE));
        }
    
    } else {
    
        gtk_text_buffer_get_bounds (buffer, &start, &end);
        if (strcmp (TEXT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
        {
            TEST_FAIL ("Text isn't correct \n%s\n%s", TEXT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE));
        }
        if (result)
        {
            TEST_FAIL ("gtk_text_buffer_insert_interactive() returns TRUE although TextBuffer is not editable", NULL);
        }
    }
    
    #undef TEXT
    #undef INSERT
    #undef LENGTH 
    #undef LINE 
    #undef OFFS 
    #undef TAG
    #undef EDITABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_interactive_at_cursor
 * Params: GtkTextBuffer *buffer,  const gchar *text, gint len, gboolean default_editable
 * Returns: gboolean
 * Assertion: Calls gtk_text_buffer_insert_interactive() at the cursor position
 * Params Values: GtkTextBuffer *buffer, const gchar *text, gint len, gboolean default_editable
 * Expected: gboolean  
 */
static void test_purpose_114()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    #define INSERT "insert"
    #define LENGTH -1
    #define LINE 0
    #define OFFS 5
    #define EDITABLE TRUE
    #define TAG TRUE
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    if (TAG)
    {
        tag = gtk_text_tag_new ("Tag");
        g_object_set (tag, "editable", (gboolean) EDITABLE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_place_cursor (buffer, &start);
    
    result = gtk_text_buffer_insert_interactive_at_cursor (buffer, INSERT, LENGTH, EDITABLE);
    
    if (EDITABLE) 
    {
        gtk_text_buffer_get_iter_at_line_index (buffer, &start, LINE, OFFS);
        gtk_text_buffer_get_iter_at_line_index (buffer, &end, LINE, OFFS + strlen (INSERT));
        if (strcmp (INSERT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
        {
            TEST_FAIL ("Text isn't correct \n%s\n%s", INSERT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE));
        }
    
    } else {
    
        gtk_text_buffer_get_bounds (buffer, &start, &end);
        if (strcmp (TEXT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
        {
            TEST_FAIL ("Text isn't correct \n%s\n%s", TEXT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE));
        }
        if (result)
        {
            TEST_FAIL ("gtk_text_buffer_insert_interactive_at_cursor() returns TRUE although TextBuffer is not editable", NULL);
        }
    }
    
    #undef TEXT
    #undef INSERT
    #undef LENGTH 
    #undef LINE 
    #undef OFFS 
    #undef TAG
    #undef EDITABLE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_interactive_at_cursor
 * Params: GtkTextBuffer *buffer,  const gchar *text, gint len, gboolean default_editable
 * Returns: gboolean
 * Assertion: Calls gtk_text_buffer_insert_interactive() at the cursor position
 * Params Values: GtkTextBuffer *buffer, const gchar *text, gint len, gboolean default_editable
 * Expected: gboolean  
 */
static void test_purpose_115()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    #define INSERT "insert"
    #define LENGTH -1
    #define LINE 0
    #define OFFS 3
    #define EDITABLE TRUE
    #define TAG FALSE
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    if (TAG)
    {
        tag = gtk_text_tag_new ("Tag");
        g_object_set (tag, "editable", (gboolean) EDITABLE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_place_cursor (buffer, &start);
    
    result = gtk_text_buffer_insert_interactive_at_cursor (buffer, INSERT, LENGTH, EDITABLE);
    
    if (EDITABLE) 
    {
        gtk_text_buffer_get_iter_at_line_index (buffer, &start, LINE, OFFS);
        gtk_text_buffer_get_iter_at_line_index (buffer, &end, LINE, OFFS + strlen (INSERT));
        if (strcmp (INSERT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
        {
            TEST_FAIL ("Text isn't correct \n%s\n%s", INSERT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE));
        }
    
    } else {
    
        gtk_text_buffer_get_bounds (buffer, &start, &end);
        if (strcmp (TEXT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
        {
            TEST_FAIL ("Text isn't correct \n%s\n%s", TEXT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE));
        }
        if (result)
        {
            TEST_FAIL ("gtk_text_buffer_insert_interactive_at_cursor() returns TRUE although TextBuffer is not editable", NULL);
        }
    }
    
    #undef TEXT
    #undef INSERT
    #undef LENGTH 
    #undef LINE 
    #undef OFFS 
    #undef TAG
    #undef EDITABLE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_interactive_at_cursor
 * Params: GtkTextBuffer *buffer,  const gchar *text, gint len, gboolean default_editable
 * Returns: gboolean
 * Assertion: Calls gtk_text_buffer_insert_interactive() at the cursor position
 * Params Values: GtkTextBuffer *buffer, const gchar *text, gint len, gboolean default_editable
 * Expected: gboolean  
 */
static void test_purpose_116()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\nabcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRS\n" 
    #define INSERT "insert"
    #define LENGTH -1
    #define LINE 1
    #define OFFS 0
    #define EDITABLE FALSE
    #define TAG TRUE
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    if (TAG)
    {
        tag = gtk_text_tag_new ("Tag");
        g_object_set (tag, "editable", (gboolean) EDITABLE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_place_cursor (buffer, &start);
    
    result = gtk_text_buffer_insert_interactive_at_cursor (buffer, INSERT, LENGTH, EDITABLE);
    
    if (EDITABLE) 
    {
        gtk_text_buffer_get_iter_at_line_index (buffer, &start, LINE, OFFS);
        gtk_text_buffer_get_iter_at_line_index (buffer, &end, LINE, OFFS + strlen (INSERT));
        if (strcmp (INSERT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
        {
            TEST_FAIL ("Text isn't correct \n%s\n%s", INSERT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE));
        }
    
    } else {
    
        gtk_text_buffer_get_bounds (buffer, &start, &end);
        if (strcmp (TEXT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
        {
            TEST_FAIL ("Text isn't correct \n%s\n%s", TEXT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE));
        }
        if (result)
        {
            TEST_FAIL ("gtk_text_buffer_insert_interactive_at_cursor() returns TRUE although TextBuffer is not editable", NULL);
        }
    }
    
    #undef TEXT
    #undef INSERT
    #undef LENGTH 
    #undef LINE 
    #undef OFFS 
    #undef TAG
    #undef EDITABLE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_interactive_at_cursor
 * Params: GtkTextBuffer *buffer,  const gchar *text, gint len, gboolean default_editable
 * Returns: gboolean
 * Assertion: Calls gtk_text_buffer_insert_interactive() at the cursor position
 * Params Values: GtkTextBuffer *buffer, const gchar *text, gint len, gboolean default_editable
 * Expected: gboolean  
 */
static void test_purpose_117()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\nabcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRS\n" 
    #define INSERT "insert"
    #define LENGTH -1
    #define LINE 1
    #define OFFS 4
    #define EDITABLE FALSE
    #define TAG FALSE
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    if (TAG)
    {
        tag = gtk_text_tag_new ("Tag");
        g_object_set (tag, "editable", (gboolean) EDITABLE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_place_cursor (buffer, &start);
    
    result = gtk_text_buffer_insert_interactive_at_cursor (buffer, INSERT, LENGTH, EDITABLE);
    
    if (EDITABLE) 
    {
        gtk_text_buffer_get_iter_at_line_index (buffer, &start, LINE, OFFS);
        gtk_text_buffer_get_iter_at_line_index (buffer, &end, LINE, OFFS + strlen (INSERT));
        if (strcmp (INSERT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
        {
            TEST_FAIL ("Text isn't correct \n%s\n%s", INSERT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE));
        }
    
    } else {
    
        gtk_text_buffer_get_bounds (buffer, &start, &end);
        if (strcmp (TEXT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
        {
            TEST_FAIL ("Text isn't correct \n%s\n%s", TEXT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE));
        }
        if (result)
        {
            TEST_FAIL ("gtk_text_buffer_insert_interactive_at_cursor() returns TRUE although TextBuffer is not editable", NULL);
        }
    }
    
    #undef TEXT
    #undef INSERT
    #undef LENGTH 
    #undef LINE 
    #undef OFFS 
    #undef TAG
    #undef EDITABLE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_interactive_at_cursor
 * Params: GtkTextBuffer *buffer,  const gchar *text, gint len, gboolean default_editable
 * Returns: gboolean
 * Assertion: Calls gtk_text_buffer_insert_interactive() at the cursor position
 * Params Values: GtkTextBuffer *buffer, const gchar *text, gint len, gboolean default_editable
 * Expected: gboolean  
 */
static void test_purpose_118()
{
    #define TEXT "!@#$%^&*()_+|~=\";:'?<>`/\n" 
    #define INSERT "insert"
    #define LENGTH -1
    #define LINE 0
    #define OFFS 3
    #define EDITABLE TRUE
    #define TAG FALSE
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    if (TAG)
    {
        tag = gtk_text_tag_new ("Tag");
        g_object_set (tag, "editable", (gboolean) EDITABLE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_place_cursor (buffer, &start);
    
    result = gtk_text_buffer_insert_interactive_at_cursor (buffer, INSERT, LENGTH, EDITABLE);
    
    if (EDITABLE) 
    {
        gtk_text_buffer_get_iter_at_line_index (buffer, &start, LINE, OFFS);
        gtk_text_buffer_get_iter_at_line_index (buffer, &end, LINE, OFFS + strlen (INSERT));
        if (strcmp (INSERT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
        {
            TEST_FAIL ("Text isn't correct \n%s\n%s", INSERT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE));
        }
    
    } else {
    
        gtk_text_buffer_get_bounds (buffer, &start, &end);
        if (strcmp (TEXT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
        {
            TEST_FAIL ("Text isn't correct \n%s\n%s", TEXT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE));
        }
        if (result)
        {
            TEST_FAIL ("gtk_text_buffer_insert_interactive_at_cursor() returns TRUE although TextBuffer is not editable", NULL);
        }
    }
    
    #undef TEXT
    #undef INSERT
    #undef LENGTH 
    #undef LINE 
    #undef OFFS 
    #undef TAG
    #undef EDITABLE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_interactive_at_cursor
 * Params: GtkTextBuffer *buffer,  const gchar *text, gint len, gboolean default_editable
 * Returns: gboolean
 * Assertion: Calls gtk_text_buffer_insert_interactive() at the cursor position
 * Params Values: GtkTextBuffer *buffer, const gchar *text, gint len, gboolean default_editable
 * Expected: gboolean  
 */
static void test_purpose_119()
{
    #define TEXT "\b\n\t\n" 
    #define INSERT "insert"
    #define LENGTH -1
    #define LINE 0
    #define OFFS 0
    #define EDITABLE FALSE
    #define TAG TRUE
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    if (TAG)
    {
        tag = gtk_text_tag_new ("Tag");
        g_object_set (tag, "editable", (gboolean) EDITABLE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_place_cursor (buffer, &start);
    
    result = gtk_text_buffer_insert_interactive_at_cursor (buffer, INSERT, LENGTH, EDITABLE);
    
    if (EDITABLE) 
    {
        gtk_text_buffer_get_iter_at_line_index (buffer, &start, LINE, OFFS);
        gtk_text_buffer_get_iter_at_line_index (buffer, &end, LINE, OFFS + strlen (INSERT));
        if (strcmp (INSERT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
        {
            TEST_FAIL ("Text isn't correct \n%s\n%s", INSERT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE));
        }
    
    } else {
    
        gtk_text_buffer_get_bounds (buffer, &start, &end);
        if (strcmp (TEXT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
        {
            TEST_FAIL ("Text isn't correct \n%s\n%s", TEXT, gtk_text_buffer_get_text (buffer, &start, &end, TRUE));
        }
        if (result)
        {
            TEST_FAIL ("gtk_text_buffer_insert_interactive_at_cursor() returns TRUE although TextBuffer is not editable", NULL);
        }
    }
    
    #undef TEXT
    #undef INSERT
    #undef LENGTH 
    #undef LINE 
    #undef OFFS 
    #undef TAG
    #undef EDITABLE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_range
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const GtkTextIter *start, const GtkTextIter *end
 * Returns:  void
 * Assertion: Copies text, tags, and pixbufs between start and end (the order of start and end doesn't matter) and inserts the copy at iter.'
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *iter, const GtkTextIter *start, const GtkTextIter *end
 * Expected: void  
 */
static void test_purpose_120()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    
    #define COUNT 5
    
    GtkTextBuffer* buffer;
    GtkTextBuffer* buffer1;
    GdkPixbuf* pixbuf;
    GtkTextIter iter;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    GSList* list;
    gint i;
    gchar buff[20];
    gchararray name;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    for (i = 0; i < COUNT; i++) 
    {
        sprintf(buff, "Tag %i", i);
        tag = gtk_text_tag_new (buff);
        g_object_set (tag, "editable", TRUE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag(buffer, tag, &start, &end);
    }
    
    pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 10, 10);
    gtk_text_buffer_insert_pixbuf (buffer, &start, pixbuf);
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text = gtk_text_buffer_get_slice (buffer, &start, &end, TRUE);
    
    buffer1 =  gtk_text_buffer_new (gtk_text_buffer_get_tag_table (buffer));
    if (!buffer1)
    {
        TEST_FAIL ("cannot create second text buffer", NULL); 
        return;
    } 
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    gtk_text_buffer_get_iter_at_line_offset (buffer1, &iter, 0, 0);
    
    gtk_text_buffer_insert_range (buffer1, &iter, &start, &end);
    
    gtk_text_buffer_get_bounds (buffer1, &start, &end);
    if (strcmp (text, gtk_text_buffer_get_slice (buffer1, &start, &end, TRUE)))
    {
        TEST_FAIL ("text not equal \n(%s) \n(%s)", text, gtk_text_buffer_get_slice (buffer1, &start, &end, TRUE)); 
    } 
    
    if (gtk_text_iter_get_char(&start) != 0xFFFC)
    {
        TEST_FAIL ("pixbuf not included", NULL); 
    }
    
    gtk_text_iter_forward_cursor_position (&start);
    list = gtk_text_iter_get_tags(&start);
    if (!list)
    {
        TEST_FAIL ("tag1 list is NULL", NULL);
        return;
    }
    
    for (i = 0; i < g_slist_length(list); i++) 
    {
        tag = (GtkTextTag*) g_slist_nth_data(list, i); 
        g_object_get(tag, "name", &name, NULL);
        sprintf(buff, "Tag %i", i);
        if (strcmp(buff, name))
        {
            TEST_FAIL ("Tag(%i) %s  %s is wrong", i, buff, name);
        }    
    }
    
    g_slist_free(list);
    
    #undef TEXT
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_range
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const GtkTextIter *start, const GtkTextIter *end
 * Returns:  void
 * Assertion: Copies text, tags, and pixbufs between start and end (the order of start and end doesn't matter) and inserts the copy at iter.'
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *iter, const GtkTextIter *start, const GtkTextIter *end
 * Expected: void  
 */
static void test_purpose_121()
{
    #define TEXT "!@#$%^&*()_+|~=\";:'?<>`/" 
    
    #define COUNT 5
    
    GtkTextBuffer* buffer;
    GtkTextBuffer* buffer1;
    GdkPixbuf* pixbuf;
    GtkTextIter iter;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    GSList* list;
    gint i;
    gchar buff[20];
    gchararray name;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    for (i = 0; i < COUNT; i++) 
    {
        sprintf(buff, "Tag %i", i);
        tag = gtk_text_tag_new (buff);
        g_object_set (tag, "editable", TRUE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag(buffer, tag, &start, &end);
    }
    
    pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 10, 10);
    gtk_text_buffer_insert_pixbuf (buffer, &start, pixbuf);
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text = gtk_text_buffer_get_slice (buffer, &start, &end, TRUE);
    
    buffer1 =  gtk_text_buffer_new (gtk_text_buffer_get_tag_table (buffer));
    if (!buffer1)
    {
        TEST_FAIL ("cannot create second text buffer", NULL); 
        return;
    } 
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    gtk_text_buffer_get_iter_at_line_offset (buffer1, &iter, 0, 0);
    
    gtk_text_buffer_insert_range (buffer1, &iter, &start, &end);
    
    gtk_text_buffer_get_bounds (buffer1, &start, &end);
    if (strcmp (text, gtk_text_buffer_get_slice (buffer1, &start, &end, TRUE)))
    {
        TEST_FAIL ("text not equal \n(%s) \n(%s)", text, gtk_text_buffer_get_slice (buffer1, &start, &end, TRUE)); 
    } 
    
    if (gtk_text_iter_get_char(&start) != 0xFFFC)
    {
        TEST_FAIL ("pixbuf not included", NULL); 
    }
    
    gtk_text_iter_forward_cursor_position (&start);
    list = gtk_text_iter_get_tags(&start);
    if (!list)
    {
        TEST_FAIL ("tag1 list is NULL", NULL);
        return;
    }
    
    for (i = 0; i < g_slist_length(list); i++) 
    {
        tag = (GtkTextTag*) g_slist_nth_data(list, i); 
        g_object_get(tag, "name", &name, NULL);
        sprintf(buff, "Tag %i", i);
        if (strcmp(buff, name))
        {
            TEST_FAIL ("Tag(%i) %s  %s is wrong", i, buff, name);
        }    
    }
    
    g_slist_free(list);
    
    #undef TEXT
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_range
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const GtkTextIter *start, const GtkTextIter *end
 * Returns:  void
 * Assertion: Copies text, tags, and pixbufs between start and end (the order of start and end doesn't matter) and inserts the copy at iter.'
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *iter, const GtkTextIter *start, const GtkTextIter *end
 * Expected: void  
 */
static void test_purpose_122()
{
    #define TEXT "\b\n\t\n" 
    
    #define COUNT 5
    
    GtkTextBuffer* buffer;
    GtkTextBuffer* buffer1;
    GdkPixbuf* pixbuf;
    GtkTextIter iter;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    GSList* list;
    gint i;
    gchar buff[20];
    gchararray name;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    for (i = 0; i < COUNT; i++) 
    {
        sprintf(buff, "Tag %i", i);
        tag = gtk_text_tag_new (buff);
        g_object_set (tag, "editable", TRUE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag(buffer, tag, &start, &end);
    }
    
    pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 10, 10);
    gtk_text_buffer_insert_pixbuf (buffer, &start, pixbuf);
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text = gtk_text_buffer_get_slice (buffer, &start, &end, TRUE);
    
    buffer1 =  gtk_text_buffer_new (gtk_text_buffer_get_tag_table (buffer));
    if (!buffer1)
    {
        TEST_FAIL ("cannot create second text buffer", NULL); 
        return;
    } 
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    gtk_text_buffer_get_iter_at_line_offset (buffer1, &iter, 0, 0);
    
    gtk_text_buffer_insert_range (buffer1, &iter, &start, &end);
    
    gtk_text_buffer_get_bounds (buffer1, &start, &end);
    if (strcmp (text, gtk_text_buffer_get_slice (buffer1, &start, &end, TRUE)))
    {
        TEST_FAIL ("text not equal \n(%s) \n(%s)", text, gtk_text_buffer_get_slice (buffer1, &start, &end, TRUE)); 
    } 
    
    if (gtk_text_iter_get_char(&start) != 0xFFFC)
    {
        TEST_FAIL ("pixbuf not included", NULL); 
    }
    
    gtk_text_iter_forward_cursor_position (&start);
    list = gtk_text_iter_get_tags(&start);
    if (!list)
    {
        TEST_FAIL ("tag1 list is NULL", NULL);
        return;
    }
    
    for (i = 0; i < g_slist_length(list); i++) 
    {
        tag = (GtkTextTag*) g_slist_nth_data(list, i); 
        g_object_get(tag, "name", &name, NULL);
        sprintf(buff, "Tag %i", i);
        if (strcmp(buff, name))
        {
            TEST_FAIL ("Tag(%i) %s  %s is wrong", i, buff, name);
        }    
    }
    
    g_slist_free(list);
    
    #undef TEXT
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_range_interactive
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const GtkTextIter *start, const GtkTextIter *end, gboolean default_editable
 * Returns:  gboolean
 * Assertion: Same as gtk_text_buffer_insert_range(), but does nothing if the insertion point isn't editable.'
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *iter, const GtkTextIter *start, const GtkTextIter *end, gboolean default_editable
 * Expected: gboolean  
 */
static void test_purpose_123()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    #define EDITABLE TRUE
    #define TAG TRUE
    
    #define COUNT 5
    
    GtkTextBuffer* buffer;
    GtkTextBuffer* buffer1;
    GdkPixbuf* pixbuf;
    GtkTextIter iter;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    GSList* list;
    gint i;
    gchar buff[20];
    gchararray name;
    gchar* text;
    gchar* text1;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    for (i = 0; i < COUNT; i++) 
    {
        sprintf(buff, "Tag %i", i);
        tag = gtk_text_tag_new (buff);
        g_object_set (tag, "editable", TRUE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag(buffer, tag, &start, &end);
    }
    
    pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 10, 10);
    gtk_text_buffer_insert_pixbuf (buffer, &start, pixbuf);
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text = gtk_text_buffer_get_slice (buffer, &start, &end, TRUE);
    
    buffer1 =  gtk_text_buffer_new (gtk_text_buffer_get_tag_table (buffer));
    if (!buffer1)
    {
        TEST_FAIL ("cannot create second text buffer", NULL); 
        return;
    } 
    
    gtk_text_buffer_get_bounds (buffer1, &start, &end);
    text1 = gtk_text_buffer_get_text (buffer1, &start, &end, TRUE);
    
    if (TAG)
    {
        tag = gtk_text_tag_new ("Tag");
        g_object_set (tag, "editable", (gboolean) EDITABLE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer1), tag);
        gtk_text_buffer_apply_tag (buffer1, tag, &start, &end);
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer1, &iter, 0, 0);
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    result = gtk_text_buffer_insert_range_interactive (buffer1, &iter, &start, &end, EDITABLE);
    
    gtk_text_buffer_get_bounds (buffer1, &start, &end);
    if (TAG)
    {
        gtk_text_buffer_remove_tag_by_name (buffer1, "Tag", &start, &end);  
    }
    
    if (!EDITABLE) 
    {
        gtk_text_buffer_get_bounds (buffer1, &start, &end);
        if (strcmp (text1, gtk_text_buffer_get_text (buffer1, &start, &end, TRUE)))
        {
            TEST_FAIL ("Default text isn't correct \n%s\n%s", text1, gtk_text_buffer_get_slice (buffer1, &start, &end, TRUE));
        }
        if (result)
        {
            TEST_FAIL ("gtk_text_buffer_insert_interactive () returns TRUE although TextBuffer is not editable", NULL);
        }
    
    } else {
    
        gtk_text_buffer_get_bounds (buffer1, &start, &end);
    
        if (strcmp (text, gtk_text_buffer_get_slice (buffer1, &start, &end, TRUE)))
        {
            TEST_FAIL ("text not equal \n(%s) \n(%s)", text, gtk_text_buffer_get_slice (buffer1, &start, &end, TRUE)); 
        } 
    
        if (gtk_text_iter_get_char(&start) != 0xFFFC)
        {
            TEST_FAIL ("pixbuf not included", NULL); 
        }
    
        gtk_text_iter_forward_cursor_position (&start);
        list = gtk_text_iter_get_tags(&start);
        if (!list)
        {
            TEST_FAIL ("tag list is NULL", NULL);
            return;
        }
    
        for (i = 0; i < g_slist_length(list); i++) 
        {
            tag = (GtkTextTag*) g_slist_nth_data(list, i); 
            g_object_get(tag, "name", &name, NULL);
            sprintf(buff, "Tag %i", i);
            if (strcmp(buff, name))
            {
                TEST_FAIL ("Tag(%i) %s  %s is wrong", i, buff, name);
            }    
        }
        g_slist_free (list);
    }
    
    
    #undef TEXT
    #undef TAG
    #undef EDITABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_range_interactive
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const GtkTextIter *start, const GtkTextIter *end, gboolean default_editable
 * Returns:  gboolean
 * Assertion: Same as gtk_text_buffer_insert_range(), but does nothing if the insertion point isn't editable.'
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *iter, const GtkTextIter *start, const GtkTextIter *end, gboolean default_editable
 * Expected: gboolean  
 */
static void test_purpose_124()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    #define EDITABLE TRUE
    #define TAG FALSE
    
    #define COUNT 5
    
    GtkTextBuffer* buffer;
    GtkTextBuffer* buffer1;
    GdkPixbuf* pixbuf;
    GtkTextIter iter;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    GSList* list;
    gint i;
    gchar buff[20];
    gchararray name;
    gchar* text;
    gchar* text1;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    for (i = 0; i < COUNT; i++) 
    {
        sprintf(buff, "Tag %i", i);
        tag = gtk_text_tag_new (buff);
        g_object_set (tag, "editable", TRUE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag(buffer, tag, &start, &end);
    }
    
    pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 10, 10);
    gtk_text_buffer_insert_pixbuf (buffer, &start, pixbuf);
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text = gtk_text_buffer_get_slice (buffer, &start, &end, TRUE);
    
    buffer1 =  gtk_text_buffer_new (gtk_text_buffer_get_tag_table (buffer));
    if (!buffer1)
    {
        TEST_FAIL ("cannot create second text buffer", NULL); 
        return;
    } 
    
    gtk_text_buffer_get_bounds (buffer1, &start, &end);
    text1 = gtk_text_buffer_get_text (buffer1, &start, &end, TRUE);
    
    if (TAG)
    {
        tag = gtk_text_tag_new ("Tag");
        g_object_set (tag, "editable", (gboolean) EDITABLE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer1), tag);
        gtk_text_buffer_apply_tag (buffer1, tag, &start, &end);
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer1, &iter, 0, 0);
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    result = gtk_text_buffer_insert_range_interactive (buffer1, &iter, &start, &end, EDITABLE);
    
    gtk_text_buffer_get_bounds (buffer1, &start, &end);
    if (TAG)
    {
        gtk_text_buffer_remove_tag_by_name (buffer1, "Tag", &start, &end);  
    }
    
    if (!EDITABLE) 
    {
        gtk_text_buffer_get_bounds (buffer1, &start, &end);
        if (strcmp (text1, gtk_text_buffer_get_text (buffer1, &start, &end, TRUE)))
        {
            TEST_FAIL ("Default text isn't correct \n%s\n%s", text1, gtk_text_buffer_get_slice (buffer1, &start, &end, TRUE));
        }
        if (result)
        {
            TEST_FAIL ("gtk_text_buffer_insert_interactive () returns TRUE although TextBuffer is not editable", NULL);
        }
    
    } else {
    
        gtk_text_buffer_get_bounds (buffer1, &start, &end);
    
        if (strcmp (text, gtk_text_buffer_get_slice (buffer1, &start, &end, TRUE)))
        {
            TEST_FAIL ("text not equal \n(%s) \n(%s)", text, gtk_text_buffer_get_slice (buffer1, &start, &end, TRUE)); 
        } 
    
        if (gtk_text_iter_get_char(&start) != 0xFFFC)
        {
            TEST_FAIL ("pixbuf not included", NULL); 
        }
    
        gtk_text_iter_forward_cursor_position (&start);
        list = gtk_text_iter_get_tags(&start);
        if (!list)
        {
            TEST_FAIL ("tag list is NULL", NULL);
            return;
        }
    
        for (i = 0; i < g_slist_length(list); i++) 
        {
            tag = (GtkTextTag*) g_slist_nth_data(list, i); 
            g_object_get(tag, "name", &name, NULL);
            sprintf(buff, "Tag %i", i);
            if (strcmp(buff, name))
            {
                TEST_FAIL ("Tag(%i) %s  %s is wrong", i, buff, name);
            }    
        }
        g_slist_free (list);
    }
    
    
    #undef TEXT
    #undef TAG
    #undef EDITABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_range_interactive
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const GtkTextIter *start, const GtkTextIter *end, gboolean default_editable
 * Returns:  gboolean
 * Assertion: Same as gtk_text_buffer_insert_range(), but does nothing if the insertion point isn't editable.'
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *iter, const GtkTextIter *start, const GtkTextIter *end, gboolean default_editable
 * Expected: gboolean  
 */
static void test_purpose_125()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    #define EDITABLE FALSE
    #define TAG TRUE
    
    #define COUNT 5
    
    GtkTextBuffer* buffer;
    GtkTextBuffer* buffer1;
    GdkPixbuf* pixbuf;
    GtkTextIter iter;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    GSList* list;
    gint i;
    gchar buff[20];
    gchararray name;
    gchar* text;
    gchar* text1;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    for (i = 0; i < COUNT; i++) 
    {
        sprintf(buff, "Tag %i", i);
        tag = gtk_text_tag_new (buff);
        g_object_set (tag, "editable", TRUE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag(buffer, tag, &start, &end);
    }
    
    pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 10, 10);
    gtk_text_buffer_insert_pixbuf (buffer, &start, pixbuf);
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text = gtk_text_buffer_get_slice (buffer, &start, &end, TRUE);
    
    buffer1 =  gtk_text_buffer_new (gtk_text_buffer_get_tag_table (buffer));
    if (!buffer1)
    {
        TEST_FAIL ("cannot create second text buffer", NULL); 
        return;
    } 
    
    gtk_text_buffer_get_bounds (buffer1, &start, &end);
    text1 = gtk_text_buffer_get_text (buffer1, &start, &end, TRUE);
    
    if (TAG)
    {
        tag = gtk_text_tag_new ("Tag");
        g_object_set (tag, "editable", (gboolean) EDITABLE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer1), tag);
        gtk_text_buffer_apply_tag (buffer1, tag, &start, &end);
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer1, &iter, 0, 0);
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    result = gtk_text_buffer_insert_range_interactive (buffer1, &iter, &start, &end, EDITABLE);
    
    gtk_text_buffer_get_bounds (buffer1, &start, &end);
    if (TAG)
    {
        gtk_text_buffer_remove_tag_by_name (buffer1, "Tag", &start, &end);  
    }
    
    if (!EDITABLE) 
    {
        gtk_text_buffer_get_bounds (buffer1, &start, &end);
        if (strcmp (text1, gtk_text_buffer_get_text (buffer1, &start, &end, TRUE)))
        {
            TEST_FAIL ("Default text isn't correct \n%s\n%s", text1, gtk_text_buffer_get_slice (buffer1, &start, &end, TRUE));
        }
        if (result)
        {
            TEST_FAIL ("gtk_text_buffer_insert_interactive () returns TRUE although TextBuffer is not editable", NULL);
        }
    
    } else {
    
        gtk_text_buffer_get_bounds (buffer1, &start, &end);
    
        if (strcmp (text, gtk_text_buffer_get_slice (buffer1, &start, &end, TRUE)))
        {
            TEST_FAIL ("text not equal \n(%s) \n(%s)", text, gtk_text_buffer_get_slice (buffer1, &start, &end, TRUE)); 
        } 
    
        if (gtk_text_iter_get_char(&start) != 0xFFFC)
        {
            TEST_FAIL ("pixbuf not included", NULL); 
        }
    
        gtk_text_iter_forward_cursor_position (&start);
        list = gtk_text_iter_get_tags(&start);
        if (!list)
        {
            TEST_FAIL ("tag list is NULL", NULL);
            return;
        }
    
        for (i = 0; i < g_slist_length(list); i++) 
        {
            tag = (GtkTextTag*) g_slist_nth_data(list, i); 
            g_object_get(tag, "name", &name, NULL);
            sprintf(buff, "Tag %i", i);
            if (strcmp(buff, name))
            {
                TEST_FAIL ("Tag(%i) %s  %s is wrong", i, buff, name);
            }    
        }
        g_slist_free (list);
    }
    
    
    #undef TEXT
    #undef TAG
    #undef EDITABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_range_interactive
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const GtkTextIter *start, const GtkTextIter *end, gboolean default_editable
 * Returns:  gboolean
 * Assertion: Same as gtk_text_buffer_insert_range(), but does nothing if the insertion point isn't editable.'
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *iter, const GtkTextIter *start, const GtkTextIter *end, gboolean default_editable
 * Expected: gboolean  
 */
static void test_purpose_126()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    #define EDITABLE FALSE
    #define TAG FALSE
    
    #define COUNT 5
    
    GtkTextBuffer* buffer;
    GtkTextBuffer* buffer1;
    GdkPixbuf* pixbuf;
    GtkTextIter iter;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    GSList* list;
    gint i;
    gchar buff[20];
    gchararray name;
    gchar* text;
    gchar* text1;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    for (i = 0; i < COUNT; i++) 
    {
        sprintf(buff, "Tag %i", i);
        tag = gtk_text_tag_new (buff);
        g_object_set (tag, "editable", TRUE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag(buffer, tag, &start, &end);
    }
    
    pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 10, 10);
    gtk_text_buffer_insert_pixbuf (buffer, &start, pixbuf);
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text = gtk_text_buffer_get_slice (buffer, &start, &end, TRUE);
    
    buffer1 =  gtk_text_buffer_new (gtk_text_buffer_get_tag_table (buffer));
    if (!buffer1)
    {
        TEST_FAIL ("cannot create second text buffer", NULL); 
        return;
    } 
    
    gtk_text_buffer_get_bounds (buffer1, &start, &end);
    text1 = gtk_text_buffer_get_text (buffer1, &start, &end, TRUE);
    
    if (TAG)
    {
        tag = gtk_text_tag_new ("Tag");
        g_object_set (tag, "editable", (gboolean) EDITABLE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer1), tag);
        gtk_text_buffer_apply_tag (buffer1, tag, &start, &end);
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer1, &iter, 0, 0);
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    result = gtk_text_buffer_insert_range_interactive (buffer1, &iter, &start, &end, EDITABLE);
    
    gtk_text_buffer_get_bounds (buffer1, &start, &end);
    if (TAG)
    {
        gtk_text_buffer_remove_tag_by_name (buffer1, "Tag", &start, &end);  
    }
    
    if (!EDITABLE) 
    {
        gtk_text_buffer_get_bounds (buffer1, &start, &end);
        if (strcmp (text1, gtk_text_buffer_get_text (buffer1, &start, &end, TRUE)))
        {
            TEST_FAIL ("Default text isn't correct \n%s\n%s", text1, gtk_text_buffer_get_slice (buffer1, &start, &end, TRUE));
        }
        if (result)
        {
            TEST_FAIL ("gtk_text_buffer_insert_interactive () returns TRUE although TextBuffer is not editable", NULL);
        }
    
    } else {
    
        gtk_text_buffer_get_bounds (buffer1, &start, &end);
    
        if (strcmp (text, gtk_text_buffer_get_slice (buffer1, &start, &end, TRUE)))
        {
            TEST_FAIL ("text not equal \n(%s) \n(%s)", text, gtk_text_buffer_get_slice (buffer1, &start, &end, TRUE)); 
        } 
    
        if (gtk_text_iter_get_char(&start) != 0xFFFC)
        {
            TEST_FAIL ("pixbuf not included", NULL); 
        }
    
        gtk_text_iter_forward_cursor_position (&start);
        list = gtk_text_iter_get_tags(&start);
        if (!list)
        {
            TEST_FAIL ("tag list is NULL", NULL);
            return;
        }
    
        for (i = 0; i < g_slist_length(list); i++) 
        {
            tag = (GtkTextTag*) g_slist_nth_data(list, i); 
            g_object_get(tag, "name", &name, NULL);
            sprintf(buff, "Tag %i", i);
            if (strcmp(buff, name))
            {
                TEST_FAIL ("Tag(%i) %s  %s is wrong", i, buff, name);
            }    
        }
        g_slist_free (list);
    }
    
    
    #undef TEXT
    #undef TAG
    #undef EDITABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_range_interactive
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const GtkTextIter *start, const GtkTextIter *end, gboolean default_editable
 * Returns:  gboolean
 * Assertion: Same as gtk_text_buffer_insert_range(), but does nothing if the insertion point isn't editable.'
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *iter, const GtkTextIter *start, const GtkTextIter *end, gboolean default_editable
 * Expected: gboolean  
 */
static void test_purpose_127()
{
    #define TEXT "!@#$%^&*()_+|~=\";:'?<>`/" 
    #define EDITABLE TRUE
    #define TAG FALSE
    
    #define COUNT 5
    
    GtkTextBuffer* buffer;
    GtkTextBuffer* buffer1;
    GdkPixbuf* pixbuf;
    GtkTextIter iter;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    GSList* list;
    gint i;
    gchar buff[20];
    gchararray name;
    gchar* text;
    gchar* text1;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    for (i = 0; i < COUNT; i++) 
    {
        sprintf(buff, "Tag %i", i);
        tag = gtk_text_tag_new (buff);
        g_object_set (tag, "editable", TRUE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag(buffer, tag, &start, &end);
    }
    
    pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 10, 10);
    gtk_text_buffer_insert_pixbuf (buffer, &start, pixbuf);
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text = gtk_text_buffer_get_slice (buffer, &start, &end, TRUE);
    
    buffer1 =  gtk_text_buffer_new (gtk_text_buffer_get_tag_table (buffer));
    if (!buffer1)
    {
        TEST_FAIL ("cannot create second text buffer", NULL); 
        return;
    } 
    
    gtk_text_buffer_get_bounds (buffer1, &start, &end);
    text1 = gtk_text_buffer_get_text (buffer1, &start, &end, TRUE);
    
    if (TAG)
    {
        tag = gtk_text_tag_new ("Tag");
        g_object_set (tag, "editable", (gboolean) EDITABLE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer1), tag);
        gtk_text_buffer_apply_tag (buffer1, tag, &start, &end);
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer1, &iter, 0, 0);
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    result = gtk_text_buffer_insert_range_interactive (buffer1, &iter, &start, &end, EDITABLE);
    
    gtk_text_buffer_get_bounds (buffer1, &start, &end);
    if (TAG)
    {
        gtk_text_buffer_remove_tag_by_name (buffer1, "Tag", &start, &end);  
    }
    
    if (!EDITABLE) 
    {
        gtk_text_buffer_get_bounds (buffer1, &start, &end);
        if (strcmp (text1, gtk_text_buffer_get_text (buffer1, &start, &end, TRUE)))
        {
            TEST_FAIL ("Default text isn't correct \n%s\n%s", text1, gtk_text_buffer_get_slice (buffer1, &start, &end, TRUE));
        }
        if (result)
        {
            TEST_FAIL ("gtk_text_buffer_insert_interactive () returns TRUE although TextBuffer is not editable", NULL);
        }
    
    } else {
    
        gtk_text_buffer_get_bounds (buffer1, &start, &end);
    
        if (strcmp (text, gtk_text_buffer_get_slice (buffer1, &start, &end, TRUE)))
        {
            TEST_FAIL ("text not equal \n(%s) \n(%s)", text, gtk_text_buffer_get_slice (buffer1, &start, &end, TRUE)); 
        } 
    
        if (gtk_text_iter_get_char(&start) != 0xFFFC)
        {
            TEST_FAIL ("pixbuf not included", NULL); 
        }
    
        gtk_text_iter_forward_cursor_position (&start);
        list = gtk_text_iter_get_tags(&start);
        if (!list)
        {
            TEST_FAIL ("tag list is NULL", NULL);
            return;
        }
    
        for (i = 0; i < g_slist_length(list); i++) 
        {
            tag = (GtkTextTag*) g_slist_nth_data(list, i); 
            g_object_get(tag, "name", &name, NULL);
            sprintf(buff, "Tag %i", i);
            if (strcmp(buff, name))
            {
                TEST_FAIL ("Tag(%i) %s  %s is wrong", i, buff, name);
            }    
        }
        g_slist_free (list);
    }
    
    
    #undef TEXT
    #undef TAG
    #undef EDITABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_range_interactive
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const GtkTextIter *start, const GtkTextIter *end, gboolean default_editable
 * Returns:  gboolean
 * Assertion: Same as gtk_text_buffer_insert_range(), but does nothing if the insertion point isn't editable.'
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *iter, const GtkTextIter *start, const GtkTextIter *end, gboolean default_editable
 * Expected: gboolean  
 */
static void test_purpose_128()
{
    #define TEXT "\t\n\b\n" 
    #define EDITABLE FALSE
    #define TAG TRUE
    
    #define COUNT 5
    
    GtkTextBuffer* buffer;
    GtkTextBuffer* buffer1;
    GdkPixbuf* pixbuf;
    GtkTextIter iter;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    GSList* list;
    gint i;
    gchar buff[20];
    gchararray name;
    gchar* text;
    gchar* text1;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    for (i = 0; i < COUNT; i++) 
    {
        sprintf(buff, "Tag %i", i);
        tag = gtk_text_tag_new (buff);
        g_object_set (tag, "editable", TRUE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag(buffer, tag, &start, &end);
    }
    
    pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 10, 10);
    gtk_text_buffer_insert_pixbuf (buffer, &start, pixbuf);
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text = gtk_text_buffer_get_slice (buffer, &start, &end, TRUE);
    
    buffer1 =  gtk_text_buffer_new (gtk_text_buffer_get_tag_table (buffer));
    if (!buffer1)
    {
        TEST_FAIL ("cannot create second text buffer", NULL); 
        return;
    } 
    
    gtk_text_buffer_get_bounds (buffer1, &start, &end);
    text1 = gtk_text_buffer_get_text (buffer1, &start, &end, TRUE);
    
    if (TAG)
    {
        tag = gtk_text_tag_new ("Tag");
        g_object_set (tag, "editable", (gboolean) EDITABLE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer1), tag);
        gtk_text_buffer_apply_tag (buffer1, tag, &start, &end);
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer1, &iter, 0, 0);
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    result = gtk_text_buffer_insert_range_interactive (buffer1, &iter, &start, &end, EDITABLE);
    
    gtk_text_buffer_get_bounds (buffer1, &start, &end);
    if (TAG)
    {
        gtk_text_buffer_remove_tag_by_name (buffer1, "Tag", &start, &end);  
    }
    
    if (!EDITABLE) 
    {
        gtk_text_buffer_get_bounds (buffer1, &start, &end);
        if (strcmp (text1, gtk_text_buffer_get_text (buffer1, &start, &end, TRUE)))
        {
            TEST_FAIL ("Default text isn't correct \n%s\n%s", text1, gtk_text_buffer_get_slice (buffer1, &start, &end, TRUE));
        }
        if (result)
        {
            TEST_FAIL ("gtk_text_buffer_insert_interactive () returns TRUE although TextBuffer is not editable", NULL);
        }
    
    } else {
    
        gtk_text_buffer_get_bounds (buffer1, &start, &end);
    
        if (strcmp (text, gtk_text_buffer_get_slice (buffer1, &start, &end, TRUE)))
        {
            TEST_FAIL ("text not equal \n(%s) \n(%s)", text, gtk_text_buffer_get_slice (buffer1, &start, &end, TRUE)); 
        } 
    
        if (gtk_text_iter_get_char(&start) != 0xFFFC)
        {
            TEST_FAIL ("pixbuf not included", NULL); 
        }
    
        gtk_text_iter_forward_cursor_position (&start);
        list = gtk_text_iter_get_tags(&start);
        if (!list)
        {
            TEST_FAIL ("tag list is NULL", NULL);
            return;
        }
    
        for (i = 0; i < g_slist_length(list); i++) 
        {
            tag = (GtkTextTag*) g_slist_nth_data(list, i); 
            g_object_get(tag, "name", &name, NULL);
            sprintf(buff, "Tag %i", i);
            if (strcmp(buff, name))
            {
                TEST_FAIL ("Tag(%i) %s  %s is wrong", i, buff, name);
            }    
        }
        g_slist_free (list);
    }
    
    
    #undef TEXT
    #undef TAG
    #undef EDITABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_with_tags
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len, GtkTextTag *first_tag, ...
 * Returns:  void
 * Assertion: Inserts text into buffer at iter, applying the list of tags to the newly-inserted text.
 * Params Values:  GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len, GtkTextTag *first_tag, ...
 * Expected: void
 * 
 * Name: gtk_text_buffer_insert_with_tags
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len, GtkTextTag *first_tag, ...
 * Returns:  void
 * Assertion: Equivalent to calling gtk_text_buffer_insert(), then gtk_text_buffer_apply_tag() on the inserted text; gtk_text_buffer_insert_with_tags() is just a convenience function
 * Params Values:  GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len, GtkTextTag *first_tag, ...
 * Expected: void  
 */
static void test_purpose_129()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyz\nABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    #define INSERT "insert"
    #define LENGTH -1
    #define LINE 0
    #define OFFS 0
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag1;
    GtkTextTag* tag2;
    GtkTextTag* tag3;
    gint i;
    GSList* list;
    gchararray name;
    gchar buff[20];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    tag1 = gtk_text_tag_new ("Tag 1");
    g_object_set (tag1, "editable", TRUE, NULL);
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag1);
    
    tag2 = gtk_text_tag_new ("Tag 2");
    g_object_set (tag2, "size", 10, NULL);
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag2);
    
    tag3 = gtk_text_tag_new ("Tag 3");
    g_object_set (tag3, "editable", TRUE, NULL);
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag3);
    
    gtk_text_buffer_insert_with_tags (buffer, &start, INSERT, LENGTH, tag1, tag2, tag3, NULL);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE, OFFS + strlen (INSERT));
    
    list = gtk_text_iter_get_tags(&start);
    if (!list)
    {
        TEST_FAIL ("tag list is NULL", NULL);
        return;
    }
    
    if (g_slist_length(list) != 3) 
    {
        TEST_FAIL ("wrong tag count", NULL);
    }
    
    for (i = 1; i <= g_slist_length(list); i++) 
    {
        tag1 = (GtkTextTag*) g_slist_nth_data(list, i-1); 
        g_object_get(G_OBJECT (tag1), "name", &name, NULL);
        sprintf(buff, "Tag %i", i);
        if (strcmp(buff, name))
        {
            TEST_FAIL ("Tag(%i) %s  %s is wrong", i, buff, name);
        }    
    }
    g_slist_free (list);
    
    #undef TEXT
    #undef INSERT
    #undef LENGTH 
    #undef LINE 
    #undef OFFS 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_with_tags
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len, GtkTextTag *first_tag, ...
 * Returns:  void
 * Assertion: Inserts text into buffer at iter, applying the list of tags to the newly-inserted text.
 * Params Values:  GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len, GtkTextTag *first_tag, ...
 * Expected: void
 * 
 * Name: gtk_text_buffer_insert_with_tags
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len, GtkTextTag *first_tag, ...
 * Returns:  void
 * Assertion: Equivalent to calling gtk_text_buffer_insert(), then gtk_text_buffer_apply_tag() on the inserted text; gtk_text_buffer_insert_with_tags() is just a convenience function
 * Params Values:  GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len, GtkTextTag *first_tag, ...
 * Expected: void  
 */
static void test_purpose_130()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyz\nABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    #define INSERT "insert"
    #define LENGTH -1
    #define LINE 1
    #define OFFS 0
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag1;
    GtkTextTag* tag2;
    GtkTextTag* tag3;
    gint i;
    GSList* list;
    gchararray name;
    gchar buff[20];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    tag1 = gtk_text_tag_new ("Tag 1");
    g_object_set (tag1, "editable", TRUE, NULL);
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag1);
    
    tag2 = gtk_text_tag_new ("Tag 2");
    g_object_set (tag2, "size", 10, NULL);
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag2);
    
    tag3 = gtk_text_tag_new ("Tag 3");
    g_object_set (tag3, "editable", TRUE, NULL);
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag3);
    
    gtk_text_buffer_insert_with_tags (buffer, &start, INSERT, LENGTH, tag1, tag2, tag3, NULL);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE, OFFS + strlen (INSERT));
    
    list = gtk_text_iter_get_tags(&start);
    if (!list)
    {
        TEST_FAIL ("tag list is NULL", NULL);
        return;
    }
    
    if (g_slist_length(list) != 3) 
    {
        TEST_FAIL ("wrong tag count", NULL);
    }
    
    for (i = 1; i <= g_slist_length(list); i++) 
    {
        tag1 = (GtkTextTag*) g_slist_nth_data(list, i-1); 
        g_object_get(G_OBJECT (tag1), "name", &name, NULL);
        sprintf(buff, "Tag %i", i);
        if (strcmp(buff, name))
        {
            TEST_FAIL ("Tag(%i) %s  %s is wrong", i, buff, name);
        }    
    }
    g_slist_free (list);
    
    #undef TEXT
    #undef INSERT
    #undef LENGTH 
    #undef LINE 
    #undef OFFS 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_with_tags
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len, GtkTextTag *first_tag, ...
 * Returns:  void
 * Assertion: Inserts text into buffer at iter, applying the list of tags to the newly-inserted text.
 * Params Values:  GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len, GtkTextTag *first_tag, ...
 * Expected: void
 * 
 * Name: gtk_text_buffer_insert_with_tags
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len, GtkTextTag *first_tag, ...
 * Returns:  void
 * Assertion: Equivalent to calling gtk_text_buffer_insert(), then gtk_text_buffer_apply_tag() on the inserted text; gtk_text_buffer_insert_with_tags() is just a convenience function
 * Params Values:  GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len, GtkTextTag *first_tag, ...
 * Expected: void  
 */
static void test_purpose_131()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyz\nABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    #define INSERT "insert"
    #define LENGTH -1
    #define LINE 1
    #define OFFS 26
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag1;
    GtkTextTag* tag2;
    GtkTextTag* tag3;
    gint i;
    GSList* list;
    gchararray name;
    gchar buff[20];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    tag1 = gtk_text_tag_new ("Tag 1");
    g_object_set (tag1, "editable", TRUE, NULL);
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag1);
    
    tag2 = gtk_text_tag_new ("Tag 2");
    g_object_set (tag2, "size", 10, NULL);
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag2);
    
    tag3 = gtk_text_tag_new ("Tag 3");
    g_object_set (tag3, "editable", TRUE, NULL);
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag3);
    
    gtk_text_buffer_insert_with_tags (buffer, &start, INSERT, LENGTH, tag1, tag2, tag3, NULL);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE, OFFS + strlen (INSERT));
    
    list = gtk_text_iter_get_tags(&start);
    if (!list)
    {
        TEST_FAIL ("tag list is NULL", NULL);
        return;
    }
    
    if (g_slist_length(list) != 3) 
    {
        TEST_FAIL ("wrong tag count", NULL);
    }
    
    for (i = 1; i <= g_slist_length(list); i++) 
    {
        tag1 = (GtkTextTag*) g_slist_nth_data(list, i-1); 
        g_object_get(G_OBJECT (tag1), "name", &name, NULL);
        sprintf(buff, "Tag %i", i);
        if (strcmp(buff, name))
        {
            TEST_FAIL ("Tag(%i) %s  %s is wrong", i, buff, name);
        }    
    }
    g_slist_free (list);
    
    #undef TEXT
    #undef INSERT
    #undef LENGTH 
    #undef LINE 
    #undef OFFS 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_with_tags_by_name
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len, const gchar *first_tag_name, ...
 * Returns:  void
 * Assertion: Same as gtk_text_buffer_insert_with_tags(), but allows you to pass in tag names instead of tag objects.
 * Params Values:  GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len, const gchar *first_tag_name, ...
 * Expected: void  
 */
static void test_purpose_132()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyz\nABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    #define INSERT "insert"
    #define LENGTH -1
    #define LINE 0
    #define OFFS 0
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag1;
    GtkTextTag* tag2;
    GtkTextTag* tag3;
    gint i;
    GSList* list;
    gchararray name;
    gchar buff[20];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    tag1 = gtk_text_tag_new ("Tag 1");
    g_object_set (tag1, "editable", TRUE, NULL);
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag1);
    
    tag2 = gtk_text_tag_new ("Tag 2");
    g_object_set (tag2, "size", 10, NULL);
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag2);
    
    tag3 = gtk_text_tag_new ("Tag 3");
    g_object_set (tag3, "editable", TRUE, NULL);
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag3);
    
    gtk_text_buffer_insert_with_tags_by_name (buffer, &start, INSERT, LENGTH, "Tag 1", "Tag 2", "Tag 3", NULL);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE, OFFS + strlen (INSERT));
    
    list = gtk_text_iter_get_tags(&start);
    if (!list)
    {
        TEST_FAIL ("tag list is NULL", NULL);
        return;
    }
    
    if (g_slist_length(list) != 3) 
    {
        TEST_FAIL ("wrong tag count", NULL);
    }
    
    for (i = 1; i <= g_slist_length(list); i++) 
    {
        tag1 = (GtkTextTag*) g_slist_nth_data(list, i-1); 
        g_object_get(G_OBJECT (tag1), "name", &name, NULL);
        sprintf(buff, "Tag %i", i);
        if (strcmp(buff, name))
        {
            TEST_FAIL ("Tag(%i) %s  %s is wrong", i, buff, name);
        }    
    }
    g_slist_free (list);
    
    
    #undef TEXT
    #undef INSERT
    #undef LENGTH 
    #undef LINE 
    #undef OFFS 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_with_tags_by_name
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len, const gchar *first_tag_name, ...
 * Returns:  void
 * Assertion: Same as gtk_text_buffer_insert_with_tags(), but allows you to pass in tag names instead of tag objects.
 * Params Values:  GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len, const gchar *first_tag_name, ...
 * Expected: void  
 */
static void test_purpose_133()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyz\nABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    #define INSERT "insert"
    #define LENGTH -1
    #define LINE 1
    #define OFFS 0
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag1;
    GtkTextTag* tag2;
    GtkTextTag* tag3;
    gint i;
    GSList* list;
    gchararray name;
    gchar buff[20];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    tag1 = gtk_text_tag_new ("Tag 1");
    g_object_set (tag1, "editable", TRUE, NULL);
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag1);
    
    tag2 = gtk_text_tag_new ("Tag 2");
    g_object_set (tag2, "size", 10, NULL);
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag2);
    
    tag3 = gtk_text_tag_new ("Tag 3");
    g_object_set (tag3, "editable", TRUE, NULL);
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag3);
    
    gtk_text_buffer_insert_with_tags_by_name (buffer, &start, INSERT, LENGTH, "Tag 1", "Tag 2", "Tag 3", NULL);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE, OFFS + strlen (INSERT));
    
    list = gtk_text_iter_get_tags(&start);
    if (!list)
    {
        TEST_FAIL ("tag list is NULL", NULL);
        return;
    }
    
    if (g_slist_length(list) != 3) 
    {
        TEST_FAIL ("wrong tag count", NULL);
    }
    
    for (i = 1; i <= g_slist_length(list); i++) 
    {
        tag1 = (GtkTextTag*) g_slist_nth_data(list, i-1); 
        g_object_get(G_OBJECT (tag1), "name", &name, NULL);
        sprintf(buff, "Tag %i", i);
        if (strcmp(buff, name))
        {
            TEST_FAIL ("Tag(%i) %s  %s is wrong", i, buff, name);
        }    
    }
    g_slist_free (list);
    
    
    #undef TEXT
    #undef INSERT
    #undef LENGTH 
    #undef LINE 
    #undef OFFS 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_with_tags_by_name
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len, const gchar *first_tag_name, ...
 * Returns:  void
 * Assertion: Same as gtk_text_buffer_insert_with_tags(), but allows you to pass in tag names instead of tag objects.
 * Params Values:  GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *text, gint len, const gchar *first_tag_name, ...
 * Expected: void  
 */
static void test_purpose_134()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyz\nABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    #define INSERT "insert"
    #define LENGTH -1
    #define LINE 1
    #define OFFS 26
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag1;
    GtkTextTag* tag2;
    GtkTextTag* tag3;
    gint i;
    GSList* list;
    gchararray name;
    gchar buff[20];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    tag1 = gtk_text_tag_new ("Tag 1");
    g_object_set (tag1, "editable", TRUE, NULL);
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag1);
    
    tag2 = gtk_text_tag_new ("Tag 2");
    g_object_set (tag2, "size", 10, NULL);
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag2);
    
    tag3 = gtk_text_tag_new ("Tag 3");
    g_object_set (tag3, "editable", TRUE, NULL);
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag3);
    
    gtk_text_buffer_insert_with_tags_by_name (buffer, &start, INSERT, LENGTH, "Tag 1", "Tag 2", "Tag 3", NULL);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE, OFFS + strlen (INSERT));
    
    list = gtk_text_iter_get_tags(&start);
    if (!list)
    {
        TEST_FAIL ("tag list is NULL", NULL);
        return;
    }
    
    if (g_slist_length(list) != 3) 
    {
        TEST_FAIL ("wrong tag count", NULL);
    }
    
    for (i = 1; i <= g_slist_length(list); i++) 
    {
        tag1 = (GtkTextTag*) g_slist_nth_data(list, i-1); 
        g_object_get(G_OBJECT (tag1), "name", &name, NULL);
        sprintf(buff, "Tag %i", i);
        if (strcmp(buff, name))
        {
            TEST_FAIL ("Tag(%i) %s  %s is wrong", i, buff, name);
        }    
    }
    g_slist_free (list);
    
    
    #undef TEXT
    #undef INSERT
    #undef LENGTH 
    #undef LINE 
    #undef OFFS 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_delete
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end
 * Returns:  void
 * Assertion: Deletes text between start and end.
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end
 * Expected: void  
 */
static void test_purpose_135()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 0
    #define LINE1 0
    #define OFFS1 2
    #define RES_TEXT "2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    
    gtk_text_buffer_delete (buffer, &start, &end);
    
    text = g_locale_from_utf8 (gtk_text_buffer_get_text (buffer, &start, &end, TRUE), -1, NULL, NULL, NULL);
    
    if (strcmp (text, ""))
    {
        TEST_FAIL ("Text between start and end not deleted", NULL);
    }
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text = g_locale_from_utf8 (gtk_text_buffer_get_text (buffer, &start, &end, TRUE), -1, NULL, NULL, NULL);
    
    if (strcmp (RES_TEXT, text))
    {
        TEST_FAIL ("Text isn't correct \n%s\n%s", text, RES_TEXT);
    }
    
    #undef TEXT
    #undef LINE 
    #undef OFFS 
    #undef LINE1 
    #undef OFFS1 
    #undef RES_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_delete
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end
 * Returns:  void
 * Assertion: Deletes text between start and end.
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end
 * Expected: void  
 */
static void test_purpose_136()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 1
    #define LINE1 1
    #define OFFS1 20
    #define RES_TEXT "1\n"
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    
    gtk_text_buffer_delete (buffer, &start, &end);
    
    text = g_locale_from_utf8 (gtk_text_buffer_get_text (buffer, &start, &end, TRUE), -1, NULL, NULL, NULL);
    
    if (strcmp (text, ""))
    {
        TEST_FAIL ("Text between start and end not deleted", NULL);
    }
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text = g_locale_from_utf8 (gtk_text_buffer_get_text (buffer, &start, &end, TRUE), -1, NULL, NULL, NULL);
    
    if (strcmp (RES_TEXT, text))
    {
        TEST_FAIL ("Text isn't correct \n%s\n%s", text, RES_TEXT);
    }
    
    #undef TEXT
    #undef LINE 
    #undef OFFS 
    #undef LINE1 
    #undef OFFS1 
    #undef RES_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_delete
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end
 * Returns:  void
 * Assertion: Deletes text between start and end.
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end
 * Expected: void  
 */
static void test_purpose_137()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 0
    #define LINE1 1
    #define OFFS1 0
    #define RES_TEXT " 1 2 3 4 5 6 7 8 9 0\n"
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    
    gtk_text_buffer_delete (buffer, &start, &end);
    
    text = g_locale_from_utf8 (gtk_text_buffer_get_text (buffer, &start, &end, TRUE), -1, NULL, NULL, NULL);
    
    if (strcmp (text, ""))
    {
        TEST_FAIL ("Text between start and end not deleted", NULL);
    }
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text = g_locale_from_utf8 (gtk_text_buffer_get_text (buffer, &start, &end, TRUE), -1, NULL, NULL, NULL);
    
    if (strcmp (RES_TEXT, text))
    {
        TEST_FAIL ("Text isn't correct \n%s\n%s", text, RES_TEXT);
    }
    
    #undef TEXT
    #undef LINE 
    #undef OFFS 
    #undef LINE1 
    #undef OFFS1 
    #undef RES_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_delete
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end
 * Returns:  void
 * Assertion: This function actually emits the "delete_range" signal, and the default handler of that signal deletes the text.
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end
 * Expected: void  
 */
static void test_purpose_138()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 0
    #define LINE1 0
    #define OFFS1 2
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (buffer), "delete-range", GTK_SIGNAL_FUNC (global_delete_range), NULL);
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    
    gtk_text_buffer_delete (buffer, &start, &end);
    
    if (!modified_catched)
    {
        TEST_FAIL ("'delete-range' signal not catched", NULL);
    }
    
    #undef TEXT
    #undef LINE 
    #undef OFFS 
    #undef LINE1 
    #undef OFFS1 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_delete
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end
 * Returns:  void
 * Assertion: This function actually emits the "delete_range" signal, and the default handler of that signal deletes the text.
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end
 * Expected: void  
 */
static void test_purpose_139()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 1
    #define LINE1 1
    #define OFFS1 20
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (buffer), "delete-range", GTK_SIGNAL_FUNC (global_delete_range), NULL);
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    
    gtk_text_buffer_delete (buffer, &start, &end);
    
    if (!modified_catched)
    {
        TEST_FAIL ("'delete-range' signal not catched", NULL);
    }
    
    #undef TEXT
    #undef LINE 
    #undef OFFS 
    #undef LINE1 
    #undef OFFS1 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_delete
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end
 * Returns:  void
 * Assertion: This function actually emits the "delete_range" signal, and the default handler of that signal deletes the text.
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end
 * Expected: void  
 */
static void test_purpose_140()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 0
    #define LINE1 1
    #define OFFS1 0
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (buffer), "delete-range", GTK_SIGNAL_FUNC (global_delete_range), NULL);
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    
    gtk_text_buffer_delete (buffer, &start, &end);
    
    if (!modified_catched)
    {
        TEST_FAIL ("'delete-range' signal not catched", NULL);
    }
    
    #undef TEXT
    #undef LINE 
    #undef OFFS 
    #undef LINE1 
    #undef OFFS1 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_delete_interactive
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end, gboolean default_editable
 * Returns:  gboolean
 * Assertion: Deletes all editable text in the given range.
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end, gboolean default_editable
 * Expected: gboolean
 * 
 * Name: gtk_text_buffer_delete_interactive
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end, gboolean default_editable
 * Returns:  gboolean
 * Assertion: Calls gtk_text_buffer_delete() for each editable sub-range of [start,end).
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end, gboolean default_editable
 * Expected: gboolean
 * 
 * Name: gtk_text_buffer_delete_interactive
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end, gboolean default_editable
 * Returns:  gboolean
 * Assertion: start and end are revalidated to point to the location of the last deleted range, or left untouched if no text was deleted.
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end, gboolean default_editable
 * Expected: gboolean  
 */
static void test_purpose_141()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 0
    #define LINE1 0
    #define OFFS1 2
    #define RES_TEXT "2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define EDITABLE TRUE
    #define TAG TRUE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    gchar* text;
    gchar* text1;
    gint result;
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    if (TAG)
    {
        tag = gtk_text_tag_new ("Tag");
        g_object_set (tag, "editable", (gboolean) EDITABLE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    }
    text1 = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    
    result = gtk_text_buffer_delete_interactive (buffer, &start, &end, EDITABLE);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text = g_locale_from_utf8 (gtk_text_buffer_get_text (buffer, &start, &end, TRUE), -1, NULL, NULL, NULL);
    
    if (!EDITABLE) 
    {
        if (strcmp (text1, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
        {
            TEST_FAIL ("Default text isn't correct \n%s\n%s", text1, gtk_text_buffer_get_text (buffer, &start, &end, TRUE));
        }
    
        if (result)
        {
            TEST_FAIL ("gtk_text_buffer_delete_interactive () returns TRUE although TextBuffer is not editable", NULL);
        }
    
    } else {
    
        if (strcmp (RES_TEXT, text))
        {
            TEST_FAIL ("Text isn't correct \n%s\n%s", text, RES_TEXT);
        }
    }
    
    #undef TEXT
    #undef LINE 
    #undef OFFS 
    #undef LINE1 
    #undef OFFS1 
    #undef RES_TEXT
    #undef TAG
    #undef EDITABLE 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_delete_interactive
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end, gboolean default_editable
 * Returns:  gboolean
 * Assertion: Deletes all editable text in the given range.
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end, gboolean default_editable
 * Expected: gboolean
 * 
 * Name: gtk_text_buffer_delete_interactive
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end, gboolean default_editable
 * Returns:  gboolean
 * Assertion: Calls gtk_text_buffer_delete() for each editable sub-range of [start,end).
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end, gboolean default_editable
 * Expected: gboolean
 * 
 * Name: gtk_text_buffer_delete_interactive
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end, gboolean default_editable
 * Returns:  gboolean
 * Assertion: start and end are revalidated to point to the location of the last deleted range, or left untouched if no text was deleted.
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end, gboolean default_editable
 * Expected: gboolean  
 */
static void test_purpose_142()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 1
    #define LINE1 1
    #define OFFS1 20
    #define RES_TEXT "1\n"
    #define EDITABLE TRUE
    #define TAG FALSE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    gchar* text;
    gchar* text1;
    gint result;
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    if (TAG)
    {
        tag = gtk_text_tag_new ("Tag");
        g_object_set (tag, "editable", (gboolean) EDITABLE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    }
    text1 = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    
    result = gtk_text_buffer_delete_interactive (buffer, &start, &end, EDITABLE);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text = g_locale_from_utf8 (gtk_text_buffer_get_text (buffer, &start, &end, TRUE), -1, NULL, NULL, NULL);
    
    if (!EDITABLE) 
    {
        if (strcmp (text1, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
        {
            TEST_FAIL ("Default text isn't correct \n%s\n%s", text1, gtk_text_buffer_get_text (buffer, &start, &end, TRUE));
        }
    
        if (result)
        {
            TEST_FAIL ("gtk_text_buffer_delete_interactive () returns TRUE although TextBuffer is not editable", NULL);
        }
    
    } else {
    
        if (strcmp (RES_TEXT, text))
        {
            TEST_FAIL ("Text isn't correct \n%s\n%s", text, RES_TEXT);
        }
    }
    
    #undef TEXT
    #undef LINE 
    #undef OFFS 
    #undef LINE1 
    #undef OFFS1 
    #undef RES_TEXT
    #undef TAG
    #undef EDITABLE 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_delete_interactive
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end, gboolean default_editable
 * Returns:  gboolean
 * Assertion: Deletes all editable text in the given range.
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end, gboolean default_editable
 * Expected: gboolean
 * 
 * Name: gtk_text_buffer_delete_interactive
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end, gboolean default_editable
 * Returns:  gboolean
 * Assertion: Calls gtk_text_buffer_delete() for each editable sub-range of [start,end).
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end, gboolean default_editable
 * Expected: gboolean
 * 
 * Name: gtk_text_buffer_delete_interactive
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end, gboolean default_editable
 * Returns:  gboolean
 * Assertion: start and end are revalidated to point to the location of the last deleted range, or left untouched if no text was deleted.
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end, gboolean default_editable
 * Expected: gboolean  
 */
static void test_purpose_143()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 0
    #define LINE1 1
    #define OFFS1 0
    #define RES_TEXT " 1 2 3 4 5 6 7 8 9 0\n"
    #define EDITABLE FALSE
    #define TAG TRUE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    gchar* text;
    gchar* text1;
    gint result;
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    if (TAG)
    {
        tag = gtk_text_tag_new ("Tag");
        g_object_set (tag, "editable", (gboolean) EDITABLE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    }
    text1 = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    
    result = gtk_text_buffer_delete_interactive (buffer, &start, &end, EDITABLE);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text = g_locale_from_utf8 (gtk_text_buffer_get_text (buffer, &start, &end, TRUE), -1, NULL, NULL, NULL);
    
    if (!EDITABLE) 
    {
        if (strcmp (text1, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
        {
            TEST_FAIL ("Default text isn't correct \n%s\n%s", text1, gtk_text_buffer_get_text (buffer, &start, &end, TRUE));
        }
    
        if (result)
        {
            TEST_FAIL ("gtk_text_buffer_delete_interactive () returns TRUE although TextBuffer is not editable", NULL);
        }
    
    } else {
    
        if (strcmp (RES_TEXT, text))
        {
            TEST_FAIL ("Text isn't correct \n%s\n%s", text, RES_TEXT);
        }
    }
    
    #undef TEXT
    #undef LINE 
    #undef OFFS 
    #undef LINE1 
    #undef OFFS1 
    #undef RES_TEXT
    #undef TAG
    #undef EDITABLE 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_delete_interactive
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end, gboolean default_editable
 * Returns:  gboolean
 * Assertion: Deletes all editable text in the given range.
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end, gboolean default_editable
 * Expected: gboolean
 * 
 * Name: gtk_text_buffer_delete_interactive
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end, gboolean default_editable
 * Returns:  gboolean
 * Assertion: Calls gtk_text_buffer_delete() for each editable sub-range of [start,end).
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end, gboolean default_editable
 * Expected: gboolean
 * 
 * Name: gtk_text_buffer_delete_interactive
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end, gboolean default_editable
 * Returns:  gboolean
 * Assertion: start and end are revalidated to point to the location of the last deleted range, or left untouched if no text was deleted.
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end, gboolean default_editable
 * Expected: gboolean  
 */
static void test_purpose_144()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 0
    #define LINE1 1
    #define OFFS1 0
    #define RES_TEXT " 1 2 3 4 5 6 7 8 9 0\n"
    #define EDITABLE FALSE
    #define TAG TRUE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    gchar* text;
    gchar* text1;
    gint result;
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    if (TAG)
    {
        tag = gtk_text_tag_new ("Tag");
        g_object_set (tag, "editable", (gboolean) EDITABLE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    }
    text1 = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    
    result = gtk_text_buffer_delete_interactive (buffer, &start, &end, EDITABLE);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text = g_locale_from_utf8 (gtk_text_buffer_get_text (buffer, &start, &end, TRUE), -1, NULL, NULL, NULL);
    
    if (!EDITABLE) 
    {
        if (strcmp (text1, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
        {
            TEST_FAIL ("Default text isn't correct \n%s\n%s", text1, gtk_text_buffer_get_text (buffer, &start, &end, TRUE));
        }
    
        if (result)
        {
            TEST_FAIL ("gtk_text_buffer_delete_interactive () returns TRUE although TextBuffer is not editable", NULL);
        }
    
    } else {
    
        if (strcmp (RES_TEXT, text))
        {
            TEST_FAIL ("Text isn't correct \n%s\n%s", text, RES_TEXT);
        }
    }
    
    #undef TEXT
    #undef LINE 
    #undef OFFS 
    #undef LINE1 
    #undef OFFS1 
    #undef RES_TEXT
    #undef TAG
    #undef EDITABLE 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_delete_interactive
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end, gboolean default_editable
 * Returns:  gboolean
 * Assertion: Deletes all editable text in the given range.
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end, gboolean default_editable
 * Expected: gboolean
 * 
 * Name: gtk_text_buffer_delete_interactive
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end, gboolean default_editable
 * Returns:  gboolean
 * Assertion: Calls gtk_text_buffer_delete() for each editable sub-range of [start,end).
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end, gboolean default_editable
 * Expected: gboolean
 * 
 * Name: gtk_text_buffer_delete_interactive
 * Params: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end, gboolean default_editable
 * Returns:  gboolean
 * Assertion: start and end are revalidated to point to the location of the last deleted range, or left untouched if no text was deleted.
 * Params Values: GtkTextBuffer *buffer, GtkTextIter *start, GtkTextIter *end, gboolean default_editable
 * Expected: gboolean  
 */
static void test_purpose_145()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 0
    #define LINE1 1
    #define OFFS1 0
    #define RES_TEXT " 1 2 3 4 5 6 7 8 9 0\n"
    #define EDITABLE FALSE
    #define TAG FALSE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    gchar* text;
    gchar* text1;
    gint result;
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    if (TAG)
    {
        tag = gtk_text_tag_new ("Tag");
        g_object_set (tag, "editable", (gboolean) EDITABLE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    }
    text1 = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    
    result = gtk_text_buffer_delete_interactive (buffer, &start, &end, EDITABLE);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text = g_locale_from_utf8 (gtk_text_buffer_get_text (buffer, &start, &end, TRUE), -1, NULL, NULL, NULL);
    
    if (!EDITABLE) 
    {
        if (strcmp (text1, gtk_text_buffer_get_text (buffer, &start, &end, TRUE)))
        {
            TEST_FAIL ("Default text isn't correct \n%s\n%s", text1, gtk_text_buffer_get_text (buffer, &start, &end, TRUE));
        }
    
        if (result)
        {
            TEST_FAIL ("gtk_text_buffer_delete_interactive () returns TRUE although TextBuffer is not editable", NULL);
        }
    
    } else {
    
        if (strcmp (RES_TEXT, text))
        {
            TEST_FAIL ("Text isn't correct \n%s\n%s", text, RES_TEXT);
        }
    }
    
    #undef TEXT
    #undef LINE 
    #undef OFFS 
    #undef LINE1 
    #undef OFFS1 
    #undef RES_TEXT
    #undef TAG
    #undef EDITABLE 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_pixbuf
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, GdkPixbuf *pixbuf
 * Returns:  void
 * Assertion: Inserts an image into the text buffer at iter.
 * Params Values: GtkTextBuffer *buffer, const, GtkTextIter *iter, GdkPixbuf *pixbuf
 * Expected:  void
 * 
 * Name: gtk_text_buffer_insert_pixbuf
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, GdkPixbuf *pixbuf
 * Returns:  void
 * Assertion: The image will be counted as one character in character counts, and when obtaining the buffer contents as a string, will be represented by the Unicode "object replacement character" 0xFFFC.
 * Params Values: GtkTextBuffer *buffer, const, GtkTextIter *iter, GdkPixbuf *pixbuf
 * Expected:  void  
 */
static void test_purpose_146()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 0
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GdkPixbuf* pixbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 10, 10);
    gtk_text_buffer_insert_pixbuf (buffer, &start, pixbuf);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    if (gtk_text_iter_get_char(&start) != 0xFFFC)
    {
        TEST_FAIL ("pixbuf not included", NULL); 
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_pixbuf
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, GdkPixbuf *pixbuf
 * Returns:  void
 * Assertion: Inserts an image into the text buffer at iter.
 * Params Values: GtkTextBuffer *buffer, const, GtkTextIter *iter, GdkPixbuf *pixbuf
 * Expected:  void
 * 
 * Name: gtk_text_buffer_insert_pixbuf
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, GdkPixbuf *pixbuf
 * Returns:  void
 * Assertion: The image will be counted as one character in character counts, and when obtaining the buffer contents as a string, will be represented by the Unicode "object replacement character" 0xFFFC.
 * Params Values: GtkTextBuffer *buffer, const, GtkTextIter *iter, GdkPixbuf *pixbuf
 * Expected:  void  
 */
static void test_purpose_147()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 19
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GdkPixbuf* pixbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 10, 10);
    gtk_text_buffer_insert_pixbuf (buffer, &start, pixbuf);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    if (gtk_text_iter_get_char(&start) != 0xFFFC)
    {
        TEST_FAIL ("pixbuf not included", NULL); 
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_pixbuf
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, GdkPixbuf *pixbuf
 * Returns:  void
 * Assertion: Inserts an image into the text buffer at iter.
 * Params Values: GtkTextBuffer *buffer, const, GtkTextIter *iter, GdkPixbuf *pixbuf
 * Expected:  void
 * 
 * Name: gtk_text_buffer_insert_pixbuf
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, GdkPixbuf *pixbuf
 * Returns:  void
 * Assertion: The image will be counted as one character in character counts, and when obtaining the buffer contents as a string, will be represented by the Unicode "object replacement character" 0xFFFC.
 * Params Values: GtkTextBuffer *buffer, const, GtkTextIter *iter, GdkPixbuf *pixbuf
 * Expected:  void  
 */
static void test_purpose_148()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 1
    #define OFFS 20
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GdkPixbuf* pixbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 10, 10);
    gtk_text_buffer_insert_pixbuf (buffer, &start, pixbuf);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    if (gtk_text_iter_get_char(&start) != 0xFFFC)
    {
        TEST_FAIL ("pixbuf not included", NULL); 
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_child_anchor
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, GtkTextChildAnchor *anchor
 * Returns:  void
 * Assertion: Inserts a child widget anchor into the text buffer at iter.
 * Params Values: GtkTextBuffer *buffer, const, GtkTextIter *iter
 * Expected:  void
 * 
 * Name: gtk_text_buffer_insert_child_anchor
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, GtkTextChildAnchor *anchor
 * Returns: void
 * Assertion: The buffer will add a reference to the anchor, so you can unref it after insertion
 * Params Values: GtkTextBuffer *buffer, const, GtkTextIter *iter
 * Expected:  void  
 */
static void test_purpose_149()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 0
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextChildAnchor* anchor;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    anchor = gtk_text_child_anchor_new ();
    gtk_text_buffer_insert_child_anchor (buffer, &start, anchor);
    
    if (G_OBJECT (anchor)->ref_count != 2)
    {
        TEST_FAIL ("ref_count = %i, should be 2", G_OBJECT (anchor)->ref_count);
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    if (gtk_text_iter_get_char(&start) != 0xFFFC)
    {
        TEST_FAIL ("pixbuf not included", NULL); 
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_child_anchor
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, GtkTextChildAnchor *anchor
 * Returns:  void
 * Assertion: Inserts a child widget anchor into the text buffer at iter.
 * Params Values: GtkTextBuffer *buffer, const, GtkTextIter *iter
 * Expected:  void
 * 
 * Name: gtk_text_buffer_insert_child_anchor
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, GtkTextChildAnchor *anchor
 * Returns: void
 * Assertion: The buffer will add a reference to the anchor, so you can unref it after insertion
 * Params Values: GtkTextBuffer *buffer, const, GtkTextIter *iter
 * Expected:  void  
 */
static void test_purpose_150()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 19
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextChildAnchor* anchor;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    anchor = gtk_text_child_anchor_new ();
    gtk_text_buffer_insert_child_anchor (buffer, &start, anchor);
    
    if (G_OBJECT (anchor)->ref_count != 2)
    {
        TEST_FAIL ("ref_count = %i, should be 2", G_OBJECT (anchor)->ref_count);
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    if (gtk_text_iter_get_char(&start) != 0xFFFC)
    {
        TEST_FAIL ("pixbuf not included", NULL); 
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_insert_child_anchor
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, GtkTextChildAnchor *anchor
 * Returns:  void
 * Assertion: Inserts a child widget anchor into the text buffer at iter.
 * Params Values: GtkTextBuffer *buffer, const, GtkTextIter *iter
 * Expected:  void
 * 
 * Name: gtk_text_buffer_insert_child_anchor
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, GtkTextChildAnchor *anchor
 * Returns: void
 * Assertion: The buffer will add a reference to the anchor, so you can unref it after insertion
 * Params Values: GtkTextBuffer *buffer, const, GtkTextIter *iter
 * Expected:  void  
 */
static void test_purpose_151()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 1
    #define OFFS 20
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextChildAnchor* anchor;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    anchor = gtk_text_child_anchor_new ();
    gtk_text_buffer_insert_child_anchor (buffer, &start, anchor);
    
    if (G_OBJECT (anchor)->ref_count != 2)
    {
        TEST_FAIL ("ref_count = %i, should be 2", G_OBJECT (anchor)->ref_count);
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    if (gtk_text_iter_get_char(&start) != 0xFFFC)
    {
        TEST_FAIL ("pixbuf not included", NULL); 
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_create_child_anchor
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter
 * Returns: GtkTextChildAnchor*
 * Assertion: This is a convenience function which simply creates a child anchor with gtk_text_child_anchor_new() and inserts it into the buffer with gtk_text_buffer_insert_child_anchor().
 * Params Values: GtkTextBuffer *buffer, const, GtkTextIter *iter
 * Expected: GtkTextChildAnchor*
 * 
 * Name: gtk_text_buffer_create_child_anchor
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter
 * Returns: GtkTextChildAnchor*
 * Assertion: The new anchor is owned by the buffer; no reference count is returned to the caller of gtk_text_buffer_create_child_anchor()
 * Params Values: GtkTextBuffer *buffer, const, GtkTextIter *iter
 * Expected:  GtkTextChildAnchor*  
 */
static void test_purpose_152()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 0
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextChildAnchor* anchor;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    anchor = gtk_text_buffer_create_child_anchor (buffer, &start);
    if (!anchor)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    if (G_OBJECT (anchor)->ref_count != 1)
    {
        TEST_FAIL ("Tag count = %i, should be 1", G_OBJECT (anchor)->ref_count);
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    if (gtk_text_iter_get_char(&start) != 0xFFFC)
    {
        TEST_FAIL ("anchor not included", NULL); 
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_create_child_anchor
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter
 * Returns: GtkTextChildAnchor*
 * Assertion: This is a convenience function which simply creates a child anchor with gtk_text_child_anchor_new() and inserts it into the buffer with gtk_text_buffer_insert_child_anchor().
 * Params Values: GtkTextBuffer *buffer, const, GtkTextIter *iter
 * Expected: GtkTextChildAnchor*
 * 
 * Name: gtk_text_buffer_create_child_anchor
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter
 * Returns: GtkTextChildAnchor*
 * Assertion: The new anchor is owned by the buffer; no reference count is returned to the caller of gtk_text_buffer_create_child_anchor()
 * Params Values: GtkTextBuffer *buffer, const, GtkTextIter *iter
 * Expected:  GtkTextChildAnchor*  
 */
static void test_purpose_153()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 19
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextChildAnchor* anchor;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    anchor = gtk_text_buffer_create_child_anchor (buffer, &start);
    if (!anchor)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    if (G_OBJECT (anchor)->ref_count != 1)
    {
        TEST_FAIL ("Tag count = %i, should be 1", G_OBJECT (anchor)->ref_count);
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    if (gtk_text_iter_get_char(&start) != 0xFFFC)
    {
        TEST_FAIL ("anchor not included", NULL); 
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_create_child_anchor
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter
 * Returns: GtkTextChildAnchor*
 * Assertion: This is a convenience function which simply creates a child anchor with gtk_text_child_anchor_new() and inserts it into the buffer with gtk_text_buffer_insert_child_anchor().
 * Params Values: GtkTextBuffer *buffer, const, GtkTextIter *iter
 * Expected: GtkTextChildAnchor*
 * 
 * Name: gtk_text_buffer_create_child_anchor
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter
 * Returns: GtkTextChildAnchor*
 * Assertion: The new anchor is owned by the buffer; no reference count is returned to the caller of gtk_text_buffer_create_child_anchor()
 * Params Values: GtkTextBuffer *buffer, const, GtkTextIter *iter
 * Expected:  GtkTextChildAnchor*  
 */
static void test_purpose_154()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 1
    #define OFFS 20
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextChildAnchor* anchor;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    anchor = gtk_text_buffer_create_child_anchor (buffer, &start);
    if (!anchor)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    if (G_OBJECT (anchor)->ref_count != 1)
    {
        TEST_FAIL ("Tag count = %i, should be 1", G_OBJECT (anchor)->ref_count);
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    if (gtk_text_iter_get_char(&start) != 0xFFFC)
    {
        TEST_FAIL ("anchor not included", NULL); 
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_iter_at_child_anchor
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, GtkTextChildAnchor* anchor
 * Returns: void
 * Assertion: Obtains the location of anchor within buffer
 * Params Values: GtkTextBuffer *buffer, const, GtkTextIter *iter, GtkTextChildAnchor* anchor
 * Expected: void  
 */
static void test_purpose_155()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 0
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextChildAnchor* anchor;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    anchor = gtk_text_buffer_create_child_anchor (buffer, &start);
    if (!anchor)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    if (G_OBJECT (anchor)->ref_count != 1)
    {
        TEST_FAIL ("Tag count = %i, should be 1", G_OBJECT (anchor)->ref_count);
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    if (gtk_text_iter_get_char (&start) != 0xFFFC)
    {
        TEST_FAIL ("anchor not included", NULL); 
    }
    
    gtk_text_buffer_get_iter_at_child_anchor (buffer, &end, anchor);
    if (!gtk_text_iter_equal (&start, &end))
    {
        TEST_FAIL ("iters not equal", NULL); 
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_iter_at_child_anchor
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, GtkTextChildAnchor* anchor
 * Returns: void
 * Assertion: Obtains the location of anchor within buffer
 * Params Values: GtkTextBuffer *buffer, const, GtkTextIter *iter, GtkTextChildAnchor* anchor
 * Expected: void  
 */
static void test_purpose_156()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 19
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextChildAnchor* anchor;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    anchor = gtk_text_buffer_create_child_anchor (buffer, &start);
    if (!anchor)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    if (G_OBJECT (anchor)->ref_count != 1)
    {
        TEST_FAIL ("Tag count = %i, should be 1", G_OBJECT (anchor)->ref_count);
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    if (gtk_text_iter_get_char (&start) != 0xFFFC)
    {
        TEST_FAIL ("anchor not included", NULL); 
    }
    
    gtk_text_buffer_get_iter_at_child_anchor (buffer, &end, anchor);
    if (!gtk_text_iter_equal (&start, &end))
    {
        TEST_FAIL ("iters not equal", NULL); 
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_get_iter_at_child_anchor
 * Params: GtkTextBuffer *buffer, GtkTextIter *iter, GtkTextChildAnchor* anchor
 * Returns: void
 * Assertion: Obtains the location of anchor within buffer
 * Params Values: GtkTextBuffer *buffer, const, GtkTextIter *iter, GtkTextChildAnchor* anchor
 * Expected: void  
 */
static void test_purpose_157()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 1
    #define OFFS 20
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextChildAnchor* anchor;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    anchor = gtk_text_buffer_create_child_anchor (buffer, &start);
    if (!anchor)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    if (G_OBJECT (anchor)->ref_count != 1)
    {
        TEST_FAIL ("Tag count = %i, should be 1", G_OBJECT (anchor)->ref_count);
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    if (gtk_text_iter_get_char (&start) != 0xFFFC)
    {
        TEST_FAIL ("anchor not included", NULL); 
    }
    
    gtk_text_buffer_get_iter_at_child_anchor (buffer, &end, anchor);
    if (!gtk_text_iter_equal (&start, &end))
    {
        TEST_FAIL ("iters not equal", NULL); 
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_create_mark
 * Params: GtkTextBuffer *buffer, const gchar *mark_name, const GtkTextIter *where, gboolean left_gravity
 * Returns: GtkTextMark*
 * Assertion: Creates a mark at position where.
 * Params Values: GtkTextBuffer *buffer, const gchar *mark_name, const GtkTextIter *where, gboolean left_gravity
 * Expected: GtkTextMark*  
 */
static void test_purpose_158()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define NAME "Mark 1"
    #define LINE 0
    #define OFFS 0
    #define LEFT_GRAVITY TRUE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    mark = gtk_text_buffer_create_mark (buffer, NAME, &start, LEFT_GRAVITY);
    if (!mark)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_MARK (mark))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_get_iter_at_mark (buffer, &end, mark);
    if (gtk_text_iter_compare (&start, &end))
    {
        TEST_FAIL ("iters not equal (%i, %i) \n (%i, %i)", gtk_text_iter_get_line (&start), gtk_text_iter_get_offset (&start), 
                    gtk_text_iter_get_line (&end), gtk_text_iter_get_offset (&end)); 
    }
    
    
    #undef TEXT
    #undef NAME
    #undef LINE
    #undef OFFS
    #undef LEFT_GRAVITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_create_mark
 * Params: GtkTextBuffer *buffer, const gchar *mark_name, const GtkTextIter *where, gboolean left_gravity
 * Returns: GtkTextMark*
 * Assertion: Creates a mark at position where.
 * Params Values: GtkTextBuffer *buffer, const gchar *mark_name, const GtkTextIter *where, gboolean left_gravity
 * Expected: GtkTextMark*  
 */
static void test_purpose_159()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define NAME NULL
    #define LINE 0
    #define OFFS 19
    #define LEFT_GRAVITY FALSE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    mark = gtk_text_buffer_create_mark (buffer, NAME, &start, LEFT_GRAVITY);
    if (!mark)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_MARK (mark))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_get_iter_at_mark (buffer, &end, mark);
    if (gtk_text_iter_compare (&start, &end))
    {
        TEST_FAIL ("iters not equal (%i, %i) \n (%i, %i)", gtk_text_iter_get_line (&start), gtk_text_iter_get_offset (&start), 
                    gtk_text_iter_get_line (&end), gtk_text_iter_get_offset (&end)); 
    }
    
    
    #undef TEXT
    #undef NAME
    #undef LINE
    #undef OFFS
    #undef LEFT_GRAVITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_create_mark
 * Params: GtkTextBuffer *buffer, const gchar *mark_name, const GtkTextIter *where, gboolean left_gravity
 * Returns: GtkTextMark*
 * Assertion: Creates a mark at position where.
 * Params Values: GtkTextBuffer *buffer, const gchar *mark_name, const GtkTextIter *where, gboolean left_gravity
 * Expected: GtkTextMark*  
 */
static void test_purpose_160()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define NAME NULL
    #define LINE 1
    #define OFFS 20
    #define LEFT_GRAVITY FALSE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    mark = gtk_text_buffer_create_mark (buffer, NAME, &start, LEFT_GRAVITY);
    if (!mark)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_MARK (mark))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_get_iter_at_mark (buffer, &end, mark);
    if (gtk_text_iter_compare (&start, &end))
    {
        TEST_FAIL ("iters not equal (%i, %i) \n (%i, %i)", gtk_text_iter_get_line (&start), gtk_text_iter_get_offset (&start), 
                    gtk_text_iter_get_line (&end), gtk_text_iter_get_offset (&end)); 
    }
    
    
    #undef TEXT
    #undef NAME
    #undef LINE
    #undef OFFS
    #undef LEFT_GRAVITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_create_mark
 * Params: GtkTextBuffer *buffer, const gchar *mark_name, const GtkTextIter *where, gboolean left_gravity
 * Returns: GtkTextMark*
 * Assertion: If mark_name is NULL, the mark is anonymous; otherwise, the mark can be retrieved by name using gtk_text_buffer_get_mark().
 * Params Values: GtkTextBuffer *buffer, const gchar *mark_name, const GtkTextIter *where, gboolean left_gravity
 * Expected: GtkTextMark*  
 */
static void test_purpose_161()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define NAME "Mark 1"
    #define LINE 0
    #define OFFS 0
    #define LEFT_GRAVITY TRUE
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    mark = gtk_text_buffer_create_mark (buffer, NAME, &start, LEFT_GRAVITY);
    if (!mark)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_MARK (mark))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    if (NAME)
    {
        if (gtk_text_buffer_get_mark (buffer, NAME) != mark)
        {
            TEST_FAIL ("mark not found", NULL); 
        }
    }
    
    gtk_text_buffer_get_iter_at_mark (buffer, &end, mark);
    if (gtk_text_iter_compare (&start, &end))
    {
        TEST_FAIL ("iters not equal (%i, %i) \n (%i, %i)", gtk_text_iter_get_line (&start), gtk_text_iter_get_offset (&start), 
                    gtk_text_iter_get_line (&end), gtk_text_iter_get_offset (&end)); 
    }
    
    
    #undef TEXT
    #undef NAME
    #undef LINE
    #undef OFFS
    #undef LEFT_GRAVITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_create_mark
 * Params: GtkTextBuffer *buffer, const gchar *mark_name, const GtkTextIter *where, gboolean left_gravity
 * Returns: GtkTextMark*
 * Assertion: If mark_name is NULL, the mark is anonymous; otherwise, the mark can be retrieved by name using gtk_text_buffer_get_mark().
 * Params Values: GtkTextBuffer *buffer, const gchar *mark_name, const GtkTextIter *where, gboolean left_gravity
 * Expected: GtkTextMark*  
 */
static void test_purpose_162()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define NAME "Mark 1"
    #define LINE 0
    #define OFFS 19
    #define LEFT_GRAVITY FALSE
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    mark = gtk_text_buffer_create_mark (buffer, NAME, &start, LEFT_GRAVITY);
    if (!mark)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_MARK (mark))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    if (NAME)
    {
        if (gtk_text_buffer_get_mark (buffer, NAME) != mark)
        {
            TEST_FAIL ("mark not found", NULL); 
        }
    }
    
    gtk_text_buffer_get_iter_at_mark (buffer, &end, mark);
    if (gtk_text_iter_compare (&start, &end))
    {
        TEST_FAIL ("iters not equal (%i, %i) \n (%i, %i)", gtk_text_iter_get_line (&start), gtk_text_iter_get_offset (&start), 
                    gtk_text_iter_get_line (&end), gtk_text_iter_get_offset (&end)); 
    }
    
    
    #undef TEXT
    #undef NAME
    #undef LINE
    #undef OFFS
    #undef LEFT_GRAVITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_create_mark
 * Params: GtkTextBuffer *buffer, const gchar *mark_name, const GtkTextIter *where, gboolean left_gravity
 * Returns: GtkTextMark*
 * Assertion: If mark_name is NULL, the mark is anonymous; otherwise, the mark can be retrieved by name using gtk_text_buffer_get_mark().
 * Params Values: GtkTextBuffer *buffer, const gchar *mark_name, const GtkTextIter *where, gboolean left_gravity
 * Expected: GtkTextMark*  
 */
static void test_purpose_163()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define NAME "Mark 1"
    #define LINE 1
    #define OFFS 20
    #define LEFT_GRAVITY FALSE
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    mark = gtk_text_buffer_create_mark (buffer, NAME, &start, LEFT_GRAVITY);
    if (!mark)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_MARK (mark))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    if (NAME)
    {
        if (gtk_text_buffer_get_mark (buffer, NAME) != mark)
        {
            TEST_FAIL ("mark not found", NULL); 
        }
    }
    
    gtk_text_buffer_get_iter_at_mark (buffer, &end, mark);
    if (gtk_text_iter_compare (&start, &end))
    {
        TEST_FAIL ("iters not equal (%i, %i) \n (%i, %i)", gtk_text_iter_get_line (&start), gtk_text_iter_get_offset (&start), 
                    gtk_text_iter_get_line (&end), gtk_text_iter_get_offset (&end)); 
    }
    
    
    #undef TEXT
    #undef NAME
    #undef LINE
    #undef OFFS
    #undef LEFT_GRAVITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_create_mark
 * Params: GtkTextBuffer *buffer, const gchar *mark_name, const GtkTextIter *where, gboolean left_gravity
 * Returns: GtkTextMark*
 * Assertion: Emits the "mark_set" signal as notification of the mark's initial placement.'
 * Params Values: GtkTextBuffer *buffer, const gchar *mark_name, const GtkTextIter *where, gboolean left_gravity
 * Expected: GtkTextMark*  
 */
static void test_purpose_164()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define NAME "Mark 1"
    #define LINE 0
    #define OFFS 0
    #define LEFT_GRAVITY TRUE
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    g_signal_connect (G_OBJECT (buffer), "mark-set", GTK_SIGNAL_FUNC (global_mark), NULL);
    
    mark = gtk_text_buffer_create_mark (buffer, NAME, &start, LEFT_GRAVITY);
    if (!mark)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_MARK (mark))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    if (!modified_catched)
    {
        TEST_FAIL ("'mark_set' signal not catched", NULL);
    }
    
    #undef TEXT
    #undef NAME
    #undef LINE
    #undef OFFS
    #undef LEFT_GRAVITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_create_mark
 * Params: GtkTextBuffer *buffer, const gchar *mark_name, const GtkTextIter *where, gboolean left_gravity
 * Returns: GtkTextMark*
 * Assertion: Emits the "mark_set" signal as notification of the mark's initial placement.'
 * Params Values: GtkTextBuffer *buffer, const gchar *mark_name, const GtkTextIter *where, gboolean left_gravity
 * Expected: GtkTextMark*  
 */
static void test_purpose_165()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define NAME "Mark 1"
    #define LINE 0
    #define OFFS 19
    #define LEFT_GRAVITY FALSE
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    g_signal_connect (G_OBJECT (buffer), "mark-set", GTK_SIGNAL_FUNC (global_mark), NULL);
    
    mark = gtk_text_buffer_create_mark (buffer, NAME, &start, LEFT_GRAVITY);
    if (!mark)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_MARK (mark))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    if (!modified_catched)
    {
        TEST_FAIL ("'mark_set' signal not catched", NULL);
    }
    
    #undef TEXT
    #undef NAME
    #undef LINE
    #undef OFFS
    #undef LEFT_GRAVITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_create_mark
 * Params: GtkTextBuffer *buffer, const gchar *mark_name, const GtkTextIter *where, gboolean left_gravity
 * Returns: GtkTextMark*
 * Assertion: Emits the "mark_set" signal as notification of the mark's initial placement.'
 * Params Values: GtkTextBuffer *buffer, const gchar *mark_name, const GtkTextIter *where, gboolean left_gravity
 * Expected: GtkTextMark*  
 */
static void test_purpose_166()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define NAME "Mark 1"
    #define LINE 1
    #define OFFS 20
    #define LEFT_GRAVITY FALSE
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    g_signal_connect (G_OBJECT (buffer), "mark-set", GTK_SIGNAL_FUNC (global_mark), NULL);
    
    mark = gtk_text_buffer_create_mark (buffer, NAME, &start, LEFT_GRAVITY);
    if (!mark)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_MARK (mark))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    if (!modified_catched)
    {
        TEST_FAIL ("'mark_set' signal not catched", NULL);
    }
    
    #undef TEXT
    #undef NAME
    #undef LINE
    #undef OFFS
    #undef LEFT_GRAVITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_create_mark
 * Params: GtkTextBuffer *buffer, const gchar *mark_name, const GtkTextIter *where, gboolean left_gravity
 * Returns: GtkTextMark*
 * Assertion: If a mark has left gravity, and text is inserted at the mark's current location, the mark will be moved to the left of the newly-inserted text '
 * Params Values: GtkTextBuffer *buffer, const gchar *mark_name, const GtkTextIter *where, gboolean left_gravity
 * Expected: GtkTextMark*  
 */
static void test_purpose_167()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define NAME "Mark 1"
    #define LINE 0
    #define OFFS 0
    #define INSERT "insert"
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    mark = gtk_text_buffer_create_mark (buffer, NAME, &start, TRUE);
    if (!mark)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_insert (buffer, &start, INSERT, -1);
    gtk_text_buffer_get_iter_at_mark (buffer, &start, mark);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE, OFFS);
    if (gtk_text_iter_compare (&start, &end))
    {
        TEST_FAIL ("iters not equal (%i, %i) \n (%i, %i)", gtk_text_iter_get_line (&start), gtk_text_iter_get_offset (&start), 
                    gtk_text_iter_get_line (&end), gtk_text_iter_get_offset (&end)); 
    }
    
    
    #undef TEXT
    #undef NAME
    #undef LINE
    #undef OFFS
    #undef INSERT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_create_mark
 * Params: GtkTextBuffer *buffer, const gchar *mark_name, const GtkTextIter *where, gboolean left_gravity
 * Returns: GtkTextMark*
 * Assertion: If a mark has left gravity, and text is inserted at the mark's current location, the mark will be moved to the left of the newly-inserted text '
 * Params Values: GtkTextBuffer *buffer, const gchar *mark_name, const GtkTextIter *where, gboolean left_gravity
 * Expected: GtkTextMark*  
 */
static void test_purpose_168()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define NAME "Mark 1"
    #define LINE 1
    #define OFFS 20
    #define INSERT "insert"
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    mark = gtk_text_buffer_create_mark (buffer, NAME, &start, TRUE);
    if (!mark)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_insert (buffer, &start, INSERT, -1);
    gtk_text_buffer_get_iter_at_mark (buffer, &start, mark);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE, OFFS);
    if (gtk_text_iter_compare (&start, &end))
    {
        TEST_FAIL ("iters not equal (%i, %i) \n (%i, %i)", gtk_text_iter_get_line (&start), gtk_text_iter_get_offset (&start), 
                    gtk_text_iter_get_line (&end), gtk_text_iter_get_offset (&end)); 
    }
    
    
    #undef TEXT
    #undef NAME
    #undef LINE
    #undef OFFS
    #undef INSERT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_create_mark
 * Params: GtkTextBuffer *buffer, const gchar *mark_name, const GtkTextIter *where, gboolean left_gravity
 * Returns: GtkTextMark*
 * Assertion: If the mark has right gravity (left_gravity = FALSE), the mark will end up on the right of newly-inserted text.
 * Params Values: GtkTextBuffer *buffer, const gchar *mark_name, const GtkTextIter *where, gboolean left_gravity
 * Expected: GtkTextMark*  
 */
static void test_purpose_169()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define NAME "Mark 1"
    #define LINE 0
    #define OFFS 0
    #define INSERT "insert"
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE, OFFS);
    
    mark = gtk_text_buffer_create_mark (buffer, NAME, &start, FALSE);
    if (!mark)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_insert (buffer, &start, INSERT, -1);
    gtk_text_buffer_get_iter_at_mark (buffer, &end, mark);
    
    if (gtk_text_iter_compare (&start, &end))
    {
        TEST_FAIL ("iters not equal (%i, %i) \n (%i, %i)", gtk_text_iter_get_line (&start), gtk_text_iter_get_offset (&start), 
                    gtk_text_iter_get_line (&end), gtk_text_iter_get_offset (&end)); 
    }
    
    
    #undef TEXT
    #undef NAME
    #undef LINE
    #undef OFFS
    #undef INSERT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_create_mark
 * Params: GtkTextBuffer *buffer, const gchar *mark_name, const GtkTextIter *where, gboolean left_gravity
 * Returns: GtkTextMark*
 * Assertion: If the mark has right gravity (left_gravity = FALSE), the mark will end up on the right of newly-inserted text.
 * Params Values: GtkTextBuffer *buffer, const gchar *mark_name, const GtkTextIter *where, gboolean left_gravity
 * Expected: GtkTextMark*  
 */
static void test_purpose_170()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define NAME "Mark 1"
    #define LINE 1
    #define OFFS 20
    #define INSERT "insert"
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE, OFFS);
    
    mark = gtk_text_buffer_create_mark (buffer, NAME, &start, FALSE);
    if (!mark)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_insert (buffer, &start, INSERT, -1);
    gtk_text_buffer_get_iter_at_mark (buffer, &end, mark);
    
    if (gtk_text_iter_compare (&start, &end))
    {
        TEST_FAIL ("iters not equal (%i, %i) \n (%i, %i)", gtk_text_iter_get_line (&start), gtk_text_iter_get_offset (&start), 
                    gtk_text_iter_get_line (&end), gtk_text_iter_get_offset (&end)); 
    }
    
    
    #undef TEXT
    #undef NAME
    #undef LINE
    #undef OFFS
    #undef INSERT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_move_mark
 * Params: GtkTextBuffer *buffer, GtkTextMark *mark, const GtkTextIter *where
 * Returns: void
 * Assertion: Moves mark to the new location where.
 * Params Values: GtkTextBuffer *buffer, GtkTextMark *mark, const GtkTextIter *where
 * Expected: void  
 */
static void test_purpose_171()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 0
    #define LINE1 0
    #define OFFS1 19
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    
    mark = gtk_text_buffer_create_mark (buffer, "Mark 1", &start, TRUE);
    if (!mark)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_move_mark (buffer, mark, &end);
    
    if (gtk_text_buffer_get_mark (buffer, "Mark 1") != mark)
    {
        TEST_FAIL ("mark not found", NULL); 
    }
    
    gtk_text_buffer_get_iter_at_mark (buffer, &start, gtk_text_buffer_get_mark (buffer, "Mark 1"));
    if (gtk_text_iter_compare (&start, &end))
    {
        TEST_FAIL ("iters not equal (%i, %i) \n (%i, %i)", gtk_text_iter_get_line (&start), gtk_text_iter_get_offset (&start), 
                    gtk_text_iter_get_line (&end), gtk_text_iter_get_offset (&end)); 
    }
    
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_move_mark
 * Params: GtkTextBuffer *buffer, GtkTextMark *mark, const GtkTextIter *where
 * Returns: void
 * Assertion: Moves mark to the new location where.
 * Params Values: GtkTextBuffer *buffer, GtkTextMark *mark, const GtkTextIter *where
 * Expected: void  
 */
static void test_purpose_172()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 0
    #define LINE1 1
    #define OFFS1 20
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    
    mark = gtk_text_buffer_create_mark (buffer, "Mark 1", &start, TRUE);
    if (!mark)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_move_mark (buffer, mark, &end);
    
    if (gtk_text_buffer_get_mark (buffer, "Mark 1") != mark)
    {
        TEST_FAIL ("mark not found", NULL); 
    }
    
    gtk_text_buffer_get_iter_at_mark (buffer, &start, gtk_text_buffer_get_mark (buffer, "Mark 1"));
    if (gtk_text_iter_compare (&start, &end))
    {
        TEST_FAIL ("iters not equal (%i, %i) \n (%i, %i)", gtk_text_iter_get_line (&start), gtk_text_iter_get_offset (&start), 
                    gtk_text_iter_get_line (&end), gtk_text_iter_get_offset (&end)); 
    }
    
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_move_mark
 * Params: GtkTextBuffer *buffer, GtkTextMark *mark, const GtkTextIter *where
 * Returns: void
 * Assertion: Emits the "mark_set" signal as notification of the move.
 * Params Values: GtkTextBuffer *buffer, GtkTextMark *mark, const GtkTextIter *where
 * Expected: void  
 */
static void test_purpose_173()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 0
    #define LINE1 0
    #define OFFS1 19
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    g_signal_connect (G_OBJECT (buffer), "mark-set", GTK_SIGNAL_FUNC (global_mark), NULL);
    
    mark = gtk_text_buffer_create_mark (buffer, "Mark 1", &start, TRUE);
    if (!mark)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_move_mark (buffer, mark, &end);
    
    if (!modified_catched)
    {
        TEST_FAIL ("'mark_set' signal not catched", NULL);
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_move_mark
 * Params: GtkTextBuffer *buffer, GtkTextMark *mark, const GtkTextIter *where
 * Returns: void
 * Assertion: Emits the "mark_set" signal as notification of the move.
 * Params Values: GtkTextBuffer *buffer, GtkTextMark *mark, const GtkTextIter *where
 * Expected: void  
 */
static void test_purpose_174()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 0
    #define LINE1 1
    #define OFFS1 20
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    g_signal_connect (G_OBJECT (buffer), "mark-set", GTK_SIGNAL_FUNC (global_mark), NULL);
    
    mark = gtk_text_buffer_create_mark (buffer, "Mark 1", &start, TRUE);
    if (!mark)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_move_mark (buffer, mark, &end);
    
    if (!modified_catched)
    {
        TEST_FAIL ("'mark_set' signal not catched", NULL);
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_move_mark_by_name
 * Params: GtkTextBuffer *buffer, const gchar *name, const GtkTextIter *where
 * Returns: void
 * Assertion: Moves the mark named name (which must exist) to location where.
 * Params Values:  GtkTextBuffer *buffer, const gchar *name, const GtkTextIter *where
 * Expected: void  
 */
static void test_purpose_175()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define NAME "Mark"
    #define LINE 0
    #define OFFS 0
    #define LINE1 0
    #define OFFS1 19
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    
    mark = gtk_text_buffer_create_mark (buffer, NAME, &start, TRUE);
    if (!mark)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_move_mark_by_name (buffer, NAME, &end);
    
    if (gtk_text_buffer_get_mark (buffer, NAME) != mark)
    {
        TEST_FAIL ("mark not found", NULL); 
    }
    
    gtk_text_buffer_get_iter_at_mark (buffer, &start, gtk_text_buffer_get_mark (buffer, NAME));
    if (gtk_text_iter_compare (&start, &end))
    {
        TEST_FAIL ("iters not equal", NULL); 
    }
    
    
    #undef TEXT
    #undef NAME
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_move_mark_by_name
 * Params: GtkTextBuffer *buffer, const gchar *name, const GtkTextIter *where
 * Returns: void
 * Assertion: Moves the mark named name (which must exist) to location where.
 * Params Values:  GtkTextBuffer *buffer, const gchar *name, const GtkTextIter *where
 * Expected: void  
 */
static void test_purpose_176()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define NAME "Mark looooooooong name"
    #define LINE 0
    #define OFFS 0
    #define LINE1 1
    #define OFFS1 20
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    
    mark = gtk_text_buffer_create_mark (buffer, NAME, &start, TRUE);
    if (!mark)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_move_mark_by_name (buffer, NAME, &end);
    
    if (gtk_text_buffer_get_mark (buffer, NAME) != mark)
    {
        TEST_FAIL ("mark not found", NULL); 
    }
    
    gtk_text_buffer_get_iter_at_mark (buffer, &start, gtk_text_buffer_get_mark (buffer, NAME));
    if (gtk_text_iter_compare (&start, &end))
    {
        TEST_FAIL ("iters not equal", NULL); 
    }
    
    
    #undef TEXT
    #undef NAME
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_delete_mark
 * Params: GtkTextBuffer *buffer, GtkTextMark* mark
 * Returns: void
 * Assertion: Deletes mark, so that it's no longer located anywhere in the buffer.'
 * Params Values:  GtkTextBuffer *buffer, GtkTextMark* mark
 * Expected: void
 * 
 * Name:  gtk_text_buffer_delete_mark
 * Params: GtkTextBuffer *buffer, GtkTextMark* mark
 * Returns: void
 * Assertion: gtk_text_mark_get_deleted() will return TRUE after this function has been called on a mark; gtk_text_mark_get_deleted() indicates that a mark no longer belongs to a buffer
 * Params Values:  GtkTextBuffer *buffer, GtkTextMark* mark
 * Expected: void  
 */
static void test_purpose_177()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 0
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    mark = gtk_text_buffer_create_mark (buffer, "Mark 1", &start, TRUE);
    if (!mark)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_object_ref (mark);
    gtk_text_buffer_delete_mark (buffer, mark);
    
    if (gtk_text_buffer_get_mark (buffer, "Mark 1") != NULL)
    {
        TEST_FAIL ("mark still exists", NULL); 
    }
    
    if (!gtk_text_mark_get_deleted (mark))
    {
        TEST_FAIL ("gtk_text_mark_get_deleted () returns FALSE", NULL); 
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_delete_mark
 * Params: GtkTextBuffer *buffer, GtkTextMark* mark
 * Returns: void
 * Assertion: Deletes mark, so that it's no longer located anywhere in the buffer.'
 * Params Values:  GtkTextBuffer *buffer, GtkTextMark* mark
 * Expected: void
 * 
 * Name:  gtk_text_buffer_delete_mark
 * Params: GtkTextBuffer *buffer, GtkTextMark* mark
 * Returns: void
 * Assertion: gtk_text_mark_get_deleted() will return TRUE after this function has been called on a mark; gtk_text_mark_get_deleted() indicates that a mark no longer belongs to a buffer
 * Params Values:  GtkTextBuffer *buffer, GtkTextMark* mark
 * Expected: void  
 */
static void test_purpose_178()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 1
    #define OFFS 20
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    mark = gtk_text_buffer_create_mark (buffer, "Mark 1", &start, TRUE);
    if (!mark)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_object_ref (mark);
    gtk_text_buffer_delete_mark (buffer, mark);
    
    if (gtk_text_buffer_get_mark (buffer, "Mark 1") != NULL)
    {
        TEST_FAIL ("mark still exists", NULL); 
    }
    
    if (!gtk_text_mark_get_deleted (mark))
    {
        TEST_FAIL ("gtk_text_mark_get_deleted () returns FALSE", NULL); 
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_delete_mark
 * Params: GtkTextBuffer *buffer, GtkTextMark* mark
 * Returns: void
 * Assertion: The "mark_deleted" signal will be emitted as notification after the mark is deleted.
 * Params Values: GtkTextBuffer *buffer, GtkTextMark* mark 
 * Expected: void  
 */
static void test_purpose_179()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 19
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    g_signal_connect (G_OBJECT (buffer), "mark-deleted", GTK_SIGNAL_FUNC (global_mark), NULL);
    
    mark = gtk_text_buffer_create_mark (buffer, "Mark 1", &start, TRUE);
    if (!mark)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_delete_mark (buffer, mark);
    
    if (!modified_catched)
    {
        TEST_FAIL ("'mark_deleted' signal not catched", NULL);
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_delete_mark
 * Params: GtkTextBuffer *buffer, GtkTextMark* mark
 * Returns: void
 * Assertion: The "mark_deleted" signal will be emitted as notification after the mark is deleted.
 * Params Values: GtkTextBuffer *buffer, GtkTextMark* mark 
 * Expected: void  
 */
static void test_purpose_180()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 1
    #define OFFS 20
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    g_signal_connect (G_OBJECT (buffer), "mark-deleted", GTK_SIGNAL_FUNC (global_mark), NULL);
    
    mark = gtk_text_buffer_create_mark (buffer, "Mark 1", &start, TRUE);
    if (!mark)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_delete_mark (buffer, mark);
    
    if (!modified_catched)
    {
        TEST_FAIL ("'mark_deleted' signal not catched", NULL);
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_delete_mark_by_name
 * Params: GtkTextBuffer *buffer, const gchar* name
 * Returns: void
 * Assertion: Deletes the mark named name; the mark must exist.
 * Params Values:  GtkTextBuffer *buffer, const gchar* name
 * Expected: void  
 */
static void test_purpose_181()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define NAME "Mark"
    #define LINE 0
    #define OFFS 0
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    mark = gtk_text_buffer_create_mark (buffer, NAME, &start, TRUE);
    if (!mark)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_object_ref (mark);
    gtk_text_buffer_delete_mark_by_name (buffer, NAME);
    
    if (gtk_text_buffer_get_mark (buffer, NAME) != NULL)
    {
        TEST_FAIL ("mark still exists", NULL); 
    }
    
    if (!gtk_text_mark_get_deleted (mark))
    {
        TEST_FAIL ("gtk_text_mark_get_deleted () returns FALSE", NULL); 
    }
    
    #undef TEXT
    #undef NAME
    #undef LINE
    #undef OFFS
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_delete_mark_by_name
 * Params: GtkTextBuffer *buffer, const gchar* name
 * Returns: void
 * Assertion: Deletes the mark named name; the mark must exist.
 * Params Values:  GtkTextBuffer *buffer, const gchar* name
 * Expected: void  
 */
static void test_purpose_182()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define NAME "Mark 1"
    #define LINE 1
    #define OFFS 20
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    mark = gtk_text_buffer_create_mark (buffer, NAME, &start, TRUE);
    if (!mark)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_object_ref (mark);
    gtk_text_buffer_delete_mark_by_name (buffer, NAME);
    
    if (gtk_text_buffer_get_mark (buffer, NAME) != NULL)
    {
        TEST_FAIL ("mark still exists", NULL); 
    }
    
    if (!gtk_text_mark_get_deleted (mark))
    {
        TEST_FAIL ("gtk_text_mark_get_deleted () returns FALSE", NULL); 
    }
    
    #undef TEXT
    #undef NAME
    #undef LINE
    #undef OFFS
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_place_cursor
 * Params: GtkTextBuffer *buffer, const GtkTextIter *where
 * Returns: void
 * Assertion: This function moves the "insert" and "selection_bound" marks simultaneously.
 * Params Values: GtkTextBuffer *buffer, const GtkTextIter *where
 * Expected: void  
 */
static void test_purpose_183()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 1
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    gtk_text_buffer_place_cursor (buffer, &start);
    
    gtk_text_buffer_get_iter_at_mark (buffer, &end, gtk_text_buffer_get_mark (buffer, "insert"));
    if (gtk_text_iter_compare (&start, &end))
    {
        TEST_FAIL ("'insert' mark not moved", NULL); 
    }
    
    gtk_text_buffer_get_iter_at_mark (buffer, &end, gtk_text_buffer_get_mark (buffer, "selection_bound"));
    if (gtk_text_iter_compare (&start, &end))
    {
        TEST_FAIL ("'selection_bound' mark not moved", NULL); 
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_place_cursor
 * Params: GtkTextBuffer *buffer, const GtkTextIter *where
 * Returns: void
 * Assertion: This function moves the "insert" and "selection_bound" marks simultaneously.
 * Params Values: GtkTextBuffer *buffer, const GtkTextIter *where
 * Expected: void  
 */
static void test_purpose_184()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 1
    #define OFFS 20
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    gtk_text_buffer_place_cursor (buffer, &start);
    
    gtk_text_buffer_get_iter_at_mark (buffer, &end, gtk_text_buffer_get_mark (buffer, "insert"));
    if (gtk_text_iter_compare (&start, &end))
    {
        TEST_FAIL ("'insert' mark not moved", NULL); 
    }
    
    gtk_text_buffer_get_iter_at_mark (buffer, &end, gtk_text_buffer_get_mark (buffer, "selection_bound"));
    if (gtk_text_iter_compare (&start, &end))
    {
        TEST_FAIL ("'selection_bound' mark not moved", NULL); 
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_apply_tag
 * Params: GtkTextBuffer *buffer, GtkTextTag *tag, const GtkTextIter *start, const GtkTextIter *end
 * Returns: void
 * Assertion: Emits the "apply_tag" signal on buffer.
 * Params Values: GtkTextBuffer *buffer, GtkTextTag *tag, const GtkTextIter *start, const GtkTextIter *end
 * Expected: void
 * 
 * Name:  gtk_text_buffer_apply_tag
 * Params: GtkTextBuffer *buffer, GtkTextTag *tag, const GtkTextIter *start, const GtkTextIter *end
 * Returns: void
 * Assertion: The default handler for the signal applies tag to the given range.
 * Params Values: GtkTextBuffer *buffer, GtkTextTag *tag, const GtkTextIter *start, const GtkTextIter *end
 * Expected: void  
 */
static void test_purpose_185()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 0
    #define LINE1 0
    #define OFFS1 19
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    g_signal_connect (G_OBJECT (buffer), "apply-tag", GTK_SIGNAL_FUNC (global_tag), NULL);
    
    tag = gtk_text_tag_new ("Tag");
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    if (!modified_catched)
    {
        TEST_FAIL ("'apply-tag' signal not catched", NULL);
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_apply_tag
 * Params: GtkTextBuffer *buffer, GtkTextTag *tag, const GtkTextIter *start, const GtkTextIter *end
 * Returns: void
 * Assertion: Emits the "apply_tag" signal on buffer.
 * Params Values: GtkTextBuffer *buffer, GtkTextTag *tag, const GtkTextIter *start, const GtkTextIter *end
 * Expected: void
 * 
 * Name:  gtk_text_buffer_apply_tag
 * Params: GtkTextBuffer *buffer, GtkTextTag *tag, const GtkTextIter *start, const GtkTextIter *end
 * Returns: void
 * Assertion: The default handler for the signal applies tag to the given range.
 * Params Values: GtkTextBuffer *buffer, GtkTextTag *tag, const GtkTextIter *start, const GtkTextIter *end
 * Expected: void  
 */
static void test_purpose_186()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 0
    #define LINE1 1
    #define OFFS1 20
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    g_signal_connect (G_OBJECT (buffer), "apply-tag", GTK_SIGNAL_FUNC (global_tag), NULL);
    
    tag = gtk_text_tag_new ("Tag");
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    if (!modified_catched)
    {
        TEST_FAIL ("'apply-tag' signal not catched", NULL);
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_remove_tag
 * Params: GtkTextBuffer *buffer, GtkTextTag *tag, const GtkTextIter *start, const GtkTextIter *end
 * Returns: void
 * Assertion: Emits the "remove_tag" signal.
 * Params Values: GtkTextBuffer *buffer, GtkTextTag *tag, const GtkTextIter *start, const GtkTextIter *end
 * Expected: void
 * 
 * Name:  gtk_text_buffer_remove_tag
 * Params: GtkTextBuffer *buffer, GtkTextTag *tag, const GtkTextIter *start, const GtkTextIter *end
 * Returns: void
 * Assertion: The default handler for the signal removes all occurrences of tag from the given range
 * Params Values: GtkTextBuffer *buffer, GtkTextTag *tag, const GtkTextIter *start, const GtkTextIter *end
 * Expected: void  
 */
static void test_purpose_187()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 0
    #define LINE1 0
    #define OFFS1 19
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    GSList* list;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    g_signal_connect (G_OBJECT (buffer), "remove-tag", GTK_SIGNAL_FUNC (global_tag), NULL);
    
    tag = gtk_text_tag_new ("Tag");
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    gtk_text_buffer_remove_tag (buffer, tag, &start, &end);
    
    if (!modified_catched)
    {
        TEST_FAIL ("'remove-tag' signal not catched", NULL);
    }
    
    list = gtk_text_iter_get_tags (&start);
    if (list)
    {
        TEST_FAIL ("tag list should be NULL", NULL);
        return;
    }
    
    list = gtk_text_iter_get_tags (&end);
    if (list)
    {
        TEST_FAIL ("tag list should be NULL", NULL);
        return;
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_remove_tag
 * Params: GtkTextBuffer *buffer, GtkTextTag *tag, const GtkTextIter *start, const GtkTextIter *end
 * Returns: void
 * Assertion: Emits the "remove_tag" signal.
 * Params Values: GtkTextBuffer *buffer, GtkTextTag *tag, const GtkTextIter *start, const GtkTextIter *end
 * Expected: void
 * 
 * Name:  gtk_text_buffer_remove_tag
 * Params: GtkTextBuffer *buffer, GtkTextTag *tag, const GtkTextIter *start, const GtkTextIter *end
 * Returns: void
 * Assertion: The default handler for the signal removes all occurrences of tag from the given range
 * Params Values: GtkTextBuffer *buffer, GtkTextTag *tag, const GtkTextIter *start, const GtkTextIter *end
 * Expected: void  
 */
static void test_purpose_188()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 0
    #define LINE1 1
    #define OFFS1 20
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    GSList* list;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    g_signal_connect (G_OBJECT (buffer), "remove-tag", GTK_SIGNAL_FUNC (global_tag), NULL);
    
    tag = gtk_text_tag_new ("Tag");
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    gtk_text_buffer_remove_tag (buffer, tag, &start, &end);
    
    if (!modified_catched)
    {
        TEST_FAIL ("'remove-tag' signal not catched", NULL);
    }
    
    list = gtk_text_iter_get_tags (&start);
    if (list)
    {
        TEST_FAIL ("tag list should be NULL", NULL);
        return;
    }
    
    list = gtk_text_iter_get_tags (&end);
    if (list)
    {
        TEST_FAIL ("tag list should be NULL", NULL);
        return;
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_apply_tag_by_name
 * Params: GtkTextBuffer *buffer, const gchar* name, const GtkTextIter *start, const GtkTextIter *end
 * Returns: void
 * Assertion: Calls gtk_text_tag_table_lookup() on the buffer's tag table to get a GtkTextTag, then calls gtk_text_buffer_apply_tag().'
 * Params Values: GtkTextBuffer *buffer, const gchar* name, const GtkTextIter *start, const GtkTextIter *end
 * Expected: void  
 */
static void test_purpose_189()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define NAME "Tag"
    #define LINE 0
    #define OFFS 0
    #define LINE1 0
    #define OFFS1 19
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    g_signal_connect (G_OBJECT (buffer), "apply-tag", GTK_SIGNAL_FUNC (global_tag), NULL);
    
    tag = gtk_text_tag_new (NAME);
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    
    if (tag != gtk_text_tag_table_lookup (gtk_text_buffer_get_tag_table (buffer), NAME))
    {
        TEST_FAIL ("gtk_text_tag_table_lookup () not found tag", NULL);
    }
    
    gtk_text_buffer_apply_tag_by_name (buffer, NAME, &start, &end);
    
    if (!modified_catched)
    {
        TEST_FAIL ("'apply-tag' signal not catched", NULL);
    }
    
    #undef TEXT
    #undef NAME
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_apply_tag_by_name
 * Params: GtkTextBuffer *buffer, const gchar* name, const GtkTextIter *start, const GtkTextIter *end
 * Returns: void
 * Assertion: Calls gtk_text_tag_table_lookup() on the buffer's tag table to get a GtkTextTag, then calls gtk_text_buffer_apply_tag().'
 * Params Values: GtkTextBuffer *buffer, const gchar* name, const GtkTextIter *start, const GtkTextIter *end
 * Expected: void  
 */
static void test_purpose_190()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define NAME "tag loooooooooooooooong name"
    #define LINE 0
    #define OFFS 0
    #define LINE1 1
    #define OFFS1 20
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    g_signal_connect (G_OBJECT (buffer), "apply-tag", GTK_SIGNAL_FUNC (global_tag), NULL);
    
    tag = gtk_text_tag_new (NAME);
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    
    if (tag != gtk_text_tag_table_lookup (gtk_text_buffer_get_tag_table (buffer), NAME))
    {
        TEST_FAIL ("gtk_text_tag_table_lookup () not found tag", NULL);
    }
    
    gtk_text_buffer_apply_tag_by_name (buffer, NAME, &start, &end);
    
    if (!modified_catched)
    {
        TEST_FAIL ("'apply-tag' signal not catched", NULL);
    }
    
    #undef TEXT
    #undef NAME
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_remove_tag_by_name
 * Params: GtkTextBuffer *buffer, const gchar* name, const GtkTextIter *start, const GtkTextIter *end
 * Returns: void
 * Assertion: Calls gtk_text_tag_table_lookup() on the buffer's tag table to get a GtkTextTag, then calls gtk_text_buffer_remove_tag().'
 * Params Values: GtkTextBuffer *buffer, const gchar* name, const GtkTextIter *start, const GtkTextIter *end
 * Expected: void  
 */
static void test_purpose_191()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define NAME "Tag"
    #define LINE 0
    #define OFFS 0
    #define LINE1 0
    #define OFFS1 19
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    g_signal_connect (G_OBJECT (buffer), "remove-tag", GTK_SIGNAL_FUNC (global_tag), NULL);
    
    tag = gtk_text_tag_new (NAME);
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    
    if (tag != gtk_text_tag_table_lookup (gtk_text_buffer_get_tag_table (buffer), NAME))
    {
        TEST_FAIL ("gtk_text_tag_table_lookup () not found tag", NULL);
    }
    
    gtk_text_buffer_apply_tag_by_name (buffer, NAME, &start, &end);
    
    gtk_text_buffer_remove_tag_by_name (buffer, NAME, &start, &end);
    
    if (!modified_catched)
    {
        TEST_FAIL ("'remove-tag' signal not catched", NULL);
    }
    
    #undef TEXT
    #undef NAME
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_remove_tag_by_name
 * Params: GtkTextBuffer *buffer, const gchar* name, const GtkTextIter *start, const GtkTextIter *end
 * Returns: void
 * Assertion: Calls gtk_text_tag_table_lookup() on the buffer's tag table to get a GtkTextTag, then calls gtk_text_buffer_remove_tag().'
 * Params Values: GtkTextBuffer *buffer, const gchar* name, const GtkTextIter *start, const GtkTextIter *end
 * Expected: void  
 */
static void test_purpose_192()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define NAME "tag loooooooooooooooong name"
    #define LINE 0
    #define OFFS 0
    #define LINE1 1
    #define OFFS1 20
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    g_signal_connect (G_OBJECT (buffer), "remove-tag", GTK_SIGNAL_FUNC (global_tag), NULL);
    
    tag = gtk_text_tag_new (NAME);
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    
    if (tag != gtk_text_tag_table_lookup (gtk_text_buffer_get_tag_table (buffer), NAME))
    {
        TEST_FAIL ("gtk_text_tag_table_lookup () not found tag", NULL);
    }
    
    gtk_text_buffer_apply_tag_by_name (buffer, NAME, &start, &end);
    
    gtk_text_buffer_remove_tag_by_name (buffer, NAME, &start, &end);
    
    if (!modified_catched)
    {
        TEST_FAIL ("'remove-tag' signal not catched", NULL);
    }
    
    #undef TEXT
    #undef NAME
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_remove_all_tags
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end
 * Returns: void
 * Assertion: Removes all tags in the range between start and end.
 * Params Values: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end
 * Expected: void  
 */
static void test_purpose_193()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 0
    #define LINE1 0
    #define OFFS1 19
    #define DLINE 0
    #define DOFFS 1
    #define DLINE1 0
    #define DOFFS1 2
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    GdkRectangle r1;
    GdkRectangle r2;
    GdkRectangle r3;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    g_signal_connect (G_OBJECT (buffer), "remove-tag", GTK_SIGNAL_FUNC (global_tag), NULL);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    tag = gtk_text_tag_new ("Tag");
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    r1.x = OFFS;
    r1.y = LINE;
    r1.width = OFFS1 - OFFS + 1;
    r1.height = LINE1 - LINE + 1;
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, DLINE, DOFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, DLINE1, DOFFS1);
    gtk_text_buffer_remove_all_tags (buffer, &start, &end);
    r2.x = DOFFS;
    r2.y = DLINE;
    r2.width = DOFFS1 - DOFFS + 1;
    r2.height = DLINE1 - DLINE + 1;
    
    tag = gtk_text_tag_table_lookup (gtk_text_buffer_get_tag_table (buffer), "Tag");
    
    if (gdk_rectangle_intersect (&r1, &r2, &r3))
    {
        if ((r1.x == r3.x) && (r1.y == r3.y) && (r1.width == r3.width) && (r1.height == r3.height))
        {
            if (tag)
            { 
                TEST_FAIL ("Tag should be deleted\n r1=(%i, %i, %i, %i)\n r2=(%i, %i, %i, %i)\n r3=(%i, %i, %i, %i)", 
                           r1.x, r1.y, r1.width, r1.height,  r2.x, r2.y, r2.width, r2.height,  r3.x, r3.y, r3.width, r3.height);
            }
        }
    
        if (!modified_catched)
        {
            TEST_FAIL ("Tag should be deleted", NULL);
        } 
    
    } else {
    
        if (!tag)
        {
            TEST_FAIL ("Tag not found", NULL);
        }
    
        if (modified_catched)
        {
            TEST_FAIL ("Rectangles doesn't intersect but tag deleted", NULL);
        }
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef DLINE
    #undef DOFFS
    #undef DLINE1
    #undef DOFFS1
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_remove_all_tags
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end
 * Returns: void
 * Assertion: Removes all tags in the range between start and end.
 * Params Values: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end
 * Expected: void  
 */
static void test_purpose_194()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 1
    #define LINE1 1
    #define OFFS1 20
    #define DLINE 0
    #define DOFFS 0
    #define DLINE1 0
    #define DOFFS1 5
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    GdkRectangle r1;
    GdkRectangle r2;
    GdkRectangle r3;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    g_signal_connect (G_OBJECT (buffer), "remove-tag", GTK_SIGNAL_FUNC (global_tag), NULL);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    tag = gtk_text_tag_new ("Tag");
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    r1.x = OFFS;
    r1.y = LINE;
    r1.width = OFFS1 - OFFS + 1;
    r1.height = LINE1 - LINE + 1;
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, DLINE, DOFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, DLINE1, DOFFS1);
    gtk_text_buffer_remove_all_tags (buffer, &start, &end);
    r2.x = DOFFS;
    r2.y = DLINE;
    r2.width = DOFFS1 - DOFFS + 1;
    r2.height = DLINE1 - DLINE + 1;
    
    tag = gtk_text_tag_table_lookup (gtk_text_buffer_get_tag_table (buffer), "Tag");
    
    if (gdk_rectangle_intersect (&r1, &r2, &r3))
    {
        if ((r1.x == r3.x) && (r1.y == r3.y) && (r1.width == r3.width) && (r1.height == r3.height))
        {
            if (tag)
            { 
                TEST_FAIL ("Tag should be deleted\n r1=(%i, %i, %i, %i)\n r2=(%i, %i, %i, %i)\n r3=(%i, %i, %i, %i)", 
                           r1.x, r1.y, r1.width, r1.height,  r2.x, r2.y, r2.width, r2.height,  r3.x, r3.y, r3.width, r3.height);
            }
        }
    
        if (!modified_catched)
        {
            TEST_FAIL ("Tag should be deleted", NULL);
        } 
    
    } else {
    
        if (!tag)
        {
            TEST_FAIL ("Tag not found", NULL);
        }
    
        if (modified_catched)
        {
            TEST_FAIL ("Rectangles doesn't intersect but tag deleted", NULL);
        }
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef DLINE
    #undef DOFFS
    #undef DLINE1
    #undef DOFFS1
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_remove_all_tags
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end
 * Returns: void
 * Assertion: Removes all tags in the range between start and end.
 * Params Values: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end
 * Expected: void  
 */
static void test_purpose_195()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 1
    #define LINE1 1
    #define OFFS1 15
    #define DLINE 1
    #define DOFFS 0
    #define DLINE1 1
    #define DOFFS1 20
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    GdkRectangle r1;
    GdkRectangle r2;
    GdkRectangle r3;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    g_signal_connect (G_OBJECT (buffer), "remove-tag", GTK_SIGNAL_FUNC (global_tag), NULL);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    tag = gtk_text_tag_new ("Tag");
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    r1.x = OFFS;
    r1.y = LINE;
    r1.width = OFFS1 - OFFS + 1;
    r1.height = LINE1 - LINE + 1;
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, DLINE, DOFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, DLINE1, DOFFS1);
    gtk_text_buffer_remove_all_tags (buffer, &start, &end);
    r2.x = DOFFS;
    r2.y = DLINE;
    r2.width = DOFFS1 - DOFFS + 1;
    r2.height = DLINE1 - DLINE + 1;
    
    tag = gtk_text_tag_table_lookup (gtk_text_buffer_get_tag_table (buffer), "Tag");
    
    if (gdk_rectangle_intersect (&r1, &r2, &r3))
    {
        if ((r1.x == r3.x) && (r1.y == r3.y) && (r1.width == r3.width) && (r1.height == r3.height))
        {
            if (tag)
            { 
                TEST_FAIL ("Tag should be deleted\n r1=(%i, %i, %i, %i)\n r2=(%i, %i, %i, %i)\n r3=(%i, %i, %i, %i)", 
                           r1.x, r1.y, r1.width, r1.height,  r2.x, r2.y, r2.width, r2.height,  r3.x, r3.y, r3.width, r3.height);
            }
        }
    
        if (!modified_catched)
        {
            TEST_FAIL ("Tag should be deleted", NULL);
        } 
    
    } else {
    
        if (!tag)
        {
            TEST_FAIL ("Tag not found", NULL);
        }
    
        if (modified_catched)
        {
            TEST_FAIL ("Rectangles doesn't intersect but tag deleted", NULL);
        }
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef DLINE
    #undef DOFFS
    #undef DLINE1
    #undef DOFFS1
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_remove_all_tags
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end
 * Returns: void
 * Assertion: Removes all tags in the range between start and end.
 * Params Values: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end
 * Expected: void  
 */
static void test_purpose_196()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 1
    #define LINE1 0
    #define OFFS1 5
    #define DLINE 1
    #define DOFFS 0
    #define DLINE1 1
    #define DOFFS1 5
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    GdkRectangle r1;
    GdkRectangle r2;
    GdkRectangle r3;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    g_signal_connect (G_OBJECT (buffer), "remove-tag", GTK_SIGNAL_FUNC (global_tag), NULL);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    tag = gtk_text_tag_new ("Tag");
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    r1.x = OFFS;
    r1.y = LINE;
    r1.width = OFFS1 - OFFS + 1;
    r1.height = LINE1 - LINE + 1;
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, DLINE, DOFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, DLINE1, DOFFS1);
    gtk_text_buffer_remove_all_tags (buffer, &start, &end);
    r2.x = DOFFS;
    r2.y = DLINE;
    r2.width = DOFFS1 - DOFFS + 1;
    r2.height = DLINE1 - DLINE + 1;
    
    tag = gtk_text_tag_table_lookup (gtk_text_buffer_get_tag_table (buffer), "Tag");
    
    if (gdk_rectangle_intersect (&r1, &r2, &r3))
    {
        if ((r1.x == r3.x) && (r1.y == r3.y) && (r1.width == r3.width) && (r1.height == r3.height))
        {
            if (tag)
            { 
                TEST_FAIL ("Tag should be deleted\n r1=(%i, %i, %i, %i)\n r2=(%i, %i, %i, %i)\n r3=(%i, %i, %i, %i)", 
                           r1.x, r1.y, r1.width, r1.height,  r2.x, r2.y, r2.width, r2.height,  r3.x, r3.y, r3.width, r3.height);
            }
        }
    
        if (!modified_catched)
        {
            TEST_FAIL ("Tag should be deleted", NULL);
        } 
    
    } else {
    
        if (!tag)
        {
            TEST_FAIL ("Tag not found", NULL);
        }
    
        if (modified_catched)
        {
            TEST_FAIL ("Rectangles doesn't intersect but tag deleted", NULL);
        }
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef DLINE
    #undef DOFFS
    #undef DLINE1
    #undef DOFFS1
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_remove_all_tags
 * Params: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end
 * Returns: void
 * Assertion: Removes all tags in the range between start and end.
 * Params Values: GtkTextBuffer *buffer, const GtkTextIter *start, const GtkTextIter *end
 * Expected: void  
 */
static void test_purpose_197()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define LINE 0
    #define OFFS 1
    #define LINE1 0
    #define OFFS1 5
    #define DLINE 0
    #define DOFFS 4
    #define DLINE1 0
    #define DOFFS1 10
    
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    GdkRectangle r1;
    GdkRectangle r2;
    GdkRectangle r3;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    g_signal_connect (G_OBJECT (buffer), "remove-tag", GTK_SIGNAL_FUNC (global_tag), NULL);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    tag = gtk_text_tag_new ("Tag");
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    r1.x = OFFS;
    r1.y = LINE;
    r1.width = OFFS1 - OFFS + 1;
    r1.height = LINE1 - LINE + 1;
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, DLINE, DOFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, DLINE1, DOFFS1);
    gtk_text_buffer_remove_all_tags (buffer, &start, &end);
    r2.x = DOFFS;
    r2.y = DLINE;
    r2.width = DOFFS1 - DOFFS + 1;
    r2.height = DLINE1 - DLINE + 1;
    
    tag = gtk_text_tag_table_lookup (gtk_text_buffer_get_tag_table (buffer), "Tag");
    
    if (gdk_rectangle_intersect (&r1, &r2, &r3))
    {
        if ((r1.x == r3.x) && (r1.y == r3.y) && (r1.width == r3.width) && (r1.height == r3.height))
        {
            if (tag)
            { 
                TEST_FAIL ("Tag should be deleted\n r1=(%i, %i, %i, %i)\n r2=(%i, %i, %i, %i)\n r3=(%i, %i, %i, %i)", 
                           r1.x, r1.y, r1.width, r1.height,  r2.x, r2.y, r2.width, r2.height,  r3.x, r3.y, r3.width, r3.height);
            }
        }
    
        if (!modified_catched)
        {
            TEST_FAIL ("Tag should be deleted", NULL);
        } 
    
    } else {
    
        if (!tag)
        {
            TEST_FAIL ("Tag not found", NULL);
        }
    
        if (modified_catched)
        {
            TEST_FAIL ("Rectangles doesn't intersect but tag deleted", NULL);
        }
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef DLINE
    #undef DOFFS
    #undef DLINE1
    #undef DOFFS1
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_create_tag
 * Params: GtkTextBuffer *buffer, const gchar *tag_name, const gchar *first_property_name, ...
 * Returns: GtkTextTag*
 * Assertion: Creates a tag and adds it to the tag table for buffer.
 * Params Values: GtkTextBuffer *buffer, const gchar *tag_name, const gchar *first_property_name, ...
 * Expected: GtkTextTag*
 * 
 * Name: gtk_text_buffer_create_tag
 * Params: GtkTextBuffer *buffer, const gchar *tag_name, const gchar *first_property_name, ...
 * Returns: GtkTextTag*
 * Assertion: Equivalent to calling gtk_text_tag_new() and then adding the tag to the buffer's tag table.'
 * Params Values: GtkTextBuffer *buffer, const gchar *tag_name, const gchar *first_property_name, ...
 * Expected: GtkTextTag*
 * 
 * Name: gtk_text_buffer_create_tag
 * Params: GtkTextBuffer *buffer, const gchar *tag_name, const gchar *first_property_name, ...
 * Returns: GtkTextTag*
 * Assertion: The returned tag is owned by the buffer's tag table, so the ref count will be equal to one.'
 * Params Values: GtkTextBuffer *buffer, const gchar *tag_name, const gchar *first_property_name, ...
 * Expected: GtkTextTag*  
 */
static void test_purpose_198()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define NAME "Tag 1"
    #define ARG "editable"
    #define VALUE TRUE
    #define TYPE gboolean
    
    GtkTextBuffer* buffer;
    GtkTextTag* tag;
    TYPE value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    tag = gtk_text_buffer_create_tag (buffer, NAME, ARG, VALUE, NULL);
    
    if (G_OBJECT (tag)->ref_count != 1)
    {
        TEST_FAIL ("Tag count = %i, should be 1", G_OBJECT (tag)->ref_count);
    }
    
    if (NAME)
    {
        if (tag != gtk_text_tag_table_lookup (gtk_text_buffer_get_tag_table (buffer), NAME))
        {
            TEST_FAIL ("%s not found %p %p", NAME, tag, gtk_text_tag_table_lookup (gtk_text_buffer_get_tag_table (buffer), NAME));
        }
    }
    g_object_get (tag, ARG, &value, NULL);
    
    if (value != (TYPE)VALUE)
    {
        TEST_FAIL ("Arg ""%s"" doesn't set correct", ARG);
    }
    
    #undef TEXT
    #undef NAME
    #undef PARAMS
    #undef ARG
    #undef VALUE
    #undef TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_create_tag
 * Params: GtkTextBuffer *buffer, const gchar *tag_name, const gchar *first_property_name, ...
 * Returns: GtkTextTag*
 * Assertion: Creates a tag and adds it to the tag table for buffer.
 * Params Values: GtkTextBuffer *buffer, const gchar *tag_name, const gchar *first_property_name, ...
 * Expected: GtkTextTag*
 * 
 * Name: gtk_text_buffer_create_tag
 * Params: GtkTextBuffer *buffer, const gchar *tag_name, const gchar *first_property_name, ...
 * Returns: GtkTextTag*
 * Assertion: Equivalent to calling gtk_text_tag_new() and then adding the tag to the buffer's tag table.'
 * Params Values: GtkTextBuffer *buffer, const gchar *tag_name, const gchar *first_property_name, ...
 * Expected: GtkTextTag*
 * 
 * Name: gtk_text_buffer_create_tag
 * Params: GtkTextBuffer *buffer, const gchar *tag_name, const gchar *first_property_name, ...
 * Returns: GtkTextTag*
 * Assertion: The returned tag is owned by the buffer's tag table, so the ref count will be equal to one.'
 * Params Values: GtkTextBuffer *buffer, const gchar *tag_name, const gchar *first_property_name, ...
 * Expected: GtkTextTag*  
 */
static void test_purpose_199()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define NAME "Tag 2"
    #define ARG "size"
    #define VALUE 10
    #define TYPE gint
    
    GtkTextBuffer* buffer;
    GtkTextTag* tag;
    TYPE value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    tag = gtk_text_buffer_create_tag (buffer, NAME, ARG, VALUE, NULL);
    
    if (G_OBJECT (tag)->ref_count != 1)
    {
        TEST_FAIL ("Tag count = %i, should be 1", G_OBJECT (tag)->ref_count);
    }
    
    if (NAME)
    {
        if (tag != gtk_text_tag_table_lookup (gtk_text_buffer_get_tag_table (buffer), NAME))
        {
            TEST_FAIL ("%s not found %p %p", NAME, tag, gtk_text_tag_table_lookup (gtk_text_buffer_get_tag_table (buffer), NAME));
        }
    }
    g_object_get (tag, ARG, &value, NULL);
    
    if (value != (TYPE)VALUE)
    {
        TEST_FAIL ("Arg ""%s"" doesn't set correct", ARG);
    }
    
    #undef TEXT
    #undef NAME
    #undef PARAMS
    #undef ARG
    #undef VALUE
    #undef TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_create_tag
 * Params: GtkTextBuffer *buffer, const gchar *tag_name, const gchar *first_property_name, ...
 * Returns: GtkTextTag*
 * Assertion: If tag_name is NULL, the tag is anonymous.
 * Params Values: GtkTextBuffer *buffer, const gchar *tag_name, const gchar *first_property_name, ...
 * Expected: GtkTextTag*  
 */
static void test_purpose_200()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define ARG "editable"
    #define VALUE TRUE
    #define TYPE gboolean
    
    GtkTextBuffer* buffer;
    GtkTextTag* tag;
    TYPE value;
    gchar* real_name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    tag = gtk_text_buffer_create_tag (buffer, NULL, ARG, VALUE, NULL);
    
    g_object_get (tag, "name", &real_name, NULL);
    if (real_name != NULL)
    {
        TEST_FAIL ("name is '%s', should be NULL for anonymous tags", real_name);
    }
    
    #undef TEXT
    #undef ARG
    #undef VALUE
    #undef TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_delete_selection
 * Params: GtkTextBuffer *buffer, gboolean interactive, gboolean default_editable
 * Returns:  gboolean
 * Assertion: Deletes the range between the "insert" and "selection_bound" marks, that is, the currently-selected text. 
 * Params Values: GtkTextBuffer *buffer, 5, TRUE
 * Expected: gboolean
 * 
 * Name: gtk_text_buffer_delete_selection
 * Params: GtkTextBuffer *buffer, gboolean interactive, gboolean default_editable
 * Returns:  gboolean
 * Assertion: If interactive is TRUE, the editability of the selection will be considered (users can't delete uneditable text).'
 * Params Values: GtkTextBuffer *buffer, 5, TRUE
 * Expected: gboolean  
 */
static void test_purpose_201()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    #define LINE 0
    #define OFFS 0
    #define LINE1 0
    #define OFFS1 5
    #define DEF_EDITABLE TRUE
    #define INTERACTIVE TRUE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    gchar* text;
    gchar* text1;
    gchar* deleted;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    tag = gtk_text_tag_new ("Tag");
    g_object_set (tag, "editable", (gboolean) DEF_EDITABLE, NULL);
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    deleted = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    gtk_text_buffer_move_mark_by_name (buffer, "insert", &start);
    gtk_text_buffer_move_mark_by_name (buffer, "selection_bound", &end);
    
    result = gtk_text_buffer_delete_selection (buffer, INTERACTIVE, DEF_EDITABLE);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_insert (buffer, &start, deleted, -1);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text1 =  gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    if (result)  
    {
        if (!strcmp (deleted, ""))
        {
            TEST_FAIL ("Text deleted incorrect", NULL);
        }    
    
    } else {
    
        if (strcmp (deleted, ""))
        {
            TEST_FAIL ("Text deleted incorrect", NULL);
        }    
    
    }
    
    if (INTERACTIVE)
    {
        if (DEF_EDITABLE && strcmp (text, text1))
        {
            TEST_FAIL ("Result texts not equal", NULL);
        }
    
    } else {
    
        if (strcmp (text, text1))
        {
            TEST_FAIL ("Result texts not equal", NULL);
        }
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef DEF_EDITABLE
    #undef INTERACTIVE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_delete_selection
 * Params: GtkTextBuffer *buffer, gboolean interactive, gboolean default_editable
 * Returns:  gboolean
 * Assertion: Deletes the range between the "insert" and "selection_bound" marks, that is, the currently-selected text. 
 * Params Values: GtkTextBuffer *buffer, 10, FALSE
 * Expected: gboolean
 * 
 * Name: gtk_text_buffer_delete_selection
 * Params: GtkTextBuffer *buffer, gboolean interactive, gboolean default_editable
 * Returns:  gboolean
 * Assertion: If interactive is TRUE, the editability of the selection will be considered (users can't delete uneditable text).'
 * Params Values: GtkTextBuffer *buffer, 10, FALSE
 * Expected: gboolean  
 */
static void test_purpose_202()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    #define LINE 0
    #define OFFS 1
    #define LINE1 0
    #define OFFS1 10
    #define DEF_EDITABLE FALSE
    #define INTERACTIVE FALSE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    gchar* text;
    gchar* text1;
    gchar* deleted;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    tag = gtk_text_tag_new ("Tag");
    g_object_set (tag, "editable", (gboolean) DEF_EDITABLE, NULL);
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    deleted = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    gtk_text_buffer_move_mark_by_name (buffer, "insert", &start);
    gtk_text_buffer_move_mark_by_name (buffer, "selection_bound", &end);
    
    result = gtk_text_buffer_delete_selection (buffer, INTERACTIVE, DEF_EDITABLE);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_insert (buffer, &start, deleted, -1);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text1 =  gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    if (result)  
    {
        if (!strcmp (deleted, ""))
        {
            TEST_FAIL ("Text deleted incorrect", NULL);
        }    
    
    } else {
    
        if (strcmp (deleted, ""))
        {
            TEST_FAIL ("Text deleted incorrect", NULL);
        }    
    
    }
    
    if (INTERACTIVE)
    {
        if (DEF_EDITABLE && strcmp (text, text1))
        {
            TEST_FAIL ("Result texts not equal", NULL);
        }
    
    } else {
    
        if (strcmp (text, text1))
        {
            TEST_FAIL ("Result texts not equal", NULL);
        }
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef DEF_EDITABLE
    #undef INTERACTIVE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_delete_selection
 * Params: GtkTextBuffer *buffer, gboolean interactive, gboolean default_editable
 * Returns:  gboolean
 * Assertion: Deletes the range between the "insert" and "selection_bound" marks, that is, the currently-selected text. 
 * Params Values: GtkTextBuffer *buffer, 5, TRUE
 * Expected: gboolean
 * 
 * Name: gtk_text_buffer_delete_selection
 * Params: GtkTextBuffer *buffer, gboolean interactive, gboolean default_editable
 * Returns:  gboolean
 * Assertion: If interactive is TRUE, the editability of the selection will be considered (users can't delete uneditable text).'
 * Params Values: GtkTextBuffer *buffer, 5, TRUE
 * Expected: gboolean  
 */
static void test_purpose_203()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    #define LINE 0
    #define OFFS 4
    #define LINE1 0
    #define OFFS1 5
    #define DEF_EDITABLE TRUE
    #define INTERACTIVE FALSE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    gchar* text;
    gchar* text1;
    gchar* deleted;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    tag = gtk_text_tag_new ("Tag");
    g_object_set (tag, "editable", (gboolean) DEF_EDITABLE, NULL);
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    deleted = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    gtk_text_buffer_move_mark_by_name (buffer, "insert", &start);
    gtk_text_buffer_move_mark_by_name (buffer, "selection_bound", &end);
    
    result = gtk_text_buffer_delete_selection (buffer, INTERACTIVE, DEF_EDITABLE);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_insert (buffer, &start, deleted, -1);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text1 =  gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    if (result)  
    {
        if (!strcmp (deleted, ""))
        {
            TEST_FAIL ("Text deleted incorrect", NULL);
        }    
    
    } else {
    
        if (strcmp (deleted, ""))
        {
            TEST_FAIL ("Text deleted incorrect", NULL);
        }    
    
    }
    
    if (INTERACTIVE)
    {
        if (DEF_EDITABLE && strcmp (text, text1))
        {
            TEST_FAIL ("Result texts not equal", NULL);
        }
    
    } else {
    
        if (strcmp (text, text1))
        {
            TEST_FAIL ("Result texts not equal", NULL);
        }
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef DEF_EDITABLE
    #undef INTERACTIVE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_delete_selection
 * Params: GtkTextBuffer *buffer, gboolean interactive, gboolean default_editable
 * Returns:  gboolean
 * Assertion: Deletes the range between the "insert" and "selection_bound" marks, that is, the currently-selected text. 
 * Params Values: GtkTextBuffer *buffer, 10, FALSE
 * Expected: gboolean
 * 
 * Name: gtk_text_buffer_delete_selection
 * Params: GtkTextBuffer *buffer, gboolean interactive, gboolean default_editable
 * Returns:  gboolean
 * Assertion: If interactive is TRUE, the editability of the selection will be considered (users can't delete uneditable text).'
 * Params Values: GtkTextBuffer *buffer, 10, FALSE
 * Expected: gboolean  
 */
static void test_purpose_204()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    #define LINE 0
    #define OFFS 0
    #define LINE1 0
    #define OFFS1 10
    #define DEF_EDITABLE FALSE
    #define INTERACTIVE TRUE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    gchar* text;
    gchar* text1;
    gchar* deleted;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    tag = gtk_text_tag_new ("Tag");
    g_object_set (tag, "editable", (gboolean) DEF_EDITABLE, NULL);
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    deleted = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    gtk_text_buffer_move_mark_by_name (buffer, "insert", &start);
    gtk_text_buffer_move_mark_by_name (buffer, "selection_bound", &end);
    
    result = gtk_text_buffer_delete_selection (buffer, INTERACTIVE, DEF_EDITABLE);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_insert (buffer, &start, deleted, -1);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text1 =  gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    if (result)  
    {
        if (!strcmp (deleted, ""))
        {
            TEST_FAIL ("Text deleted incorrect", NULL);
        }    
    
    } else {
    
        if (strcmp (deleted, ""))
        {
            TEST_FAIL ("Text deleted incorrect", NULL);
        }    
    
    }
    
    if (INTERACTIVE)
    {
        if (DEF_EDITABLE && strcmp (text, text1))
        {
            TEST_FAIL ("Result texts not equal", NULL);
        }
    
    } else {
    
        if (strcmp (text, text1))
        {
            TEST_FAIL ("Result texts not equal", NULL);
        }
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef DEF_EDITABLE
    #undef INTERACTIVE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_delete_selection
 * Params: GtkTextBuffer *buffer, gboolean interactive, gboolean default_editable
 * Returns:  gboolean
 * Assertion: Deletes the range between the "insert" and "selection_bound" marks, that is, the currently-selected text. 
 * Params Values: GtkTextBuffer *buffer, 1, FALSE
 * Expected: gboolean
 * 
 * Name: gtk_text_buffer_delete_selection
 * Params: GtkTextBuffer *buffer, gboolean interactive, gboolean default_editable
 * Returns:  gboolean
 * Assertion: If interactive is TRUE, the editability of the selection will be considered (users can't delete uneditable text).'
 * Params Values: GtkTextBuffer *buffer, 1, FALSE
 * Expected: gboolean  
 */
static void test_purpose_205()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    #define LINE 0
    #define OFFS 1
    #define LINE1 0
    #define OFFS1 1
    #define DEF_EDITABLE FALSE
    #define INTERACTIVE FALSE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    gchar* text;
    gchar* text1;
    gchar* deleted;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    tag = gtk_text_tag_new ("Tag");
    g_object_set (tag, "editable", (gboolean) DEF_EDITABLE, NULL);
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    deleted = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    gtk_text_buffer_move_mark_by_name (buffer, "insert", &start);
    gtk_text_buffer_move_mark_by_name (buffer, "selection_bound", &end);
    
    result = gtk_text_buffer_delete_selection (buffer, INTERACTIVE, DEF_EDITABLE);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_insert (buffer, &start, deleted, -1);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text1 =  gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    if (result)  
    {
        if (!strcmp (deleted, ""))
        {
            TEST_FAIL ("Text deleted incorrect", NULL);
        }    
    
    } else {
    
        if (strcmp (deleted, ""))
        {
            TEST_FAIL ("Text deleted incorrect", NULL);
        }    
    
    }
    
    if (INTERACTIVE)
    {
        if (DEF_EDITABLE && strcmp (text, text1))
        {
            TEST_FAIL ("Result texts not equal", NULL);
        }
    
    } else {
    
        if (strcmp (text, text1))
        {
            TEST_FAIL ("Result texts not equal", NULL);
        }
    }
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef DEF_EDITABLE
    #undef INTERACTIVE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_copy_clipboard 
 * Params: GtkTextBuffer *buffer, GtkClipboard *clipboard
 * Returns:  void
 * Assertion: Copies the currently-selected text to a clipboard.
 * Params Values: GtkTextBuffer *buffer, GtkClipboard *clipboard
 * Expected: void  
 */
static void test_purpose_206()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    #define LINE 0
    #define OFFS 0
    #define LINE1 0
    #define OFFS1 20
    
    GtkTextBuffer* buffer;
    GtkClipboard* clipboard;
    GtkTextIter start;
    GtkTextIter end;
    gchar* text;
    gchar* text1;
    gchar* deleted;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL ("", NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    text = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    gtk_text_buffer_move_mark_by_name (buffer, "insert", &start);
    gtk_text_buffer_move_mark_by_name (buffer, "selection_bound", &end);
    
    gtk_text_buffer_copy_clipboard (buffer, gtk_clipboard_get (GDK_NONE));
    
    text1 = gtk_clipboard_wait_for_text (clipboard);
    
    if (strcmp (text, text1))
    {
        TEST_FAIL ("Text wrong '%s'\n'%s'", text, text1);
    }    
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_copy_clipboard 
 * Params: GtkTextBuffer *buffer, GtkClipboard *clipboard
 * Returns:  void
 * Assertion: Copies the currently-selected text to a clipboard.
 * Params Values: GtkTextBuffer *buffer, GtkClipboard *clipboard
 * Expected: void  
 */
static void test_purpose_207()
{
    #define TEXT "\b\n\t\n" 
    #define LINE 0
    #define OFFS 0
    #define LINE1 0
    #define OFFS1 1
    
    GtkTextBuffer* buffer;
    GtkClipboard* clipboard;
    GtkTextIter start;
    GtkTextIter end;
    gchar* text;
    gchar* text1;
    gchar* deleted;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL ("", NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    text = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    gtk_text_buffer_move_mark_by_name (buffer, "insert", &start);
    gtk_text_buffer_move_mark_by_name (buffer, "selection_bound", &end);
    
    gtk_text_buffer_copy_clipboard (buffer, gtk_clipboard_get (GDK_NONE));
    
    text1 = gtk_clipboard_wait_for_text (clipboard);
    
    if (strcmp (text, text1))
    {
        TEST_FAIL ("Text wrong '%s'\n'%s'", text, text1);
    }    
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_copy_clipboard 
 * Params: GtkTextBuffer *buffer, GtkClipboard *clipboard
 * Returns:  void
 * Assertion: Copies the currently-selected text to a clipboard.
 * Params Values: GtkTextBuffer *buffer, GtkClipboard *clipboard
 * Expected: void  
 */
static void test_purpose_208()
{
    #define TEXT "!@#$%^&*()_+|~=\";:'?<>`/" 
    #define LINE 0
    #define OFFS 0
    #define LINE1 0
    #define OFFS1 24
    
    GtkTextBuffer* buffer;
    GtkClipboard* clipboard;
    GtkTextIter start;
    GtkTextIter end;
    gchar* text;
    gchar* text1;
    gchar* deleted;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL ("", NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    text = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    gtk_text_buffer_move_mark_by_name (buffer, "insert", &start);
    gtk_text_buffer_move_mark_by_name (buffer, "selection_bound", &end);
    
    gtk_text_buffer_copy_clipboard (buffer, gtk_clipboard_get (GDK_NONE));
    
    text1 = gtk_clipboard_wait_for_text (clipboard);
    
    if (strcmp (text, text1))
    {
        TEST_FAIL ("Text wrong '%s'\n'%s'", text, text1);
    }    
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_cut_clipboard 
 * Params: GtkTextBuffer *buffer, GtkClipboard *clipboard, gboolean default_editable
 * Returns:  void
 * Assertion: Copies the currently-selected text to a clipboard, then deletes said text if it's editable.'
 * Params Values: GtkTextBuffer *buffer, GtkClipboard *clipboard, TRUE
 * Expected: void  
 */
static void test_purpose_209()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    #define LINE 0
    #define OFFS 0
    #define LINE1 0
    #define OFFS1 20
    #define EDITABLE TRUE
    #define TAG TRUE
    
    GtkTextBuffer* buffer;
    GtkClipboard* clipboard;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    gchar* text;
    gchar* text1;
    gchar* deleted;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL ("", NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    if (TAG)
    {
        tag = gtk_text_tag_new ("Tag");
        g_object_set (tag, "editable", (gboolean) EDITABLE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    }
    text = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    deleted = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    gtk_text_buffer_move_mark_by_name (buffer, "insert", &start);
    gtk_text_buffer_move_mark_by_name (buffer, "selection_bound", &end);
    
    gtk_text_buffer_cut_clipboard (buffer, clipboard, EDITABLE);
    
    text1 = gtk_clipboard_wait_for_text (clipboard);
    
    if (strcmp (deleted, text1))
    {
        TEST_FAIL ("Text wrong:\n'%s'\n'%s'", deleted, text1);
    }    
    
    if (EDITABLE)
    {
        gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
        gtk_text_buffer_insert (buffer, &start, deleted, -1);
        gtk_text_buffer_get_bounds (buffer, &start, &end);
        text1 = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
        if (strcmp (text, text1))
        {
            TEST_FAIL ("Buffer is editable, but text not pasted", NULL);
        }    
    
    } else {
    
        gtk_text_buffer_get_bounds (buffer, &start, &end);
        text1 = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
        if (strcmp (text, text1))
        {
            TEST_FAIL ("Text wrong:\n'%s'\n'%s'", text, text1);
        }    
    
    }
    
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef TAG
    #undef EDITABLE 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_cut_clipboard 
 * Params: GtkTextBuffer *buffer, GtkClipboard *clipboard, gboolean default_editable
 * Returns:  void
 * Assertion: Copies the currently-selected text to a clipboard, then deletes said text if it's editable.'
 * Params Values: GtkTextBuffer *buffer, GtkClipboard *clipboard, TRUE
 * Expected: void  
 */
static void test_purpose_210()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    #define LINE 0
    #define OFFS 0
    #define LINE1 0
    #define OFFS1 20
    #define EDITABLE TRUE
    #define TAG FALSE
    
    GtkTextBuffer* buffer;
    GtkClipboard* clipboard;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    gchar* text;
    gchar* text1;
    gchar* deleted;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL ("", NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    if (TAG)
    {
        tag = gtk_text_tag_new ("Tag");
        g_object_set (tag, "editable", (gboolean) EDITABLE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    }
    text = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    deleted = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    gtk_text_buffer_move_mark_by_name (buffer, "insert", &start);
    gtk_text_buffer_move_mark_by_name (buffer, "selection_bound", &end);
    
    gtk_text_buffer_cut_clipboard (buffer, clipboard, EDITABLE);
    
    text1 = gtk_clipboard_wait_for_text (clipboard);
    
    if (strcmp (deleted, text1))
    {
        TEST_FAIL ("Text wrong:\n'%s'\n'%s'", deleted, text1);
    }    
    
    if (EDITABLE)
    {
        gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
        gtk_text_buffer_insert (buffer, &start, deleted, -1);
        gtk_text_buffer_get_bounds (buffer, &start, &end);
        text1 = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
        if (strcmp (text, text1))
        {
            TEST_FAIL ("Buffer is editable, but text not pasted", NULL);
        }    
    
    } else {
    
        gtk_text_buffer_get_bounds (buffer, &start, &end);
        text1 = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
        if (strcmp (text, text1))
        {
            TEST_FAIL ("Text wrong:\n'%s'\n'%s'", text, text1);
        }    
    
    }
    
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef TAG
    #undef EDITABLE 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_cut_clipboard 
 * Params: GtkTextBuffer *buffer, GtkClipboard *clipboard, gboolean default_editable
 * Returns:  void
 * Assertion: Copies the currently-selected text to a clipboard, then deletes said text if it's editable.'
 * Params Values: GtkTextBuffer *buffer, GtkClipboard *clipboard, FALSE
 * Expected: void  
 */
static void test_purpose_211()
{
    #define TEXT "!@#$%^&*()_+|~=\";:'?<>`/" 
    #define LINE 0
    #define OFFS 0
    #define LINE1 0
    #define OFFS1 24
    #define EDITABLE FALSE
    #define TAG TRUE
    
    GtkTextBuffer* buffer;
    GtkClipboard* clipboard;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    gchar* text;
    gchar* text1;
    gchar* deleted;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL ("", NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    if (TAG)
    {
        tag = gtk_text_tag_new ("Tag");
        g_object_set (tag, "editable", (gboolean) EDITABLE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    }
    text = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    deleted = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    gtk_text_buffer_move_mark_by_name (buffer, "insert", &start);
    gtk_text_buffer_move_mark_by_name (buffer, "selection_bound", &end);
    
    gtk_text_buffer_cut_clipboard (buffer, clipboard, EDITABLE);
    
    text1 = gtk_clipboard_wait_for_text (clipboard);
    
    if (strcmp (deleted, text1))
    {
        TEST_FAIL ("Text wrong:\n'%s'\n'%s'", deleted, text1);
    }    
    
    if (EDITABLE)
    {
        gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
        gtk_text_buffer_insert (buffer, &start, deleted, -1);
        gtk_text_buffer_get_bounds (buffer, &start, &end);
        text1 = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
        if (strcmp (text, text1))
        {
            TEST_FAIL ("Buffer is editable, but text not pasted", NULL);
        }    
    
    } else {
    
        gtk_text_buffer_get_bounds (buffer, &start, &end);
        text1 = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
        if (strcmp (text, text1))
        {
            TEST_FAIL ("Text wrong:\n'%s'\n'%s'", text, text1);
        }    
    
    }
    
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef TAG
    #undef EDITABLE 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_cut_clipboard 
 * Params: GtkTextBuffer *buffer, GtkClipboard *clipboard, gboolean default_editable
 * Returns:  void
 * Assertion: Copies the currently-selected text to a clipboard, then deletes said text if it's editable.'
 * Params Values: GtkTextBuffer *buffer, GtkClipboard *clipboard, FALSE
 * Expected: void  
 */
static void test_purpose_212()
{
    #define TEXT "\b\n\t\n" 
    #define LINE 0
    #define OFFS 0
    #define LINE1 0
    #define OFFS1 1
    #define EDITABLE FALSE
    #define TAG FALSE
    
    GtkTextBuffer* buffer;
    GtkClipboard* clipboard;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    gchar* text;
    gchar* text1;
    gchar* deleted;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL ("", NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    if (TAG)
    {
        tag = gtk_text_tag_new ("Tag");
        g_object_set (tag, "editable", (gboolean) EDITABLE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    }
    text = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    deleted = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    gtk_text_buffer_move_mark_by_name (buffer, "insert", &start);
    gtk_text_buffer_move_mark_by_name (buffer, "selection_bound", &end);
    
    gtk_text_buffer_cut_clipboard (buffer, clipboard, EDITABLE);
    
    text1 = gtk_clipboard_wait_for_text (clipboard);
    
    if (strcmp (deleted, text1))
    {
        TEST_FAIL ("Text wrong:\n'%s'\n'%s'", deleted, text1);
    }    
    
    if (EDITABLE)
    {
        gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
        gtk_text_buffer_insert (buffer, &start, deleted, -1);
        gtk_text_buffer_get_bounds (buffer, &start, &end);
        text1 = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
        if (strcmp (text, text1))
        {
            TEST_FAIL ("Buffer is editable, but text not pasted", NULL);
        }    
    
    } else {
    
        gtk_text_buffer_get_bounds (buffer, &start, &end);
        text1 = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
        if (strcmp (text, text1))
        {
            TEST_FAIL ("Text wrong:\n'%s'\n'%s'", text, text1);
        }    
    
    }
    
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef TAG
    #undef EDITABLE 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_paste_clipboard 
 * Params: GtkTextBuffer *buffer, GtkClipboard *clipboard, GtkTextIter *override_location, gboolean default_editable
 * Returns:  void
 * Assertion: Pastes the contents of a clipboard at the insertion point, or at override_location.
 * Params Values: GtkTextBuffer *buffer, GtkClipboard *clipboard, GtkTextIter *override_location, TRUE
 * Expected: void  
 */
static void test_purpose_213()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    #define LINE 0
    #define OFFS 0
    #define LINE1 0
    #define OFFS1 20
    #define EDITABLE TRUE
    #define TAG TRUE
    
    GtkTextBuffer* buffer;
    GtkClipboard* clipboard;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    gchar* text;
    gchar* text1;
    gchar* tail;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL ("", NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    if (TAG)
    {
        tag = gtk_text_tag_new ("Tag");
        g_object_set (tag, "editable", (gboolean) EDITABLE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    
    gtk_text_buffer_move_mark_by_name (buffer, "insert", &start);
    gtk_text_buffer_move_mark_by_name (buffer, "selection_bound", &end);
    gtk_text_buffer_cut_clipboard (buffer, clipboard, TRUE);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    tail = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    gtk_text_buffer_paste_clipboard (buffer, clipboard, &start, EDITABLE);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text1 = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    if(EDITABLE)
    {
        if (strcmp (text, text1))
        {
            TEST_FAIL ("Buffer is editable, but text not pasted \n'%s'\n'%s'", text, text1);
        }    
    } else {
        if (strcmp (tail, text1))
        {
            TEST_FAIL ("Buffer is editable, but text not pasted \n'%s'\n'%s'", tail, text1);
        }    
    }
    
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef TAG
    #undef EDITABLE 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_paste_clipboard 
 * Params: GtkTextBuffer *buffer, GtkClipboard *clipboard, GtkTextIter *override_location, gboolean default_editable
 * Returns:  void
 * Assertion: Pastes the contents of a clipboard at the insertion point, or at override_location.
 * Params Values: GtkTextBuffer *buffer, GtkClipboard *clipboard, GtkTextIter *override_location, TRUE
 * Expected: void  
 */
static void test_purpose_214()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    #define LINE 0
    #define OFFS 0
    #define LINE1 0
    #define OFFS1 20
    #define EDITABLE TRUE
    #define TAG FALSE
    
    GtkTextBuffer* buffer;
    GtkClipboard* clipboard;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    gchar* text;
    gchar* text1;
    gchar* tail;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL ("", NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    if (TAG)
    {
        tag = gtk_text_tag_new ("Tag");
        g_object_set (tag, "editable", (gboolean) EDITABLE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    
    gtk_text_buffer_move_mark_by_name (buffer, "insert", &start);
    gtk_text_buffer_move_mark_by_name (buffer, "selection_bound", &end);
    gtk_text_buffer_cut_clipboard (buffer, clipboard, TRUE);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    tail = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    gtk_text_buffer_paste_clipboard (buffer, clipboard, &start, EDITABLE);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text1 = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    if(EDITABLE)
    {
        if (strcmp (text, text1))
        {
            TEST_FAIL ("Buffer is editable, but text not pasted \n'%s'\n'%s'", text, text1);
        }    
    } else {
        if (strcmp (tail, text1))
        {
            TEST_FAIL ("Buffer is editable, but text not pasted \n'%s'\n'%s'", tail, text1);
        }    
    }
    
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef TAG
    #undef EDITABLE 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_paste_clipboard 
 * Params: GtkTextBuffer *buffer, GtkClipboard *clipboard, GtkTextIter *override_location, gboolean default_editable
 * Returns:  void
 * Assertion: Pastes the contents of a clipboard at the insertion point, or at override_location.
 * Params Values: GtkTextBuffer *buffer, GtkClipboard *clipboard, GtkTextIter *override_location, FALSE
 * Expected: void  
 */
static void test_purpose_215()
{
    #define TEXT "!@#$%^&*()_+|~=`\";:'?<>/" 
    #define LINE 0
    #define OFFS 0
    #define LINE1 0
    #define OFFS1 24
    #define EDITABLE FALSE
    #define TAG TRUE
    
    GtkTextBuffer* buffer;
    GtkClipboard* clipboard;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    gchar* text;
    gchar* text1;
    gchar* tail;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL ("", NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    if (TAG)
    {
        tag = gtk_text_tag_new ("Tag");
        g_object_set (tag, "editable", (gboolean) EDITABLE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    
    gtk_text_buffer_move_mark_by_name (buffer, "insert", &start);
    gtk_text_buffer_move_mark_by_name (buffer, "selection_bound", &end);
    gtk_text_buffer_cut_clipboard (buffer, clipboard, TRUE);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    tail = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    gtk_text_buffer_paste_clipboard (buffer, clipboard, &start, EDITABLE);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text1 = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    if(EDITABLE)
    {
        if (strcmp (text, text1))
        {
            TEST_FAIL ("Buffer is editable, but text not pasted \n'%s'\n'%s'", text, text1);
        }    
    } else {
        if (strcmp (tail, text1))
        {
            TEST_FAIL ("Buffer is editable, but text not pasted \n'%s'\n'%s'", tail, text1);
        }    
    }
    
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef TAG
    #undef EDITABLE 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_paste_clipboard 
 * Params: GtkTextBuffer *buffer, GtkClipboard *clipboard, GtkTextIter *override_location, gboolean default_editable
 * Returns:  void
 * Assertion: Pastes the contents of a clipboard at the insertion point, or at override_location.
 * Params Values: GtkTextBuffer *buffer, GtkClipboard *clipboard, GtkTextIter *override_location, FALSE
 * Expected: void  
 */
static void test_purpose_216()
{
    #define TEXT "\b\n\t\n" 
    #define LINE 0
    #define OFFS 0
    #define LINE1 0
    #define OFFS1 1
    #define EDITABLE FALSE
    #define TAG FALSE
    
    GtkTextBuffer* buffer;
    GtkClipboard* clipboard;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextTag* tag;
    gchar* text;
    gchar* text1;
    gchar* tail;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL ("", NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen ((char*) TEXT));
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    if (TAG)
    {
        tag = gtk_text_tag_new ("Tag");
        g_object_set (tag, "editable", (gboolean) EDITABLE, NULL);
        gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
        gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE1, OFFS1);
    
    gtk_text_buffer_move_mark_by_name (buffer, "insert", &start);
    gtk_text_buffer_move_mark_by_name (buffer, "selection_bound", &end);
    gtk_text_buffer_cut_clipboard (buffer, clipboard, TRUE);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    
    tail = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    
    gtk_text_buffer_paste_clipboard (buffer, clipboard, &start, EDITABLE);
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    text1 = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
    
    if(EDITABLE)
    {
        if (strcmp (text, text1))
        {
            TEST_FAIL ("Buffer is editable, but text not pasted \n'%s'\n'%s'", text, text1);
        }    
    } else {
        if (strcmp (tail, text1))
        {
            TEST_FAIL ("Buffer is editable, but text not pasted \n'%s'\n'%s'", tail, text1);
        }    
    }
    
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef TAG
    #undef EDITABLE 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_begin_user_action
 * Params: GtkTextBuffer *buffer
 * Returns: void
 * Assertion: Called to indicate that the buffer operations between here and a call to gtk_text_buffer_end_user_action() are part of a single user-visible operation.
 * Params Values: GtkTextBuffer *buffer
 * Expected: void  
 */
static void test_purpose_217()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define NOT_PAIR TRUE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    g_signal_connect (G_OBJECT (buffer), "begin-user-action", GTK_SIGNAL_FUNC (global_user_action), NULL);
    
    if (NOT_PAIR)
    {
        gtk_text_buffer_begin_user_action (buffer);
    }
    gtk_text_buffer_begin_user_action (buffer);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, 0, 0);
    gtk_text_buffer_insert (buffer, &start, "insert1", -1);
    gtk_text_buffer_insert (buffer, &start, "insert2", -1);
    
    gtk_text_buffer_end_user_action (buffer);
    
    if (!modified_catched)
    {
        if (!NOT_PAIR)
        {
            TEST_FAIL ("'begin-user-action' signal not catched", NULL);
        }
    }
    
    #undef TEXT
    #undef NOT_PAIR
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_begin_user_action
 * Params: GtkTextBuffer *buffer
 * Returns: void
 * Assertion: Called to indicate that the buffer operations between here and a call to gtk_text_buffer_end_user_action() are part of a single user-visible operation.
 * Params Values: GtkTextBuffer *buffer
 * Expected: void  
 */
static void test_purpose_218()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define NOT_PAIR FALSE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    g_signal_connect (G_OBJECT (buffer), "begin-user-action", GTK_SIGNAL_FUNC (global_user_action), NULL);
    
    if (NOT_PAIR)
    {
        gtk_text_buffer_begin_user_action (buffer);
    }
    gtk_text_buffer_begin_user_action (buffer);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, 0, 0);
    gtk_text_buffer_insert (buffer, &start, "insert1", -1);
    gtk_text_buffer_insert (buffer, &start, "insert2", -1);
    
    gtk_text_buffer_end_user_action (buffer);
    
    if (!modified_catched)
    {
        if (!NOT_PAIR)
        {
            TEST_FAIL ("'begin-user-action' signal not catched", NULL);
        }
    }
    
    #undef TEXT
    #undef NOT_PAIR
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_end_user_action
 * Params: GtkTextBuffer *buffer
 * Returns: void
 * Assertion: Should be paired with a call to gtk_text_buffer_begin_user_action().
 * Params Values: GtkTextBuffer *buffer
 * Expected: void  
 */
static void test_purpose_219()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define NOT_PAIR TRUE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    g_signal_connect (G_OBJECT (buffer), "end-user-action", GTK_SIGNAL_FUNC (global_user_action), NULL);
    
    if (NOT_PAIR)
    {
        gtk_text_buffer_begin_user_action (buffer);
    }
    gtk_text_buffer_begin_user_action (buffer);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, 0, 0);
    gtk_text_buffer_insert (buffer, &start, "insert1", -1);
    gtk_text_buffer_insert (buffer, &start, "insert2", -1);
    
    gtk_text_buffer_end_user_action (buffer);
    
    if (!modified_catched)
    {
        if (!NOT_PAIR) 
        {
            TEST_FAIL ("'end-user-action' signal not catched", NULL);
        }
    }
    
    #undef TEXT
    #undef NOT_PAIR
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_buffer_end_user_action
 * Params: GtkTextBuffer *buffer
 * Returns: void
 * Assertion: Should be paired with a call to gtk_text_buffer_begin_user_action().
 * Params Values: GtkTextBuffer *buffer
 * Expected: void  
 */
static void test_purpose_220()
{
    #define TEXT "1 2 3 4 5 6 7 8 9 0\n 1 2 3 4 5 6 7 8 9 0\n"
    #define NOT_PAIR FALSE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark* mark;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    modified_catched = 0;
    buffer =  gtk_text_buffer_new (NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_set_text (buffer, TEXT, strlen (TEXT));
    g_signal_connect (G_OBJECT (buffer), "end-user-action", GTK_SIGNAL_FUNC (global_user_action), NULL);
    
    if (NOT_PAIR)
    {
        gtk_text_buffer_begin_user_action (buffer);
    }
    gtk_text_buffer_begin_user_action (buffer);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, 0, 0);
    gtk_text_buffer_insert (buffer, &start, "insert1", -1);
    gtk_text_buffer_insert (buffer, &start, "insert2", -1);
    
    gtk_text_buffer_end_user_action (buffer);
    
    if (!modified_catched)
    {
        if (!NOT_PAIR) 
        {
            TEST_FAIL ("'end-user-action' signal not catched", NULL);
        }
    }
    
    #undef TEXT
    #undef NOT_PAIR
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_add_selection_clipboard
 * Params: GtkTextBuffer *buffer, GtkClipboard *clipboard
 * Returns: void
 * Assertion: Adds clipboard to the list of clipboards in which the selection contents of buffer are available.
 * Params Values: GtkTextBuffer *buffer, GtkClipboard *clipboard
 * Expected: void  
 */
static void test_purpose_221()
{
    GtkTextBuffer* buffer;
    GtkClipboard *clipboard;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    clipboard = gtk_clipboard_get (GDK_SELECTION_PRIMARY);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_add_selection_clipboard (buffer, clipboard);
    
    
    if (!global_find_selection_clipboard (buffer, clipboard))
    {
        TEST_FAIL ("Clipboard not found", NULL);
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_buffer_remove_selection_clipboard
 * Params: GtkTextBuffer *buffer, GtkClipboard *clipboard
 * Returns: void
 * Assertion: Removes a GtkClipboard added with gtk_text_buffer_add_selection_clipboard()
 * Params Values: GtkTextBuffer *buffer, GtkClipboard *clipboard
 * Expected: void  
 */
static void test_purpose_222()
{
    GtkTextBuffer* buffer;
    GtkClipboard *clipboard;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new (NULL);
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    clipboard = gtk_clipboard_get (GDK_SELECTION_PRIMARY);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_text_buffer_add_selection_clipboard (buffer, clipboard);
    gtk_text_buffer_remove_selection_clipboard (buffer, clipboard);
    
    if (global_find_selection_clipboard (buffer, clipboard))
    {
        TEST_FAIL ("Clipboard is found", NULL);
    }
    
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkTextBuffer ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {test_purpose_52, 1},
    {test_purpose_53, 1},
    {test_purpose_54, 1},
    {test_purpose_55, 1},
    {test_purpose_56, 1},
    {test_purpose_57, 1},
    {test_purpose_58, 1},
    {test_purpose_59, 1},
    {test_purpose_60, 1},
    {test_purpose_61, 1},
    {test_purpose_62, 1},
    {test_purpose_63, 1},
    {test_purpose_64, 1},
    {test_purpose_65, 1},
    {test_purpose_66, 1},
    {test_purpose_67, 1},
    {test_purpose_68, 1},
    {test_purpose_69, 1},
    {test_purpose_70, 1},
    {test_purpose_71, 1},
    {test_purpose_72, 1},
    {test_purpose_73, 1},
    {test_purpose_74, 1},
    {test_purpose_75, 1},
    {test_purpose_76, 1},
    {test_purpose_77, 1},
    {test_purpose_78, 1},
    {test_purpose_79, 1},
    {test_purpose_80, 1},
    {test_purpose_81, 1},
    {test_purpose_82, 1},
    {test_purpose_83, 1},
    {test_purpose_84, 1},
    {test_purpose_85, 1},
    {test_purpose_86, 1},
    {test_purpose_87, 1},
    {test_purpose_88, 1},
    {test_purpose_89, 1},
    {test_purpose_90, 1},
    {test_purpose_91, 1},
    {test_purpose_92, 1},
    {test_purpose_93, 1},
    {test_purpose_94, 1},
    {test_purpose_95, 1},
    {test_purpose_96, 1},
    {test_purpose_97, 1},
    {test_purpose_98, 1},
    {test_purpose_99, 1},
    {test_purpose_100, 1},
    {test_purpose_101, 1},
    {test_purpose_102, 1},
    {test_purpose_103, 1},
    {test_purpose_104, 1},
    {test_purpose_105, 1},
    {test_purpose_106, 1},
    {test_purpose_107, 1},
    {test_purpose_108, 1},
    {test_purpose_109, 1},
    {test_purpose_110, 1},
    {test_purpose_111, 1},
    {test_purpose_112, 1},
    {test_purpose_113, 1},
    {test_purpose_114, 1},
    {test_purpose_115, 1},
    {test_purpose_116, 1},
    {test_purpose_117, 1},
    {test_purpose_118, 1},
    {test_purpose_119, 1},
    {test_purpose_120, 1},
    {test_purpose_121, 1},
    {test_purpose_122, 1},
    {test_purpose_123, 1},
    {test_purpose_124, 1},
    {test_purpose_125, 1},
    {test_purpose_126, 1},
    {test_purpose_127, 1},
    {test_purpose_128, 1},
    {test_purpose_129, 1},
    {test_purpose_130, 1},
    {test_purpose_131, 1},
    {test_purpose_132, 1},
    {test_purpose_133, 1},
    {test_purpose_134, 1},
    {test_purpose_135, 1},
    {test_purpose_136, 1},
    {test_purpose_137, 1},
    {test_purpose_138, 1},
    {test_purpose_139, 1},
    {test_purpose_140, 1},
    {test_purpose_141, 1},
    {test_purpose_142, 1},
    {test_purpose_143, 1},
    {test_purpose_144, 1},
    {test_purpose_145, 1},
    {test_purpose_146, 1},
    {test_purpose_147, 1},
    {test_purpose_148, 1},
    {test_purpose_149, 1},
    {test_purpose_150, 1},
    {test_purpose_151, 1},
    {test_purpose_152, 1},
    {test_purpose_153, 1},
    {test_purpose_154, 1},
    {test_purpose_155, 1},
    {test_purpose_156, 1},
    {test_purpose_157, 1},
    {test_purpose_158, 1},
    {test_purpose_159, 1},
    {test_purpose_160, 1},
    {test_purpose_161, 1},
    {test_purpose_162, 1},
    {test_purpose_163, 1},
    {test_purpose_164, 1},
    {test_purpose_165, 1},
    {test_purpose_166, 1},
    {test_purpose_167, 1},
    {test_purpose_168, 1},
    {test_purpose_169, 1},
    {test_purpose_170, 1},
    {test_purpose_171, 1},
    {test_purpose_172, 1},
    {test_purpose_173, 1},
    {test_purpose_174, 1},
    {test_purpose_175, 1},
    {test_purpose_176, 1},
    {test_purpose_177, 1},
    {test_purpose_178, 1},
    {test_purpose_179, 1},
    {test_purpose_180, 1},
    {test_purpose_181, 1},
    {test_purpose_182, 1},
    {test_purpose_183, 1},
    {test_purpose_184, 1},
    {test_purpose_185, 1},
    {test_purpose_186, 1},
    {test_purpose_187, 1},
    {test_purpose_188, 1},
    {test_purpose_189, 1},
    {test_purpose_190, 1},
    {test_purpose_191, 1},
    {test_purpose_192, 1},
    {test_purpose_193, 1},
    {test_purpose_194, 1},
    {test_purpose_195, 1},
    {test_purpose_196, 1},
    {test_purpose_197, 1},
    {test_purpose_198, 1},
    {test_purpose_199, 1},
    {test_purpose_200, 1},
    {test_purpose_201, 1},
    {test_purpose_202, 1},
    {test_purpose_203, 1},
    {test_purpose_204, 1},
    {test_purpose_205, 1},
    {test_purpose_206, 1},
    {test_purpose_207, 1},
    {test_purpose_208, 1},
    {test_purpose_209, 1},
    {test_purpose_210, 1},
    {test_purpose_211, 1},
    {test_purpose_212, 1},
    {test_purpose_213, 1},
    {test_purpose_214, 1},
    {test_purpose_215, 1},
    {test_purpose_216, 1},
    {test_purpose_217, 1},
    {test_purpose_218, 1},
    {test_purpose_219, 1},
    {test_purpose_220, 1},
    {test_purpose_221, 1},
    {test_purpose_222, 1},
    {NULL,0}
};
