/*
 * GtkTreeSelection methods tests
 * Testing GtkTreeSelection methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
gboolean global_result;
gint global_counter;
gint res = 0;

void global_func (GtkTreeModel* model,GtkTreePath *path,GtkTreeIter* iter,gpointer data)
{
    if (model == data) res = 1;
    
    global_result = TRUE;
}

gboolean global_selection_func (GtkTreeSelection *selection,GtkTreeModel *model,GtkTreePath *path, gboolean path_currently_selected, gpointer data)
{
    res++;
    return TRUE;
}

void global_changed (GtkTreeSelection *selection,gpointer data)
{
    global_counter ++;
}

void global_selected_func (GtkTreeModel* model,GtkTreePath *path,GtkTreeIter* iter,gpointer data)
{
    global_counter++;
}

struct ListSort
{
  gint number1;
  gint number2;
};

struct ListSort data[] =
{
  { 3, 4 },
  { 2, 6 },
  { 0, 49 },
  { 856856, 965 },
  { 1, 34663 },
};

struct ListSort child_data[] =
{
  { 10, 149 },
  { 12, 13 },
  { 1856856, 1965 },
  { 11, 15 },
  { 14, 14 },
};

const gint NUM_TREE_ELEMS = 5;


/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: Sets the selection mode of the selection.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_get_mode
 * Params: GtkTreeSelection *selection
 * Returns: GtkSelectionMode
 * Assertion: Gets the selection mode for selection.
 * Params Values: newly created GtkTreeSelection*
 * Expected: GTK_SELECTION_SINGLE  
 */
static void test_purpose_1()
{
    #define TYPE GTK_SELECTION_SINGLE
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkSelectionMode type;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (GTK_TREE_STORE (model), &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (GTK_TREE_STORE (model), &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    
    if (!selection)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TREE_SELECTION (selection))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_selection_set_mode (selection, TYPE);
    
    type = gtk_tree_selection_get_mode (selection);
    
    if (type != TYPE)
    {
        TEST_FAIL ("type = '%s', should be '%s'", type, (char*) TYPE)
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: Sets the selection mode of the selection.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_NONE
 * Expected: void
 * 
 * Name: gtk_tree_selection_get_mode
 * Params: GtkTreeSelection *selection
 * Returns: GtkSelectionMode
 * Assertion: Gets the selection mode for selection.
 * Params Values: newly created GtkTreeSelection*
 * Expected: GTK_SELECTION_NONE  
 */
static void test_purpose_2()
{
    #define TYPE GTK_SELECTION_NONE
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkSelectionMode type;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (GTK_TREE_STORE (model), &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (GTK_TREE_STORE (model), &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    
    if (!selection)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TREE_SELECTION (selection))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_selection_set_mode (selection, TYPE);
    
    type = gtk_tree_selection_get_mode (selection);
    
    if (type != TYPE)
    {
        TEST_FAIL ("type = '%s', should be '%s'", type, (char*) TYPE)
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: Sets the selection mode of the selection.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_get_mode
 * Params: GtkTreeSelection *selection
 * Returns: GtkSelectionMode
 * Assertion: Gets the selection mode for selection.
 * Params Values: newly created GtkTreeSelection*
 * Expected: GTK_SELECTION_BROWSE  
 */
static void test_purpose_3()
{
    #define TYPE GTK_SELECTION_BROWSE
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkSelectionMode type;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (GTK_TREE_STORE (model), &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (GTK_TREE_STORE (model), &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    
    if (!selection)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TREE_SELECTION (selection))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_selection_set_mode (selection, TYPE);
    
    type = gtk_tree_selection_get_mode (selection);
    
    if (type != TYPE)
    {
        TEST_FAIL ("type = '%s', should be '%s'", type, (char*) TYPE)
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: Sets the selection mode of the selection.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_get_mode
 * Params: GtkTreeSelection *selection
 * Returns: GtkSelectionMode
 * Assertion: Gets the selection mode for selection.
 * Params Values: newly created GtkTreeSelection*
 * Expected: GTK_SELECTION_MULTIPLE  
 */
static void test_purpose_4()
{
    #define TYPE GTK_SELECTION_MULTIPLE
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkSelectionMode type;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (GTK_TREE_STORE (model), &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (GTK_TREE_STORE (model), &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    
    if (!selection)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TREE_SELECTION (selection))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_selection_set_mode (selection, TYPE);
    
    type = gtk_tree_selection_get_mode (selection);
    
    if (type != TYPE)
    {
        TEST_FAIL ("type = '%s', should be '%s'", type, (char*) TYPE)
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "0:0"
 * Expected: void  
 */
static void test_purpose_5()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "0:0"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "0:1"
 * Expected: void  
 */
static void test_purpose_6()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "0:1"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "0:4"
 * Expected: void  
 */
static void test_purpose_7()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "0:4"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "1:0"
 * Expected: void  
 */
static void test_purpose_8()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "1:0"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "1:2"
 * Expected: void  
 */
static void test_purpose_9()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "1:2"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "1:4"
 * Expected: void  
 */
static void test_purpose_10()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "1:4"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "4:0"
 * Expected: void  
 */
static void test_purpose_11()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "4:0"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "4:1"
 * Expected: void  
 */
static void test_purpose_12()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "4:1"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "4:4"
 * Expected: void  
 */
static void test_purpose_13()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "4:4"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "0:0"
 * Expected: void  
 */
static void test_purpose_14()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "0:0"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "0:1"
 * Expected: void  
 */
static void test_purpose_15()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "0:1"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "0:2"
 * Expected: void  
 */
static void test_purpose_16()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "0:2"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "0:3"
 * Expected: void  
 */
static void test_purpose_17()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "0:3"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "0:4"
 * Expected: void  
 */
static void test_purpose_18()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "0:4"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "1:2"
 * Expected: void  
 */
static void test_purpose_19()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "1:2"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "1:3"
 * Expected: void  
 */
static void test_purpose_20()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "1:3"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "1:4"
 * Expected: void  
 */
static void test_purpose_21()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "1:4"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "4:0"
 * Expected: void  
 */
static void test_purpose_22()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "4:0"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "4:1"
 * Expected: void  
 */
static void test_purpose_23()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "4:1"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "4:2"
 * Expected: void  
 */
static void test_purpose_24()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "4:2"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "4:3"
 * Expected: void  
 */
static void test_purpose_25()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "4:3"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "4:4"
 * Expected: void  
 */
static void test_purpose_26()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "4:4"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "0:0"
 * Expected: void  
 */
static void test_purpose_27()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "0:0"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "0:1"
 * Expected: void  
 */
static void test_purpose_28()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "0:1"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "0:2"
 * Expected: void  
 */
static void test_purpose_29()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "0:2"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "0:3"
 * Expected: void  
 */
static void test_purpose_30()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "0:3"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "0:4"
 * Expected: void  
 */
static void test_purpose_31()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "0:4"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "1:0"
 * Expected: void  
 */
static void test_purpose_32()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "1:0"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "1:1"
 * Expected: void  
 */
static void test_purpose_33()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "1:1"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "1:2"
 * Expected: void  
 */
static void test_purpose_34()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "1:2"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "1:3"
 * Expected: void  
 */
static void test_purpose_35()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "1:3"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "1:4"
 * Expected: void  
 */
static void test_purpose_36()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "1:4"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "4:0"
 * Expected: void  
 */
static void test_purpose_37()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "4:0"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "4:1"
 * Expected: void  
 */
static void test_purpose_38()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "4:1"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "4:2"
 * Expected: void  
 */
static void test_purpose_39()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "4:2"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "4:3"
 * Expected: void  
 */
static void test_purpose_40()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "4:3"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_mode
 * Params: GtkTreeSelection *selection, GtkSelectionMode type
 * Returns: void
 * Assertion: If the previous type was GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.
 * Params Values: newly created GtkTreeSelection*, "4:4"
 * Expected: void  
 */
static void test_purpose_41()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "4:4"
    
    GtkWidget *tree_view;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeStore* model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean result = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("1: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_tree_selection_unselect_all (GTK_TREE_SELECTION (selection));
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
    gtk_tree_selection_select_range (selection, path, path);
    gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), MODE);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("2: path is not selected, PATH = %s, MODE = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_tree_view
 * Params: GtkTreeSelection *selection
 * Returns: GtkTreeView*
 * Assertion: Returns the tree view associated with selection.
 * Params Values: newly created GtkTreeSelection*
 * Expected: GtkTreeView*  
 */
static void test_purpose_42()
{
    
    GtkWidget *tree_view;
    GtkTreeView *real_tree_view;
    GtkTreeStore *model;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreeSelection *selection;
    GtkSelectionMode type;
    gpointer pointer;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    
    real_tree_view = gtk_tree_selection_get_tree_view (GTK_TREE_SELECTION (selection));
    if (GTK_WIDGET (real_tree_view) != tree_view)
    {
        TEST_FAIL("tree_view is not correct",NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_user_data
 * Params: GtkTreeSelection *selection
 * Returns: qpointer
 * Assertion: Returns the user data for the selection function.
 * Params Values: newly created GtkTreeSelection*
 * Expected: qpointer  
 */
static void test_purpose_43()
{
    #define DATA model
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkSelectionMode type;
    gpointer pointer;
    gint i;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    
    gtk_tree_selection_set_select_function (selection,(GtkTreeSelectionFunc)global_selection_func,DATA,NULL);
    
    pointer = gtk_tree_selection_get_user_data (GTK_TREE_SELECTION (selection));
    if (pointer != DATA)
    {
        TEST_FAIL ("User data is not returned",NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_user_data
 * Params: GtkTreeSelection *selection
 * Returns: qpointer
 * Assertion: Returns the user data for the selection function.
 * Params Values: newly created GtkTreeSelection*
 * Expected: qpointer  
 */
static void test_purpose_44()
{
    #define DATA tree_view
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkSelectionMode type;
    gpointer pointer;
    gint i;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    
    gtk_tree_selection_set_select_function (selection,(GtkTreeSelectionFunc)global_selection_func,DATA,NULL);
    
    pointer = gtk_tree_selection_get_user_data (GTK_TREE_SELECTION (selection));
    if (pointer != DATA)
    {
        TEST_FAIL ("User data is not returned",NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_45()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "0:0"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_46()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "0:1"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_47()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "0:2"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_48()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "0:3"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_49()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "0:4"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_50()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "1:0"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_51()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "1:1"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_52()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "1:2"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_53()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "1:3"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_54()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "1:4"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_55()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "2:0"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_56()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "2:1"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_57()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "2:2"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_58()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "2:3"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_59()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "2:4"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_60()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "3:0"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_61()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "3:1"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_62()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "3:2"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_63()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "3:3"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_64()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "3:4"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_65()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "4:0"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_66()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "4:1"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_67()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "4:2"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_68()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "4:3"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_69()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "4:4"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_70()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "0:0"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_71()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "0:1"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_72()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "0:2"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_73()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "0:3"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_74()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "0:4"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_75()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "1:0"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_76()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "1:1"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_77()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "1:2"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_78()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "1:3"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_79()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "1:4"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_80()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "2:0"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_81()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "2:1"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_82()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "2:2"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_83()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "2:3"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_84()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "2:4"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_85()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "3:0"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_86()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "3:1"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_87()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "3:2"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_88()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "3:3"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_89()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "3:4"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_90()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "4:0"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_91()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "4:1"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_92()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "4:2"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_93()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "4:3"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: Sets iter to the currently selected node if selection is set to GTK_SELECTION_SINGLE or GTK_SELECTION_BROWSE.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean
 * 
 * Name: gtk_tree_selection_get_selected 
 * Params: GtkTreeSelection *selection, GtkTreeModel **model, GtkTreeIter *iter
 * Returns: qboolean
 * Assertion: iter may be NULL if you just want to test if selection has any selected nodes.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel**, GtkTreeIter*
 * Expected: qboolean  
 */
static void test_purpose_94()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "4:4"
    
    GtkWidget *tree_view;
    GtkTreeStore* model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter child_iter;
    gboolean val;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_selection_get_selected (GTK_TREE_SELECTION (selection), NULL, &select_iter);
    if (!val)
    {
        TEST_FAIL ("There is no selected node",NULL);
    } else if (iter.stamp != select_iter.stamp) {
        TEST_FAIL ("iter.stamp != select_iter.stamp", NULL);
    } 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_95()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "0:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_96()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "0:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_97()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "0:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_98()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "0:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_99()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "0:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_100()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "1:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_101()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "1:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_102()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "1:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_103()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "1:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_104()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "1:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_105()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "2:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_106()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "2:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_107()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "2:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_108()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "2:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_109()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "2:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_110()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "3:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_111()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "3:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_112()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "3:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_113()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "3:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_114()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "3:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_115()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "4:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_116()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "4:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_117()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "4:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_118()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "4:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_SINGLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_119()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "4:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_120()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "0:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_121()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "0:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_122()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "0:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_123()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "0:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_124()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "0:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_125()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "1:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_126()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "1:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_127()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "1:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_128()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "1:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_129()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "1:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_130()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "2:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_131()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "2:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_132()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "2:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_133()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "2:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_134()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "2:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_135()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "3:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_136()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "3:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_137()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "3:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_138()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "3:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_139()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "3:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_140()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "4:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_141()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "4:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_142()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "4:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_143()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "4:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_BROWSE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_144()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "4:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_145()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "0:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_146()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "0:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_147()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "0:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_148()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "0:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_149()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "0:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_150()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "1:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_151()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "1:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_152()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "1:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_153()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "1:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_154()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "1:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_155()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "2:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_156()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "2:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_157()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "2:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_158()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "2:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_159()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "2:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_160()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "3:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_161()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "3:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_162()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "3:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_163()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "3:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_164()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "3:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_165()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "4:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_166()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "4:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_167()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "4:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_168()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "4:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Select the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_path 
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: void
 * Assertion: Unselects the row at path.
 * Params Values: newly created GtkTreeSelection*, GTK_SELECTION_MULTIPLE
 * Expected: void
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: Returns TRUE if the row pointed to by path is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected
 * 
 * Name: gtk_tree_selection_path_is_selected
 * Params: GtkTreeSelection *selection, GtkTreePath *path
 * Returns: gboolean
 * Assertion: If path does not point to a valid location, FALSE is returned
 * Params Values: newly created GtkTreeSelection*, GtkTreePath*
 * Expected: TRUE if path is selected, FALSE if unselected  
 */
static void test_purpose_169()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "4:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter select_iter;
    GtkTreeIter unselect_iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (!result)
    {
        TEST_FAIL ("Path '%s' is not selected, mode = %d", PATH, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_path (selection, path);
    
    result = gtk_tree_selection_path_is_selected (selection, path);
    if (result)
    {
        TEST_FAIL ("Path '%s' is not unselected, mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_selected_foreach
 * Params: GtkTreeSelection *selection,GtkTreeSelectionForeachFunc func, gpointer data
 * Returns: void
 * Assertion: Calls a function for each selected node.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionForeachFunc, gpointer 
 * Expected: void  
 */
static void test_purpose_170()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "0:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = FALSE;
    
    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    gtk_tree_selection_selected_foreach (selection, global_func, model);
    
    if (!global_result)
    {
        TEST_FAIL ("Function is not called.",NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_selected_foreach
 * Params: GtkTreeSelection *selection,GtkTreeSelectionForeachFunc func, gpointer data
 * Returns: void
 * Assertion: Calls a function for each selected node.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionForeachFunc, gpointer 
 * Expected: void  
 */
static void test_purpose_171()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "2:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = FALSE;
    
    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    gtk_tree_selection_selected_foreach (selection, global_func, model);
    
    if (!global_result)
    {
        TEST_FAIL ("Function is not called.",NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_selected_foreach
 * Params: GtkTreeSelection *selection,GtkTreeSelectionForeachFunc func, gpointer data
 * Returns: void
 * Assertion: Calls a function for each selected node.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionForeachFunc, gpointer 
 * Expected: void  
 */
static void test_purpose_172()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "0:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = FALSE;
    
    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    gtk_tree_selection_selected_foreach (selection, global_func, model);
    
    if (!global_result)
    {
        TEST_FAIL ("Function is not called.",NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_selected_foreach
 * Params: GtkTreeSelection *selection,GtkTreeSelectionForeachFunc func, gpointer data
 * Returns: void
 * Assertion: Calls a function for each selected node.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionForeachFunc, gpointer 
 * Expected: void  
 */
static void test_purpose_173()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "2:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = FALSE;
    
    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    gtk_tree_selection_selected_foreach (selection, global_func, model);
    
    if (!global_result)
    {
        TEST_FAIL ("Function is not called.",NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_selected_foreach
 * Params: GtkTreeSelection *selection,GtkTreeSelectionForeachFunc func, gpointer data
 * Returns: void
 * Assertion: Calls a function for each selected node.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionForeachFunc, gpointer 
 * Expected: void  
 */
static void test_purpose_174()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "0:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = FALSE;
    
    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    gtk_tree_selection_selected_foreach (selection, global_func, model);
    
    if (!global_result)
    {
        TEST_FAIL ("Function is not called.",NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_selected_foreach
 * Params: GtkTreeSelection *selection,GtkTreeSelectionForeachFunc func, gpointer data
 * Returns: void
 * Assertion: Calls a function for each selected node.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionForeachFunc, gpointer 
 * Expected: void  
 */
static void test_purpose_175()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "2:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = FALSE;
    
    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    gtk_tree_selection_select_path (selection, path);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    
    gtk_tree_selection_selected_foreach (selection, global_func, model);
    
    if (!global_result)
    {
        TEST_FAIL ("Function is not called.",NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_176()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "0:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_177()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "0:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_178()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "0:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_179()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "0:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_180()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "0:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_181()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "1:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_182()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "1:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_183()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "1:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_184()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "1:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_185()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "1:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_186()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "2:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_187()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "2:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_188()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "2:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_189()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "2:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_190()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "2:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_191()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "3:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_192()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "3:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_193()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "3:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_194()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "3:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_195()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "3:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_196()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "4:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_197()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "4:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_198()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "4:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_199()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "4:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_200()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "4:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_201()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "0:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_202()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "0:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_203()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "0:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_204()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "0:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_205()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "0:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_206()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "1:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_207()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "1:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_208()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "1:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_209()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "1:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_210()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "1:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_211()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "2:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_212()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "2:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_213()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "2:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_214()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "2:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_215()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "2:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_216()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "3:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_217()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "3:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_218()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "3:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_219()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "3:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_220()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "3:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_221()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "4:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_222()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "4:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_223()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "4:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_224()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "4:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_225()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "4:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_226()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "0:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_227()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "0:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_228()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "0:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_229()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "0:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_230()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "0:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_231()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "1:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_232()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "1:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_233()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "1:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_234()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "1:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_235()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "1:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_236()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "2:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_237()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "2:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_238()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "2:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_239()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "2:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_240()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "2:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_241()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "3:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_242()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "3:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_243()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "3:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_244()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "3:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_245()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "3:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_246()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "4:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_247()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "4:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_248()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "4:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_249()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "4:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the selection function.
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void
 * 
 * Name: gtk_tree_selection_set_select_function
 * Params: GtkTreeSelection *selection, GtkTreeSelectionFunc func,gpointer data,GtkDestroyNotify destroy
 * Returns: void
 * Assertion: If set, this function is called before any node is selected or unselected, giving some control over which nodes are selected. 
 * Params Values: newly created GtkTreeSelection*,GtkTreeSelectionFunc,gpointer,NULL
 * Expected: void  
 */
static void test_purpose_250()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "4:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    gboolean val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc)global_selection_func, model, NULL);
    
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    
    res = 0;
    gtk_tree_selection_select_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("select: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    res = 0;
    gtk_tree_selection_unselect_path (selection, path);
    if (res < 1)
    {
        TEST_FAIL ("unselect: selection function was not called, res = %d, should be > 0, path = '%s', mode = %d", res, PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_all 
 * Params: GtkTreeSelection *selection
 * Returns: void
 * Assertion: Selects all the nodes.
 * Params Values: newly created GtkTreeSelection*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_all 
 * Params: GtkTreeSelection *selection
 * Returns: void
 * Assertion: Unselects all the nodes.
 * Params Values: newly created GtkTreeSelection*
 * Expected: void  
 */
static void test_purpose_251()
{
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    }
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    
    g_signal_connect (G_OBJECT (selection), "changed", 
                        GTK_SIGNAL_FUNC (global_changed), NULL);
    
    gtk_tree_selection_select_all (selection);
    if (global_counter == 0)
    {
        TEST_FAIL ("Iter is not selected",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_all (selection);
    global_counter = 0;
    
    gtk_tree_selection_selected_foreach (selection, global_selected_func, NULL);
    if (global_counter != 0)
    {
        TEST_FAIL ("%d unseleted items after unselect_all() remained", 
                   global_counter);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_252()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "0:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_253()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "0:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_254()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "0:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_255()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "0:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_256()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "0:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_257()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "1:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_258()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "1:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_259()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "1:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_260()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "1:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_261()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "1:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_262()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "2:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_263()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "2:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_264()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "2:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_265()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "2:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_266()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "2:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_267()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "3:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_268()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "3:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_269()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "3:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_270()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "3:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_271()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "3:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_272()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "4:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_273()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "4:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_274()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "4:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_275()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "4:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_276()
{
    #define MODE GTK_SELECTION_SINGLE
    #define PATH "4:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_277()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "0:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_278()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "0:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_279()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "0:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_280()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "0:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_281()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "0:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_282()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "1:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_283()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "1:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_284()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "1:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_285()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "1:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_286()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "1:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_287()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "2:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_288()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "2:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_289()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "2:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_290()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "2:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_291()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "2:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_292()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "3:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_293()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "3:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_294()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "3:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_295()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "3:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_296()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "3:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_297()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "4:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_298()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "4:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_299()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "4:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_300()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "4:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_301()
{
    #define MODE GTK_SELECTION_BROWSE
    #define PATH "4:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_302()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "0:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_303()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "0:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_304()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "0:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_305()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "0:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_306()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "0:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_307()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "1:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_308()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "1:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_309()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "1:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_310()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "1:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_311()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "1:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_312()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "2:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_313()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "2:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_314()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "2:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_315()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "2:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_316()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "2:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_317()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "3:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_318()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "3:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_319()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "3:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_320()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "3:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_321()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "3:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_322()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "4:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_323()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "4:1"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_324()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "4:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_325()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "4:3"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Selects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_unselect_iter 
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: void
 * Assertion: Unselects the specified iterator.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: void
 * 
 * Name: gtk_tree_selection_iter_is_selected
 * Params: GtkTreeSelection *selection, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if the row at iter is currently selected.
 * Params Values: newly created GtkTreeSelection*, GtkTreeIter*
 * Expected: TRUE, if iter is selected  
 */
static void test_purpose_326()
{
    #define MODE GTK_SELECTION_MULTIPLE
    #define PATH "4:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    guint i;
    guint j;
    gboolean val;
    gboolean result = FALSE;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, MODE);
    path = gtk_tree_path_new_from_string (PATH);
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned",NULL);
        return;
    }
    
    gtk_tree_selection_select_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (!result)
    {
        TEST_FAIL ("Iter is not selected, path = '%s', mode = %d", PATH, MODE);
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_iter (selection, &iter);
    result = gtk_tree_selection_iter_is_selected (selection, &iter);
    if (result)
    {
        TEST_FAIL ("Iter is not unselected, path = '%s', mode = %d", PATH, MODE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef MODE
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_range
 * Params: GtkTreeSelection *selection, GtkTreePath *start_path, GtkTreePath *end_path
 * Returns: void
 * Assertion: Selects a range of nodes, determined by start_path and end_path inclusive.
 * Params Values: newly created GtkTreeSelection*, <%2%>, <%3%>
 * Expected: void  
 */
static void test_purpose_327()
{
    #define START_PATH "0:0"
    #define END_PATH "4:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *start_path;
    GtkTreePath *end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreeIter ch_iter;
    GtkTreeIter next_iter;
    guint i;
    guint j;
    gchar* iter_path_str;
    gboolean has_first_iter = FALSE;
    gboolean selected = FALSE;
    gboolean val = FALSE;
    gboolean has_children = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    start_path = gtk_tree_path_new_from_string (START_PATH);
    end_path = gtk_tree_path_new_from_string (END_PATH);
    
    gtk_tree_selection_select_range (selection, start_path, end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, start_path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned!",NULL);
        return;
    }
    
    has_first_iter = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), &iter);
    if (!has_first_iter)
    {
        TEST_FAIL ("model doesn't have the first iter", NULL);
        return;
    }
    
    start_path = gtk_tree_path_new_from_string (START_PATH);
    end_path = gtk_tree_path_new_from_string (END_PATH);
    while (gtk_tree_model_iter_children 
           (GTK_TREE_MODEL (model), &ch_iter, &iter))
    {
        
        gboolean has_next = FALSE;
        do {
            GtkTreePath* ch_path;
            
            ch_path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &ch_iter);
            if (gtk_tree_path_compare (ch_path, start_path) >= 0
                && gtk_tree_path_compare (ch_path, end_path) <= 0)
            {
                if (!gtk_tree_selection_iter_is_selected (selection, &ch_iter))
                {
                    TEST_FAIL ("1:path \"%s\" from the selected range is not selected actially", gtk_tree_path_to_string (ch_path));
                }
            } else {
                if (gtk_tree_selection_iter_is_selected (selection, &ch_iter))
                {
                    TEST_FAIL ("2:path \"%s\" which is not from the selected range is selected actually", gtk_tree_path_to_string (ch_path));
                }
            }
            has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &ch_iter);
        } while (has_next);
        if (!gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter))
        {
            break;
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef START_PATH
    #undef END_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_range
 * Params: GtkTreeSelection *selection, GtkTreePath *start_path, GtkTreePath *end_path
 * Returns: void
 * Assertion: Selects a range of nodes, determined by start_path and end_path inclusive.
 * Params Values: newly created GtkTreeSelection*, <%2%>, <%3%>
 * Expected: void  
 */
static void test_purpose_328()
{
    #define START_PATH "0:0"
    #define END_PATH "0:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *start_path;
    GtkTreePath *end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreeIter ch_iter;
    GtkTreeIter next_iter;
    guint i;
    guint j;
    gchar* iter_path_str;
    gboolean has_first_iter = FALSE;
    gboolean selected = FALSE;
    gboolean val = FALSE;
    gboolean has_children = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    start_path = gtk_tree_path_new_from_string (START_PATH);
    end_path = gtk_tree_path_new_from_string (END_PATH);
    
    gtk_tree_selection_select_range (selection, start_path, end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, start_path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned!",NULL);
        return;
    }
    
    has_first_iter = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), &iter);
    if (!has_first_iter)
    {
        TEST_FAIL ("model doesn't have the first iter", NULL);
        return;
    }
    
    start_path = gtk_tree_path_new_from_string (START_PATH);
    end_path = gtk_tree_path_new_from_string (END_PATH);
    while (gtk_tree_model_iter_children 
           (GTK_TREE_MODEL (model), &ch_iter, &iter))
    {
        
        gboolean has_next = FALSE;
        do {
            GtkTreePath* ch_path;
            
            ch_path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &ch_iter);
            if (gtk_tree_path_compare (ch_path, start_path) >= 0
                && gtk_tree_path_compare (ch_path, end_path) <= 0)
            {
                if (!gtk_tree_selection_iter_is_selected (selection, &ch_iter))
                {
                    TEST_FAIL ("1:path \"%s\" from the selected range is not selected actially", gtk_tree_path_to_string (ch_path));
                }
            } else {
                if (gtk_tree_selection_iter_is_selected (selection, &ch_iter))
                {
                    TEST_FAIL ("2:path \"%s\" which is not from the selected range is selected actually", gtk_tree_path_to_string (ch_path));
                }
            }
            has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &ch_iter);
        } while (has_next);
        if (!gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter))
        {
            break;
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef START_PATH
    #undef END_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_range
 * Params: GtkTreeSelection *selection, GtkTreePath *start_path, GtkTreePath *end_path
 * Returns: void
 * Assertion: Selects a range of nodes, determined by start_path and end_path inclusive.
 * Params Values: newly created GtkTreeSelection*, <%2%>, <%3%>
 * Expected: void  
 */
static void test_purpose_329()
{
    #define START_PATH "4:4"
    #define END_PATH "4:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *start_path;
    GtkTreePath *end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreeIter ch_iter;
    GtkTreeIter next_iter;
    guint i;
    guint j;
    gchar* iter_path_str;
    gboolean has_first_iter = FALSE;
    gboolean selected = FALSE;
    gboolean val = FALSE;
    gboolean has_children = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    start_path = gtk_tree_path_new_from_string (START_PATH);
    end_path = gtk_tree_path_new_from_string (END_PATH);
    
    gtk_tree_selection_select_range (selection, start_path, end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, start_path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned!",NULL);
        return;
    }
    
    has_first_iter = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), &iter);
    if (!has_first_iter)
    {
        TEST_FAIL ("model doesn't have the first iter", NULL);
        return;
    }
    
    start_path = gtk_tree_path_new_from_string (START_PATH);
    end_path = gtk_tree_path_new_from_string (END_PATH);
    while (gtk_tree_model_iter_children 
           (GTK_TREE_MODEL (model), &ch_iter, &iter))
    {
        
        gboolean has_next = FALSE;
        do {
            GtkTreePath* ch_path;
            
            ch_path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &ch_iter);
            if (gtk_tree_path_compare (ch_path, start_path) >= 0
                && gtk_tree_path_compare (ch_path, end_path) <= 0)
            {
                if (!gtk_tree_selection_iter_is_selected (selection, &ch_iter))
                {
                    TEST_FAIL ("1:path \"%s\" from the selected range is not selected actially", gtk_tree_path_to_string (ch_path));
                }
            } else {
                if (gtk_tree_selection_iter_is_selected (selection, &ch_iter))
                {
                    TEST_FAIL ("2:path \"%s\" which is not from the selected range is selected actually", gtk_tree_path_to_string (ch_path));
                }
            }
            has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &ch_iter);
        } while (has_next);
        if (!gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter))
        {
            break;
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef START_PATH
    #undef END_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_range
 * Params: GtkTreeSelection *selection, GtkTreePath *start_path, GtkTreePath *end_path
 * Returns: void
 * Assertion: Selects a range of nodes, determined by start_path and end_path inclusive.
 * Params Values: newly created GtkTreeSelection*, <%2%>, <%3%>
 * Expected: void  
 */
static void test_purpose_330()
{
    #define START_PATH "2:0"
    #define END_PATH "4:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *start_path;
    GtkTreePath *end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreeIter ch_iter;
    GtkTreeIter next_iter;
    guint i;
    guint j;
    gchar* iter_path_str;
    gboolean has_first_iter = FALSE;
    gboolean selected = FALSE;
    gboolean val = FALSE;
    gboolean has_children = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    start_path = gtk_tree_path_new_from_string (START_PATH);
    end_path = gtk_tree_path_new_from_string (END_PATH);
    
    gtk_tree_selection_select_range (selection, start_path, end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, start_path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned!",NULL);
        return;
    }
    
    has_first_iter = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), &iter);
    if (!has_first_iter)
    {
        TEST_FAIL ("model doesn't have the first iter", NULL);
        return;
    }
    
    start_path = gtk_tree_path_new_from_string (START_PATH);
    end_path = gtk_tree_path_new_from_string (END_PATH);
    while (gtk_tree_model_iter_children 
           (GTK_TREE_MODEL (model), &ch_iter, &iter))
    {
        
        gboolean has_next = FALSE;
        do {
            GtkTreePath* ch_path;
            
            ch_path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &ch_iter);
            if (gtk_tree_path_compare (ch_path, start_path) >= 0
                && gtk_tree_path_compare (ch_path, end_path) <= 0)
            {
                if (!gtk_tree_selection_iter_is_selected (selection, &ch_iter))
                {
                    TEST_FAIL ("1:path \"%s\" from the selected range is not selected actially", gtk_tree_path_to_string (ch_path));
                }
            } else {
                if (gtk_tree_selection_iter_is_selected (selection, &ch_iter))
                {
                    TEST_FAIL ("2:path \"%s\" which is not from the selected range is selected actually", gtk_tree_path_to_string (ch_path));
                }
            }
            has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &ch_iter);
        } while (has_next);
        if (!gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter))
        {
            break;
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef START_PATH
    #undef END_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_select_range
 * Params: GtkTreeSelection *selection, GtkTreePath *start_path, GtkTreePath *end_path
 * Returns: void
 * Assertion: Selects a range of nodes, determined by start_path and end_path inclusive.
 * Params Values: newly created GtkTreeSelection*, <%2%>, <%3%>
 * Expected: void  
 */
static void test_purpose_331()
{
    #define START_PATH "2:3"
    #define END_PATH "3:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *start_path;
    GtkTreePath *end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreeIter ch_iter;
    GtkTreeIter next_iter;
    guint i;
    guint j;
    gchar* iter_path_str;
    gboolean has_first_iter = FALSE;
    gboolean selected = FALSE;
    gboolean val = FALSE;
    gboolean has_children = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    start_path = gtk_tree_path_new_from_string (START_PATH);
    end_path = gtk_tree_path_new_from_string (END_PATH);
    
    gtk_tree_selection_select_range (selection, start_path, end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, start_path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned!",NULL);
        return;
    }
    
    has_first_iter = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), &iter);
    if (!has_first_iter)
    {
        TEST_FAIL ("model doesn't have the first iter", NULL);
        return;
    }
    
    start_path = gtk_tree_path_new_from_string (START_PATH);
    end_path = gtk_tree_path_new_from_string (END_PATH);
    while (gtk_tree_model_iter_children 
           (GTK_TREE_MODEL (model), &ch_iter, &iter))
    {
        
        gboolean has_next = FALSE;
        do {
            GtkTreePath* ch_path;
            
            ch_path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &ch_iter);
            if (gtk_tree_path_compare (ch_path, start_path) >= 0
                && gtk_tree_path_compare (ch_path, end_path) <= 0)
            {
                if (!gtk_tree_selection_iter_is_selected (selection, &ch_iter))
                {
                    TEST_FAIL ("1:path \"%s\" from the selected range is not selected actially", gtk_tree_path_to_string (ch_path));
                }
            } else {
                if (gtk_tree_selection_iter_is_selected (selection, &ch_iter))
                {
                    TEST_FAIL ("2:path \"%s\" which is not from the selected range is selected actually", gtk_tree_path_to_string (ch_path));
                }
            }
            has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &ch_iter);
        } while (has_next);
        if (!gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter))
        {
            break;
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef START_PATH
    #undef END_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_unselect_range
 * Params: GtkTreeSelection *selection, GtkTreePath *start_path, GtkTreePath *end_path
 * Returns: void
 * Assertion: Unselects a range of nodes, determined by start_path and end_path inclusive.
 * Params Values: newly created GtkTreeSelection*, "4", 0
 * Expected: void  
 */
static void test_purpose_332()
{
    #define SELECT_START_PATH "0"
    #define SELECT_END_PATH "4"
    #define UNSELECT_START_PATH "0"
    #define UNSELECT_END_PATH "4"
    #define CORRECT_SELECTED_ROWS_COUNT 0
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *select_start_path;
    GtkTreePath *select_end_path;
    GtkTreePath *unselect_start_path;
    GtkTreePath *unselect_end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreeIter ch_iter;
    GtkTreeIter next_iter;
    gint selected_rows_count;
    guint i;
    guint j;
    gchar* iter_path_str;
    gboolean has_first_iter = FALSE;
    gboolean selected = FALSE;
    gboolean val = FALSE;
    gboolean has_children = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    
    select_start_path = gtk_tree_path_new_from_string (SELECT_START_PATH);
    select_end_path = gtk_tree_path_new_from_string (SELECT_END_PATH);
    unselect_start_path = gtk_tree_path_new_from_string (UNSELECT_START_PATH);
    unselect_end_path = gtk_tree_path_new_from_string (UNSELECT_END_PATH);
    
    gtk_tree_selection_select_range (selection, select_start_path, select_end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_range (selection, unselect_start_path, unselect_end_path);
    selected_rows_count = gtk_tree_selection_count_selected_rows (selection);
    if (selected_rows_count != CORRECT_SELECTED_ROWS_COUNT)
    {
        TEST_FAIL ("%d instead of %d rows selected after unselection", 
                   selected_rows_count, CORRECT_SELECTED_ROWS_COUNT);
    }
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, unselect_start_path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned!",NULL);
        return;
    }
    
    has_first_iter = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), &iter);
    if (!has_first_iter)
    {
        TEST_FAIL ("model doesn't have the first iter", NULL);
        return;
    }
    
    while (gtk_tree_model_iter_children 
           (GTK_TREE_MODEL (model), &ch_iter, &iter))
    {
        
        gboolean has_next = FALSE;
        do 
        {
            GtkTreePath* ch_path;
            
            ch_path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &ch_iter);
            if (gtk_tree_path_compare (ch_path, unselect_start_path) >= 0
                && gtk_tree_path_compare (ch_path, unselect_end_path) <= 0)
            {
                if (gtk_tree_selection_iter_is_selected (selection, &ch_iter))
                {
                    TEST_FAIL ("1:path \"%s\" from unselected range is selected actially", gtk_tree_path_to_string (ch_path));
                }
            } 
            has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &ch_iter);
        } while (has_next);
    
        if (!gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter))
        {
            break;
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef SELECT_START_PATH
    #undef SELECT_END_PATH
    #undef UNSELECT_START_PATH
    #undef UNSELECT_END_PATH
    #undef CORRECT_SELECTED_ROWS_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_unselect_range
 * Params: GtkTreeSelection *selection, GtkTreePath *start_path, GtkTreePath *end_path
 * Returns: void
 * Assertion: Unselects a range of nodes, determined by start_path and end_path inclusive.
 * Params Values: newly created GtkTreeSelection*, "4:4", 1
 * Expected: void  
 */
static void test_purpose_333()
{
    #define SELECT_START_PATH "0"
    #define SELECT_END_PATH "4"
    #define UNSELECT_START_PATH "0:0"
    #define UNSELECT_END_PATH "4:4"
    #define CORRECT_SELECTED_ROWS_COUNT 1
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *select_start_path;
    GtkTreePath *select_end_path;
    GtkTreePath *unselect_start_path;
    GtkTreePath *unselect_end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreeIter ch_iter;
    GtkTreeIter next_iter;
    gint selected_rows_count;
    guint i;
    guint j;
    gchar* iter_path_str;
    gboolean has_first_iter = FALSE;
    gboolean selected = FALSE;
    gboolean val = FALSE;
    gboolean has_children = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    
    select_start_path = gtk_tree_path_new_from_string (SELECT_START_PATH);
    select_end_path = gtk_tree_path_new_from_string (SELECT_END_PATH);
    unselect_start_path = gtk_tree_path_new_from_string (UNSELECT_START_PATH);
    unselect_end_path = gtk_tree_path_new_from_string (UNSELECT_END_PATH);
    
    gtk_tree_selection_select_range (selection, select_start_path, select_end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_range (selection, unselect_start_path, unselect_end_path);
    selected_rows_count = gtk_tree_selection_count_selected_rows (selection);
    if (selected_rows_count != CORRECT_SELECTED_ROWS_COUNT)
    {
        TEST_FAIL ("%d instead of %d rows selected after unselection", 
                   selected_rows_count, CORRECT_SELECTED_ROWS_COUNT);
    }
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, unselect_start_path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned!",NULL);
        return;
    }
    
    has_first_iter = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), &iter);
    if (!has_first_iter)
    {
        TEST_FAIL ("model doesn't have the first iter", NULL);
        return;
    }
    
    while (gtk_tree_model_iter_children 
           (GTK_TREE_MODEL (model), &ch_iter, &iter))
    {
        
        gboolean has_next = FALSE;
        do 
        {
            GtkTreePath* ch_path;
            
            ch_path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &ch_iter);
            if (gtk_tree_path_compare (ch_path, unselect_start_path) >= 0
                && gtk_tree_path_compare (ch_path, unselect_end_path) <= 0)
            {
                if (gtk_tree_selection_iter_is_selected (selection, &ch_iter))
                {
                    TEST_FAIL ("1:path \"%s\" from unselected range is selected actially", gtk_tree_path_to_string (ch_path));
                }
            } 
            has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &ch_iter);
        } while (has_next);
    
        if (!gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter))
        {
            break;
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef SELECT_START_PATH
    #undef SELECT_END_PATH
    #undef UNSELECT_START_PATH
    #undef UNSELECT_END_PATH
    #undef CORRECT_SELECTED_ROWS_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_unselect_range
 * Params: GtkTreeSelection *selection, GtkTreePath *start_path, GtkTreePath *end_path
 * Returns: void
 * Assertion: Unselects a range of nodes, determined by start_path and end_path inclusive.
 * Params Values: newly created GtkTreeSelection*, "3:2", 23
 * Expected: void  
 */
static void test_purpose_334()
{
    #define SELECT_START_PATH "0:0"
    #define SELECT_END_PATH "4:4"
    #define UNSELECT_START_PATH "2:3"
    #define UNSELECT_END_PATH "3:2"
    #define CORRECT_SELECTED_ROWS_COUNT 23
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *select_start_path;
    GtkTreePath *select_end_path;
    GtkTreePath *unselect_start_path;
    GtkTreePath *unselect_end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreeIter ch_iter;
    GtkTreeIter next_iter;
    gint selected_rows_count;
    guint i;
    guint j;
    gchar* iter_path_str;
    gboolean has_first_iter = FALSE;
    gboolean selected = FALSE;
    gboolean val = FALSE;
    gboolean has_children = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    
    select_start_path = gtk_tree_path_new_from_string (SELECT_START_PATH);
    select_end_path = gtk_tree_path_new_from_string (SELECT_END_PATH);
    unselect_start_path = gtk_tree_path_new_from_string (UNSELECT_START_PATH);
    unselect_end_path = gtk_tree_path_new_from_string (UNSELECT_END_PATH);
    
    gtk_tree_selection_select_range (selection, select_start_path, select_end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_range (selection, unselect_start_path, unselect_end_path);
    selected_rows_count = gtk_tree_selection_count_selected_rows (selection);
    if (selected_rows_count != CORRECT_SELECTED_ROWS_COUNT)
    {
        TEST_FAIL ("%d instead of %d rows selected after unselection", 
                   selected_rows_count, CORRECT_SELECTED_ROWS_COUNT);
    }
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, unselect_start_path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned!",NULL);
        return;
    }
    
    has_first_iter = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), &iter);
    if (!has_first_iter)
    {
        TEST_FAIL ("model doesn't have the first iter", NULL);
        return;
    }
    
    while (gtk_tree_model_iter_children 
           (GTK_TREE_MODEL (model), &ch_iter, &iter))
    {
        
        gboolean has_next = FALSE;
        do 
        {
            GtkTreePath* ch_path;
            
            ch_path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &ch_iter);
            if (gtk_tree_path_compare (ch_path, unselect_start_path) >= 0
                && gtk_tree_path_compare (ch_path, unselect_end_path) <= 0)
            {
                if (gtk_tree_selection_iter_is_selected (selection, &ch_iter))
                {
                    TEST_FAIL ("1:path \"%s\" from unselected range is selected actially", gtk_tree_path_to_string (ch_path));
                }
            } 
            has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &ch_iter);
        } while (has_next);
    
        if (!gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter))
        {
            break;
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef SELECT_START_PATH
    #undef SELECT_END_PATH
    #undef UNSELECT_START_PATH
    #undef UNSELECT_END_PATH
    #undef CORRECT_SELECTED_ROWS_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_unselect_range
 * Params: GtkTreeSelection *selection, GtkTreePath *start_path, GtkTreePath *end_path
 * Returns: void
 * Assertion: Unselects a range of nodes, determined by start_path and end_path inclusive.
 * Params Values: newly created GtkTreeSelection*, "0:0", 0
 * Expected: void  
 */
static void test_purpose_335()
{
    #define SELECT_START_PATH "0:0"
    #define SELECT_END_PATH "0:0"
    #define UNSELECT_START_PATH "0:0"
    #define UNSELECT_END_PATH "0:0"
    #define CORRECT_SELECTED_ROWS_COUNT 0
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *select_start_path;
    GtkTreePath *select_end_path;
    GtkTreePath *unselect_start_path;
    GtkTreePath *unselect_end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreeIter ch_iter;
    GtkTreeIter next_iter;
    gint selected_rows_count;
    guint i;
    guint j;
    gchar* iter_path_str;
    gboolean has_first_iter = FALSE;
    gboolean selected = FALSE;
    gboolean val = FALSE;
    gboolean has_children = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    
    select_start_path = gtk_tree_path_new_from_string (SELECT_START_PATH);
    select_end_path = gtk_tree_path_new_from_string (SELECT_END_PATH);
    unselect_start_path = gtk_tree_path_new_from_string (UNSELECT_START_PATH);
    unselect_end_path = gtk_tree_path_new_from_string (UNSELECT_END_PATH);
    
    gtk_tree_selection_select_range (selection, select_start_path, select_end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_range (selection, unselect_start_path, unselect_end_path);
    selected_rows_count = gtk_tree_selection_count_selected_rows (selection);
    if (selected_rows_count != CORRECT_SELECTED_ROWS_COUNT)
    {
        TEST_FAIL ("%d instead of %d rows selected after unselection", 
                   selected_rows_count, CORRECT_SELECTED_ROWS_COUNT);
    }
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, unselect_start_path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned!",NULL);
        return;
    }
    
    has_first_iter = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), &iter);
    if (!has_first_iter)
    {
        TEST_FAIL ("model doesn't have the first iter", NULL);
        return;
    }
    
    while (gtk_tree_model_iter_children 
           (GTK_TREE_MODEL (model), &ch_iter, &iter))
    {
        
        gboolean has_next = FALSE;
        do 
        {
            GtkTreePath* ch_path;
            
            ch_path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &ch_iter);
            if (gtk_tree_path_compare (ch_path, unselect_start_path) >= 0
                && gtk_tree_path_compare (ch_path, unselect_end_path) <= 0)
            {
                if (gtk_tree_selection_iter_is_selected (selection, &ch_iter))
                {
                    TEST_FAIL ("1:path \"%s\" from unselected range is selected actially", gtk_tree_path_to_string (ch_path));
                }
            } 
            has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &ch_iter);
        } while (has_next);
    
        if (!gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter))
        {
            break;
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef SELECT_START_PATH
    #undef SELECT_END_PATH
    #undef UNSELECT_START_PATH
    #undef UNSELECT_END_PATH
    #undef CORRECT_SELECTED_ROWS_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_unselect_range
 * Params: GtkTreeSelection *selection, GtkTreePath *start_path, GtkTreePath *end_path
 * Returns: void
 * Assertion: Unselects a range of nodes, determined by start_path and end_path inclusive.
 * Params Values: newly created GtkTreeSelection*, "4:4", 0
 * Expected: void  
 */
static void test_purpose_336()
{
    #define SELECT_START_PATH "4:4"
    #define SELECT_END_PATH "4:4"
    #define UNSELECT_START_PATH "4:4"
    #define UNSELECT_END_PATH "4:4"
    #define CORRECT_SELECTED_ROWS_COUNT 0
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *select_start_path;
    GtkTreePath *select_end_path;
    GtkTreePath *unselect_start_path;
    GtkTreePath *unselect_end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreeIter ch_iter;
    GtkTreeIter next_iter;
    gint selected_rows_count;
    guint i;
    guint j;
    gchar* iter_path_str;
    gboolean has_first_iter = FALSE;
    gboolean selected = FALSE;
    gboolean val = FALSE;
    gboolean has_children = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    
    select_start_path = gtk_tree_path_new_from_string (SELECT_START_PATH);
    select_end_path = gtk_tree_path_new_from_string (SELECT_END_PATH);
    unselect_start_path = gtk_tree_path_new_from_string (UNSELECT_START_PATH);
    unselect_end_path = gtk_tree_path_new_from_string (UNSELECT_END_PATH);
    
    gtk_tree_selection_select_range (selection, select_start_path, select_end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_range (selection, unselect_start_path, unselect_end_path);
    selected_rows_count = gtk_tree_selection_count_selected_rows (selection);
    if (selected_rows_count != CORRECT_SELECTED_ROWS_COUNT)
    {
        TEST_FAIL ("%d instead of %d rows selected after unselection", 
                   selected_rows_count, CORRECT_SELECTED_ROWS_COUNT);
    }
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, unselect_start_path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned!",NULL);
        return;
    }
    
    has_first_iter = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), &iter);
    if (!has_first_iter)
    {
        TEST_FAIL ("model doesn't have the first iter", NULL);
        return;
    }
    
    while (gtk_tree_model_iter_children 
           (GTK_TREE_MODEL (model), &ch_iter, &iter))
    {
        
        gboolean has_next = FALSE;
        do 
        {
            GtkTreePath* ch_path;
            
            ch_path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &ch_iter);
            if (gtk_tree_path_compare (ch_path, unselect_start_path) >= 0
                && gtk_tree_path_compare (ch_path, unselect_end_path) <= 0)
            {
                if (gtk_tree_selection_iter_is_selected (selection, &ch_iter))
                {
                    TEST_FAIL ("1:path \"%s\" from unselected range is selected actially", gtk_tree_path_to_string (ch_path));
                }
            } 
            has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &ch_iter);
        } while (has_next);
    
        if (!gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter))
        {
            break;
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef SELECT_START_PATH
    #undef SELECT_END_PATH
    #undef UNSELECT_START_PATH
    #undef UNSELECT_END_PATH
    #undef CORRECT_SELECTED_ROWS_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_unselect_range
 * Params: GtkTreeSelection *selection, GtkTreePath *start_path, GtkTreePath *end_path
 * Returns: void
 * Assertion: Unselects a range of nodes, determined by start_path and end_path inclusive.
 * Params Values: newly created GtkTreeSelection*, "1:2", 0
 * Expected: void  
 */
static void test_purpose_337()
{
    #define SELECT_START_PATH "0:0"
    #define SELECT_END_PATH "1:2"
    #define UNSELECT_START_PATH "0:0"
    #define UNSELECT_END_PATH "1:2"
    #define CORRECT_SELECTED_ROWS_COUNT 0
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *select_start_path;
    GtkTreePath *select_end_path;
    GtkTreePath *unselect_start_path;
    GtkTreePath *unselect_end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreeIter ch_iter;
    GtkTreeIter next_iter;
    gint selected_rows_count;
    guint i;
    guint j;
    gchar* iter_path_str;
    gboolean has_first_iter = FALSE;
    gboolean selected = FALSE;
    gboolean val = FALSE;
    gboolean has_children = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    
    select_start_path = gtk_tree_path_new_from_string (SELECT_START_PATH);
    select_end_path = gtk_tree_path_new_from_string (SELECT_END_PATH);
    unselect_start_path = gtk_tree_path_new_from_string (UNSELECT_START_PATH);
    unselect_end_path = gtk_tree_path_new_from_string (UNSELECT_END_PATH);
    
    gtk_tree_selection_select_range (selection, select_start_path, select_end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_range (selection, unselect_start_path, unselect_end_path);
    selected_rows_count = gtk_tree_selection_count_selected_rows (selection);
    if (selected_rows_count != CORRECT_SELECTED_ROWS_COUNT)
    {
        TEST_FAIL ("%d instead of %d rows selected after unselection", 
                   selected_rows_count, CORRECT_SELECTED_ROWS_COUNT);
    }
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, unselect_start_path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned!",NULL);
        return;
    }
    
    has_first_iter = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), &iter);
    if (!has_first_iter)
    {
        TEST_FAIL ("model doesn't have the first iter", NULL);
        return;
    }
    
    while (gtk_tree_model_iter_children 
           (GTK_TREE_MODEL (model), &ch_iter, &iter))
    {
        
        gboolean has_next = FALSE;
        do 
        {
            GtkTreePath* ch_path;
            
            ch_path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &ch_iter);
            if (gtk_tree_path_compare (ch_path, unselect_start_path) >= 0
                && gtk_tree_path_compare (ch_path, unselect_end_path) <= 0)
            {
                if (gtk_tree_selection_iter_is_selected (selection, &ch_iter))
                {
                    TEST_FAIL ("1:path \"%s\" from unselected range is selected actially", gtk_tree_path_to_string (ch_path));
                }
            } 
            has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &ch_iter);
        } while (has_next);
    
        if (!gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter))
        {
            break;
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef SELECT_START_PATH
    #undef SELECT_END_PATH
    #undef UNSELECT_START_PATH
    #undef UNSELECT_END_PATH
    #undef CORRECT_SELECTED_ROWS_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_unselect_range
 * Params: GtkTreeSelection *selection, GtkTreePath *start_path, GtkTreePath *end_path
 * Returns: void
 * Assertion: Unselects a range of nodes, determined by start_path and end_path inclusive.
 * Params Values: newly created GtkTreeSelection*, "0:3", 5
 * Expected: void  
 */
static void test_purpose_338()
{
    #define SELECT_START_PATH "0:0"
    #define SELECT_END_PATH "1:2"
    #define UNSELECT_START_PATH "0:0"
    #define UNSELECT_END_PATH "0:3"
    #define CORRECT_SELECTED_ROWS_COUNT 5
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *select_start_path;
    GtkTreePath *select_end_path;
    GtkTreePath *unselect_start_path;
    GtkTreePath *unselect_end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreeIter ch_iter;
    GtkTreeIter next_iter;
    gint selected_rows_count;
    guint i;
    guint j;
    gchar* iter_path_str;
    gboolean has_first_iter = FALSE;
    gboolean selected = FALSE;
    gboolean val = FALSE;
    gboolean has_children = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    
    select_start_path = gtk_tree_path_new_from_string (SELECT_START_PATH);
    select_end_path = gtk_tree_path_new_from_string (SELECT_END_PATH);
    unselect_start_path = gtk_tree_path_new_from_string (UNSELECT_START_PATH);
    unselect_end_path = gtk_tree_path_new_from_string (UNSELECT_END_PATH);
    
    gtk_tree_selection_select_range (selection, select_start_path, select_end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_range (selection, unselect_start_path, unselect_end_path);
    selected_rows_count = gtk_tree_selection_count_selected_rows (selection);
    if (selected_rows_count != CORRECT_SELECTED_ROWS_COUNT)
    {
        TEST_FAIL ("%d instead of %d rows selected after unselection", 
                   selected_rows_count, CORRECT_SELECTED_ROWS_COUNT);
    }
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, unselect_start_path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned!",NULL);
        return;
    }
    
    has_first_iter = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), &iter);
    if (!has_first_iter)
    {
        TEST_FAIL ("model doesn't have the first iter", NULL);
        return;
    }
    
    while (gtk_tree_model_iter_children 
           (GTK_TREE_MODEL (model), &ch_iter, &iter))
    {
        
        gboolean has_next = FALSE;
        do 
        {
            GtkTreePath* ch_path;
            
            ch_path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &ch_iter);
            if (gtk_tree_path_compare (ch_path, unselect_start_path) >= 0
                && gtk_tree_path_compare (ch_path, unselect_end_path) <= 0)
            {
                if (gtk_tree_selection_iter_is_selected (selection, &ch_iter))
                {
                    TEST_FAIL ("1:path \"%s\" from unselected range is selected actially", gtk_tree_path_to_string (ch_path));
                }
            } 
            has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &ch_iter);
        } while (has_next);
    
        if (!gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter))
        {
            break;
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef SELECT_START_PATH
    #undef SELECT_END_PATH
    #undef UNSELECT_START_PATH
    #undef UNSELECT_END_PATH
    #undef CORRECT_SELECTED_ROWS_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_unselect_range
 * Params: GtkTreeSelection *selection, GtkTreePath *start_path, GtkTreePath *end_path
 * Returns: void
 * Assertion: Unselects a range of nodes, determined by start_path and end_path inclusive.
 * Params Values: newly created GtkTreeSelection*, "3:3", 0
 * Expected: void  
 */
static void test_purpose_339()
{
    #define SELECT_START_PATH "0:0"
    #define SELECT_END_PATH "1:2"
    #define UNSELECT_START_PATH "0:0"
    #define UNSELECT_END_PATH "3:3"
    #define CORRECT_SELECTED_ROWS_COUNT 0
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *select_start_path;
    GtkTreePath *select_end_path;
    GtkTreePath *unselect_start_path;
    GtkTreePath *unselect_end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreeIter ch_iter;
    GtkTreeIter next_iter;
    gint selected_rows_count;
    guint i;
    guint j;
    gchar* iter_path_str;
    gboolean has_first_iter = FALSE;
    gboolean selected = FALSE;
    gboolean val = FALSE;
    gboolean has_children = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    
    select_start_path = gtk_tree_path_new_from_string (SELECT_START_PATH);
    select_end_path = gtk_tree_path_new_from_string (SELECT_END_PATH);
    unselect_start_path = gtk_tree_path_new_from_string (UNSELECT_START_PATH);
    unselect_end_path = gtk_tree_path_new_from_string (UNSELECT_END_PATH);
    
    gtk_tree_selection_select_range (selection, select_start_path, select_end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_range (selection, unselect_start_path, unselect_end_path);
    selected_rows_count = gtk_tree_selection_count_selected_rows (selection);
    if (selected_rows_count != CORRECT_SELECTED_ROWS_COUNT)
    {
        TEST_FAIL ("%d instead of %d rows selected after unselection", 
                   selected_rows_count, CORRECT_SELECTED_ROWS_COUNT);
    }
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, unselect_start_path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned!",NULL);
        return;
    }
    
    has_first_iter = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), &iter);
    if (!has_first_iter)
    {
        TEST_FAIL ("model doesn't have the first iter", NULL);
        return;
    }
    
    while (gtk_tree_model_iter_children 
           (GTK_TREE_MODEL (model), &ch_iter, &iter))
    {
        
        gboolean has_next = FALSE;
        do 
        {
            GtkTreePath* ch_path;
            
            ch_path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &ch_iter);
            if (gtk_tree_path_compare (ch_path, unselect_start_path) >= 0
                && gtk_tree_path_compare (ch_path, unselect_end_path) <= 0)
            {
                if (gtk_tree_selection_iter_is_selected (selection, &ch_iter))
                {
                    TEST_FAIL ("1:path \"%s\" from unselected range is selected actially", gtk_tree_path_to_string (ch_path));
                }
            } 
            has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &ch_iter);
        } while (has_next);
    
        if (!gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter))
        {
            break;
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef SELECT_START_PATH
    #undef SELECT_END_PATH
    #undef UNSELECT_START_PATH
    #undef UNSELECT_END_PATH
    #undef CORRECT_SELECTED_ROWS_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_unselect_range
 * Params: GtkTreeSelection *selection, GtkTreePath *start_path, GtkTreePath *end_path
 * Returns: void
 * Assertion: Unselects a range of nodes, determined by start_path and end_path inclusive.
 * Params Values: newly created GtkTreeSelection*, "1:3", 11
 * Expected: void  
 */
static void test_purpose_340()
{
    #define SELECT_START_PATH "1:3"
    #define SELECT_END_PATH "3:2"
    #define UNSELECT_START_PATH "0:0"
    #define UNSELECT_END_PATH "1:3"
    #define CORRECT_SELECTED_ROWS_COUNT 11
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *select_start_path;
    GtkTreePath *select_end_path;
    GtkTreePath *unselect_start_path;
    GtkTreePath *unselect_end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreeIter ch_iter;
    GtkTreeIter next_iter;
    gint selected_rows_count;
    guint i;
    guint j;
    gchar* iter_path_str;
    gboolean has_first_iter = FALSE;
    gboolean selected = FALSE;
    gboolean val = FALSE;
    gboolean has_children = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    
    select_start_path = gtk_tree_path_new_from_string (SELECT_START_PATH);
    select_end_path = gtk_tree_path_new_from_string (SELECT_END_PATH);
    unselect_start_path = gtk_tree_path_new_from_string (UNSELECT_START_PATH);
    unselect_end_path = gtk_tree_path_new_from_string (UNSELECT_END_PATH);
    
    gtk_tree_selection_select_range (selection, select_start_path, select_end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_range (selection, unselect_start_path, unselect_end_path);
    selected_rows_count = gtk_tree_selection_count_selected_rows (selection);
    if (selected_rows_count != CORRECT_SELECTED_ROWS_COUNT)
    {
        TEST_FAIL ("%d instead of %d rows selected after unselection", 
                   selected_rows_count, CORRECT_SELECTED_ROWS_COUNT);
    }
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, unselect_start_path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned!",NULL);
        return;
    }
    
    has_first_iter = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), &iter);
    if (!has_first_iter)
    {
        TEST_FAIL ("model doesn't have the first iter", NULL);
        return;
    }
    
    while (gtk_tree_model_iter_children 
           (GTK_TREE_MODEL (model), &ch_iter, &iter))
    {
        
        gboolean has_next = FALSE;
        do 
        {
            GtkTreePath* ch_path;
            
            ch_path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &ch_iter);
            if (gtk_tree_path_compare (ch_path, unselect_start_path) >= 0
                && gtk_tree_path_compare (ch_path, unselect_end_path) <= 0)
            {
                if (gtk_tree_selection_iter_is_selected (selection, &ch_iter))
                {
                    TEST_FAIL ("1:path \"%s\" from unselected range is selected actially", gtk_tree_path_to_string (ch_path));
                }
            } 
            has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &ch_iter);
        } while (has_next);
    
        if (!gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter))
        {
            break;
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef SELECT_START_PATH
    #undef SELECT_END_PATH
    #undef UNSELECT_START_PATH
    #undef UNSELECT_END_PATH
    #undef CORRECT_SELECTED_ROWS_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_unselect_range
 * Params: GtkTreeSelection *selection, GtkTreePath *start_path, GtkTreePath *end_path
 * Returns: void
 * Assertion: Unselects a range of nodes, determined by start_path and end_path inclusive.
 * Params Values: newly created GtkTreeSelection*, "2:3", 5
 * Expected: void  
 */
static void test_purpose_341()
{
    #define SELECT_START_PATH "1:3"
    #define SELECT_END_PATH "3:2"
    #define UNSELECT_START_PATH "0:0"
    #define UNSELECT_END_PATH "2:3"
    #define CORRECT_SELECTED_ROWS_COUNT 5
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *select_start_path;
    GtkTreePath *select_end_path;
    GtkTreePath *unselect_start_path;
    GtkTreePath *unselect_end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreeIter ch_iter;
    GtkTreeIter next_iter;
    gint selected_rows_count;
    guint i;
    guint j;
    gchar* iter_path_str;
    gboolean has_first_iter = FALSE;
    gboolean selected = FALSE;
    gboolean val = FALSE;
    gboolean has_children = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    
    select_start_path = gtk_tree_path_new_from_string (SELECT_START_PATH);
    select_end_path = gtk_tree_path_new_from_string (SELECT_END_PATH);
    unselect_start_path = gtk_tree_path_new_from_string (UNSELECT_START_PATH);
    unselect_end_path = gtk_tree_path_new_from_string (UNSELECT_END_PATH);
    
    gtk_tree_selection_select_range (selection, select_start_path, select_end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_range (selection, unselect_start_path, unselect_end_path);
    selected_rows_count = gtk_tree_selection_count_selected_rows (selection);
    if (selected_rows_count != CORRECT_SELECTED_ROWS_COUNT)
    {
        TEST_FAIL ("%d instead of %d rows selected after unselection", 
                   selected_rows_count, CORRECT_SELECTED_ROWS_COUNT);
    }
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, unselect_start_path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned!",NULL);
        return;
    }
    
    has_first_iter = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), &iter);
    if (!has_first_iter)
    {
        TEST_FAIL ("model doesn't have the first iter", NULL);
        return;
    }
    
    while (gtk_tree_model_iter_children 
           (GTK_TREE_MODEL (model), &ch_iter, &iter))
    {
        
        gboolean has_next = FALSE;
        do 
        {
            GtkTreePath* ch_path;
            
            ch_path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &ch_iter);
            if (gtk_tree_path_compare (ch_path, unselect_start_path) >= 0
                && gtk_tree_path_compare (ch_path, unselect_end_path) <= 0)
            {
                if (gtk_tree_selection_iter_is_selected (selection, &ch_iter))
                {
                    TEST_FAIL ("1:path \"%s\" from unselected range is selected actially", gtk_tree_path_to_string (ch_path));
                }
            } 
            has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &ch_iter);
        } while (has_next);
    
        if (!gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter))
        {
            break;
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef SELECT_START_PATH
    #undef SELECT_END_PATH
    #undef UNSELECT_START_PATH
    #undef UNSELECT_END_PATH
    #undef CORRECT_SELECTED_ROWS_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_unselect_range
 * Params: GtkTreeSelection *selection, GtkTreePath *start_path, GtkTreePath *end_path
 * Returns: void
 * Assertion: Unselects a range of nodes, determined by start_path and end_path inclusive.
 * Params Values: newly created GtkTreeSelection*, "4:3", 0
 * Expected: void  
 */
static void test_purpose_342()
{
    #define SELECT_START_PATH "1:3"
    #define SELECT_END_PATH "3:2"
    #define UNSELECT_START_PATH "1:0"
    #define UNSELECT_END_PATH "4:3"
    #define CORRECT_SELECTED_ROWS_COUNT 0
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *select_start_path;
    GtkTreePath *select_end_path;
    GtkTreePath *unselect_start_path;
    GtkTreePath *unselect_end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreeIter ch_iter;
    GtkTreeIter next_iter;
    gint selected_rows_count;
    guint i;
    guint j;
    gchar* iter_path_str;
    gboolean has_first_iter = FALSE;
    gboolean selected = FALSE;
    gboolean val = FALSE;
    gboolean has_children = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    
    select_start_path = gtk_tree_path_new_from_string (SELECT_START_PATH);
    select_end_path = gtk_tree_path_new_from_string (SELECT_END_PATH);
    unselect_start_path = gtk_tree_path_new_from_string (UNSELECT_START_PATH);
    unselect_end_path = gtk_tree_path_new_from_string (UNSELECT_END_PATH);
    
    gtk_tree_selection_select_range (selection, select_start_path, select_end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_range (selection, unselect_start_path, unselect_end_path);
    selected_rows_count = gtk_tree_selection_count_selected_rows (selection);
    if (selected_rows_count != CORRECT_SELECTED_ROWS_COUNT)
    {
        TEST_FAIL ("%d instead of %d rows selected after unselection", 
                   selected_rows_count, CORRECT_SELECTED_ROWS_COUNT);
    }
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, unselect_start_path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned!",NULL);
        return;
    }
    
    has_first_iter = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), &iter);
    if (!has_first_iter)
    {
        TEST_FAIL ("model doesn't have the first iter", NULL);
        return;
    }
    
    while (gtk_tree_model_iter_children 
           (GTK_TREE_MODEL (model), &ch_iter, &iter))
    {
        
        gboolean has_next = FALSE;
        do 
        {
            GtkTreePath* ch_path;
            
            ch_path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &ch_iter);
            if (gtk_tree_path_compare (ch_path, unselect_start_path) >= 0
                && gtk_tree_path_compare (ch_path, unselect_end_path) <= 0)
            {
                if (gtk_tree_selection_iter_is_selected (selection, &ch_iter))
                {
                    TEST_FAIL ("1:path \"%s\" from unselected range is selected actially", gtk_tree_path_to_string (ch_path));
                }
            } 
            has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &ch_iter);
        } while (has_next);
    
        if (!gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter))
        {
            break;
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef SELECT_START_PATH
    #undef SELECT_END_PATH
    #undef UNSELECT_START_PATH
    #undef UNSELECT_END_PATH
    #undef CORRECT_SELECTED_ROWS_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_unselect_range
 * Params: GtkTreeSelection *selection, GtkTreePath *start_path, GtkTreePath *end_path
 * Returns: void
 * Assertion: Unselects a range of nodes, determined by start_path and end_path inclusive.
 * Params Values: newly created GtkTreeSelection*, "4:3", 11
 * Expected: void  
 */
static void test_purpose_343()
{
    #define SELECT_START_PATH "1:3"
    #define SELECT_END_PATH "3:2"
    #define UNSELECT_START_PATH "3:2"
    #define UNSELECT_END_PATH "4:3"
    #define CORRECT_SELECTED_ROWS_COUNT 11
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *select_start_path;
    GtkTreePath *select_end_path;
    GtkTreePath *unselect_start_path;
    GtkTreePath *unselect_end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreeIter ch_iter;
    GtkTreeIter next_iter;
    gint selected_rows_count;
    guint i;
    guint j;
    gchar* iter_path_str;
    gboolean has_first_iter = FALSE;
    gboolean selected = FALSE;
    gboolean val = FALSE;
    gboolean has_children = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    
    select_start_path = gtk_tree_path_new_from_string (SELECT_START_PATH);
    select_end_path = gtk_tree_path_new_from_string (SELECT_END_PATH);
    unselect_start_path = gtk_tree_path_new_from_string (UNSELECT_START_PATH);
    unselect_end_path = gtk_tree_path_new_from_string (UNSELECT_END_PATH);
    
    gtk_tree_selection_select_range (selection, select_start_path, select_end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_range (selection, unselect_start_path, unselect_end_path);
    selected_rows_count = gtk_tree_selection_count_selected_rows (selection);
    if (selected_rows_count != CORRECT_SELECTED_ROWS_COUNT)
    {
        TEST_FAIL ("%d instead of %d rows selected after unselection", 
                   selected_rows_count, CORRECT_SELECTED_ROWS_COUNT);
    }
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, unselect_start_path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned!",NULL);
        return;
    }
    
    has_first_iter = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), &iter);
    if (!has_first_iter)
    {
        TEST_FAIL ("model doesn't have the first iter", NULL);
        return;
    }
    
    while (gtk_tree_model_iter_children 
           (GTK_TREE_MODEL (model), &ch_iter, &iter))
    {
        
        gboolean has_next = FALSE;
        do 
        {
            GtkTreePath* ch_path;
            
            ch_path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &ch_iter);
            if (gtk_tree_path_compare (ch_path, unselect_start_path) >= 0
                && gtk_tree_path_compare (ch_path, unselect_end_path) <= 0)
            {
                if (gtk_tree_selection_iter_is_selected (selection, &ch_iter))
                {
                    TEST_FAIL ("1:path \"%s\" from unselected range is selected actially", gtk_tree_path_to_string (ch_path));
                }
            } 
            has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &ch_iter);
        } while (has_next);
    
        if (!gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter))
        {
            break;
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef SELECT_START_PATH
    #undef SELECT_END_PATH
    #undef UNSELECT_START_PATH
    #undef UNSELECT_END_PATH
    #undef CORRECT_SELECTED_ROWS_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_unselect_range
 * Params: GtkTreeSelection *selection, GtkTreePath *start_path, GtkTreePath *end_path
 * Returns: void
 * Assertion: Unselects a range of nodes, determined by start_path and end_path inclusive.
 * Params Values: newly created GtkTreeSelection*, "4:3", 12
 * Expected: void  
 */
static void test_purpose_344()
{
    #define SELECT_START_PATH "1:3"
    #define SELECT_END_PATH "3:2"
    #define UNSELECT_START_PATH "3:3"
    #define UNSELECT_END_PATH "4:3"
    #define CORRECT_SELECTED_ROWS_COUNT 12
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *select_start_path;
    GtkTreePath *select_end_path;
    GtkTreePath *unselect_start_path;
    GtkTreePath *unselect_end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreeIter ch_iter;
    GtkTreeIter next_iter;
    gint selected_rows_count;
    guint i;
    guint j;
    gchar* iter_path_str;
    gboolean has_first_iter = FALSE;
    gboolean selected = FALSE;
    gboolean val = FALSE;
    gboolean has_children = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    
    select_start_path = gtk_tree_path_new_from_string (SELECT_START_PATH);
    select_end_path = gtk_tree_path_new_from_string (SELECT_END_PATH);
    unselect_start_path = gtk_tree_path_new_from_string (UNSELECT_START_PATH);
    unselect_end_path = gtk_tree_path_new_from_string (UNSELECT_END_PATH);
    
    gtk_tree_selection_select_range (selection, select_start_path, select_end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_range (selection, unselect_start_path, unselect_end_path);
    selected_rows_count = gtk_tree_selection_count_selected_rows (selection);
    if (selected_rows_count != CORRECT_SELECTED_ROWS_COUNT)
    {
        TEST_FAIL ("%d instead of %d rows selected after unselection", 
                   selected_rows_count, CORRECT_SELECTED_ROWS_COUNT);
    }
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, unselect_start_path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned!",NULL);
        return;
    }
    
    has_first_iter = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), &iter);
    if (!has_first_iter)
    {
        TEST_FAIL ("model doesn't have the first iter", NULL);
        return;
    }
    
    while (gtk_tree_model_iter_children 
           (GTK_TREE_MODEL (model), &ch_iter, &iter))
    {
        
        gboolean has_next = FALSE;
        do 
        {
            GtkTreePath* ch_path;
            
            ch_path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &ch_iter);
            if (gtk_tree_path_compare (ch_path, unselect_start_path) >= 0
                && gtk_tree_path_compare (ch_path, unselect_end_path) <= 0)
            {
                if (gtk_tree_selection_iter_is_selected (selection, &ch_iter))
                {
                    TEST_FAIL ("1:path \"%s\" from unselected range is selected actially", gtk_tree_path_to_string (ch_path));
                }
            } 
            has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &ch_iter);
        } while (has_next);
    
        if (!gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter))
        {
            break;
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef SELECT_START_PATH
    #undef SELECT_END_PATH
    #undef UNSELECT_START_PATH
    #undef UNSELECT_END_PATH
    #undef CORRECT_SELECTED_ROWS_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_unselect_range
 * Params: GtkTreeSelection *selection, GtkTreePath *start_path, GtkTreePath *end_path
 * Returns: void
 * Assertion: Unselects a range of nodes, determined by start_path and end_path inclusive.
 * Params Values: newly created GtkTreeSelection*, "2:0", 9
 * Expected: void  
 */
static void test_purpose_345()
{
    #define SELECT_START_PATH "1:3"
    #define SELECT_END_PATH "3:2"
    #define UNSELECT_START_PATH "1:4"
    #define UNSELECT_END_PATH "2:0"
    #define CORRECT_SELECTED_ROWS_COUNT 9
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *select_start_path;
    GtkTreePath *select_end_path;
    GtkTreePath *unselect_start_path;
    GtkTreePath *unselect_end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreeIter ch_iter;
    GtkTreeIter next_iter;
    gint selected_rows_count;
    guint i;
    guint j;
    gchar* iter_path_str;
    gboolean has_first_iter = FALSE;
    gboolean selected = FALSE;
    gboolean val = FALSE;
    gboolean has_children = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    
    select_start_path = gtk_tree_path_new_from_string (SELECT_START_PATH);
    select_end_path = gtk_tree_path_new_from_string (SELECT_END_PATH);
    unselect_start_path = gtk_tree_path_new_from_string (UNSELECT_START_PATH);
    unselect_end_path = gtk_tree_path_new_from_string (UNSELECT_END_PATH);
    
    gtk_tree_selection_select_range (selection, select_start_path, select_end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_range (selection, unselect_start_path, unselect_end_path);
    selected_rows_count = gtk_tree_selection_count_selected_rows (selection);
    if (selected_rows_count != CORRECT_SELECTED_ROWS_COUNT)
    {
        TEST_FAIL ("%d instead of %d rows selected after unselection", 
                   selected_rows_count, CORRECT_SELECTED_ROWS_COUNT);
    }
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, unselect_start_path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned!",NULL);
        return;
    }
    
    has_first_iter = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), &iter);
    if (!has_first_iter)
    {
        TEST_FAIL ("model doesn't have the first iter", NULL);
        return;
    }
    
    while (gtk_tree_model_iter_children 
           (GTK_TREE_MODEL (model), &ch_iter, &iter))
    {
        
        gboolean has_next = FALSE;
        do 
        {
            GtkTreePath* ch_path;
            
            ch_path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &ch_iter);
            if (gtk_tree_path_compare (ch_path, unselect_start_path) >= 0
                && gtk_tree_path_compare (ch_path, unselect_end_path) <= 0)
            {
                if (gtk_tree_selection_iter_is_selected (selection, &ch_iter))
                {
                    TEST_FAIL ("1:path \"%s\" from unselected range is selected actially", gtk_tree_path_to_string (ch_path));
                }
            } 
            has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &ch_iter);
        } while (has_next);
    
        if (!gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter))
        {
            break;
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef SELECT_START_PATH
    #undef SELECT_END_PATH
    #undef UNSELECT_START_PATH
    #undef UNSELECT_END_PATH
    #undef CORRECT_SELECTED_ROWS_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_unselect_range
 * Params: GtkTreeSelection *selection, GtkTreePath *start_path, GtkTreePath *end_path
 * Returns: void
 * Assertion: Unselects a range of nodes, determined by start_path and end_path inclusive.
 * Params Values: newly created GtkTreeSelection*, "3:1", 2
 * Expected: void  
 */
static void test_purpose_346()
{
    #define SELECT_START_PATH "1:3"
    #define SELECT_END_PATH "3:2"
    #define UNSELECT_START_PATH "1:4"
    #define UNSELECT_END_PATH "3:1"
    #define CORRECT_SELECTED_ROWS_COUNT 2
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *select_start_path;
    GtkTreePath *select_end_path;
    GtkTreePath *unselect_start_path;
    GtkTreePath *unselect_end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreeIter ch_iter;
    GtkTreeIter next_iter;
    gint selected_rows_count;
    guint i;
    guint j;
    gchar* iter_path_str;
    gboolean has_first_iter = FALSE;
    gboolean selected = FALSE;
    gboolean val = FALSE;
    gboolean has_children = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    
    select_start_path = gtk_tree_path_new_from_string (SELECT_START_PATH);
    select_end_path = gtk_tree_path_new_from_string (SELECT_END_PATH);
    unselect_start_path = gtk_tree_path_new_from_string (UNSELECT_START_PATH);
    unselect_end_path = gtk_tree_path_new_from_string (UNSELECT_END_PATH);
    
    gtk_tree_selection_select_range (selection, select_start_path, select_end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_range (selection, unselect_start_path, unselect_end_path);
    selected_rows_count = gtk_tree_selection_count_selected_rows (selection);
    if (selected_rows_count != CORRECT_SELECTED_ROWS_COUNT)
    {
        TEST_FAIL ("%d instead of %d rows selected after unselection", 
                   selected_rows_count, CORRECT_SELECTED_ROWS_COUNT);
    }
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, unselect_start_path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned!",NULL);
        return;
    }
    
    has_first_iter = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), &iter);
    if (!has_first_iter)
    {
        TEST_FAIL ("model doesn't have the first iter", NULL);
        return;
    }
    
    while (gtk_tree_model_iter_children 
           (GTK_TREE_MODEL (model), &ch_iter, &iter))
    {
        
        gboolean has_next = FALSE;
        do 
        {
            GtkTreePath* ch_path;
            
            ch_path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &ch_iter);
            if (gtk_tree_path_compare (ch_path, unselect_start_path) >= 0
                && gtk_tree_path_compare (ch_path, unselect_end_path) <= 0)
            {
                if (gtk_tree_selection_iter_is_selected (selection, &ch_iter))
                {
                    TEST_FAIL ("1:path \"%s\" from unselected range is selected actially", gtk_tree_path_to_string (ch_path));
                }
            } 
            has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &ch_iter);
        } while (has_next);
    
        if (!gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter))
        {
            break;
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef SELECT_START_PATH
    #undef SELECT_END_PATH
    #undef UNSELECT_START_PATH
    #undef UNSELECT_END_PATH
    #undef CORRECT_SELECTED_ROWS_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_unselect_range
 * Params: GtkTreeSelection *selection, GtkTreePath *start_path, GtkTreePath *end_path
 * Returns: void
 * Assertion: Unselects a range of nodes, determined by start_path and end_path inclusive.
 * Params Values: newly created GtkTreeSelection*, "4:3", 1
 * Expected: void  
 */
static void test_purpose_347()
{
    #define SELECT_START_PATH "3:2"
    #define SELECT_END_PATH "4:3"
    #define UNSELECT_START_PATH "3:3"
    #define UNSELECT_END_PATH "4:3"
    #define CORRECT_SELECTED_ROWS_COUNT 1
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *select_start_path;
    GtkTreePath *select_end_path;
    GtkTreePath *unselect_start_path;
    GtkTreePath *unselect_end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreeIter ch_iter;
    GtkTreeIter next_iter;
    gint selected_rows_count;
    guint i;
    guint j;
    gchar* iter_path_str;
    gboolean has_first_iter = FALSE;
    gboolean selected = FALSE;
    gboolean val = FALSE;
    gboolean has_children = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    
    select_start_path = gtk_tree_path_new_from_string (SELECT_START_PATH);
    select_end_path = gtk_tree_path_new_from_string (SELECT_END_PATH);
    unselect_start_path = gtk_tree_path_new_from_string (UNSELECT_START_PATH);
    unselect_end_path = gtk_tree_path_new_from_string (UNSELECT_END_PATH);
    
    gtk_tree_selection_select_range (selection, select_start_path, select_end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_range (selection, unselect_start_path, unselect_end_path);
    selected_rows_count = gtk_tree_selection_count_selected_rows (selection);
    if (selected_rows_count != CORRECT_SELECTED_ROWS_COUNT)
    {
        TEST_FAIL ("%d instead of %d rows selected after unselection", 
                   selected_rows_count, CORRECT_SELECTED_ROWS_COUNT);
    }
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, unselect_start_path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned!",NULL);
        return;
    }
    
    has_first_iter = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), &iter);
    if (!has_first_iter)
    {
        TEST_FAIL ("model doesn't have the first iter", NULL);
        return;
    }
    
    while (gtk_tree_model_iter_children 
           (GTK_TREE_MODEL (model), &ch_iter, &iter))
    {
        
        gboolean has_next = FALSE;
        do 
        {
            GtkTreePath* ch_path;
            
            ch_path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &ch_iter);
            if (gtk_tree_path_compare (ch_path, unselect_start_path) >= 0
                && gtk_tree_path_compare (ch_path, unselect_end_path) <= 0)
            {
                if (gtk_tree_selection_iter_is_selected (selection, &ch_iter))
                {
                    TEST_FAIL ("1:path \"%s\" from unselected range is selected actially", gtk_tree_path_to_string (ch_path));
                }
            } 
            has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &ch_iter);
        } while (has_next);
    
        if (!gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter))
        {
            break;
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef SELECT_START_PATH
    #undef SELECT_END_PATH
    #undef UNSELECT_START_PATH
    #undef UNSELECT_END_PATH
    #undef CORRECT_SELECTED_ROWS_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_unselect_range
 * Params: GtkTreeSelection *selection, GtkTreePath *start_path, GtkTreePath *end_path
 * Returns: void
 * Assertion: Unselects a range of nodes, determined by start_path and end_path inclusive.
 * Params Values: newly created GtkTreeSelection*, "4:3", 0
 * Expected: void  
 */
static void test_purpose_348()
{
    #define SELECT_START_PATH "3:2"
    #define SELECT_END_PATH "4:3"
    #define UNSELECT_START_PATH "3:2"
    #define UNSELECT_END_PATH "4:3"
    #define CORRECT_SELECTED_ROWS_COUNT 0
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *select_start_path;
    GtkTreePath *select_end_path;
    GtkTreePath *unselect_start_path;
    GtkTreePath *unselect_end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreeIter ch_iter;
    GtkTreeIter next_iter;
    gint selected_rows_count;
    guint i;
    guint j;
    gchar* iter_path_str;
    gboolean has_first_iter = FALSE;
    gboolean selected = FALSE;
    gboolean val = FALSE;
    gboolean has_children = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    
    select_start_path = gtk_tree_path_new_from_string (SELECT_START_PATH);
    select_end_path = gtk_tree_path_new_from_string (SELECT_END_PATH);
    unselect_start_path = gtk_tree_path_new_from_string (UNSELECT_START_PATH);
    unselect_end_path = gtk_tree_path_new_from_string (UNSELECT_END_PATH);
    
    gtk_tree_selection_select_range (selection, select_start_path, select_end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_range (selection, unselect_start_path, unselect_end_path);
    selected_rows_count = gtk_tree_selection_count_selected_rows (selection);
    if (selected_rows_count != CORRECT_SELECTED_ROWS_COUNT)
    {
        TEST_FAIL ("%d instead of %d rows selected after unselection", 
                   selected_rows_count, CORRECT_SELECTED_ROWS_COUNT);
    }
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, unselect_start_path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned!",NULL);
        return;
    }
    
    has_first_iter = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), &iter);
    if (!has_first_iter)
    {
        TEST_FAIL ("model doesn't have the first iter", NULL);
        return;
    }
    
    while (gtk_tree_model_iter_children 
           (GTK_TREE_MODEL (model), &ch_iter, &iter))
    {
        
        gboolean has_next = FALSE;
        do 
        {
            GtkTreePath* ch_path;
            
            ch_path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &ch_iter);
            if (gtk_tree_path_compare (ch_path, unselect_start_path) >= 0
                && gtk_tree_path_compare (ch_path, unselect_end_path) <= 0)
            {
                if (gtk_tree_selection_iter_is_selected (selection, &ch_iter))
                {
                    TEST_FAIL ("1:path \"%s\" from unselected range is selected actially", gtk_tree_path_to_string (ch_path));
                }
            } 
            has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &ch_iter);
        } while (has_next);
    
        if (!gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter))
        {
            break;
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef SELECT_START_PATH
    #undef SELECT_END_PATH
    #undef UNSELECT_START_PATH
    #undef UNSELECT_END_PATH
    #undef CORRECT_SELECTED_ROWS_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_unselect_range
 * Params: GtkTreeSelection *selection, GtkTreePath *start_path, GtkTreePath *end_path
 * Returns: void
 * Assertion: Unselects a range of nodes, determined by start_path and end_path inclusive.
 * Params Values: newly created GtkTreeSelection*, "4:3", 7
 * Expected: void  
 */
static void test_purpose_349()
{
    #define SELECT_START_PATH "3:2"
    #define SELECT_END_PATH "4:3"
    #define UNSELECT_START_PATH "4:3"
    #define UNSELECT_END_PATH "4:3"
    #define CORRECT_SELECTED_ROWS_COUNT 7
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *select_start_path;
    GtkTreePath *select_end_path;
    GtkTreePath *unselect_start_path;
    GtkTreePath *unselect_end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreeIter ch_iter;
    GtkTreeIter next_iter;
    gint selected_rows_count;
    guint i;
    guint j;
    gchar* iter_path_str;
    gboolean has_first_iter = FALSE;
    gboolean selected = FALSE;
    gboolean val = FALSE;
    gboolean has_children = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    
    select_start_path = gtk_tree_path_new_from_string (SELECT_START_PATH);
    select_end_path = gtk_tree_path_new_from_string (SELECT_END_PATH);
    unselect_start_path = gtk_tree_path_new_from_string (UNSELECT_START_PATH);
    unselect_end_path = gtk_tree_path_new_from_string (UNSELECT_END_PATH);
    
    gtk_tree_selection_select_range (selection, select_start_path, select_end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_range (selection, unselect_start_path, unselect_end_path);
    selected_rows_count = gtk_tree_selection_count_selected_rows (selection);
    if (selected_rows_count != CORRECT_SELECTED_ROWS_COUNT)
    {
        TEST_FAIL ("%d instead of %d rows selected after unselection", 
                   selected_rows_count, CORRECT_SELECTED_ROWS_COUNT);
    }
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, unselect_start_path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned!",NULL);
        return;
    }
    
    has_first_iter = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), &iter);
    if (!has_first_iter)
    {
        TEST_FAIL ("model doesn't have the first iter", NULL);
        return;
    }
    
    while (gtk_tree_model_iter_children 
           (GTK_TREE_MODEL (model), &ch_iter, &iter))
    {
        
        gboolean has_next = FALSE;
        do 
        {
            GtkTreePath* ch_path;
            
            ch_path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &ch_iter);
            if (gtk_tree_path_compare (ch_path, unselect_start_path) >= 0
                && gtk_tree_path_compare (ch_path, unselect_end_path) <= 0)
            {
                if (gtk_tree_selection_iter_is_selected (selection, &ch_iter))
                {
                    TEST_FAIL ("1:path \"%s\" from unselected range is selected actially", gtk_tree_path_to_string (ch_path));
                }
            } 
            has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &ch_iter);
        } while (has_next);
    
        if (!gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter))
        {
            break;
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef SELECT_START_PATH
    #undef SELECT_END_PATH
    #undef UNSELECT_START_PATH
    #undef UNSELECT_END_PATH
    #undef CORRECT_SELECTED_ROWS_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_unselect_range
 * Params: GtkTreeSelection *selection, GtkTreePath *start_path, GtkTreePath *end_path
 * Returns: void
 * Assertion: Unselects a range of nodes, determined by start_path and end_path inclusive.
 * Params Values: newly created GtkTreeSelection*, "4:4", 0
 * Expected: void  
 */
static void test_purpose_350()
{
    #define SELECT_START_PATH "3:2"
    #define SELECT_END_PATH "4:3"
    #define UNSELECT_START_PATH "0:0"
    #define UNSELECT_END_PATH "4:4"
    #define CORRECT_SELECTED_ROWS_COUNT 0
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *select_start_path;
    GtkTreePath *select_end_path;
    GtkTreePath *unselect_start_path;
    GtkTreePath *unselect_end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreeIter ch_iter;
    GtkTreeIter next_iter;
    gint selected_rows_count;
    guint i;
    guint j;
    gchar* iter_path_str;
    gboolean has_first_iter = FALSE;
    gboolean selected = FALSE;
    gboolean val = FALSE;
    gboolean has_children = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    
    select_start_path = gtk_tree_path_new_from_string (SELECT_START_PATH);
    select_end_path = gtk_tree_path_new_from_string (SELECT_END_PATH);
    unselect_start_path = gtk_tree_path_new_from_string (UNSELECT_START_PATH);
    unselect_end_path = gtk_tree_path_new_from_string (UNSELECT_END_PATH);
    
    gtk_tree_selection_select_range (selection, select_start_path, select_end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    gtk_tree_selection_unselect_range (selection, unselect_start_path, unselect_end_path);
    selected_rows_count = gtk_tree_selection_count_selected_rows (selection);
    if (selected_rows_count != CORRECT_SELECTED_ROWS_COUNT)
    {
        TEST_FAIL ("%d instead of %d rows selected after unselection", 
                   selected_rows_count, CORRECT_SELECTED_ROWS_COUNT);
    }
    
    val = gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, unselect_start_path);
    if (!val)
    {
        TEST_FAIL ("iter is not returned!",NULL);
        return;
    }
    
    has_first_iter = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), &iter);
    if (!has_first_iter)
    {
        TEST_FAIL ("model doesn't have the first iter", NULL);
        return;
    }
    
    while (gtk_tree_model_iter_children 
           (GTK_TREE_MODEL (model), &ch_iter, &iter))
    {
        
        gboolean has_next = FALSE;
        do 
        {
            GtkTreePath* ch_path;
            
            ch_path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &ch_iter);
            if (gtk_tree_path_compare (ch_path, unselect_start_path) >= 0
                && gtk_tree_path_compare (ch_path, unselect_end_path) <= 0)
            {
                if (gtk_tree_selection_iter_is_selected (selection, &ch_iter))
                {
                    TEST_FAIL ("1:path \"%s\" from unselected range is selected actially", gtk_tree_path_to_string (ch_path));
                }
            } 
            has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &ch_iter);
        } while (has_next);
    
        if (!gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter))
        {
            break;
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef SELECT_START_PATH
    #undef SELECT_END_PATH
    #undef UNSELECT_START_PATH
    #undef UNSELECT_END_PATH
    #undef CORRECT_SELECTED_ROWS_COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected_rows
 * Params: GtkTreeSelection *selection,  GtkTreeModel **model
 * Returns: GList*
 * Assertion: Creates a list of path of all selected rows.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel*
 * Expected: GList*  
 */
static void test_purpose_351()
{
    #define START_PATH "0:0"
    #define END_PATH "4:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *start_path;
    GtkTreePath *end_path;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreeIter ch_iter;
    GtkTreeIter next_iter;
    guint i;
    guint j;
    gchar* iter_path_str;
    GList* selected_rows_list;
    gint selected_rows_list_length;
    GList* plist;
    gint selected_rows_count;
    gboolean has_first_iter = FALSE;
    gboolean selected = FALSE;
    gboolean val = FALSE;
    gboolean has_children = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    start_path = gtk_tree_path_new_from_string (START_PATH);
    end_path = gtk_tree_path_new_from_string (END_PATH);
    
    gtk_tree_selection_select_range (selection, start_path, end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selected_rows_list = gtk_tree_selection_get_selected_rows 
                             (selection, (GtkTreeModel**)&model);
    selected_rows_list_length = g_list_length (selected_rows_list);
    selected_rows_count = gtk_tree_selection_count_selected_rows (selection);
    if (selected_rows_list_length != selected_rows_count)
    {
        TEST_FAIL ("selected_rows_list_length = %d, selected_rows_count = %d",
                   selected_rows_list_length, selected_rows_count);
    }
    
    for (i = 0; i < g_list_length (selected_rows_list); i++)
    {
        path = (GtkTreePath*) g_list_nth_data (selected_rows_list, i);
        if (!path)
        {
            TEST_FAIL ("path = NULL (i = %d)", i);
        } else {
            if (!gtk_tree_selection_path_is_selected (selection, path))
            {
                TEST_FAIL ("path '%s' from selected_rows_list is not selected (i = %d)", gtk_tree_path_to_string (path), i);
            }
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef START_PATH
    #undef END_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected_rows
 * Params: GtkTreeSelection *selection,  GtkTreeModel **model
 * Returns: GList*
 * Assertion: Creates a list of path of all selected rows.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel*
 * Expected: GList*  
 */
static void test_purpose_352()
{
    #define START_PATH "0:0"
    #define END_PATH "0:0"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *start_path;
    GtkTreePath *end_path;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreeIter ch_iter;
    GtkTreeIter next_iter;
    guint i;
    guint j;
    gchar* iter_path_str;
    GList* selected_rows_list;
    gint selected_rows_list_length;
    GList* plist;
    gint selected_rows_count;
    gboolean has_first_iter = FALSE;
    gboolean selected = FALSE;
    gboolean val = FALSE;
    gboolean has_children = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    start_path = gtk_tree_path_new_from_string (START_PATH);
    end_path = gtk_tree_path_new_from_string (END_PATH);
    
    gtk_tree_selection_select_range (selection, start_path, end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selected_rows_list = gtk_tree_selection_get_selected_rows 
                             (selection, (GtkTreeModel**)&model);
    selected_rows_list_length = g_list_length (selected_rows_list);
    selected_rows_count = gtk_tree_selection_count_selected_rows (selection);
    if (selected_rows_list_length != selected_rows_count)
    {
        TEST_FAIL ("selected_rows_list_length = %d, selected_rows_count = %d",
                   selected_rows_list_length, selected_rows_count);
    }
    
    for (i = 0; i < g_list_length (selected_rows_list); i++)
    {
        path = (GtkTreePath*) g_list_nth_data (selected_rows_list, i);
        if (!path)
        {
            TEST_FAIL ("path = NULL (i = %d)", i);
        } else {
            if (!gtk_tree_selection_path_is_selected (selection, path))
            {
                TEST_FAIL ("path '%s' from selected_rows_list is not selected (i = %d)", gtk_tree_path_to_string (path), i);
            }
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef START_PATH
    #undef END_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected_rows
 * Params: GtkTreeSelection *selection,  GtkTreeModel **model
 * Returns: GList*
 * Assertion: Creates a list of path of all selected rows.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel*
 * Expected: GList*  
 */
static void test_purpose_353()
{
    #define START_PATH "4:4"
    #define END_PATH "4:4"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *start_path;
    GtkTreePath *end_path;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreeIter ch_iter;
    GtkTreeIter next_iter;
    guint i;
    guint j;
    gchar* iter_path_str;
    GList* selected_rows_list;
    gint selected_rows_list_length;
    GList* plist;
    gint selected_rows_count;
    gboolean has_first_iter = FALSE;
    gboolean selected = FALSE;
    gboolean val = FALSE;
    gboolean has_children = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    start_path = gtk_tree_path_new_from_string (START_PATH);
    end_path = gtk_tree_path_new_from_string (END_PATH);
    
    gtk_tree_selection_select_range (selection, start_path, end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selected_rows_list = gtk_tree_selection_get_selected_rows 
                             (selection, (GtkTreeModel**)&model);
    selected_rows_list_length = g_list_length (selected_rows_list);
    selected_rows_count = gtk_tree_selection_count_selected_rows (selection);
    if (selected_rows_list_length != selected_rows_count)
    {
        TEST_FAIL ("selected_rows_list_length = %d, selected_rows_count = %d",
                   selected_rows_list_length, selected_rows_count);
    }
    
    for (i = 0; i < g_list_length (selected_rows_list); i++)
    {
        path = (GtkTreePath*) g_list_nth_data (selected_rows_list, i);
        if (!path)
        {
            TEST_FAIL ("path = NULL (i = %d)", i);
        } else {
            if (!gtk_tree_selection_path_is_selected (selection, path))
            {
                TEST_FAIL ("path '%s' from selected_rows_list is not selected (i = %d)", gtk_tree_path_to_string (path), i);
            }
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef START_PATH
    #undef END_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected_rows
 * Params: GtkTreeSelection *selection,  GtkTreeModel **model
 * Returns: GList*
 * Assertion: Creates a list of path of all selected rows.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel*
 * Expected: GList*  
 */
static void test_purpose_354()
{
    #define START_PATH "2:0"
    #define END_PATH "4:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *start_path;
    GtkTreePath *end_path;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreeIter ch_iter;
    GtkTreeIter next_iter;
    guint i;
    guint j;
    gchar* iter_path_str;
    GList* selected_rows_list;
    gint selected_rows_list_length;
    GList* plist;
    gint selected_rows_count;
    gboolean has_first_iter = FALSE;
    gboolean selected = FALSE;
    gboolean val = FALSE;
    gboolean has_children = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    start_path = gtk_tree_path_new_from_string (START_PATH);
    end_path = gtk_tree_path_new_from_string (END_PATH);
    
    gtk_tree_selection_select_range (selection, start_path, end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selected_rows_list = gtk_tree_selection_get_selected_rows 
                             (selection, (GtkTreeModel**)&model);
    selected_rows_list_length = g_list_length (selected_rows_list);
    selected_rows_count = gtk_tree_selection_count_selected_rows (selection);
    if (selected_rows_list_length != selected_rows_count)
    {
        TEST_FAIL ("selected_rows_list_length = %d, selected_rows_count = %d",
                   selected_rows_list_length, selected_rows_count);
    }
    
    for (i = 0; i < g_list_length (selected_rows_list); i++)
    {
        path = (GtkTreePath*) g_list_nth_data (selected_rows_list, i);
        if (!path)
        {
            TEST_FAIL ("path = NULL (i = %d)", i);
        } else {
            if (!gtk_tree_selection_path_is_selected (selection, path))
            {
                TEST_FAIL ("path '%s' from selected_rows_list is not selected (i = %d)", gtk_tree_path_to_string (path), i);
            }
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef START_PATH
    #undef END_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_get_selected_rows
 * Params: GtkTreeSelection *selection,  GtkTreeModel **model
 * Returns: GList*
 * Assertion: Creates a list of path of all selected rows.
 * Params Values: newly created GtkTreeSelection*, GtkTreeModel*
 * Expected: GList*  
 */
static void test_purpose_355()
{
    #define START_PATH "2:3"
    #define END_PATH "3:2"
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *start_path;
    GtkTreePath *end_path;
    GtkTreePath *path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreeIter ch_iter;
    GtkTreeIter next_iter;
    guint i;
    guint j;
    gchar* iter_path_str;
    GList* selected_rows_list;
    gint selected_rows_list_length;
    GList* plist;
    gint selected_rows_count;
    gboolean has_first_iter = FALSE;
    gboolean selected = FALSE;
    gboolean val = FALSE;
    gboolean has_children = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    start_path = gtk_tree_path_new_from_string (START_PATH);
    end_path = gtk_tree_path_new_from_string (END_PATH);
    
    gtk_tree_selection_select_range (selection, start_path, end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    selected_rows_list = gtk_tree_selection_get_selected_rows 
                             (selection, (GtkTreeModel**)&model);
    selected_rows_list_length = g_list_length (selected_rows_list);
    selected_rows_count = gtk_tree_selection_count_selected_rows (selection);
    if (selected_rows_list_length != selected_rows_count)
    {
        TEST_FAIL ("selected_rows_list_length = %d, selected_rows_count = %d",
                   selected_rows_list_length, selected_rows_count);
    }
    
    for (i = 0; i < g_list_length (selected_rows_list); i++)
    {
        path = (GtkTreePath*) g_list_nth_data (selected_rows_list, i);
        if (!path)
        {
            TEST_FAIL ("path = NULL (i = %d)", i);
        } else {
            if (!gtk_tree_selection_path_is_selected (selection, path))
            {
                TEST_FAIL ("path '%s' from selected_rows_list is not selected (i = %d)", gtk_tree_path_to_string (path), i);
            }
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef START_PATH
    #undef END_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_count_selected_rows
 * Params: GtkTreeSelection *selection
 * Returns: gint
 * Assertion: Returns the number of rows that have been selected in tree.
 * Params Values: newly created GtkTreeSelection* with selected range from "0" to "4:4"
 * Expected: 30  
 */
static void test_purpose_356()
{
    #define START_PATH "0"
    #define END_PATH "4:4"
    #define CORRECT_RES 30
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *start_path;
    GtkTreePath *end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint sel_rows_num;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    start_path = gtk_tree_path_new_from_string (START_PATH);
    end_path = gtk_tree_path_new_from_string (END_PATH);
    
    gtk_tree_selection_unselect_all (selection);
    gtk_tree_selection_select_range (selection, start_path, end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    sel_rows_num = gtk_tree_selection_count_selected_rows (selection);
    if (sel_rows_num != CORRECT_RES)
    {
        TEST_FAIL ("%d rows instead of %d are selected", sel_rows_num, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef START_PATH
    #undef END_PATH
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_count_selected_rows
 * Params: GtkTreeSelection *selection
 * Returns: gint
 * Assertion: Returns the number of rows that have been selected in tree.
 * Params Values: newly created GtkTreeSelection* with selected range from "0" to "1"
 * Expected: 7  
 */
static void test_purpose_357()
{
    #define START_PATH "0"
    #define END_PATH "1"
    #define CORRECT_RES 7
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *start_path;
    GtkTreePath *end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint sel_rows_num;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    start_path = gtk_tree_path_new_from_string (START_PATH);
    end_path = gtk_tree_path_new_from_string (END_PATH);
    
    gtk_tree_selection_unselect_all (selection);
    gtk_tree_selection_select_range (selection, start_path, end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    sel_rows_num = gtk_tree_selection_count_selected_rows (selection);
    if (sel_rows_num != CORRECT_RES)
    {
        TEST_FAIL ("%d rows instead of %d are selected", sel_rows_num, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef START_PATH
    #undef END_PATH
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_count_selected_rows
 * Params: GtkTreeSelection *selection
 * Returns: gint
 * Assertion: Returns the number of rows that have been selected in tree.
 * Params Values: newly created GtkTreeSelection* with selected range from "0" to "4"
 * Expected: 25  
 */
static void test_purpose_358()
{
    #define START_PATH "0"
    #define END_PATH "4"
    #define CORRECT_RES 25
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *start_path;
    GtkTreePath *end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint sel_rows_num;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    start_path = gtk_tree_path_new_from_string (START_PATH);
    end_path = gtk_tree_path_new_from_string (END_PATH);
    
    gtk_tree_selection_unselect_all (selection);
    gtk_tree_selection_select_range (selection, start_path, end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    sel_rows_num = gtk_tree_selection_count_selected_rows (selection);
    if (sel_rows_num != CORRECT_RES)
    {
        TEST_FAIL ("%d rows instead of %d are selected", sel_rows_num, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef START_PATH
    #undef END_PATH
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_count_selected_rows
 * Params: GtkTreeSelection *selection
 * Returns: gint
 * Assertion: Returns the number of rows that have been selected in tree.
 * Params Values: newly created GtkTreeSelection* with selected range from "0:0" to "4:4"
 * Expected: 29  
 */
static void test_purpose_359()
{
    #define START_PATH "0:0"
    #define END_PATH "4:4"
    #define CORRECT_RES 29
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *start_path;
    GtkTreePath *end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint sel_rows_num;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    start_path = gtk_tree_path_new_from_string (START_PATH);
    end_path = gtk_tree_path_new_from_string (END_PATH);
    
    gtk_tree_selection_unselect_all (selection);
    gtk_tree_selection_select_range (selection, start_path, end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    sel_rows_num = gtk_tree_selection_count_selected_rows (selection);
    if (sel_rows_num != CORRECT_RES)
    {
        TEST_FAIL ("%d rows instead of %d are selected", sel_rows_num, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef START_PATH
    #undef END_PATH
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_count_selected_rows
 * Params: GtkTreeSelection *selection
 * Returns: gint
 * Assertion: Returns the number of rows that have been selected in tree.
 * Params Values: newly created GtkTreeSelection* with selected range from "0:0" to "0:0"
 * Expected: 1  
 */
static void test_purpose_360()
{
    #define START_PATH "0:0"
    #define END_PATH "0:0"
    #define CORRECT_RES 1
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *start_path;
    GtkTreePath *end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint sel_rows_num;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    start_path = gtk_tree_path_new_from_string (START_PATH);
    end_path = gtk_tree_path_new_from_string (END_PATH);
    
    gtk_tree_selection_unselect_all (selection);
    gtk_tree_selection_select_range (selection, start_path, end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    sel_rows_num = gtk_tree_selection_count_selected_rows (selection);
    if (sel_rows_num != CORRECT_RES)
    {
        TEST_FAIL ("%d rows instead of %d are selected", sel_rows_num, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef START_PATH
    #undef END_PATH
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_count_selected_rows
 * Params: GtkTreeSelection *selection
 * Returns: gint
 * Assertion: Returns the number of rows that have been selected in tree.
 * Params Values: newly created GtkTreeSelection* with selected range from "4:4" to "4:4"
 * Expected: 1  
 */
static void test_purpose_361()
{
    #define START_PATH "4:4"
    #define END_PATH "4:4"
    #define CORRECT_RES 1
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *start_path;
    GtkTreePath *end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint sel_rows_num;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    start_path = gtk_tree_path_new_from_string (START_PATH);
    end_path = gtk_tree_path_new_from_string (END_PATH);
    
    gtk_tree_selection_unselect_all (selection);
    gtk_tree_selection_select_range (selection, start_path, end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    sel_rows_num = gtk_tree_selection_count_selected_rows (selection);
    if (sel_rows_num != CORRECT_RES)
    {
        TEST_FAIL ("%d rows instead of %d are selected", sel_rows_num, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef START_PATH
    #undef END_PATH
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_count_selected_rows
 * Params: GtkTreeSelection *selection
 * Returns: gint
 * Assertion: Returns the number of rows that have been selected in tree.
 * Params Values: newly created GtkTreeSelection* with selected range from "2:0" to "4:2"
 * Expected: 15  
 */
static void test_purpose_362()
{
    #define START_PATH "2:0"
    #define END_PATH "4:2"
    #define CORRECT_RES 15
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *start_path;
    GtkTreePath *end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint sel_rows_num;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    start_path = gtk_tree_path_new_from_string (START_PATH);
    end_path = gtk_tree_path_new_from_string (END_PATH);
    
    gtk_tree_selection_unselect_all (selection);
    gtk_tree_selection_select_range (selection, start_path, end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    sel_rows_num = gtk_tree_selection_count_selected_rows (selection);
    if (sel_rows_num != CORRECT_RES)
    {
        TEST_FAIL ("%d rows instead of %d are selected", sel_rows_num, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef START_PATH
    #undef END_PATH
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_selection_count_selected_rows
 * Params: GtkTreeSelection *selection
 * Returns: gint
 * Assertion: Returns the number of rows that have been selected in tree.
 * Params Values: newly created GtkTreeSelection* with selected range from "2:3" to "3:2"
 * Expected: 6  
 */
static void test_purpose_363()
{
    #define START_PATH "2:3"
    #define END_PATH "3:2"
    #define CORRECT_RES 6
    
    GtkWidget *tree_view;
    GtkTreeStore *model;
    GtkTreeSelection *selection;
    GtkTreePath *start_path;
    GtkTreePath *end_path;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint sel_rows_num;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_UINT);
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (model, &iter, NULL);
        gtk_tree_store_set (model, &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (model, &child_iter, &iter);
            gtk_tree_store_set (model, &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    {
        GtkCellRenderer* renderer = gtk_cell_renderer_text_new ();
        GtkTreeViewColumn* column0;
        GtkTreeViewColumn* column1;
    
        column0 = gtk_tree_view_column_new_with_attributes ("Number 1", renderer,
                                                            "text", 0,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
        
        column1 = gtk_tree_view_column_new_with_attributes ("Number 2", renderer,
                                                            "text", 1,
                                                            NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
        gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
    }
    
    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
    start_path = gtk_tree_path_new_from_string (START_PATH);
    end_path = gtk_tree_path_new_from_string (END_PATH);
    
    gtk_tree_selection_unselect_all (selection);
    gtk_tree_selection_select_range (selection, start_path, end_path);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    sel_rows_num = gtk_tree_selection_count_selected_rows (selection);
    if (sel_rows_num != CORRECT_RES)
    {
        TEST_FAIL ("%d rows instead of %d are selected", sel_rows_num, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef START_PATH
    #undef END_PATH
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkTreeSelection ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {test_purpose_52, 1},
    {test_purpose_53, 1},
    {test_purpose_54, 1},
    {test_purpose_55, 1},
    {test_purpose_56, 1},
    {test_purpose_57, 1},
    {test_purpose_58, 1},
    {test_purpose_59, 1},
    {test_purpose_60, 1},
    {test_purpose_61, 1},
    {test_purpose_62, 1},
    {test_purpose_63, 1},
    {test_purpose_64, 1},
    {test_purpose_65, 1},
    {test_purpose_66, 1},
    {test_purpose_67, 1},
    {test_purpose_68, 1},
    {test_purpose_69, 1},
    {test_purpose_70, 1},
    {test_purpose_71, 1},
    {test_purpose_72, 1},
    {test_purpose_73, 1},
    {test_purpose_74, 1},
    {test_purpose_75, 1},
    {test_purpose_76, 1},
    {test_purpose_77, 1},
    {test_purpose_78, 1},
    {test_purpose_79, 1},
    {test_purpose_80, 1},
    {test_purpose_81, 1},
    {test_purpose_82, 1},
    {test_purpose_83, 1},
    {test_purpose_84, 1},
    {test_purpose_85, 1},
    {test_purpose_86, 1},
    {test_purpose_87, 1},
    {test_purpose_88, 1},
    {test_purpose_89, 1},
    {test_purpose_90, 1},
    {test_purpose_91, 1},
    {test_purpose_92, 1},
    {test_purpose_93, 1},
    {test_purpose_94, 1},
    {test_purpose_95, 1},
    {test_purpose_96, 1},
    {test_purpose_97, 1},
    {test_purpose_98, 1},
    {test_purpose_99, 1},
    {test_purpose_100, 1},
    {test_purpose_101, 1},
    {test_purpose_102, 1},
    {test_purpose_103, 1},
    {test_purpose_104, 1},
    {test_purpose_105, 1},
    {test_purpose_106, 1},
    {test_purpose_107, 1},
    {test_purpose_108, 1},
    {test_purpose_109, 1},
    {test_purpose_110, 1},
    {test_purpose_111, 1},
    {test_purpose_112, 1},
    {test_purpose_113, 1},
    {test_purpose_114, 1},
    {test_purpose_115, 1},
    {test_purpose_116, 1},
    {test_purpose_117, 1},
    {test_purpose_118, 1},
    {test_purpose_119, 1},
    {test_purpose_120, 1},
    {test_purpose_121, 1},
    {test_purpose_122, 1},
    {test_purpose_123, 1},
    {test_purpose_124, 1},
    {test_purpose_125, 1},
    {test_purpose_126, 1},
    {test_purpose_127, 1},
    {test_purpose_128, 1},
    {test_purpose_129, 1},
    {test_purpose_130, 1},
    {test_purpose_131, 1},
    {test_purpose_132, 1},
    {test_purpose_133, 1},
    {test_purpose_134, 1},
    {test_purpose_135, 1},
    {test_purpose_136, 1},
    {test_purpose_137, 1},
    {test_purpose_138, 1},
    {test_purpose_139, 1},
    {test_purpose_140, 1},
    {test_purpose_141, 1},
    {test_purpose_142, 1},
    {test_purpose_143, 1},
    {test_purpose_144, 1},
    {test_purpose_145, 1},
    {test_purpose_146, 1},
    {test_purpose_147, 1},
    {test_purpose_148, 1},
    {test_purpose_149, 1},
    {test_purpose_150, 1},
    {test_purpose_151, 1},
    {test_purpose_152, 1},
    {test_purpose_153, 1},
    {test_purpose_154, 1},
    {test_purpose_155, 1},
    {test_purpose_156, 1},
    {test_purpose_157, 1},
    {test_purpose_158, 1},
    {test_purpose_159, 1},
    {test_purpose_160, 1},
    {test_purpose_161, 1},
    {test_purpose_162, 1},
    {test_purpose_163, 1},
    {test_purpose_164, 1},
    {test_purpose_165, 1},
    {test_purpose_166, 1},
    {test_purpose_167, 1},
    {test_purpose_168, 1},
    {test_purpose_169, 1},
    {test_purpose_170, 1},
    {test_purpose_171, 1},
    {test_purpose_172, 1},
    {test_purpose_173, 1},
    {test_purpose_174, 1},
    {test_purpose_175, 1},
    {test_purpose_176, 1},
    {test_purpose_177, 1},
    {test_purpose_178, 1},
    {test_purpose_179, 1},
    {test_purpose_180, 1},
    {test_purpose_181, 1},
    {test_purpose_182, 1},
    {test_purpose_183, 1},
    {test_purpose_184, 1},
    {test_purpose_185, 1},
    {test_purpose_186, 1},
    {test_purpose_187, 1},
    {test_purpose_188, 1},
    {test_purpose_189, 1},
    {test_purpose_190, 1},
    {test_purpose_191, 1},
    {test_purpose_192, 1},
    {test_purpose_193, 1},
    {test_purpose_194, 1},
    {test_purpose_195, 1},
    {test_purpose_196, 1},
    {test_purpose_197, 1},
    {test_purpose_198, 1},
    {test_purpose_199, 1},
    {test_purpose_200, 1},
    {test_purpose_201, 1},
    {test_purpose_202, 1},
    {test_purpose_203, 1},
    {test_purpose_204, 1},
    {test_purpose_205, 1},
    {test_purpose_206, 1},
    {test_purpose_207, 1},
    {test_purpose_208, 1},
    {test_purpose_209, 1},
    {test_purpose_210, 1},
    {test_purpose_211, 1},
    {test_purpose_212, 1},
    {test_purpose_213, 1},
    {test_purpose_214, 1},
    {test_purpose_215, 1},
    {test_purpose_216, 1},
    {test_purpose_217, 1},
    {test_purpose_218, 1},
    {test_purpose_219, 1},
    {test_purpose_220, 1},
    {test_purpose_221, 1},
    {test_purpose_222, 1},
    {test_purpose_223, 1},
    {test_purpose_224, 1},
    {test_purpose_225, 1},
    {test_purpose_226, 1},
    {test_purpose_227, 1},
    {test_purpose_228, 1},
    {test_purpose_229, 1},
    {test_purpose_230, 1},
    {test_purpose_231, 1},
    {test_purpose_232, 1},
    {test_purpose_233, 1},
    {test_purpose_234, 1},
    {test_purpose_235, 1},
    {test_purpose_236, 1},
    {test_purpose_237, 1},
    {test_purpose_238, 1},
    {test_purpose_239, 1},
    {test_purpose_240, 1},
    {test_purpose_241, 1},
    {test_purpose_242, 1},
    {test_purpose_243, 1},
    {test_purpose_244, 1},
    {test_purpose_245, 1},
    {test_purpose_246, 1},
    {test_purpose_247, 1},
    {test_purpose_248, 1},
    {test_purpose_249, 1},
    {test_purpose_250, 1},
    {test_purpose_251, 1},
    {test_purpose_252, 1},
    {test_purpose_253, 1},
    {test_purpose_254, 1},
    {test_purpose_255, 1},
    {test_purpose_256, 1},
    {test_purpose_257, 1},
    {test_purpose_258, 1},
    {test_purpose_259, 1},
    {test_purpose_260, 1},
    {test_purpose_261, 1},
    {test_purpose_262, 1},
    {test_purpose_263, 1},
    {test_purpose_264, 1},
    {test_purpose_265, 1},
    {test_purpose_266, 1},
    {test_purpose_267, 1},
    {test_purpose_268, 1},
    {test_purpose_269, 1},
    {test_purpose_270, 1},
    {test_purpose_271, 1},
    {test_purpose_272, 1},
    {test_purpose_273, 1},
    {test_purpose_274, 1},
    {test_purpose_275, 1},
    {test_purpose_276, 1},
    {test_purpose_277, 1},
    {test_purpose_278, 1},
    {test_purpose_279, 1},
    {test_purpose_280, 1},
    {test_purpose_281, 1},
    {test_purpose_282, 1},
    {test_purpose_283, 1},
    {test_purpose_284, 1},
    {test_purpose_285, 1},
    {test_purpose_286, 1},
    {test_purpose_287, 1},
    {test_purpose_288, 1},
    {test_purpose_289, 1},
    {test_purpose_290, 1},
    {test_purpose_291, 1},
    {test_purpose_292, 1},
    {test_purpose_293, 1},
    {test_purpose_294, 1},
    {test_purpose_295, 1},
    {test_purpose_296, 1},
    {test_purpose_297, 1},
    {test_purpose_298, 1},
    {test_purpose_299, 1},
    {test_purpose_300, 1},
    {test_purpose_301, 1},
    {test_purpose_302, 1},
    {test_purpose_303, 1},
    {test_purpose_304, 1},
    {test_purpose_305, 1},
    {test_purpose_306, 1},
    {test_purpose_307, 1},
    {test_purpose_308, 1},
    {test_purpose_309, 1},
    {test_purpose_310, 1},
    {test_purpose_311, 1},
    {test_purpose_312, 1},
    {test_purpose_313, 1},
    {test_purpose_314, 1},
    {test_purpose_315, 1},
    {test_purpose_316, 1},
    {test_purpose_317, 1},
    {test_purpose_318, 1},
    {test_purpose_319, 1},
    {test_purpose_320, 1},
    {test_purpose_321, 1},
    {test_purpose_322, 1},
    {test_purpose_323, 1},
    {test_purpose_324, 1},
    {test_purpose_325, 1},
    {test_purpose_326, 1},
    {test_purpose_327, 1},
    {test_purpose_328, 1},
    {test_purpose_329, 1},
    {test_purpose_330, 1},
    {test_purpose_331, 1},
    {test_purpose_332, 1},
    {test_purpose_333, 1},
    {test_purpose_334, 1},
    {test_purpose_335, 1},
    {test_purpose_336, 1},
    {test_purpose_337, 1},
    {test_purpose_338, 1},
    {test_purpose_339, 1},
    {test_purpose_340, 1},
    {test_purpose_341, 1},
    {test_purpose_342, 1},
    {test_purpose_343, 1},
    {test_purpose_344, 1},
    {test_purpose_345, 1},
    {test_purpose_346, 1},
    {test_purpose_347, 1},
    {test_purpose_348, 1},
    {test_purpose_349, 1},
    {test_purpose_350, 1},
    {test_purpose_351, 1},
    {test_purpose_352, 1},
    {test_purpose_353, 1},
    {test_purpose_354, 1},
    {test_purpose_355, 1},
    {test_purpose_356, 1},
    {test_purpose_357, 1},
    {test_purpose_358, 1},
    {test_purpose_359, 1},
    {test_purpose_360, 1},
    {test_purpose_361, 1},
    {test_purpose_362, 1},
    {test_purpose_363, 1},
    {NULL,0}
};
